# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: otg.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\totg.proto\x12\x03otg\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xaa\x02\n\x06\x43onfig\x12\x18\n\x05ports\x18\x01 \x03(\x0b\x32\t.otg.Port\x12\x16\n\x04lags\x18\x02 \x03(\x0b\x32\x08.otg.Lag\x12\x1b\n\x06layer1\x18\x03 \x03(\x0b\x32\x0b.otg.Layer1\x12\x1e\n\x08\x63\x61ptures\x18\x04 \x03(\x0b\x32\x0c.otg.Capture\x12\x1c\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32\x0b.otg.Device\x12\x18\n\x05\x66lows\x18\x06 \x03(\x0b\x32\t.otg.Flow\x12\x1f\n\x06\x65vents\x18\x07 \x01(\x0b\x32\n.otg.EventH\x00\x88\x01\x01\x12(\n\x07options\x18\x08 \x01(\x0b\x32\x12.otg.ConfigOptionsH\x01\x88\x01\x01\x12\x17\n\x04lldp\x18\t \x03(\x0b\x32\t.otg.LldpB\t\n\x07_eventsB\n\n\x08_options\"\x97\x01\n\rConfigOptions\x12+\n\x0cport_options\x18\x01 \x01(\x0b\x32\x10.otg.PortOptionsH\x00\x88\x01\x01\x12\x33\n\x10protocol_options\x18\x02 \x01(\x0b\x32\x14.otg.ProtocolOptionsH\x01\x88\x01\x01\x42\x0f\n\r_port_optionsB\x13\n\x11_protocol_options\"8\n\x04Port\x12\x15\n\x08location\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\tB\x0b\n\t_location\"G\n\x0bPortOptions\x12 \n\x13location_preemption\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x16\n\x14_location_preemption\"\x8c\x01\n\x03Lag\x12\x1b\n\x05ports\x18\x01 \x03(\x0b\x32\x0c.otg.LagPort\x12\'\n\x08protocol\x18\x02 \x01(\x0b\x32\x10.otg.LagProtocolH\x00\x88\x01\x01\x12\x16\n\tmin_links\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x0c\n\x04name\x18\x04 \x01(\tB\x0b\n\t_protocolB\x0c\n\n_min_links\"u\n\x07LagPort\x12\x11\n\tport_name\x18\x01 \x01(\t\x12#\n\x04lacp\x18\x02 \x01(\x0b\x32\x10.otg.LagPortLacpH\x00\x88\x01\x01\x12)\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x17.otg.DeviceEthernetBaseB\x07\n\x05_lacp\"\xee\x01\n\x0bLagProtocol\x12\x31\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1c.otg.LagProtocol.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x04lacp\x18\x02 \x01(\x0b\x32\x14.otg.LagProtocolLacpH\x01\x88\x01\x01\x12+\n\x06static\x18\x03 \x01(\x0b\x32\x16.otg.LagProtocolStaticH\x02\x88\x01\x01\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04lacp\x10\x01\x12\n\n\x06static\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_lacpB\t\n\x07_static\"3\n\x11LagProtocolStatic\x12\x13\n\x06lag_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\t\n\x07_lag_id\"\xa7\x01\n\x0fLagProtocolLacp\x12\x1c\n\x0f\x61\x63tor_system_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x61\x63tor_system_priority\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\tactor_key\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x12\n\x10_actor_system_idB\x18\n\x16_actor_system_priorityB\x0c\n\n_actor_key\"\x93\x03\n\x0bLagPortLacp\x12\x1e\n\x11\x61\x63tor_port_number\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12 \n\x13\x61\x63tor_port_priority\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12@\n\x0e\x61\x63tor_activity\x18\x03 \x01(\x0e\x32#.otg.LagPortLacp.ActorActivity.EnumH\x02\x88\x01\x01\x12*\n\x1dlacpdu_periodic_time_interval\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1b\n\x0elacpdu_timeout\x18\x05 \x01(\x05H\x04\x88\x01\x01\x1a\x41\n\rActorActivity\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07passive\x10\x01\x12\n\n\x06\x61\x63tive\x10\x02\x42\x14\n\x12_actor_port_numberB\x16\n\x14_actor_port_priorityB\x11\n\x0f_actor_activityB \n\x1e_lacpdu_periodic_time_intervalB\x11\n\x0f_lacpdu_timeout\"i\n\x12\x44\x65viceEthernetBase\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x10\n\x03mtu\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1e\n\x05vlans\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x0c\n\x04name\x18\x04 \x01(\tB\x06\n\x04_mtu\"\x9e\x02\n\x0e\x44\x65viceEthernet\x12\x16\n\tport_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x30\n\nconnection\x18\x02 \x01(\x0b\x32\x17.otg.EthernetConnectionH\x01\x88\x01\x01\x12\'\n\x0eipv4_addresses\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceIpv4\x12\'\n\x0eipv6_addresses\x18\x04 \x03(\x0b\x32\x0f.otg.DeviceIpv6\x12\x0b\n\x03mac\x18\x05 \x01(\t\x12\x10\n\x03mtu\x18\x06 \x01(\x05H\x02\x88\x01\x01\x12\x1e\n\x05vlans\x18\x07 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x0c\n\x04name\x18\x08 \x01(\tB\x0c\n\n_port_nameB\r\n\x0b_connectionB\x06\n\x04_mtu\"\x9b\x02\n\x12\x45thernetConnection\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.EthernetConnection.Choice.EnumH\x00\x88\x01\x01\x12\x16\n\tport_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08lag_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nvxlan_name\x18\x04 \x01(\tH\x03\x88\x01\x01\x1aN\n\x06\x43hoice\"D\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tport_name\x10\x01\x12\x0c\n\x08lag_name\x10\x02\x12\x0e\n\nvxlan_name\x10\x03\x42\t\n\x07_choiceB\x0c\n\n_port_nameB\x0b\n\t_lag_nameB\r\n\x0b_vxlan_name\"\xe5\x01\n\nDeviceVlan\x12,\n\x04tpid\x18\x01 \x01(\x0e\x32\x19.otg.DeviceVlan.Tpid.EnumH\x00\x88\x01\x01\x12\x15\n\x08priority\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0f\n\x02id\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x04 \x01(\t\x1aV\n\x04Tpid\"N\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05x8100\x10\x01\x12\t\n\x05x88a8\x10\x02\x12\t\n\x05x9100\x10\x03\x12\t\n\x05x9200\x10\x04\x12\t\n\x05x9300\x10\x05\x42\x07\n\x05_tpidB\x0b\n\t_priorityB\x05\n\x03_id\"\xa1\x01\n\nDeviceIpv4\x12\x0f\n\x07gateway\x18\x01 \x01(\t\x12\x33\n\x0bgateway_mac\x18\x02 \x01(\x0b\x32\x19.otg.DeviceIpv4GatewayMACH\x00\x88\x01\x01\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x13\n\x06prefix\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x0c\n\x04name\x18\x05 \x01(\tB\x0e\n\x0c_gateway_macB\t\n\x07_prefix\"V\n\x12\x44\x65viceIpv4Loopback\x12\x10\n\x08\x65th_name\x18\x01 \x01(\t\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x03 \x01(\tB\n\n\x08_address\"\xcf\x01\n\x14\x44\x65viceIpv4GatewayMAC\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.DeviceIpv4GatewayMAC.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xa1\x01\n\nDeviceIpv6\x12\x0f\n\x07gateway\x18\x01 \x01(\t\x12\x33\n\x0bgateway_mac\x18\x02 \x01(\x0b\x32\x19.otg.DeviceIpv6GatewayMACH\x00\x88\x01\x01\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x13\n\x06prefix\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x0c\n\x04name\x18\x05 \x01(\tB\x0e\n\x0c_gateway_macB\t\n\x07_prefix\"V\n\x12\x44\x65viceIpv6Loopback\x12\x10\n\x08\x65th_name\x18\x01 \x01(\t\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x03 \x01(\tB\n\n\x08_address\"\xcf\x01\n\x14\x44\x65viceIpv6GatewayMAC\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.DeviceIpv6GatewayMAC.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xb4\x06\n\x06Layer1\x12\x12\n\nport_names\x18\x01 \x03(\t\x12*\n\x05speed\x18\x02 \x01(\x0e\x32\x16.otg.Layer1.Speed.EnumH\x00\x88\x01\x01\x12*\n\x05media\x18\x03 \x01(\x0e\x32\x16.otg.Layer1.Media.EnumH\x01\x88\x01\x01\x12\x18\n\x0bpromiscuous\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03mtu\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12 \n\x13ieee_media_defaults\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x1b\n\x0e\x61uto_negotiate\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x39\n\x10\x61uto_negotiation\x18\x08 \x01(\x0b\x32\x1a.otg.Layer1AutoNegotiationH\x06\x88\x01\x01\x12\x31\n\x0c\x66low_control\x18\t \x01(\x0b\x32\x16.otg.Layer1FlowControlH\x07\x88\x01\x01\x12\x0c\n\x04name\x18\n \x01(\t\x1a\x95\x02\n\x05Speed\"\x8b\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10speed_10_fd_mbps\x10\x01\x12\x14\n\x10speed_10_hd_mbps\x10\x02\x12\x15\n\x11speed_100_fd_mbps\x10\x03\x12\x15\n\x11speed_100_hd_mbps\x10\x04\x12\x10\n\x0cspeed_1_gbps\x10\x05\x12\x11\n\rspeed_10_gbps\x10\x06\x12\x11\n\rspeed_25_gbps\x10\x07\x12\x11\n\rspeed_40_gbps\x10\x08\x12\x11\n\rspeed_50_gbps\x10\t\x12\x12\n\x0espeed_100_gbps\x10\n\x12\x12\n\x0espeed_200_gbps\x10\x0b\x12\x12\n\x0espeed_400_gbps\x10\x0c\x1a\x42\n\x05Media\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63opper\x10\x01\x12\t\n\x05\x66iber\x10\x02\x12\t\n\x05sgmii\x10\x03\x42\x08\n\x06_speedB\x08\n\x06_mediaB\x0e\n\x0c_promiscuousB\x06\n\x04_mtuB\x16\n\x14_ieee_media_defaultsB\x11\n\x0f_auto_negotiateB\x13\n\x11_auto_negotiationB\x0f\n\r_flow_control\"\x93\x03\n\x15Layer1AutoNegotiation\x12 \n\x13\x61\x64vertise_1000_mbps\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_fd_mbps\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_hd_mbps\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_fd_mbps\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_hd_mbps\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rlink_training\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06rs_fec\x18\x07 \x01(\x08H\x06\x88\x01\x01\x42\x16\n\x14_advertise_1000_mbpsB\x18\n\x16_advertise_100_fd_mbpsB\x18\n\x16_advertise_100_hd_mbpsB\x17\n\x15_advertise_10_fd_mbpsB\x17\n\x15_advertise_10_hd_mbpsB\x10\n\x0e_link_trainingB\t\n\x07_rs_fec\"\xd8\x02\n\x11Layer1FlowControl\x12\x1d\n\x10\x64irected_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x37\n\x06\x63hoice\x18\x02 \x01(\x0e\x32\".otg.Layer1FlowControl.Choice.EnumH\x01\x88\x01\x01\x12\x32\n\rieee_802_1qbb\x18\x03 \x01(\x0b\x32\x16.otg.Layer1Ieee8021qbbH\x02\x88\x01\x01\x12.\n\x0bieee_802_3x\x18\x04 \x01(\x0b\x32\x14.otg.Layer1Ieee8023xH\x03\x88\x01\x01\x1a\x45\n\x06\x43hoice\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rieee_802_1qbb\x10\x01\x12\x0f\n\x0bieee_802_3x\x10\x02\x42\x13\n\x11_directed_addressB\t\n\x07_choiceB\x10\n\x0e_ieee_802_1qbbB\x0e\n\x0c_ieee_802_3x\"\x11\n\x0fLayer1Ieee8023x\"\x89\x03\n\x11Layer1Ieee8021qbb\x12\x16\n\tpfc_delay\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpfc_class_0\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x18\n\x0bpfc_class_1\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x18\n\x0bpfc_class_2\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x18\n\x0bpfc_class_3\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x18\n\x0bpfc_class_4\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x18\n\x0bpfc_class_5\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x18\n\x0bpfc_class_6\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x18\n\x0bpfc_class_7\x18\t \x01(\x05H\x08\x88\x01\x01\x42\x0c\n\n_pfc_delayB\x0e\n\x0c_pfc_class_0B\x0e\n\x0c_pfc_class_1B\x0e\n\x0c_pfc_class_2B\x0e\n\x0c_pfc_class_3B\x0e\n\x0c_pfc_class_4B\x0e\n\x0c_pfc_class_5B\x0e\n\x0c_pfc_class_6B\x0e\n\x0c_pfc_class_7\"\x93\x02\n\x07\x43\x61pture\x12\x12\n\nport_names\x18\x01 \x03(\t\x12#\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x12.otg.CaptureFilter\x12\x16\n\toverwrite\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bpacket_size\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12-\n\x06\x66ormat\x18\x05 \x01(\x0e\x32\x18.otg.Capture.Format.EnumH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a\x37\n\x06\x46ormat\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04pcap\x10\x01\x12\n\n\x06pcapng\x10\x02\x42\x0c\n\n_overwriteB\x0e\n\x0c_packet_sizeB\t\n\x07_format\"\xa2\x03\n\rCaptureFilter\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.CaptureFilter.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x12.otg.CaptureCustomH\x01\x88\x01\x01\x12+\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x14.otg.CaptureEthernetH\x02\x88\x01\x01\x12#\n\x04vlan\x18\x04 \x01(\x0b\x32\x10.otg.CaptureVlanH\x03\x88\x01\x01\x12#\n\x04ipv4\x18\x05 \x01(\x0b\x32\x10.otg.CaptureIpv4H\x04\x88\x01\x01\x12#\n\x04ipv6\x18\x06 \x01(\x0b\x32\x10.otg.CaptureIpv6H\x05\x88\x01\x01\x1aY\n\x06\x43hoice\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\x08\n\x04ipv4\x10\x04\x12\x08\n\x04ipv6\x10\x05\x42\t\n\x07_choiceB\t\n\x07_customB\x0b\n\t_ethernetB\x07\n\x05_vlanB\x07\n\x05_ipv4B\x07\n\x05_ipv6\"\xb1\x01\n\rCaptureCustom\x12\x13\n\x06offset\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x17\n\nbit_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04mask\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06negate\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\t\n\x07_offsetB\r\n\x0b_bit_lengthB\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"h\n\x0c\x43\x61ptureField\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04mask\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06negate\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"\xdf\x01\n\x0f\x43\x61ptureEthernet\x12#\n\x03src\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12#\n\x03\x64st\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12*\n\nether_type\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12)\n\tpfc_queue\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x42\x06\n\x04_srcB\x06\n\x04_dstB\r\n\x0b_ether_typeB\x0c\n\n_pfc_queue\"\xd3\x01\n\x0b\x43\x61ptureVlan\x12(\n\x08priority\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12#\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12\"\n\x02id\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12(\n\x08protocol\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x42\x0b\n\t_priorityB\x06\n\x04_cfiB\x05\n\x03_idB\x0b\n\t_protocol\"\xd1\x06\n\x0b\x43\x61ptureIpv4\x12\'\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12-\n\rheader_length\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12(\n\x08priority\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12,\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x12.\n\x0eidentification\x18\x05 \x01(\x0b\x32\x11.otg.CaptureFieldH\x04\x88\x01\x01\x12(\n\x08reserved\x18\x06 \x01(\x0b\x32\x11.otg.CaptureFieldH\x05\x88\x01\x01\x12-\n\rdont_fragment\x18\x07 \x01(\x0b\x32\x11.otg.CaptureFieldH\x06\x88\x01\x01\x12.\n\x0emore_fragments\x18\x08 \x01(\x0b\x32\x11.otg.CaptureFieldH\x07\x88\x01\x01\x12/\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\x11.otg.CaptureFieldH\x08\x88\x01\x01\x12,\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x11.otg.CaptureFieldH\t\x88\x01\x01\x12(\n\x08protocol\x18\x0b \x01(\x0b\x32\x11.otg.CaptureFieldH\n\x88\x01\x01\x12/\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\x11.otg.CaptureFieldH\x0b\x88\x01\x01\x12#\n\x03src\x18\r \x01(\x0b\x32\x11.otg.CaptureFieldH\x0c\x88\x01\x01\x12#\n\x03\x64st\x18\x0e \x01(\x0b\x32\x11.otg.CaptureFieldH\r\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_header_lengthB\x0b\n\t_priorityB\x0f\n\r_total_lengthB\x11\n\x0f_identificationB\x0b\n\t_reservedB\x10\n\x0e_dont_fragmentB\x11\n\x0f_more_fragmentsB\x12\n\x10_fragment_offsetB\x0f\n\r_time_to_liveB\x0b\n\t_protocolB\x12\n\x10_header_checksumB\x06\n\x04_srcB\x06\n\x04_dst\"\xd1\x03\n\x0b\x43\x61ptureIpv6\x12\'\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12-\n\rtraffic_class\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12*\n\nflow_label\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12.\n\x0epayload_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x12+\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x11.otg.CaptureFieldH\x04\x88\x01\x01\x12)\n\thop_limit\x18\x06 \x01(\x0b\x32\x11.otg.CaptureFieldH\x05\x88\x01\x01\x12#\n\x03src\x18\x07 \x01(\x0b\x32\x11.otg.CaptureFieldH\x06\x88\x01\x01\x12#\n\x03\x64st\x18\x08 \x01(\x0b\x32\x11.otg.CaptureFieldH\x07\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_traffic_classB\r\n\x0b_flow_labelB\x11\n\x0f_payload_lengthB\x0e\n\x0c_next_headerB\x0c\n\n_hop_limitB\x06\n\x04_srcB\x06\n\x04_dst\"\xe0\x02\n\x06\x44\x65vice\x12&\n\tethernets\x18\x01 \x03(\x0b\x32\x13.otg.DeviceEthernet\x12/\n\x0eipv4_loopbacks\x18\x02 \x03(\x0b\x32\x17.otg.DeviceIpv4Loopback\x12/\n\x0eipv6_loopbacks\x18\x03 \x03(\x0b\x32\x17.otg.DeviceIpv6Loopback\x12(\n\x04isis\x18\x04 \x01(\x0b\x32\x15.otg.DeviceIsisRouterH\x00\x88\x01\x01\x12&\n\x03\x62gp\x18\x05 \x01(\x0b\x32\x14.otg.DeviceBgpRouterH\x01\x88\x01\x01\x12$\n\x05vxlan\x18\x06 \x01(\x0b\x32\x10.otg.DeviceVxlanH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\"\n\x04rsvp\x18\x08 \x01(\x0b\x32\x0f.otg.DeviceRsvpH\x03\x88\x01\x01\x42\x07\n\x05_isisB\x06\n\x04_bgpB\x08\n\x06_vxlanB\x07\n\x05_rsvp\"A\n\x0fProtocolOptions\x12\x1b\n\x0e\x61uto_start_all\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x11\n\x0f_auto_start_all\"\x99\x03\n\x10\x44\x65viceIsisRouter\x12\x33\n\x08instance\x18\x01 \x01(\x0b\x32\x1c.otg.DeviceIsisMultiInstanceH\x00\x88\x01\x01\x12\x11\n\tsystem_id\x18\x02 \x01(\t\x12&\n\ninterfaces\x18\x03 \x03(\x0b\x32\x12.otg.IsisInterface\x12\"\n\x05\x62\x61sic\x18\x04 \x01(\x0b\x32\x0e.otg.IsisBasicH\x01\x88\x01\x01\x12(\n\x08\x61\x64vanced\x18\x05 \x01(\x0b\x32\x11.otg.IsisAdvancedH\x02\x88\x01\x01\x12\x31\n\x0brouter_auth\x18\x06 \x01(\x0b\x32\x17.otg.IsisAuthenticationH\x03\x88\x01\x01\x12(\n\tv4_routes\x18\x07 \x03(\x0b\x32\x15.otg.IsisV4RouteRange\x12(\n\tv6_routes\x18\x08 \x03(\x0b\x32\x15.otg.IsisV6RouteRange\x12\x0c\n\x04name\x18\t \x01(\tB\x0b\n\t_instanceB\x08\n\x06_basicB\x0b\n\t_advancedB\x0e\n\x0c_router_auth\"B\n\x17\x44\x65viceIsisMultiInstance\x12\x10\n\x03iid\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\r\n\x05itids\x18\x02 \x03(\x05\x42\x06\n\x04_iid\"\xde\x06\n\rIsisInterface\x12\x10\n\x08\x65th_name\x18\x01 \x01(\t\x12\x13\n\x06metric\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12>\n\x0cnetwork_type\x18\x03 \x01(\x0e\x32#.otg.IsisInterface.NetworkType.EnumH\x01\x88\x01\x01\x12:\n\nlevel_type\x18\x04 \x01(\x0e\x32!.otg.IsisInterface.LevelType.EnumH\x02\x88\x01\x01\x12\x31\n\x0bl1_settings\x18\x05 \x01(\x0b\x32\x17.otg.IsisInterfaceLevelH\x03\x88\x01\x01\x12\x31\n\x0bl2_settings\x18\x06 \x01(\x0b\x32\x17.otg.IsisInterfaceLevelH\x04\x88\x01\x01\x12\'\n\x12multi_topology_ids\x18\x07 \x03(\x0b\x32\x0b.otg.IsisMT\x12-\n\x13traffic_engineering\x18\x08 \x03(\x0b\x32\x10.otg.LinkStateTE\x12=\n\x0e\x61uthentication\x18\t \x01(\x0b\x32 .otg.IsisInterfaceAuthenticationH\x05\x88\x01\x01\x12\x31\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x1a.otg.IsisInterfaceAdvancedH\x06\x88\x01\x01\x12>\n\x0flink_protection\x18\x0b \x01(\x0b\x32 .otg.IsisInterfaceLinkProtectionH\x07\x88\x01\x01\x12\x13\n\x0bsrlg_values\x18\x0c \x03(\x05\x12\x0c\n\x04name\x18\r \x01(\t\x1aI\n\x0bNetworkType\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tbroadcast\x10\x01\x12\x12\n\x0epoint_to_point\x10\x02\x1aM\n\tLevelType\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x12\r\n\tlevel_1_2\x10\x03\x42\t\n\x07_metricB\x0f\n\r_network_typeB\r\n\x0b_level_typeB\x0e\n\x0c_l1_settingsB\x0e\n\x0c_l2_settingsB\x11\n\x0f_authenticationB\x0b\n\t_advancedB\x12\n\x10_link_protection\"\x96\x01\n\x12IsisInterfaceLevel\x12\x15\n\x08priority\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1b\n\x0ehello_interval\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1a\n\rdead_interval\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x0b\n\t_priorityB\x11\n\x0f_hello_intervalB\x10\n\x0e_dead_interval\"P\n\x06IsisMT\x12\x12\n\x05mt_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0blink_metric\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x08\n\x06_mt_idB\x0e\n\x0c_link_metric\"\xc1\x02\n\x0bLinkStateTE\x12!\n\x14\x61\x64ministrative_group\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cmetric_level\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x19\n\x0cmax_bandwith\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12%\n\x18max_reservable_bandwidth\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x42\n\x13priority_bandwidths\x18\x05 \x01(\x0b\x32 .otg.LinkStatepriorityBandwidthsH\x04\x88\x01\x01\x42\x17\n\x15_administrative_groupB\x0f\n\r_metric_levelB\x0f\n\r_max_bandwithB\x1b\n\x19_max_reservable_bandwidthB\x16\n\x14_priority_bandwidths\"\xed\x01\n\x1bLinkStatepriorityBandwidths\x12\x10\n\x03pb0\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x10\n\x03pb1\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x10\n\x03pb2\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x10\n\x03pb3\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x10\n\x03pb4\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x10\n\x03pb5\x18\x06 \x01(\x03H\x05\x88\x01\x01\x12\x10\n\x03pb6\x18\x07 \x01(\x03H\x06\x88\x01\x01\x12\x10\n\x03pb7\x18\x08 \x01(\x03H\x07\x88\x01\x01\x42\x06\n\x04_pb0B\x06\n\x04_pb1B\x06\n\x04_pb2B\x06\n\x04_pb3B\x06\n\x04_pb4B\x06\n\x04_pb5B\x06\n\x04_pb6B\x06\n\x04_pb7\"\xda\x01\n\x1bIsisInterfaceAuthentication\x12\x41\n\tauth_type\x18\x01 \x01(\x0e\x32..otg.IsisInterfaceAuthentication.AuthType.Enum\x12\x10\n\x03md5\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x01\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x06\n\x04_md5B\x0b\n\t_password\"\xd3\x02\n\x15IsisInterfaceAdvanced\x12\x1c\n\x0f\x61uto_adjust_mtu\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1d\n\x10\x61uto_adjust_area\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12,\n\x1f\x61uto_adjust_supported_protocols\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\"\n\x15\x65nable_3way_handshake\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12&\n\x19p2p_hellos_to_unicast_mac\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\x12\n\x10_auto_adjust_mtuB\x13\n\x11_auto_adjust_areaB\"\n _auto_adjust_supported_protocolsB\x18\n\x16_enable_3way_handshakeB\x1c\n\x1a_p2p_hellos_to_unicast_mac\"\xf9\x02\n\x1bIsisInterfaceLinkProtection\x12\x1a\n\rextra_traffic\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bunprotected\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06shared\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x10\x64\x65\x64icated_1_to_1\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1f\n\x12\x64\x65\x64icated_1_plus_1\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08\x65nhanced\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0breserved_40\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x18\n\x0breserved_80\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x10\n\x0e_extra_trafficB\x0e\n\x0c_unprotectedB\t\n\x07_sharedB\x13\n\x11_dedicated_1_to_1B\x15\n\x13_dedicated_1_plus_1B\x0b\n\t_enhancedB\x0e\n\x0c_reserved_40B\x0e\n\x0c_reserved_80\"\xd5\x01\n\tIsisBasic\x12\x1e\n\x11ipv4_te_router_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08hostname\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12\x65nable_wide_metric\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1f\n\x12learned_lsp_filter\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x14\n\x12_ipv4_te_router_idB\x0b\n\t_hostnameB\x15\n\x13_enable_wide_metricB\x15\n\x13_learned_lsp_filter\"\x8a\x04\n\x0cIsisAdvanced\x12!\n\x14\x65nable_hello_padding\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1f\n\x12max_area_addresses\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\x0e\x61rea_addresses\x18\x03 \x03(\t\x12\x1d\n\x10lsp_refresh_rate\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0clsp_lifetime\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12\x1a\n\rpsnp_interval\x18\x06 \x01(\x05H\x04\x88\x01\x01\x12\x1a\n\rcsnp_interval\x18\x07 \x01(\x05H\x05\x88\x01\x01\x12\x19\n\x0cmax_lsp_size\x18\x08 \x01(\x05H\x06\x88\x01\x01\x12*\n\x1dlsp_mgroup_min_trans_interval\x18\t \x01(\x05H\x07\x88\x01\x01\x12 \n\x13\x65nable_attached_bit\x18\n \x01(\x08H\x08\x88\x01\x01\x42\x17\n\x15_enable_hello_paddingB\x15\n\x13_max_area_addressesB\x13\n\x11_lsp_refresh_rateB\x0f\n\r_lsp_lifetimeB\x10\n\x0e_psnp_intervalB\x10\n\x0e_csnp_intervalB\x0f\n\r_max_lsp_sizeB \n\x1e_lsp_mgroup_min_trans_intervalB\x16\n\x14_enable_attached_bit\"\xd6\x01\n\x12IsisAuthentication\x12\x1f\n\x12ignore_receive_md5\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x33\n\tarea_auth\x18\x02 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBaseH\x01\x88\x01\x01\x12\x35\n\x0b\x64omain_auth\x18\x03 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBaseH\x02\x88\x01\x01\x42\x15\n\x13_ignore_receive_md5B\x0c\n\n_area_authB\x0e\n\x0c_domain_auth\"\xd0\x01\n\x16IsisAuthenticationBase\x12<\n\tauth_type\x18\x01 \x01(\x0e\x32).otg.IsisAuthenticationBase.AuthType.Enum\x12\x10\n\x03md5\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x01\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x06\n\x04_md5B\x0b\n\t_password\"\xca\x04\n\x10IsisV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV4RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV4RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x06\x88\x01\x01\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"{\n\x0eV4RouteAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x06prefix\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\x05H\x02\x88\x01\x01\x42\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"{\n\x0eV6RouteAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x06prefix\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\x05H\x02\x88\x01\x01\x42\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"|\n\x0fMACRouteAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x06prefix\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\x05H\x02\x88\x01\x01\x42\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"\xca\x04\n\x10IsisV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV6RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV6RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x06\x88\x01\x01\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"\x80\x01\n\x0f\x44\x65viceBgpRouter\x12\x11\n\trouter_id\x18\x01 \x01(\t\x12,\n\x0fipv4_interfaces\x18\x02 \x03(\x0b\x32\x13.otg.BgpV4Interface\x12,\n\x0fipv6_interfaces\x18\x03 \x03(\x0b\x32\x13.otg.BgpV6Interface\"\x90\x02\n\x1b\x44\x65viceBgpMessageHeaderError\x12\x43\n\x07subcode\x18\x01 \x01(\x0e\x32-.otg.DeviceBgpMessageHeaderError.Subcode.EnumH\x00\x88\x01\x01\x1a\x9f\x01\n\x07Subcode\"\x93\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12.\n*connection_not_synchronized_code1_subcode1\x10\x01\x12%\n!bad_message_length_code1_subcode2\x10\x02\x12#\n\x1f\x62\x61\x64_message_type_code1_subcode3\x10\x03\x42\n\n\x08_subcode\"\xaa\x03\n\x19\x44\x65viceBgpOpenMessageError\x12\x41\n\x07subcode\x18\x01 \x01(\x0e\x32+.otg.DeviceBgpOpenMessageError.Subcode.EnumH\x00\x88\x01\x01\x1a\xbd\x02\n\x07Subcode\"\xb1\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12-\n)unsupported_version_number_code2_subcode1\x10\x01\x12 \n\x1c\x65rror_peer_as_code2_subcode2\x10\x02\x12\x1f\n\x1b\x65rror_bgp_id_code2_subcode3\x10\x03\x12\x31\n-unsupported_optional_parameter_code2_subcode4\x10\x04\x12\x1e\n\x1a\x61uth_failed_code2_subcode5\x10\x05\x12(\n$unsupported_hold_time_code2_subcode6\x10\x06\x12)\n%unsupported_capability_code2_subcode7\x10\x07\x42\n\n\x08_subcode\"\xdc\x04\n\x1b\x44\x65viceBgpUpdateMessageError\x12\x43\n\x07subcode\x18\x01 \x01(\x0e\x32-.otg.DeviceBgpUpdateMessageError.Subcode.EnumH\x00\x88\x01\x01\x1a\xeb\x03\n\x07Subcode\"\xdf\x03\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12(\n$malformed_attrib_list_code3_subcode1\x10\x01\x12\x30\n,unrecognized_wellknown_attrib_code3_subcode2\x10\x02\x12+\n\'wellknown_attrib_missing_code3_subcode3\x10\x03\x12%\n!attrib_flags_error_code3_subcode4\x10\x04\x12&\n\"attrib_length_error_code3_subcode5\x10\x05\x12(\n$invalid_origin_attrib_code3_subcode6\x10\x06\x12\"\n\x1e\x61s_routing_loop_code3_subcode7\x10\x07\x12&\n\"invalid_nhop_attrib_code3_subcode8\x10\x08\x12(\n$error_optional_attrib_code3_subcode9\x10\t\x12)\n%invalid_network_field_code3_subcode10\x10\n\x12#\n\x1f\x61\x62normal_aspath_code3_subcode11\x10\x0b\x42\n\n\x08_subcode\"\x1b\n\x19\x44\x65viceBgpHoldTimerExpired\"\"\n DeviceBgpFiniteStateMachineError\"\xe3\x03\n\x13\x44\x65viceBgpCeaseError\x12;\n\x07subcode\x18\x01 \x01(\x0e\x32%.otg.DeviceBgpCeaseError.Subcode.EnumH\x00\x88\x01\x01\x1a\x82\x03\n\x07Subcode\"\xf6\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12,\n(max_number_prefix_reached_code6_subcode1\x10\x01\x12!\n\x1d\x61\x64min_shutdown_code6_subcode2\x10\x02\x12\x1f\n\x1bpeer_deleted_code6_subcode3\x10\x03\x12\x1e\n\x1a\x61\x64min_reset_code6_subcode4\x10\x04\x12$\n connection_reject_code6_subcode5\x10\x05\x12\'\n#other_config_changes_code6_subcode6\x10\x06\x12\x32\n.connection_collision_resolution_code6_subcode7\x10\x07\x12#\n\x1fout_of_resources_code6_subcode8\x10\x08\x12#\n\x1f\x62\x66\x64_session_down_code6_subcode9\x10\tB\n\n\x08_subcode\"T\n\x14\x44\x65viceBgpCustomError\x12\x11\n\x04\x63ode\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07subcode\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_subcode\"\xce\x06\n\tBgpV4Peer\x12\x14\n\x0cpeer_address\x18\x01 \x01(\t\x12\x39\n\x16\x65vpn_ethernet_segments\x18\x02 \x03(\x0b\x32\x19.otg.BgpV4EthernetSegment\x12+\n\x07\x61s_type\x18\x03 \x01(\x0e\x32\x1a.otg.BgpV4Peer.AsType.Enum\x12\x11\n\tas_number\x18\x04 \x01(\x05\x12?\n\x0f\x61s_number_width\x18\x05 \x01(\x0e\x32!.otg.BgpV4Peer.AsNumberWidth.EnumH\x00\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x10.otg.BgpAdvancedH\x01\x88\x01\x01\x12+\n\ncapability\x18\x07 \x01(\x0b\x32\x12.otg.BgpCapabilityH\x02\x88\x01\x01\x12I\n\x1alearned_information_filter\x18\x08 \x01(\x0b\x32 .otg.BgpLearnedInformationFilterH\x03\x88\x01\x01\x12\'\n\tv4_routes\x18\t \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\n \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\x0b \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\x0c \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x0c\n\x04name\x18\r \x01(\t\x12\x36\n\x10graceful_restart\x18\x0e \x01(\x0b\x32\x17.otg.BgpGracefulRestartH\x04\x88\x01\x01\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x12\n\x10_as_number_widthB\x0b\n\t_advancedB\r\n\x0b_capabilityB\x1d\n\x1b_learned_information_filterB\x13\n\x11_graceful_restart\"B\n\x0e\x42gpV4Interface\x12\x11\n\tipv4_name\x18\x01 \x01(\t\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV4Peer\"\xa8\x04\n\x14\x42gpV4EthernetSegment\x12;\n\x0b\x64\x66_election\x18\x01 \x01(\x0b\x32!.otg.BgpEthernetSegmentDfElectionH\x00\x88\x01\x01\x12 \n\x04\x65vis\x18\x02 \x03(\x0b\x32\x12.otg.BgpV4EvpnEvis\x12\x10\n\x03\x65si\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x43\n\x0b\x61\x63tive_mode\x18\x04 \x01(\x0e\x32).otg.BgpV4EthernetSegment.ActiveMode.EnumH\x02\x88\x01\x01\x12\x16\n\tesi_label\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x08 \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12$\n\x07\x61s_path\x18\t \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x1aH\n\nActiveMode\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsingle_active\x10\x01\x12\x0e\n\nall_active\x10\x02\x42\x0e\n\x0c_df_electionB\x06\n\x04_esiB\x0e\n\x0c_active_modeB\x0c\n\n_esi_labelB\x0b\n\t_advancedB\n\n\x08_as_path\"N\n\x1c\x42gpEthernetSegmentDfElection\x12\x1b\n\x0e\x65lection_timer\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x11\n\x0f_election_timer\"\xda\x03\n\x10\x42gpRouteAdvanced\x12-\n include_multi_exit_discriminator\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12%\n\x18multi_exit_discriminator\x18\x01 \x01(\x05H\x01\x88\x01\x01\x12\x1b\n\x0einclude_origin\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x36\n\x06origin\x18\x02 \x01(\x0e\x32!.otg.BgpRouteAdvanced.Origin.EnumH\x03\x88\x01\x01\x12%\n\x18include_local_preference\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1d\n\x10local_preference\x18\x06 \x01(\x05H\x05\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42#\n!_include_multi_exit_discriminatorB\x1b\n\x19_multi_exit_discriminatorB\x11\n\x0f_include_originB\t\n\x07_originB\x1b\n\x19_include_local_preferenceB\x13\n\x11_local_preference\"\xa4\x02\n\x0c\x42gpCommunity\x12.\n\x04type\x18\x01 \x01(\x0e\x32\x1b.otg.BgpCommunity.Type.EnumH\x00\x88\x01\x01\x12\x16\n\tas_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\tas_custom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a\x8e\x01\n\x04Type\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10manual_as_number\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\x07\n\x05_typeB\x0c\n\n_as_numberB\x0c\n\n_as_custom\"\xf9\x03\n\x0f\x42gpExtCommunity\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32\x1e.otg.BgpExtCommunity.Type.EnumH\x00\x88\x01\x01\x12\x37\n\x07subtype\x18\x02 \x01(\x0e\x32!.otg.BgpExtCommunity.Subtype.EnumH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\xbc\x01\n\x04Type\"\xb3\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x61\x64ministrator_as_2octet\x10\x01\x12\x1e\n\x1a\x61\x64ministrator_ipv4_address\x10\x02\x12\x1b\n\x17\x61\x64ministrator_as_4octet\x10\x03\x12\n\n\x06opaque\x10\x04\x12\x08\n\x04\x65vpn\x10\x05\x12*\n&administrator_as_2octet_link_bandwidth\x10\x06\x1a\x87\x01\n\x07Subtype\"|\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0croute_target\x10\x01\x12\n\n\x06origin\x10\x02\x12\x16\n\x12\x65xtended_bandwidth\x10\x03\x12\t\n\x05\x63olor\x10\x04\x12\x11\n\rencapsulation\x10\x05\x12\x0f\n\x0bmac_address\x10\x06\x42\x07\n\x05_typeB\n\n\x08_subtypeB\x08\n\x06_value\"\xbe\x02\n\tBgpAsPath\x12\x37\n\x0b\x61s_set_mode\x18\x01 \x01(\x0e\x32\x1d.otg.BgpAsPath.AsSetMode.EnumH\x00\x88\x01\x01\x12\'\n\x08segments\x18\x02 \x03(\x0b\x32\x15.otg.BgpAsPathSegment\x1a\xbe\x01\n\tAsSetMode\"\xb0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x64o_not_include_local_as\x10\x01\x12\x12\n\x0einclude_as_seq\x10\x02\x12\x12\n\x0einclude_as_set\x10\x03\x12\x19\n\x15include_as_confed_seq\x10\x04\x12\x19\n\x15include_as_confed_set\x10\x05\x12\x1c\n\x18prepend_to_first_segment\x10\x06\x42\x0e\n\x0c_as_set_mode\"\xc2\x01\n\x10\x42gpAsPathSegment\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.BgpAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\x03\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"\xbb\x01\n\rBgpV4EvpnEvis\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.BgpV4EvpnEvis.Choice.EnumH\x00\x88\x01\x01\x12*\n\tevi_vxlan\x18\x02 \x01(\x0b\x32\x12.otg.BgpV4EviVxlanH\x01\x88\x01\x01\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tevi_vxlan\x10\x01\x42\t\n\x07_choiceB\x0c\n\n_evi_vxlan\"\xa3\x06\n\rBgpV4EviVxlan\x12<\n\x11\x62roadcast_domains\x18\x01 \x03(\x0b\x32!.otg.BgpV4EviVxlanBroadcastDomain\x12\x46\n\x10replication_type\x18\x02 \x01(\x0e\x32\'.otg.BgpV4EviVxlan.ReplicationType.EnumH\x00\x88\x01\x01\x12\x17\n\npmsi_label\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x15\n\x08\x61\x64_label\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12<\n\x13route_distinguisher\x18\x05 \x01(\x0b\x32\x1a.otg.BgpRouteDistinguisherH\x03\x88\x01\x01\x12\x30\n\x13route_target_export\x18\x06 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x30\n\x13route_target_import\x18\x07 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_export\x18\x08 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_import\x18\t \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12,\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12$\n\x07\x61s_path\x18\r \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x1a\x43\n\x0fReplicationType\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13ingress_replication\x10\x01\x42\x13\n\x11_replication_typeB\r\n\x0b_pmsi_labelB\x0b\n\t_ad_labelB\x16\n\x14_route_distinguisherB\x0b\n\t_advancedB\n\n\x08_as_path\"\xb4\x01\n\x1c\x42gpV4EviVxlanBroadcastDomain\x12*\n\rcmac_ip_range\x18\x01 \x03(\x0b\x32\x13.otg.BgpCMacIpRange\x12\x1c\n\x0f\x65thernet_tag_id\x18\x02 \x01(\x03H\x00\x88\x01\x01\x12\x1f\n\x12vlan_aware_service\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x12\n\x10_ethernet_tag_idB\x15\n\x13_vlan_aware_service\"\xae\x04\n\x0e\x42gpCMacIpRange\x12\x30\n\rmac_addresses\x18\x01 \x01(\x0b\x32\x14.otg.MACRouteAddressH\x00\x88\x01\x01\x12\x12\n\x05l2vni\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x30\n\x0eipv4_addresses\x18\x03 \x01(\x0b\x32\x13.otg.V4RouteAddressH\x02\x88\x01\x01\x12\x30\n\x0eipv6_addresses\x18\x04 \x01(\x0b\x32\x13.otg.V6RouteAddressH\x03\x88\x01\x01\x12\x12\n\x05l3vni\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12$\n\x17include_default_gateway\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x07 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x06\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x08 \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\t \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12$\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPathH\x07\x88\x01\x01\x12\x0c\n\x04name\x18\x0b \x01(\tB\x10\n\x0e_mac_addressesB\x08\n\x06_l2vniB\x11\n\x0f_ipv4_addressesB\x11\n\x0f_ipv6_addressesB\x08\n\x06_l3vniB\x1a\n\x18_include_default_gatewayB\x0b\n\t_advancedB\n\n\x08_as_path\"\x98\x02\n\x15\x42gpRouteDistinguisher\x12<\n\x07rd_type\x18\x01 \x01(\x0e\x32&.otg.BgpRouteDistinguisher.RdType.EnumH\x00\x88\x01\x01\x12#\n\x16\x61uto_config_rd_ip_addr\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x15\n\x08rd_value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1aQ\n\x06RdType\"G\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tas_2octet\x10\x01\x12\x10\n\x0cipv4_address\x10\x02\x12\r\n\tas_4octet\x10\x03\x42\n\n\x08_rd_typeB\x19\n\x17_auto_config_rd_ip_addrB\x0b\n\t_rd_value\"\xca\x01\n\x0e\x42gpRouteTarget\x12\x35\n\x07rt_type\x18\x01 \x01(\x0e\x32\x1f.otg.BgpRouteTarget.RtType.EnumH\x00\x88\x01\x01\x12\x15\n\x08rt_value\x18\x02 \x01(\tH\x01\x88\x01\x01\x1aQ\n\x06RtType\"G\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tas_2octet\x10\x01\x12\x10\n\x0cipv4_address\x10\x02\x12\r\n\tas_4octet\x10\x03\x42\n\n\x08_rt_typeB\x0b\n\t_rt_value\"\xff\x01\n\x0b\x42gpAdvanced\x12\x1f\n\x12hold_time_interval\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12 \n\x13keep_alive_interval\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1c\n\x0fupdate_interval\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x14\n\x07md5_key\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x15\n\x13_hold_time_intervalB\x16\n\x14_keep_alive_intervalB\x12\n\x10_update_intervalB\x0f\n\r_time_to_liveB\n\n\x08_md5_key\"\x91\n\n\rBgpCapability\x12\x19\n\x0cipv4_unicast\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0eipv4_multicast\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x19\n\x0cipv6_unicast\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1b\n\x0eipv6_multicast\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x11\n\x04vpls\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rroute_refresh\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1d\n\x10route_constraint\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x1f\n\x12link_state_non_vpn\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12\x1b\n\x0elink_state_vpn\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x11\n\x04\x65vpn\x18\n \x01(\x08H\t\x88\x01\x01\x12\'\n\x1a\x65xtended_next_hop_encoding\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x1f\n\x12ipv4_multicast_vpn\x18\x0c \x01(\x08H\x0b\x88\x01\x01\x12\x1a\n\ripv4_mpls_vpn\x18\r \x01(\x08H\x0c\x88\x01\x01\x12\x15\n\x08ipv4_mdt\x18\x0e \x01(\x08H\r\x88\x01\x01\x12$\n\x17ipv4_multicast_mpls_vpn\x18\x0f \x01(\x08H\x0e\x88\x01\x01\x12#\n\x16ipv4_unicast_flow_spec\x18\x10 \x01(\x08H\x0f\x88\x01\x01\x12\x1e\n\x11ipv4_sr_te_policy\x18\x11 \x01(\x08H\x10\x88\x01\x01\x12\"\n\x15ipv4_unicast_add_path\x18\x12 \x01(\x08H\x11\x88\x01\x01\x12\x1f\n\x12ipv6_multicast_vpn\x18\x13 \x01(\x08H\x12\x88\x01\x01\x12\x1a\n\ripv6_mpls_vpn\x18\x14 \x01(\x08H\x13\x88\x01\x01\x12\x15\n\x08ipv6_mdt\x18\x15 \x01(\x08H\x14\x88\x01\x01\x12$\n\x17ipv6_multicast_mpls_vpn\x18\x16 \x01(\x08H\x15\x88\x01\x01\x12#\n\x16ipv6_unicast_flow_spec\x18\x17 \x01(\x08H\x16\x88\x01\x01\x12\x1e\n\x11ipv6_sr_te_policy\x18\x18 \x01(\x08H\x17\x88\x01\x01\x12\"\n\x15ipv6_unicast_add_path\x18\x19 \x01(\x08H\x18\x88\x01\x01\x42\x0f\n\r_ipv4_unicastB\x11\n\x0f_ipv4_multicastB\x0f\n\r_ipv6_unicastB\x11\n\x0f_ipv6_multicastB\x07\n\x05_vplsB\x10\n\x0e_route_refreshB\x13\n\x11_route_constraintB\x15\n\x13_link_state_non_vpnB\x11\n\x0f_link_state_vpnB\x07\n\x05_evpnB\x1d\n\x1b_extended_next_hop_encodingB\x15\n\x13_ipv4_multicast_vpnB\x10\n\x0e_ipv4_mpls_vpnB\x0b\n\t_ipv4_mdtB\x1a\n\x18_ipv4_multicast_mpls_vpnB\x19\n\x17_ipv4_unicast_flow_specB\x14\n\x12_ipv4_sr_te_policyB\x18\n\x16_ipv4_unicast_add_pathB\x15\n\x13_ipv6_multicast_vpnB\x10\n\x0e_ipv6_mpls_vpnB\x0b\n\t_ipv6_mdtB\x1a\n\x18_ipv6_multicast_mpls_vpnB\x19\n\x17_ipv6_unicast_flow_specB\x14\n\x12_ipv6_sr_te_policyB\x18\n\x16_ipv6_unicast_add_path\"\x91\x01\n\x1b\x42gpLearnedInformationFilter\x12 \n\x13unicast_ipv4_prefix\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12 \n\x13unicast_ipv6_prefix\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x16\n\x14_unicast_ipv4_prefixB\x16\n\x14_unicast_ipv6_prefix\"\x82\x06\n\x0f\x42gpV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV4RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV4RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12$\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x06\x88\x01\x01\x12\x0c\n\x04name\x18\n \x01(\t\x12-\n\x0f\x65xt_communities\x18\x0b \x03(\x0b\x32\x14.otg.BgpExtCommunity\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\n\n\x08_as_pathB\x0b\n\t_add_path\".\n\nBgpAddPath\x12\x14\n\x07path_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\n\n\x08_path_id\"\x82\x06\n\x0f\x42gpV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV6RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV6RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12$\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x06\x88\x01\x01\x12\x0c\n\x04name\x18\n \x01(\t\x12-\n\x0f\x65xt_communities\x18\x0b \x03(\x0b\x32\x14.otg.BgpExtCommunity\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\n\n\x08_as_pathB\x0b\n\t_add_path\"\x8b\x07\n\x0f\x42gpSrteV4Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x15\n\ripv4_endpoint\x18\x03 \x01(\t\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV4Policy.NextHopMode.EnumH\x02\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV4Policy.NextHopAddressType.EnumH\x03\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x05\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x06\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x07\x88\x01\x01\x12$\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPathH\x08\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV4TunnelTlv\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\t\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\x0b\n\t_add_pathB\n\n\x08_as_pathB\t\n\x07_active\"\xff\x05\n\x12\x42gpSrteV4TunnelTlv\x12\x46\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlvH\x00\x88\x01\x01\x12\x33\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlvH\x01\x88\x01\x01\x12\x37\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlvH\x02\x88\x01\x01\x12=\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlvH\x03\x88\x01\x01\x12\x46\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlvH\x04\x88\x01\x01\x12>\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlvH\x05\x88\x01\x01\x12Z\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlvH\x06\x88\x01\x01\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x0c\n\x04name\x18\t \x01(\t\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x07\x88\x01\x01\x42\x1a\n\x18_remote_endpoint_sub_tlvB\x10\n\x0e_color_sub_tlvB\x12\n\x10_binding_sub_tlvB\x15\n\x13_preference_sub_tlvB\x1a\n\x18_policy_priority_sub_tlvB\x16\n\x14_policy_name_sub_tlvB%\n#_explicit_null_label_policy_sub_tlvB\t\n\x07_active\"\xbe\x02\n\x1b\x42gpSrteRemoteEndpointSubTlv\x12\x16\n\tas_number\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12P\n\x0e\x61\x64\x64ress_family\x18\x02 \x01(\x0e\x32\x33.otg.BgpSrteRemoteEndpointSubTlv.AddressFamily.EnumH\x01\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0cipv6_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x1a<\n\rAddressFamily\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x0c\n\n_as_numberB\x11\n\x0f_address_familyB\x0f\n\r_ipv4_addressB\x0f\n\r_ipv6_address\"2\n\x12\x42gpSrteColorSubTlv\x12\x12\n\x05\x63olor\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_color\"\xea\x02\n\x14\x42gpSrteBindingSubTlv\x12L\n\x10\x62inding_sid_type\x18\x01 \x01(\x0e\x32-.otg.BgpSrteBindingSubTlv.BindingSidType.EnumH\x00\x88\x01\x01\x12\x1b\n\x0e\x66our_octet_sid\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x15\n\x08ipv6_sid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06s_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06i_flag\x18\x05 \x01(\x08H\x04\x88\x01\x01\x1a[\n\x0e\x42indingSidType\"I\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nno_binding\x10\x01\x12\x12\n\x0e\x66our_octet_sid\x10\x02\x12\x0c\n\x08ipv6_sid\x10\x03\x42\x13\n\x11_binding_sid_typeB\x11\n\x0f_four_octet_sidB\x0b\n\t_ipv6_sidB\t\n\x07_s_flagB\t\n\x07_i_flag\"A\n\x17\x42gpSrtePreferenceSubTlv\x12\x17\n\npreference\x18\x01 \x01(\x03H\x00\x88\x01\x01\x42\r\n\x0b_preference\"O\n\x1b\x42gpSrtePolicyPrioritySubTlv\x12\x1c\n\x0fpolicy_priority\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x12\n\x10_policy_priority\"C\n\x17\x42gpSrtePolicyNameSubTlv\x12\x18\n\x0bpolicy_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0e\n\x0c_policy_name\"\xd6\x02\n$BgpSrteExplicitNullLabelPolicySubTlv\x12o\n\x1a\x65xplicit_null_label_policy\x18\x01 \x01(\x0e\x32\x46.otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy.EnumH\x00\x88\x01\x01\x1a\x9d\x01\n\x17\x45xplicitNullLabelPolicy\"\x81\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rreserved_enlp\x10\x01\x12\x12\n\x0epush_ipv4_enlp\x10\x02\x12\x12\n\x0epush_ipv6_enlp\x10\x03\x12\x17\n\x13push_ipv4_ipv6_enlp\x10\x04\x12\x14\n\x10\x64o_not_push_enlp\x10\x05\x42\x1d\n\x1b_explicit_null_label_policy\"\x89\x01\n\x12\x42gpSrteSegmentList\x12\x13\n\x06weight\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12%\n\x08segments\x18\x02 \x03(\x0b\x32\x13.otg.BgpSrteSegment\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x04 \x01(\x08H\x01\x88\x01\x01\x42\t\n\x07_weightB\t\n\x07_active\"\xe8\x07\n\x0e\x42gpSrteSegment\x12:\n\x0csegment_type\x18\x01 \x01(\x0e\x32$.otg.BgpSrteSegment.SegmentType.Enum\x12\x33\n\x06type_a\x18\x02 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentATypeSubTlvH\x00\x88\x01\x01\x12\x33\n\x06type_b\x18\x03 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentBTypeSubTlvH\x01\x88\x01\x01\x12\x33\n\x06type_c\x18\x04 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentCTypeSubTlvH\x02\x88\x01\x01\x12\x33\n\x06type_d\x18\x05 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentDTypeSubTlvH\x03\x88\x01\x01\x12\x33\n\x06type_e\x18\x06 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentETypeSubTlvH\x04\x88\x01\x01\x12\x33\n\x06type_f\x18\x07 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentFTypeSubTlvH\x05\x88\x01\x01\x12\x33\n\x06type_g\x18\x08 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentGTypeSubTlvH\x06\x88\x01\x01\x12\x33\n\x06type_h\x18\t \x01(\x0b\x32\x1e.otg.BgpSrteSegmentHTypeSubTlvH\x07\x88\x01\x01\x12\x33\n\x06type_i\x18\n \x01(\x0b\x32\x1e.otg.BgpSrteSegmentITypeSubTlvH\x08\x88\x01\x01\x12\x33\n\x06type_j\x18\x0b \x01(\x0b\x32\x1e.otg.BgpSrteSegmentJTypeSubTlvH\t\x88\x01\x01\x12\x33\n\x06type_k\x18\x0c \x01(\x0b\x32\x1e.otg.BgpSrteSegmentKTypeSubTlvH\n\x88\x01\x01\x12\x0c\n\x04name\x18\r \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x0e \x01(\x08H\x0b\x88\x01\x01\x1a\xab\x01\n\x0bSegmentType\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_a\x10\x01\x12\n\n\x06type_b\x10\x02\x12\n\n\x06type_c\x10\x03\x12\n\n\x06type_d\x10\x04\x12\n\n\x06type_e\x10\x05\x12\n\n\x06type_f\x10\x06\x12\n\n\x06type_g\x10\x07\x12\n\n\x06type_h\x10\x08\x12\n\n\x06type_i\x10\t\x12\n\n\x06type_j\x10\n\x12\n\n\x06type_k\x10\x0b\x42\t\n\x07_type_aB\t\n\x07_type_bB\t\n\x07_type_cB\t\n\x07_type_dB\t\n\x07_type_eB\t\n\x07_type_fB\t\n\x07_type_gB\t\n\x07_type_hB\t\n\x07_type_iB\t\n\x07_type_jB\t\n\x07_type_kB\t\n\x07_active\"\x80\x01\n\x10\x42gpSrteSrMplsSid\x12\x12\n\x05label\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x0f\n\x02tc\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05s_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03ttl\x18\x04 \x01(\x05H\x03\x88\x01\x01\x42\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xca\x01\n*BgpSrteSRv6SIDEndpointBehaviorAndStructure\x12\x16\n\tlb_length\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x16\n\tln_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x18\n\x0b\x66unc_length\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x17\n\narg_length\x18\x04 \x01(\x05H\x03\x88\x01\x01\x42\x0c\n\n_lb_lengthB\x0c\n\n_ln_lengthB\x0e\n\x0c_func_lengthB\r\n\x0b_arg_length\"\xa7\x01\n\x19\x42gpSrteSegmentATypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05label\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0f\n\x02tc\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x12\n\x05s_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x10\n\x03ttl\x18\x05 \x01(\x05H\x04\x88\x01\x01\x42\x08\n\x06_flagsB\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xc4\x01\n\x19\x42gpSrteSegmentBTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x08srv6_sid\x18\x02 \x01(\t\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x03 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\xc1\x01\n\x19\x42gpSrteSegmentCTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x11ipv4_node_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x0e\n\x0c_sr_mpls_sid\"\xc1\x01\n\x19\x42gpSrteSegmentDTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x11ipv6_node_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x0e\n\x0c_sr_mpls_sid\"\xcd\x01\n\x19\x42gpSrteSegmentETypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x11ipv4_node_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x0e\n\x0c_sr_mpls_sid\"\xb3\x01\n\x19\x42gpSrteSegmentFTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\x12local_ipv4_address\x18\x02 \x01(\t\x12\x1b\n\x13remote_ipv4_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x0e\n\x0c_sr_mpls_sid\"\xaf\x02\n\x19\x42gpSrteSegmentGTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1f\n\x17local_ipv6_node_address\x18\x03 \x01(\t\x12 \n\x13remote_interface_id\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12 \n\x18remote_ipv6_node_address\x18\x05 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x06 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x03\x88\x01\x01\x42\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x16\n\x14_remote_interface_idB\x0e\n\x0c_sr_mpls_sid\"\xb3\x01\n\x19\x42gpSrteSegmentHTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\x12local_ipv6_address\x18\x02 \x01(\t\x12\x1b\n\x13remote_ipv6_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x0e\n\x0c_sr_mpls_sid\"\xf1\x01\n\x19\x42gpSrteSegmentITypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x11ipv6_node_address\x18\x02 \x01(\t\x12\x15\n\x08srv6_sid\x18\x03 \x01(\tH\x01\x88\x01\x01\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x04 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x0b\n\t_srv6_sidB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\xb7\x03\n\x19\x42gpSrteSegmentJTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1f\n\x17local_ipv6_node_address\x18\x04 \x01(\t\x12 \n\x13remote_interface_id\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12 \n\x18remote_ipv6_node_address\x18\x06 \x01(\t\x12\x15\n\x08srv6_sid\x18\x07 \x01(\tH\x04\x88\x01\x01\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x08 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x05\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x15\n\x13_local_interface_idB\x16\n\x14_remote_interface_idB\x0b\n\t_srv6_sidB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\xbb\x02\n\x19\x42gpSrteSegmentKTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1a\n\x12local_ipv6_address\x18\x03 \x01(\t\x12\x1b\n\x13remote_ipv6_address\x18\x04 \x01(\t\x12\x15\n\x08srv6_sid\x18\x05 \x01(\tH\x02\x88\x01\x01\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x06 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x03\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x0b\n\t_srv6_sidB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\x8a\x07\n\x0f\x42gpSrteV6Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x15\n\ripv6_endpoint\x18\x03 \x01(\t\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV6Policy.NextHopMode.EnumH\x02\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV6Policy.NextHopAddressType.EnumH\x03\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x05\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x06\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x07\x88\x01\x01\x12$\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPathH\x08\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12,\n\x0e\x65xtcommunities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV6TunnelTlv\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\t\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\x0b\n\t_add_pathB\n\n\x08_as_pathB\t\n\x07_active\"\xff\x05\n\x12\x42gpSrteV6TunnelTlv\x12\x46\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlvH\x00\x88\x01\x01\x12\x33\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlvH\x01\x88\x01\x01\x12\x37\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlvH\x02\x88\x01\x01\x12=\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlvH\x03\x88\x01\x01\x12\x46\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlvH\x04\x88\x01\x01\x12>\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlvH\x05\x88\x01\x01\x12Z\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlvH\x06\x88\x01\x01\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x0c\n\x04name\x18\t \x01(\t\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x07\x88\x01\x01\x42\x1a\n\x18_remote_endpoint_sub_tlvB\x10\n\x0e_color_sub_tlvB\x12\n\x10_binding_sub_tlvB\x15\n\x13_preference_sub_tlvB\x1a\n\x18_policy_priority_sub_tlvB\x16\n\x14_policy_name_sub_tlvB%\n#_explicit_null_label_policy_sub_tlvB\t\n\x07_active\"\xb8\x01\n\x12\x42gpGracefulRestart\x12\x16\n\tenable_gr\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x19\n\x0crestart_time\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x18\n\x0b\x65nable_llgr\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x17\n\nstale_time\x18\x04 \x01(\rH\x03\x88\x01\x01\x42\x0c\n\n_enable_grB\x0f\n\r_restart_timeB\x0e\n\x0c_enable_llgrB\r\n\x0b_stale_time\"\x9a\x07\n\tBgpV6Peer\x12\x14\n\x0cpeer_address\x18\x01 \x01(\t\x12\x36\n\x0fsegment_routing\x18\x02 \x01(\x0b\x32\x18.otg.BgpV6SegmentRoutingH\x00\x88\x01\x01\x12\x39\n\x16\x65vpn_ethernet_segments\x18\x03 \x03(\x0b\x32\x19.otg.BgpV6EthernetSegment\x12+\n\x07\x61s_type\x18\x04 \x01(\x0e\x32\x1a.otg.BgpV6Peer.AsType.Enum\x12\x11\n\tas_number\x18\x05 \x01(\x05\x12?\n\x0f\x61s_number_width\x18\x06 \x01(\x0e\x32!.otg.BgpV6Peer.AsNumberWidth.EnumH\x01\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x07 \x01(\x0b\x32\x10.otg.BgpAdvancedH\x02\x88\x01\x01\x12+\n\ncapability\x18\x08 \x01(\x0b\x32\x12.otg.BgpCapabilityH\x03\x88\x01\x01\x12I\n\x1alearned_information_filter\x18\t \x01(\x0b\x32 .otg.BgpLearnedInformationFilterH\x04\x88\x01\x01\x12\'\n\tv4_routes\x18\n \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\x0b \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\x0c \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\r \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x36\n\x10graceful_restart\x18\x0f \x01(\x0b\x32\x17.otg.BgpGracefulRestartH\x05\x88\x01\x01\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x12\n\x10_segment_routingB\x12\n\x10_as_number_widthB\x0b\n\t_advancedB\r\n\x0b_capabilityB\x1d\n\x1b_learned_information_filterB\x13\n\x11_graceful_restart\"B\n\x0e\x42gpV6Interface\x12\x11\n\tipv6_name\x18\x01 \x01(\t\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV6Peer\"\xf1\x03\n\x13\x42gpV6SegmentRouting\x12!\n\x14ingress_supports_vpn\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15reduced_encapsulation\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1e\n\x11\x63opy_time_to_live\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1d\n\x10max_sids_per_srh\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12-\n auto_generate_segment_left_value\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1f\n\x12segment_left_value\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12#\n\x16\x61\x64vertise_sr_te_policy\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x17\n\x15_ingress_supports_vpnB\x18\n\x16_reduced_encapsulationB\x14\n\x12_copy_time_to_liveB\x0f\n\r_time_to_liveB\x13\n\x11_max_sids_per_srhB#\n!_auto_generate_segment_left_valueB\x15\n\x13_segment_left_valueB\x19\n\x17_advertise_sr_te_policy\"\xa8\x04\n\x14\x42gpV6EthernetSegment\x12;\n\x0b\x64\x66_election\x18\x01 \x01(\x0b\x32!.otg.BgpEthernetSegmentDfElectionH\x00\x88\x01\x01\x12 \n\x04\x65vis\x18\x02 \x03(\x0b\x32\x12.otg.BgpV6EvpnEvis\x12\x10\n\x03\x65si\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x43\n\x0b\x61\x63tive_mode\x18\x04 \x01(\x0e\x32).otg.BgpV6EthernetSegment.ActiveMode.EnumH\x02\x88\x01\x01\x12\x16\n\tesi_label\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x08 \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12$\n\x07\x61s_path\x18\t \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x1aH\n\nActiveMode\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsingle_active\x10\x01\x12\x0e\n\nall_active\x10\x02\x42\x0e\n\x0c_df_electionB\x06\n\x04_esiB\x0e\n\x0c_active_modeB\x0c\n\n_esi_labelB\x0b\n\t_advancedB\n\n\x08_as_path\"\xbb\x01\n\rBgpV6EvpnEvis\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.BgpV6EvpnEvis.Choice.EnumH\x00\x88\x01\x01\x12*\n\tevi_vxlan\x18\x02 \x01(\x0b\x32\x12.otg.BgpV6EviVxlanH\x01\x88\x01\x01\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tevi_vxlan\x10\x01\x42\t\n\x07_choiceB\x0c\n\n_evi_vxlan\"\xa3\x06\n\rBgpV6EviVxlan\x12<\n\x11\x62roadcast_domains\x18\x01 \x03(\x0b\x32!.otg.BgpV6EviVxlanBroadcastDomain\x12\x46\n\x10replication_type\x18\x02 \x01(\x0e\x32\'.otg.BgpV6EviVxlan.ReplicationType.EnumH\x00\x88\x01\x01\x12\x17\n\npmsi_label\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x15\n\x08\x61\x64_label\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12<\n\x13route_distinguisher\x18\x05 \x01(\x0b\x32\x1a.otg.BgpRouteDistinguisherH\x03\x88\x01\x01\x12\x30\n\x13route_target_export\x18\x06 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x30\n\x13route_target_import\x18\x07 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_export\x18\x08 \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12\x33\n\x16l3_route_target_import\x18\t \x03(\x0b\x32\x13.otg.BgpRouteTarget\x12,\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12$\n\x07\x61s_path\x18\r \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x1a\x43\n\x0fReplicationType\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13ingress_replication\x10\x01\x42\x13\n\x11_replication_typeB\r\n\x0b_pmsi_labelB\x0b\n\t_ad_labelB\x16\n\x14_route_distinguisherB\x0b\n\t_advancedB\n\n\x08_as_path\"\xb4\x01\n\x1c\x42gpV6EviVxlanBroadcastDomain\x12*\n\rcmac_ip_range\x18\x01 \x03(\x0b\x32\x13.otg.BgpCMacIpRange\x12\x1c\n\x0f\x65thernet_tag_id\x18\x02 \x01(\x03H\x00\x88\x01\x01\x12\x1f\n\x12vlan_aware_service\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x12\n\x10_ethernet_tag_idB\x15\n\x13_vlan_aware_service\"]\n\x0b\x44\x65viceVxlan\x12&\n\nv4_tunnels\x18\x01 \x03(\x0b\x32\x12.otg.VxlanV4Tunnel\x12&\n\nv6_tunnels\x18\x02 \x03(\x0b\x32\x12.otg.VxlanV6Tunnel\"\xa3\x01\n\rVxlanV4Tunnel\x12\x18\n\x10source_interface\x18\x01 \x01(\t\x12\x45\n\x13\x64\x65stination_ip_mode\x18\x02 \x01(\x0b\x32#.otg.VxlanV4TunnelDestinationIPModeH\x00\x88\x01\x01\x12\x0b\n\x03vni\x18\x03 \x01(\x05\x12\x0c\n\x04name\x18\x04 \x01(\tB\x16\n\x14_destination_ip_mode\"\xa3\x01\n\rVxlanV6Tunnel\x12\x18\n\x10source_interface\x18\x01 \x01(\t\x12\x45\n\x13\x64\x65stination_ip_mode\x18\x02 \x01(\x0b\x32#.otg.VxlanV6TunnelDestinationIPModeH\x00\x88\x01\x01\x12\x0b\n\x03vni\x18\x03 \x01(\x05\x12\x0c\n\x04name\x18\x04 \x01(\tB\x16\n\x14_destination_ip_mode\"\xd2\x02\n\x1eVxlanV4TunnelDestinationIPMode\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.VxlanV4TunnelDestinationIPMode.Choice.EnumH\x00\x88\x01\x01\x12@\n\x07unicast\x18\x02 \x01(\x0b\x32*.otg.VxlanV4TunnelDestinationIPModeUnicastH\x01\x88\x01\x01\x12\x44\n\tmulticast\x18\x03 \x01(\x0b\x32,.otg.VxlanV4TunnelDestinationIPModeMulticastH\x02\x88\x01\x01\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07unicast\x10\x01\x12\r\n\tmulticast\x10\x02\x42\t\n\x07_choiceB\n\n\x08_unicastB\x0c\n\n_multicast\"\xd2\x02\n\x1eVxlanV6TunnelDestinationIPMode\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.VxlanV6TunnelDestinationIPMode.Choice.EnumH\x00\x88\x01\x01\x12@\n\x07unicast\x18\x02 \x01(\x0b\x32*.otg.VxlanV6TunnelDestinationIPModeUnicastH\x01\x88\x01\x01\x12\x44\n\tmulticast\x18\x03 \x01(\x0b\x32,.otg.VxlanV6TunnelDestinationIPModeMulticastH\x02\x88\x01\x01\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07unicast\x10\x01\x12\r\n\tmulticast\x10\x02\x42\t\n\x07_choiceB\n\n\x08_unicastB\x0c\n\n_multicast\"f\n%VxlanV4TunnelDestinationIPModeUnicast\x12=\n\x05vteps\x18\x01 \x03(\x0b\x32..otg.VxlanV4TunnelDestinationIPModeUnicastVtep\"f\n%VxlanV6TunnelDestinationIPModeUnicast\x12=\n\x05vteps\x18\x01 \x03(\x0b\x32..otg.VxlanV6TunnelDestinationIPModeUnicastVtep\"\x96\x01\n6VxlanTunnelDestinationIPModeUnicastArpSuppressionCache\x12\x1a\n\rremote_vm_mac\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0eremote_vm_ipv4\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x10\n\x0e_remote_vm_macB\x11\n\x0f_remote_vm_ipv4\"\xc1\x01\n)VxlanV4TunnelDestinationIPModeUnicastVtep\x12 \n\x13remote_vtep_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12Z\n\x15\x61rp_suppression_cache\x18\x02 \x03(\x0b\x32;.otg.VxlanTunnelDestinationIPModeUnicastArpSuppressionCacheB\x16\n\x14_remote_vtep_address\"\xc1\x01\n)VxlanV6TunnelDestinationIPModeUnicastVtep\x12 \n\x13remote_vtep_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12Z\n\x15\x61rp_suppression_cache\x18\x02 \x03(\x0b\x32;.otg.VxlanTunnelDestinationIPModeUnicastArpSuppressionCacheB\x16\n\x14_remote_vtep_address\"K\n\'VxlanV4TunnelDestinationIPModeMulticast\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_address\"K\n\'VxlanV6TunnelDestinationIPModeMulticast\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_address\"\x91\x01\n\nDeviceRsvp\x12/\n\x0fipv4_interfaces\x18\x01 \x03(\x0b\x32\x16.otg.RsvpIpv4Interface\x12\x36\n\x13lsp_ipv4_interfaces\x18\x02 \x03(\x0b\x32\x19.otg.RsvpLspIpv4Interface\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\x9d\x04\n\x11RsvpIpv4Interface\x12\x11\n\tipv4_name\x18\x01 \x01(\t\x12\x13\n\x0bneighbor_ip\x18\x02 \x01(\t\x12\x1e\n\x11label_space_start\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x1c\n\x0flabel_space_end\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12%\n\x18\x65nable_refresh_reduction\x18\x05 \x01(\x08H\x02\x88\x01\x01\x12%\n\x18summary_refresh_interval\x18\x06 \x01(\x05H\x03\x88\x01\x01\x12\x18\n\x0bsend_bundle\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x1d\n\x10\x62undle_threshold\x18\x08 \x01(\x05H\x05\x88\x01\x01\x12\x19\n\x0c\x65nable_hello\x18\t \x01(\x08H\x06\x88\x01\x01\x12\x1b\n\x0ehello_interval\x18\n \x01(\x05H\x07\x88\x01\x01\x12\x1f\n\x12timeout_multiplier\x18\x0b \x01(\x05H\x08\x88\x01\x01\x42\x14\n\x12_label_space_startB\x12\n\x10_label_space_endB\x1b\n\x19_enable_refresh_reductionB\x1b\n\x19_summary_refresh_intervalB\x0e\n\x0c_send_bundleB\x13\n\x11_bundle_thresholdB\x0f\n\r_enable_helloB\x11\n\x0f_hello_intervalB\x15\n\x13_timeout_multiplier\"\xdb\x01\n\x14RsvpLspIpv4Interface\x12\x11\n\tipv4_name\x18\x01 \x01(\t\x12L\n\x14p2p_egress_ipv4_lsps\x18\x02 \x01(\x0b\x32).otg.RsvpLspIpv4InterfaceP2PEgressIpv4LspH\x00\x88\x01\x01\x12I\n\x15p2p_ingress_ipv4_lsps\x18\x03 \x03(\x0b\x32*.otg.RsvpLspIpv4InterfaceP2PIngressIpv4LspB\x17\n\x15_p2p_egress_ipv4_lsps\"\xe3\x03\n$RsvpLspIpv4InterfaceP2PEgressIpv4Lsp\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x10refresh_interval\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1f\n\x12timeout_multiplier\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12_\n\x11reservation_style\x18\x04 \x01(\x0e\x32?.otg.RsvpLspIpv4InterfaceP2PEgressIpv4Lsp.ReservationStyle.EnumH\x02\x88\x01\x01\x12\x1f\n\x12\x65nable_fixed_label\x18\x05 \x01(\x08H\x03\x88\x01\x01\x12\x1e\n\x11\x66ixed_label_value\x18\x06 \x01(\x05H\x04\x88\x01\x01\x1a\\\n\x10ReservationStyle\"H\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0fshared_explicit\x10\x01\x12\x10\n\x0c\x66ixed_filter\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x42\x13\n\x11_refresh_intervalB\x15\n\x13_timeout_multiplierB\x14\n\x12_reservation_styleB\x15\n\x13_enable_fixed_labelB\x14\n\x12_fixed_label_value\"\xd2\x04\n%RsvpLspIpv4InterfaceP2PIngressIpv4Lsp\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0eremote_address\x18\x02 \x01(\t\x12\x16\n\ttunnel_id\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06lsp_id\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x1d\n\x10refresh_interval\x18\x05 \x01(\x05H\x02\x88\x01\x01\x12\x1f\n\x12timeout_multiplier\x18\x06 \x01(\x05H\x03\x88\x01\x01\x12\x1a\n\rbackup_lsp_id\x18\x07 \x01(\x05H\x04\x88\x01\x01\x12!\n\x14lsp_switchover_delay\x18\x08 \x01(\x05H\x05\x88\x01\x01\x12\x39\n\x11session_attribute\x18\t \x01(\x0b\x32\x19.otg.RsvpSessionAttributeH\x06\x88\x01\x01\x12\"\n\x05tspec\x18\n \x01(\x0b\x32\x0e.otg.RsvpTspecH\x07\x88\x01\x01\x12/\n\x0c\x66\x61st_reroute\x18\x0b \x01(\x0b\x32\x14.otg.RsvpFastRerouteH\x08\x88\x01\x01\x12\x1e\n\x03\x65ro\x18\x0c \x01(\x0b\x32\x0c.otg.RsvpEroH\t\x88\x01\x01\x42\x0c\n\n_tunnel_idB\t\n\x07_lsp_idB\x13\n\x11_refresh_intervalB\x15\n\x13_timeout_multiplierB\x10\n\x0e_backup_lsp_idB\x17\n\x15_lsp_switchover_delayB\x14\n\x12_session_attributeB\x08\n\x06_tspecB\x0f\n\r_fast_rerouteB\x06\n\x04_ero\"\x8d\x05\n\x14RsvpSessionAttribute\x12\'\n\x1a\x61uto_generate_session_name\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x19\n\x0csession_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0esetup_priority\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12%\n\x18local_protection_desired\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12$\n\x17label_recording_desired\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1d\n\x10se_style_desired\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12)\n\x1c\x62\x61ndwidth_protection_desired\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12$\n\x17node_protection_desired\x18\t \x01(\x08H\x08\x88\x01\x01\x12=\n\x13resource_affinities\x18\n \x01(\x0b\x32\x1b.otg.RsvpResourceAffinitiesH\t\x88\x01\x01\x42\x1d\n\x1b_auto_generate_session_nameB\x0f\n\r_session_nameB\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x1b\n\x19_local_protection_desiredB\x1a\n\x18_label_recording_desiredB\x13\n\x11_se_style_desiredB\x1f\n\x1d_bandwidth_protection_desiredB\x1a\n\x18_node_protection_desiredB\x16\n\x14_resource_affinities\"\x96\x01\n\x16RsvpResourceAffinities\x12\x18\n\x0b\x65xclude_any\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0binclude_any\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0binclude_all\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0e\n\x0c_exclude_anyB\x0e\n\x0c_include_anyB\x0e\n\x0c_include_all\"\x9f\x02\n\tRsvpTspec\x12\x1e\n\x11token_bucket_rate\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x1e\n\x11token_bucket_size\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x1b\n\x0epeak_data_rate\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12!\n\x14minimum_policed_unit\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12!\n\x14maximum_policed_unit\x18\x05 \x01(\x05H\x04\x88\x01\x01\x42\x14\n\x12_token_bucket_rateB\x14\n\x12_token_bucket_sizeB\x11\n\x0f_peak_data_rateB\x17\n\x15_minimum_policed_unitB\x17\n\x15_maximum_policed_unit\"\xc7\x03\n\x0fRsvpFastReroute\x12\x1b\n\x0esetup_priority\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1d\n\x10holding_priority\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\thop_limit\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x16\n\tbandwidth\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12\x18\n\x0b\x65xclude_any\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0binclude_any\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x18\n\x0binclude_all\x18\x07 \x01(\tH\x06\x88\x01\x01\x12&\n\x19one_to_one_backup_desired\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12$\n\x17\x66\x61\x63ility_backup_desired\x18\t \x01(\x08H\x08\x88\x01\x01\x42\x11\n\x0f_setup_priorityB\x13\n\x11_holding_priorityB\x0c\n\n_hop_limitB\x0c\n\n_bandwidthB\x0e\n\x0c_exclude_anyB\x0e\n\x0c_include_anyB\x0e\n\x0c_include_allB\x1c\n\x1a_one_to_one_backup_desiredB\x1a\n\x18_facility_backup_desired\"\xa8\x02\n\x07RsvpEro\x12\x45\n\x13prepend_neighbor_ip\x18\x01 \x01(\x0e\x32#.otg.RsvpEro.PrependNeighborIp.EnumH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12)\n\nsubobjects\x18\x03 \x03(\x0b\x32\x15.otg.RsvpEroSubobject\x1a\x65\n\x11PrependNeighborIp\"P\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x64ont_prepend\x10\x01\x12\x11\n\rprepend_loose\x10\x02\x12\x12\n\x0eprepend_strict\x10\x03\x42\x16\n\x14_prepend_neighbor_ipB\x10\n\x0e_prefix_length\"\x8c\x03\n\x10RsvpEroSubobject\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.RsvpEroSubobject.Type.EnumH\x00\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x16\n\tas_number\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x39\n\x08hop_type\x18\x05 \x01(\x0e\x32\".otg.RsvpEroSubobject.HopType.EnumH\x04\x88\x01\x01\x1a\x38\n\x04Type\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\r\n\tas_number\x10\x02\x1a\x39\n\x07HopType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06strict\x10\x01\x12\t\n\x05loose\x10\x02\x42\x07\n\x05_typeB\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\x0c\n\n_as_numberB\x0b\n\t_hop_type\"\xbc\x02\n\x04\x46low\x12\x1c\n\x05tx_rx\x18\x01 \x01(\x0b\x32\r.otg.FlowTxRx\x12\x1f\n\x06packet\x18\x02 \x03(\x0b\x32\x0f.otg.FlowHeader\x12&\n\regress_packet\x18\t \x03(\x0b\x32\x0f.otg.FlowHeader\x12 \n\x04size\x18\x03 \x01(\x0b\x32\r.otg.FlowSizeH\x00\x88\x01\x01\x12 \n\x04rate\x18\x04 \x01(\x0b\x32\r.otg.FlowRateH\x01\x88\x01\x01\x12(\n\x08\x64uration\x18\x05 \x01(\x0b\x32\x11.otg.FlowDurationH\x02\x88\x01\x01\x12&\n\x07metrics\x18\x06 \x01(\x0b\x32\x10.otg.FlowMetricsH\x03\x88\x01\x01\x12\x0c\n\x04name\x18\x07 \x01(\tB\x07\n\x05_sizeB\x07\n\x05_rateB\x0b\n\t_durationB\n\n\x08_metrics\"\xda\x01\n\x08\x46lowTxRx\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowTxRx.Choice.EnumH\x00\x88\x01\x01\x12 \n\x04port\x18\x02 \x01(\x0b\x32\r.otg.FlowPortH\x01\x88\x01\x01\x12$\n\x06\x64\x65vice\x18\x03 \x01(\x0b\x32\x0f.otg.FlowRouterH\x02\x88\x01\x01\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\n\n\x06\x64\x65vice\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_portB\t\n\x07_device\"O\n\x08\x46lowPort\x12\x0f\n\x07tx_name\x18\x01 \x01(\t\x12\x14\n\x07rx_name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x08rx_names\x18\x03 \x03(\tB\n\n\x08_rx_name\"\xa2\x01\n\nFlowRouter\x12,\n\x04mode\x18\x01 \x01(\x0e\x32\x19.otg.FlowRouter.Mode.EnumH\x00\x88\x01\x01\x12\x10\n\x08tx_names\x18\x02 \x03(\t\x12\x10\n\x08rx_names\x18\x03 \x03(\t\x1a\x39\n\x04Mode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04mesh\x10\x01\x12\x0e\n\none_to_one\x10\x02\x42\x07\n\x05_mode\"\xb1\t\n\nFlowHeader\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowHeader.Choice.EnumH\x00\x88\x01\x01\x12$\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x0f.otg.FlowCustomH\x01\x88\x01\x01\x12(\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x11.otg.FlowEthernetH\x02\x88\x01\x01\x12 \n\x04vlan\x18\x04 \x01(\x0b\x32\r.otg.FlowVlanH\x03\x88\x01\x01\x12\"\n\x05vxlan\x18\x05 \x01(\x0b\x32\x0e.otg.FlowVxlanH\x04\x88\x01\x01\x12 \n\x04ipv4\x18\x06 \x01(\x0b\x32\r.otg.FlowIpv4H\x05\x88\x01\x01\x12 \n\x04ipv6\x18\x07 \x01(\x0b\x32\r.otg.FlowIpv6H\x06\x88\x01\x01\x12(\n\x08pfcpause\x18\x08 \x01(\x0b\x32\x11.otg.FlowPfcPauseH\x07\x88\x01\x01\x12\x32\n\rethernetpause\x18\t \x01(\x0b\x32\x16.otg.FlowEthernetPauseH\x08\x88\x01\x01\x12\x1e\n\x03tcp\x18\n \x01(\x0b\x32\x0c.otg.FlowTcpH\t\x88\x01\x01\x12\x1e\n\x03udp\x18\x0b \x01(\x0b\x32\x0c.otg.FlowUdpH\n\x88\x01\x01\x12\x1e\n\x03gre\x18\x0c \x01(\x0b\x32\x0c.otg.FlowGreH\x0b\x88\x01\x01\x12\"\n\x05gtpv1\x18\r \x01(\x0b\x32\x0e.otg.FlowGtpv1H\x0c\x88\x01\x01\x12\"\n\x05gtpv2\x18\x0e \x01(\x0b\x32\x0e.otg.FlowGtpv2H\r\x88\x01\x01\x12\x1e\n\x03\x61rp\x18\x0f \x01(\x0b\x32\x0c.otg.FlowArpH\x0e\x88\x01\x01\x12 \n\x04icmp\x18\x10 \x01(\x0b\x32\r.otg.FlowIcmpH\x0f\x88\x01\x01\x12$\n\x06icmpv6\x18\x11 \x01(\x0b\x32\x0f.otg.FlowIcmpv6H\x10\x88\x01\x01\x12\x1e\n\x03ppp\x18\x12 \x01(\x0b\x32\x0c.otg.FlowPppH\x11\x88\x01\x01\x12$\n\x06igmpv1\x18\x13 \x01(\x0b\x32\x0f.otg.FlowIgmpv1H\x12\x88\x01\x01\x12 \n\x04mpls\x18\x14 \x01(\x0b\x32\r.otg.FlowMplsH\x13\x88\x01\x01\x1a\xf5\x01\n\x06\x43hoice\"\xea\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\t\n\x05vxlan\x10\x04\x12\x08\n\x04ipv4\x10\x05\x12\x08\n\x04ipv6\x10\x06\x12\x0c\n\x08pfcpause\x10\x07\x12\x11\n\rethernetpause\x10\x08\x12\x07\n\x03tcp\x10\t\x12\x07\n\x03udp\x10\n\x12\x07\n\x03gre\x10\x0b\x12\t\n\x05gtpv1\x10\x0c\x12\t\n\x05gtpv2\x10\r\x12\x07\n\x03\x61rp\x10\x0e\x12\x08\n\x04icmp\x10\x0f\x12\n\n\x06icmpv6\x10\x10\x12\x07\n\x03ppp\x10\x11\x12\n\n\x06igmpv1\x10\x12\x12\x08\n\x04mpls\x10\x13\x42\t\n\x07_choiceB\t\n\x07_customB\x0b\n\t_ethernetB\x07\n\x05_vlanB\x08\n\x06_vxlanB\x07\n\x05_ipv4B\x07\n\x05_ipv6B\x0b\n\t_pfcpauseB\x10\n\x0e_ethernetpauseB\x06\n\x04_tcpB\x06\n\x04_udpB\x06\n\x04_greB\x08\n\x06_gtpv1B\x08\n\x06_gtpv2B\x06\n\x04_arpB\x07\n\x05_icmpB\t\n\x07_icmpv6B\x06\n\x04_pppB\t\n\x07_igmpv1B\x07\n\x05_mpls\"J\n\nFlowCustom\x12\r\n\x05\x62ytes\x18\x01 \x01(\t\x12-\n\x0bmetric_tags\x18\x02 \x03(\x0b\x32\x18.otg.FlowCustomMetricTag\"c\n\x13\x46lowCustomMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\x8f\x02\n\x0c\x46lowEthernet\x12-\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetDstH\x00\x88\x01\x01\x12-\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetSrcH\x01\x88\x01\x01\x12:\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowEthernetEtherTypeH\x02\x88\x01\x01\x12\x38\n\tpfc_queue\x18\x04 \x01(\x0b\x32 .otg.PatternFlowEthernetPfcQueueH\x03\x88\x01\x01\x42\x06\n\x04_dstB\x06\n\x04_srcB\r\n\x0b_ether_typeB\x0c\n\n_pfc_queue\"\xe5\x01\n\x08\x46lowVlan\x12\x33\n\x08priority\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowVlanPriorityH\x00\x88\x01\x01\x12)\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x17.otg.PatternFlowVlanCfiH\x01\x88\x01\x01\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x16.otg.PatternFlowVlanIdH\x02\x88\x01\x01\x12+\n\x04tpid\x18\x04 \x01(\x0b\x32\x18.otg.PatternFlowVlanTpidH\x03\x88\x01\x01\x42\x0b\n\t_priorityB\x06\n\x04_cfiB\x05\n\x03_idB\x07\n\x05_tpid\"\x85\x02\n\tFlowVxlan\x12.\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowVxlanFlagsH\x00\x88\x01\x01\x12\x36\n\treserved0\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved0H\x01\x88\x01\x01\x12*\n\x03vni\x18\x03 \x01(\x0b\x32\x18.otg.PatternFlowVxlanVniH\x02\x88\x01\x01\x12\x36\n\treserved1\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved1H\x03\x88\x01\x01\x42\x08\n\x06_flagsB\x0c\n\n_reserved0B\x06\n\x04_vniB\x0c\n\n_reserved1\"\xfa\x07\n\x08\x46lowIpv4\x12\x31\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4VersionH\x00\x88\x01\x01\x12<\n\rheader_length\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv4HeaderLengthH\x01\x88\x01\x01\x12,\n\x08priority\x18\x03 \x01(\x0b\x32\x15.otg.FlowIpv4PriorityH\x02\x88\x01\x01\x12:\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TotalLengthH\x03\x88\x01\x01\x12?\n\x0eidentification\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4IdentificationH\x04\x88\x01\x01\x12\x33\n\x08reserved\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4ReservedH\x05\x88\x01\x01\x12<\n\rdont_fragment\x18\x07 \x01(\x0b\x32 .otg.PatternFlowIpv4DontFragmentH\x06\x88\x01\x01\x12>\n\x0emore_fragments\x18\x08 \x01(\x0b\x32!.otg.PatternFlowIpv4MoreFragmentsH\x07\x88\x01\x01\x12@\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\".otg.PatternFlowIpv4FragmentOffsetH\x08\x88\x01\x01\x12\x39\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x1e.otg.PatternFlowIpv4TimeToLiveH\t\x88\x01\x01\x12\x33\n\x08protocol\x18\x0b \x01(\x0b\x32\x1c.otg.PatternFlowIpv4ProtocolH\n\x88\x01\x01\x12@\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\".otg.PatternFlowIpv4HeaderChecksumH\x0b\x88\x01\x01\x12)\n\x03src\x18\r \x01(\x0b\x32\x17.otg.PatternFlowIpv4SrcH\x0c\x88\x01\x01\x12)\n\x03\x64st\x18\x0e \x01(\x0b\x32\x17.otg.PatternFlowIpv4DstH\r\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_header_lengthB\x0b\n\t_priorityB\x0f\n\r_total_lengthB\x11\n\x0f_identificationB\x0b\n\t_reservedB\x10\n\x0e_dont_fragmentB\x11\n\x0f_more_fragmentsB\x12\n\x10_fragment_offsetB\x0f\n\r_time_to_liveB\x0b\n\t_protocolB\x12\n\x10_header_checksumB\x06\n\x04_srcB\x06\n\x04_dst\"\xaa\x02\n\x10\x46lowIpv4Priority\x12\x36\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.otg.FlowIpv4Priority.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x03raw\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4PriorityRawH\x01\x88\x01\x01\x12\"\n\x03tos\x18\x03 \x01(\x0b\x32\x10.otg.FlowIpv4TosH\x02\x88\x01\x01\x12$\n\x04\x64scp\x18\x04 \x01(\x0b\x32\x11.otg.FlowIpv4DscpH\x03\x88\x01\x01\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03raw\x10\x01\x12\x07\n\x03tos\x10\x02\x12\x08\n\x04\x64scp\x10\x03\x42\t\n\x07_choiceB\x06\n\x04_rawB\x06\n\x04_tosB\x07\n\x05_dscp\"|\n\x0c\x46lowIpv4Dscp\x12-\n\x03phb\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpPhbH\x00\x88\x01\x01\x12-\n\x03\x65\x63n\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpEcnH\x01\x88\x01\x01\x42\x06\n\x04_phbB\x06\n\x04_ecn\"\xb1\x03\n\x0b\x46lowIpv4Tos\x12:\n\nprecedence\x18\x01 \x01(\x0b\x32!.otg.PatternFlowIpv4TosPrecedenceH\x00\x88\x01\x01\x12\x30\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4TosDelayH\x01\x88\x01\x01\x12:\n\nthroughput\x18\x03 \x01(\x0b\x32!.otg.PatternFlowIpv4TosThroughputH\x02\x88\x01\x01\x12<\n\x0breliability\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIpv4TosReliabilityH\x03\x88\x01\x01\x12\x36\n\x08monetary\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TosMonetaryH\x04\x88\x01\x01\x12\x32\n\x06unused\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowIpv4TosUnusedH\x05\x88\x01\x01\x42\r\n\x0b_precedenceB\x08\n\x06_delayB\r\n\x0b_throughputB\x0e\n\x0c_reliabilityB\x0b\n\t_monetaryB\t\n\x07_unused\"\xa7\x04\n\x08\x46lowIpv6\x12\x31\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv6VersionH\x00\x88\x01\x01\x12<\n\rtraffic_class\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv6TrafficClassH\x01\x88\x01\x01\x12\x36\n\nflow_label\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowIpv6FlowLabelH\x02\x88\x01\x01\x12>\n\x0epayload_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowIpv6PayloadLengthH\x03\x88\x01\x01\x12\x38\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6NextHeaderH\x04\x88\x01\x01\x12\x34\n\thop_limit\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv6HopLimitH\x05\x88\x01\x01\x12)\n\x03src\x18\x07 \x01(\x0b\x32\x17.otg.PatternFlowIpv6SrcH\x06\x88\x01\x01\x12)\n\x03\x64st\x18\x08 \x01(\x0b\x32\x17.otg.PatternFlowIpv6DstH\x07\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_traffic_classB\r\n\x0b_flow_labelB\x11\n\x0f_payload_lengthB\x0e\n\x0c_next_headerB\x0c\n\n_hop_limitB\x06\n\x04_srcB\x06\n\x04_dst\"\x9d\x08\n\x0c\x46lowPfcPause\x12-\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseDstH\x00\x88\x01\x01\x12-\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseSrcH\x01\x88\x01\x01\x12:\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowPfcPauseEtherTypeH\x02\x88\x01\x01\x12\x43\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32%.otg.PatternFlowPfcPauseControlOpCodeH\x03\x88\x01\x01\x12K\n\x13\x63lass_enable_vector\x18\x05 \x01(\x0b\x32).otg.PatternFlowPfcPauseClassEnableVectorH\x04\x88\x01\x01\x12?\n\rpause_class_0\x18\x06 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass0H\x05\x88\x01\x01\x12?\n\rpause_class_1\x18\x07 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass1H\x06\x88\x01\x01\x12?\n\rpause_class_2\x18\x08 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass2H\x07\x88\x01\x01\x12?\n\rpause_class_3\x18\t \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass3H\x08\x88\x01\x01\x12?\n\rpause_class_4\x18\n \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass4H\t\x88\x01\x01\x12?\n\rpause_class_5\x18\x0b \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass5H\n\x88\x01\x01\x12?\n\rpause_class_6\x18\x0c \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass6H\x0b\x88\x01\x01\x12?\n\rpause_class_7\x18\r \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass7H\x0c\x88\x01\x01\x42\x06\n\x04_dstB\x06\n\x04_srcB\r\n\x0b_ether_typeB\x12\n\x10_control_op_codeB\x16\n\x14_class_enable_vectorB\x10\n\x0e_pause_class_0B\x10\n\x0e_pause_class_1B\x10\n\x0e_pause_class_2B\x10\n\x0e_pause_class_3B\x10\n\x0e_pause_class_4B\x10\n\x0e_pause_class_5B\x10\n\x0e_pause_class_6B\x10\n\x0e_pause_class_7\"\xf8\x02\n\x11\x46lowEthernetPause\x12\x32\n\x03\x64st\x18\x01 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseDstH\x00\x88\x01\x01\x12\x32\n\x03src\x18\x02 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseSrcH\x01\x88\x01\x01\x12?\n\nether_type\x18\x03 \x01(\x0b\x32&.otg.PatternFlowEthernetPauseEtherTypeH\x02\x88\x01\x01\x12H\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32*.otg.PatternFlowEthernetPauseControlOpCodeH\x03\x88\x01\x01\x12\x34\n\x04time\x18\x05 \x01(\x0b\x32!.otg.PatternFlowEthernetPauseTimeH\x04\x88\x01\x01\x42\x06\n\x04_dstB\x06\n\x04_srcB\r\n\x0b_ether_typeB\x12\n\x10_control_op_codeB\x07\n\x05_time\"\xac\x07\n\x07\x46lowTcp\x12\x31\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowTcpSrcPortH\x00\x88\x01\x01\x12\x31\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowTcpDstPortH\x01\x88\x01\x01\x12/\n\x07seq_num\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowTcpSeqNumH\x02\x88\x01\x01\x12/\n\x07\x61\x63k_num\x18\x04 \x01(\x0b\x32\x19.otg.PatternFlowTcpAckNumH\x03\x88\x01\x01\x12\x37\n\x0b\x64\x61ta_offset\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowTcpDataOffsetH\x04\x88\x01\x01\x12-\n\x06\x65\x63n_ns\x18\x06 \x01(\x0b\x32\x18.otg.PatternFlowTcpEcnNsH\x05\x88\x01\x01\x12/\n\x07\x65\x63n_cwr\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowTcpEcnCwrH\x06\x88\x01\x01\x12\x31\n\x08\x65\x63n_echo\x18\x08 \x01(\x0b\x32\x1a.otg.PatternFlowTcpEcnEchoH\x07\x88\x01\x01\x12/\n\x07\x63tl_urg\x18\t \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlUrgH\x08\x88\x01\x01\x12/\n\x07\x63tl_ack\x18\n \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlAckH\t\x88\x01\x01\x12/\n\x07\x63tl_psh\x18\x0b \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlPshH\n\x88\x01\x01\x12/\n\x07\x63tl_rst\x18\x0c \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlRstH\x0b\x88\x01\x01\x12/\n\x07\x63tl_syn\x18\r \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlSynH\x0c\x88\x01\x01\x12/\n\x07\x63tl_fin\x18\x0e \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlFinH\r\x88\x01\x01\x12.\n\x06window\x18\x0f \x01(\x0b\x32\x19.otg.PatternFlowTcpWindowH\x0e\x88\x01\x01\x42\x0b\n\t_src_portB\x0b\n\t_dst_portB\n\n\x08_seq_numB\n\n\x08_ack_numB\x0e\n\x0c_data_offsetB\t\n\x07_ecn_nsB\n\n\x08_ecn_cwrB\x0b\n\t_ecn_echoB\n\n\x08_ctl_urgB\n\n\x08_ctl_ackB\n\n\x08_ctl_pshB\n\n\x08_ctl_rstB\n\n\x08_ctl_synB\n\n\x08_ctl_finB\t\n\x07_window\"\x85\x02\n\x07\x46lowUdp\x12\x31\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowUdpSrcPortH\x00\x88\x01\x01\x12\x31\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowUdpDstPortH\x01\x88\x01\x01\x12.\n\x06length\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowUdpLengthH\x02\x88\x01\x01\x12\x32\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowUdpChecksumH\x03\x88\x01\x01\x42\x0b\n\t_src_portB\x0b\n\t_dst_portB\t\n\x07_lengthB\x0b\n\t_checksum\"\xa9\x03\n\x07\x46lowGre\x12\x41\n\x10\x63hecksum_present\x18\x01 \x01(\x0b\x32\".otg.PatternFlowGreChecksumPresentH\x00\x88\x01\x01\x12\x34\n\treserved0\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved0H\x01\x88\x01\x01\x12\x30\n\x07version\x18\x03 \x01(\x0b\x32\x1a.otg.PatternFlowGreVersionH\x02\x88\x01\x01\x12\x32\n\x08protocol\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGreProtocolH\x03\x88\x01\x01\x12\x32\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\x1b.otg.PatternFlowGreChecksumH\x04\x88\x01\x01\x12\x34\n\treserved1\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved1H\x05\x88\x01\x01\x42\x13\n\x11_checksum_presentB\x0c\n\n_reserved0B\n\n\x08_versionB\x0b\n\t_protocolB\x0b\n\t_checksumB\x0c\n\n_reserved1\"\xb8\x07\n\tFlowGtpv1\x12\x32\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv1VersionH\x00\x88\x01\x01\x12=\n\rprotocol_type\x18\x02 \x01(\x0b\x32!.otg.PatternFlowGtpv1ProtocolTypeH\x01\x88\x01\x01\x12\x34\n\x08reserved\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv1ReservedH\x02\x88\x01\x01\x12/\n\x06\x65_flag\x18\x04 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1EFlagH\x03\x88\x01\x01\x12/\n\x06s_flag\x18\x05 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1SFlagH\x04\x88\x01\x01\x12\x31\n\x07pn_flag\x18\x06 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv1PnFlagH\x05\x88\x01\x01\x12;\n\x0cmessage_type\x18\x07 \x01(\x0b\x32 .otg.PatternFlowGtpv1MessageTypeH\x06\x88\x01\x01\x12?\n\x0emessage_length\x18\x08 \x01(\x0b\x32\".otg.PatternFlowGtpv1MessageLengthH\x07\x88\x01\x01\x12,\n\x04teid\x18\t \x01(\x0b\x32\x19.otg.PatternFlowGtpv1TeidH\x08\x88\x01\x01\x12?\n\x0esquence_number\x18\n \x01(\x0b\x32\".otg.PatternFlowGtpv1SquenceNumberH\t\x88\x01\x01\x12:\n\x0cn_pdu_number\x18\x0b \x01(\x0b\x32\x1f.otg.PatternFlowGtpv1NPduNumberH\n\x88\x01\x01\x12U\n\x1anext_extension_header_type\x18\x0c \x01(\x0b\x32,.otg.PatternFlowGtpv1NextExtensionHeaderTypeH\x0b\x88\x01\x01\x12\x30\n\x11\x65xtension_headers\x18\r \x03(\x0b\x32\x15.otg.FlowGtpExtensionB\n\n\x08_versionB\x10\n\x0e_protocol_typeB\x0b\n\t_reservedB\t\n\x07_e_flagB\t\n\x07_s_flagB\n\n\x08_pn_flagB\x0f\n\r_message_typeB\x11\n\x0f_message_lengthB\x07\n\x05_teidB\x11\n\x0f_squence_numberB\x0f\n\r_n_pdu_numberB\x1d\n\x1b_next_extension_header_type\"\xac\x02\n\x10\x46lowGtpExtension\x12J\n\x10\x65xtension_length\x18\x01 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionExtensionLengthH\x00\x88\x01\x01\x12;\n\x08\x63ontents\x18\x02 \x01(\x0b\x32$.otg.PatternFlowGtpExtensionContentsH\x01\x88\x01\x01\x12S\n\x15next_extension_header\x18\x03 \x01(\x0b\x32/.otg.PatternFlowGtpExtensionNextExtensionHeaderH\x02\x88\x01\x01\x42\x13\n\x11_extension_lengthB\x0b\n\t_contentsB\x18\n\x16_next_extension_header\"\x97\x05\n\tFlowGtpv2\x12\x32\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv2VersionH\x00\x88\x01\x01\x12\x45\n\x11piggybacking_flag\x18\x02 \x01(\x0b\x32%.otg.PatternFlowGtpv2PiggybackingFlagH\x01\x88\x01\x01\x12\x35\n\tteid_flag\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv2TeidFlagH\x02\x88\x01\x01\x12\x30\n\x06spare1\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare1H\x03\x88\x01\x01\x12;\n\x0cmessage_type\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2MessageTypeH\x04\x88\x01\x01\x12?\n\x0emessage_length\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2MessageLengthH\x05\x88\x01\x01\x12,\n\x04teid\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowGtpv2TeidH\x06\x88\x01\x01\x12\x41\n\x0fsequence_number\x18\x08 \x01(\x0b\x32#.otg.PatternFlowGtpv2SequenceNumberH\x07\x88\x01\x01\x12\x30\n\x06spare2\x18\t \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare2H\x08\x88\x01\x01\x42\n\n\x08_versionB\x14\n\x12_piggybacking_flagB\x0c\n\n_teid_flagB\t\n\x07_spare1B\x0f\n\r_message_typeB\x11\n\x0f_message_lengthB\x07\n\x05_teidB\x12\n\x10_sequence_numberB\t\n\x07_spare2\"\xa1\x06\n\x07\x46lowArp\x12;\n\rhardware_type\x18\x01 \x01(\x0b\x32\x1f.otg.PatternFlowArpHardwareTypeH\x00\x88\x01\x01\x12;\n\rprotocol_type\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowArpProtocolTypeH\x01\x88\x01\x01\x12?\n\x0fhardware_length\x18\x03 \x01(\x0b\x32!.otg.PatternFlowArpHardwareLengthH\x02\x88\x01\x01\x12?\n\x0fprotocol_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowArpProtocolLengthH\x03\x88\x01\x01\x12\x34\n\toperation\x18\x05 \x01(\x0b\x32\x1c.otg.PatternFlowArpOperationH\x04\x88\x01\x01\x12H\n\x14sender_hardware_addr\x18\x06 \x01(\x0b\x32%.otg.PatternFlowArpSenderHardwareAddrH\x05\x88\x01\x01\x12H\n\x14sender_protocol_addr\x18\x07 \x01(\x0b\x32%.otg.PatternFlowArpSenderProtocolAddrH\x06\x88\x01\x01\x12H\n\x14target_hardware_addr\x18\x08 \x01(\x0b\x32%.otg.PatternFlowArpTargetHardwareAddrH\x07\x88\x01\x01\x12H\n\x14target_protocol_addr\x18\t \x01(\x0b\x32%.otg.PatternFlowArpTargetProtocolAddrH\x08\x88\x01\x01\x42\x10\n\x0e_hardware_typeB\x10\n\x0e_protocol_typeB\x12\n\x10_hardware_lengthB\x12\n\x10_protocol_lengthB\x0c\n\n_operationB\x17\n\x15_sender_hardware_addrB\x17\n\x15_sender_protocol_addrB\x17\n\x15_target_hardware_addrB\x17\n\x15_target_protocol_addr\"\xa1\x01\n\x08\x46lowIcmp\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowIcmp.Choice.EnumH\x00\x88\x01\x01\x12$\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x11.otg.FlowIcmpEchoH\x01\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choiceB\x07\n\x05_echo\"\xee\x02\n\x0c\x46lowIcmpEcho\x12/\n\x04type\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoTypeH\x00\x88\x01\x01\x12/\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoCodeH\x01\x88\x01\x01\x12\x37\n\x08\x63hecksum\x18\x03 \x01(\x0b\x32 .otg.PatternFlowIcmpEchoChecksumH\x02\x88\x01\x01\x12;\n\nidentifier\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIcmpEchoIdentifierH\x03\x88\x01\x01\x12\x44\n\x0fsequence_number\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIcmpEchoSequenceNumberH\x04\x88\x01\x01\x42\x07\n\x05_typeB\x07\n\x05_codeB\x0b\n\t_checksumB\r\n\x0b_identifierB\x12\n\x10_sequence_number\"\xa7\x01\n\nFlowIcmpv6\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowIcmpv6.Choice.EnumH\x00\x88\x01\x01\x12&\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x13.otg.FlowIcmpv6EchoH\x01\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choiceB\x07\n\x05_echo\"\xfa\x02\n\x0e\x46lowIcmpv6Echo\x12\x31\n\x04type\x18\x01 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoTypeH\x00\x88\x01\x01\x12\x31\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoCodeH\x01\x88\x01\x01\x12=\n\nidentifier\x18\x03 \x01(\x0b\x32$.otg.PatternFlowIcmpv6EchoIdentifierH\x02\x88\x01\x01\x12\x46\n\x0fsequence_number\x18\x04 \x01(\x0b\x32(.otg.PatternFlowIcmpv6EchoSequenceNumberH\x03\x88\x01\x01\x12\x39\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIcmpv6EchoChecksumH\x04\x88\x01\x01\x42\x07\n\x05_typeB\x07\n\x05_codeB\r\n\x0b_identifierB\x12\n\x10_sequence_numberB\x0b\n\t_checksum\"\xd4\x01\n\x07\x46lowPpp\x12\x30\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowPppAddressH\x00\x88\x01\x01\x12\x30\n\x07\x63ontrol\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowPppControlH\x01\x88\x01\x01\x12;\n\rprotocol_type\x18\x03 \x01(\x0b\x32\x1f.otg.PatternFlowPppProtocolTypeH\x02\x88\x01\x01\x42\n\n\x08_addressB\n\n\x08_controlB\x10\n\x0e_protocol_type\"\xd9\x02\n\nFlowIgmpv1\x12\x33\n\x07version\x18\x01 \x01(\x0b\x32\x1d.otg.PatternFlowIgmpv1VersionH\x00\x88\x01\x01\x12-\n\x04type\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowIgmpv1TypeH\x01\x88\x01\x01\x12\x31\n\x06unused\x18\x03 \x01(\x0b\x32\x1c.otg.PatternFlowIgmpv1UnusedH\x02\x88\x01\x01\x12\x35\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowIgmpv1ChecksumH\x03\x88\x01\x01\x12>\n\rgroup_address\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIgmpv1GroupAddressH\x04\x88\x01\x01\x42\n\n\x08_versionB\x07\n\x05_typeB\t\n\x07_unusedB\x0b\n\t_checksumB\x10\n\x0e_group_address\"\xb4\x02\n\x08\x46lowMpls\x12-\n\x05label\x18\x01 \x01(\x0b\x32\x19.otg.PatternFlowMplsLabelH\x00\x88\x01\x01\x12<\n\rtraffic_class\x18\x02 \x01(\x0b\x32 .otg.PatternFlowMplsTrafficClassH\x01\x88\x01\x01\x12?\n\x0f\x62ottom_of_stack\x18\x03 \x01(\x0b\x32!.otg.PatternFlowMplsBottomOfStackH\x02\x88\x01\x01\x12\x39\n\x0ctime_to_live\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowMplsTimeToLiveH\x03\x88\x01\x01\x42\x08\n\x06_labelB\x10\n\x0e_traffic_classB\x12\n\x10_bottom_of_stackB\x0f\n\r_time_to_live\"\xf7\x02\n\x08\x46lowSize\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowSize.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x66ixed\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12.\n\tincrement\x18\x03 \x01(\x0b\x32\x16.otg.FlowSizeIncrementH\x02\x88\x01\x01\x12(\n\x06random\x18\x04 \x01(\x0b\x32\x13.otg.FlowSizeRandomH\x03\x88\x01\x01\x12\x33\n\x0cweight_pairs\x18\x05 \x01(\x0b\x32\x18.otg.FlowSizeWeightPairsH\x04\x88\x01\x01\x1aY\n\x06\x43hoice\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66ixed\x10\x01\x12\r\n\tincrement\x10\x02\x12\n\n\x06random\x10\x03\x12\x10\n\x0cweight_pairs\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_fixedB\x0c\n\n_incrementB\t\n\x07_randomB\x0f\n\r_weight_pairs\"g\n\x11\x46lowSizeIncrement\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x06\n\x04_endB\x07\n\x05_step\"D\n\x0e\x46lowSizeRandom\x12\x10\n\x03min\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_max\"\x8d\x03\n\x13\x46lowSizeWeightPairs\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.FlowSizeWeightPairs.Choice.EnumH\x00\x88\x01\x01\x12\x41\n\npredefined\x18\x02 \x01(\x0e\x32(.otg.FlowSizeWeightPairs.Predefined.EnumH\x01\x88\x01\x01\x12.\n\x06\x63ustom\x18\x03 \x03(\x0b\x32\x1e.otg.FlowSizeWeightPairsCustom\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\npredefined\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1ao\n\nPredefined\"a\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04imix\x10\x01\x12\x0e\n\nipsec_imix\x10\x02\x12\r\n\tipv6_imix\x10\x03\x12\x11\n\rstandard_imix\x10\x04\x12\x0c\n\x08tcp_imix\x10\x05\x42\t\n\x07_choiceB\r\n\x0b_predefined\"W\n\x19\x46lowSizeWeightPairsCustom\x12\x11\n\x04size\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x13\n\x06weight\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x07\n\x05_sizeB\t\n\x07_weight\"\xd8\x02\n\x08\x46lowRate\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowRate.Choice.EnumH\x00\x88\x01\x01\x12\x10\n\x03pps\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x10\n\x03\x62ps\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x11\n\x04kbps\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x11\n\x04mbps\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x11\n\x04gbps\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x17\n\npercentage\x18\x07 \x01(\x02H\x06\x88\x01\x01\x1a\x61\n\x06\x43hoice\"W\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03pps\x10\x01\x12\x07\n\x03\x62ps\x10\x02\x12\x08\n\x04kbps\x10\x03\x12\x08\n\x04mbps\x10\x04\x12\x08\n\x04gbps\x10\x05\x12\x0e\n\npercentage\x10\x06\x42\t\n\x07_choiceB\x06\n\x04_ppsB\x06\n\x04_bpsB\x07\n\x05_kbpsB\x07\n\x05_mbpsB\x07\n\x05_gbpsB\r\n\x0b_percentage\"\xa6\x03\n\x0c\x46lowDuration\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.FlowDuration.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\rfixed_packets\x18\x02 \x01(\x0b\x32\x15.otg.FlowFixedPacketsH\x01\x88\x01\x01\x12\x31\n\rfixed_seconds\x18\x03 \x01(\x0b\x32\x15.otg.FlowFixedSecondsH\x02\x88\x01\x01\x12\"\n\x05\x62urst\x18\x04 \x01(\x0b\x32\x0e.otg.FlowBurstH\x03\x88\x01\x01\x12,\n\ncontinuous\x18\x05 \x01(\x0b\x32\x13.otg.FlowContinuousH\x04\x88\x01\x01\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rfixed_packets\x10\x01\x12\x11\n\rfixed_seconds\x10\x02\x12\t\n\x05\x62urst\x10\x03\x12\x0e\n\ncontinuous\x10\x04\x42\t\n\x07_choiceB\x10\n\x0e_fixed_packetsB\x10\n\x0e_fixed_secondsB\x08\n\x06_burstB\r\n\x0b_continuous\"X\n\x0e\x46lowContinuous\x12\x10\n\x03gap\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\"\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x0e.otg.FlowDelayH\x01\x88\x01\x01\x42\x06\n\x04_gapB\x08\n\x06_delay\"\x8c\x02\n\tFlowDelay\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.FlowDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x02H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"|\n\x10\x46lowFixedPackets\x12\x14\n\x07packets\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\"\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayH\x02\x88\x01\x01\x42\n\n\x08_packetsB\x06\n\x04_gapB\x08\n\x06_delay\"|\n\x10\x46lowFixedSeconds\x12\x14\n\x07seconds\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\"\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayH\x02\x88\x01\x01\x42\n\n\x08_secondsB\x06\n\x04_gapB\x08\n\x06_delay\"\xb9\x01\n\tFlowBurst\x12\x13\n\x06\x62ursts\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07packets\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x10\n\x03gap\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12<\n\x0finter_burst_gap\x18\x04 \x01(\x0b\x32\x1e.otg.FlowDurationInterBurstGapH\x03\x88\x01\x01\x42\t\n\x07_burstsB\n\n\x08_packetsB\x06\n\x04_gapB\x12\n\x10_inter_burst_gap\"\xac\x02\n\x19\x46lowDurationInterBurstGap\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.FlowDurationInterBurstGap.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x01H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"\xc3\x02\n\x0b\x46lowMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x11\n\x04loss\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12,\n\x0brx_tx_ratio\x18\x06 \x01(\x0b\x32\x12.otg.FlowRxTxRatioH\x02\x88\x01\x01\x12\x17\n\ntimestamps\x18\x03 \x01(\x08H\x03\x88\x01\x01\x12-\n\x07latency\x18\x04 \x01(\x0b\x32\x17.otg.FlowLatencyMetricsH\x04\x88\x01\x01\x12<\n\x16predefined_metric_tags\x18\x05 \x01(\x0b\x32\x17.otg.FlowPredefinedTagsH\x05\x88\x01\x01\x42\t\n\x07_enableB\x07\n\x05_lossB\x0e\n\x0c_rx_tx_ratioB\r\n\x0b_timestampsB\n\n\x08_latencyB\x19\n\x17_predefined_metric_tags\"\xb8\x01\n\x12\x46lowLatencyMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32!.otg.FlowLatencyMetrics.Mode.EnumH\x01\x88\x01\x01\x1a\x43\n\x04Mode\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rstore_forward\x10\x01\x12\x0f\n\x0b\x63ut_through\x10\x02\x42\t\n\x07_enableB\x07\n\x05_mode\"6\n\x12\x46lowPredefinedTags\x12\x14\n\x07rx_name\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_rx_name\"\xe8\x01\n\rFlowRxTxRatio\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.FlowRxTxRatio.Choice.EnumH\x00\x88\x01\x01\x12\x30\n\x08rx_count\x18\x02 \x01(\x0b\x32\x19.otg.FlowRxTxRatioRxCountH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\x02H\x02\x88\x01\x01\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08rx_count\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x0b\n\t_rx_countB\x08\n\x06_value\"\x16\n\x14\x46lowRxTxRatioRxCount\"\x8a\x02\n\x05\x45vent\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12!\n\x04link\x18\x02 \x01(\x0b\x32\x0e.otg.EventLinkH\x01\x88\x01\x01\x12\x39\n\x11rx_rate_threshold\x18\x03 \x01(\x0b\x32\x19.otg.EventRxRateThresholdH\x02\x88\x01\x01\x12G\n\x18route_advertise_withdraw\x18\x04 \x01(\x0b\x32 .otg.EventRouteAdvertiseWithdrawH\x03\x88\x01\x01\x42\t\n\x07_enableB\x07\n\x05_linkB\x14\n\x12_rx_rate_thresholdB\x1b\n\x19_route_advertise_withdraw\"\\\n\x14\x45ventRxRateThreshold\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x16\n\tthreshold\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\t\n\x07_enableB\x0c\n\n_threshold\"+\n\tEventLink\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_enable\"=\n\x1b\x45ventRouteAdvertiseWithdraw\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_enable\"\xf5\x01\n\x0c\x45ventRequest\x12)\n\x04type\x18\x01 \x03(\x0e\x32\x1b.otg.EventRequest.Type.Enum\x12\x0e\n\x06source\x18\x02 \x03(\t\x1a\xa9\x01\n\x04Type\"\xa0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tlink_down\x10\x01\x12\x0b\n\x07link_up\x10\x02\x12\x12\n\x0eroute_withdraw\x10\x03\x12\x13\n\x0froute_advertise\x10\x04\x12 \n\x1c\x66low_rx_rate_above_threshold\x10\x05\x12 \n\x1c\x66low_rx_rate_below_threshold\x10\x06\"r\n\x11\x45ventSubscription\x12&\n\x06\x65vents\x18\x01 \x01(\x0b\x32\x11.otg.EventRequestH\x00\x88\x01\x01\x12\x19\n\x0c\x63\x61llback_url\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_eventsB\x0f\n\r_callback_url\"\xd1\x02\n\x04Lldp\x12\'\n\nconnection\x18\x01 \x01(\x0b\x32\x13.otg.LldpConnection\x12+\n\nchassis_id\x18\x02 \x01(\x0b\x32\x12.otg.LldpChassisIdH\x00\x88\x01\x01\x12%\n\x07port_id\x18\x03 \x01(\x0b\x32\x0f.otg.LldpPortIdH\x01\x88\x01\x01\x12-\n\x0bsystem_name\x18\x04 \x01(\x0b\x32\x13.otg.LldpSystemNameH\x02\x88\x01\x01\x12\x16\n\thold_time\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12#\n\x16\x61\x64vertisement_interval\x18\x06 \x01(\x05H\x04\x88\x01\x01\x12\x0c\n\x04name\x18\x07 \x01(\tB\r\n\x0b_chassis_idB\n\n\x08_port_idB\x0e\n\x0c_system_nameB\x0c\n\n_hold_timeB\x19\n\x17_advertisement_interval\"\xa9\x01\n\x0eLldpConnection\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.LldpConnection.Choice.EnumH\x00\x88\x01\x01\x12\x16\n\tport_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tport_name\x10\x01\x42\t\n\x07_choiceB\x0c\n\n_port_name\"\xfe\x02\n\rLldpChassisId\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.LldpChassisId.Choice.EnumH\x00\x88\x01\x01\x12<\n\x13mac_address_subtype\x18\x02 \x01(\x0b\x32\x1a.otg.LldpChassisMacSubTypeH\x01\x88\x01\x01\x12#\n\x16interface_name_subtype\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rlocal_subtype\x18\x04 \x01(\tH\x03\x88\x01\x01\x1ai\n\x06\x43hoice\"_\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13mac_address_subtype\x10\x01\x12\x1a\n\x16interface_name_subtype\x10\x02\x12\x11\n\rlocal_subtype\x10\x03\x42\t\n\x07_choiceB\x16\n\x14_mac_address_subtypeB\x19\n\x17_interface_name_subtypeB\x10\n\x0e_local_subtype\"\xff\x02\n\nLldpPortId\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.LldpPortId.Choice.EnumH\x00\x88\x01\x01\x12 \n\x13mac_address_subtype\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x46\n\x16interface_name_subtype\x18\x03 \x01(\x0b\x32!.otg.LldpPortInterfaceNameSubTypeH\x02\x88\x01\x01\x12\x1a\n\rlocal_subtype\x18\x04 \x01(\tH\x03\x88\x01\x01\x1ai\n\x06\x43hoice\"_\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x17\n\x13mac_address_subtype\x10\x01\x12\x1a\n\x16interface_name_subtype\x10\x02\x12\x11\n\rlocal_subtype\x10\x03\x42\t\n\x07_choiceB\x16\n\x14_mac_address_subtypeB\x19\n\x17_interface_name_subtypeB\x10\n\x0e_local_subtype\"\xd1\x01\n\x15LldpChassisMacSubType\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.LldpChassisMacSubType.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xdf\x01\n\x1cLldpPortInterfaceNameSubType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.LldpPortInterfaceNameSubType.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\xc3\x01\n\x0eLldpSystemName\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.LldpSystemName.Choice.EnumH\x00\x88\x01\x01\x12\x11\n\x04\x61uto\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x36\n\x06\x43hoice\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x61uto\x10\x01\x12\t\n\x05value\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_autoB\x08\n\x06_value\"\x96\x01\n\x05\x45rror\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\'\n\x04kind\x18\x02 \x01(\x0e\x32\x14.otg.Error.Kind.EnumH\x00\x88\x01\x01\x12\x0e\n\x06\x65rrors\x18\x03 \x03(\t\x1a=\n\x04Kind\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nvalidation\x10\x01\x12\x0c\n\x08internal\x10\x02\x42\x07\n\x05_kind\"\x1b\n\x07Warning\x12\x10\n\x08warnings\x18\x01 \x03(\t\"\xab\x01\n\x0c\x43onfigUpdate\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.ConfigUpdate.Choice.EnumH\x00\x88\x01\x01\x12$\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x10.otg.FlowsUpdateH\x01\x88\x01\x01\x1a,\n\x06\x43hoice\"\"\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66lows\x10\x01\x42\t\n\x07_choiceB\x08\n\x06_flows\"\xa2\x01\n\x0b\x46lowsUpdate\x12;\n\x0eproperty_names\x18\x01 \x03(\x0e\x32#.otg.FlowsUpdate.PropertyNames.Enum\x12\x18\n\x05\x66lows\x18\x02 \x03(\x0b\x32\t.otg.Flow\x1a<\n\rPropertyNames\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04rate\x10\x01\x12\x08\n\x04size\x10\x02\"\x9e\x02\n\x0c\x43ontrolState\x12-\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.ControlState.Choice.Enum\x12!\n\x04port\x18\x02 \x01(\x0b\x32\x0e.otg.StatePortH\x00\x88\x01\x01\x12)\n\x08protocol\x18\x03 \x01(\x0b\x32\x12.otg.StateProtocolH\x01\x88\x01\x01\x12\'\n\x07traffic\x18\x04 \x01(\x0b\x32\x11.otg.StateTrafficH\x02\x88\x01\x01\x1a\x46\n\x06\x43hoice\"<\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\x0c\n\x08protocol\x10\x02\x12\x0b\n\x07traffic\x10\x03\x42\x07\n\x05_portB\x0b\n\t_protocolB\n\n\x08_traffic\"\xda\x01\n\tStatePort\x12*\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.StatePort.Choice.Enum\x12%\n\x04link\x18\x02 \x01(\x0b\x32\x12.otg.StatePortLinkH\x00\x88\x01\x01\x12+\n\x07\x63\x61pture\x18\x03 \x01(\x0b\x32\x15.otg.StatePortCaptureH\x01\x88\x01\x01\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04link\x10\x01\x12\x0b\n\x07\x63\x61pture\x10\x02\x42\x07\n\x05_linkB\n\n\x08_capture\"\xc0\x01\n\x0cStateTraffic\x12-\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.StateTraffic.Choice.Enum\x12\x39\n\rflow_transmit\x18\x02 \x01(\x0b\x32\x1d.otg.StateTrafficFlowTransmitH\x00\x88\x01\x01\x1a\x34\n\x06\x43hoice\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rflow_transmit\x10\x01\x42\x10\n\x0e_flow_transmit\"\x9c\x02\n\rStateProtocol\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.StateProtocol.Choice.Enum\x12\'\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x15.otg.StateProtocolAllH\x00\x88\x01\x01\x12+\n\x05route\x18\x03 \x01(\x0b\x32\x17.otg.StateProtocolRouteH\x01\x88\x01\x01\x12)\n\x04lacp\x18\x04 \x01(\x0b\x32\x16.otg.StateProtocolLacpH\x02\x88\x01\x01\x1a?\n\x06\x43hoice\"5\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x61ll\x10\x01\x12\t\n\x05route\x10\x02\x12\x08\n\x04lacp\x10\x03\x42\x06\n\x04_allB\x08\n\x06_routeB\x07\n\x05_lacp\"}\n\tLinkState\x12\x12\n\nport_names\x18\x01 \x03(\t\x12(\n\x05state\x18\x02 \x01(\x0e\x32\x19.otg.LinkState.State.Enum\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\"\x9f\x01\n\rTransmitState\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12,\n\x05state\x18\x02 \x01(\x0e\x32\x1d.otg.TransmitState.State.Enum\x1aL\n\x05State\"C\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x12\t\n\x05pause\x10\x03\x12\n\n\x06resume\x10\x04\"\x86\x01\n\x0c\x43\x61ptureState\x12\x12\n\nport_names\x18\x01 \x03(\t\x12+\n\x05state\x18\x02 \x01(\x0e\x32\x1c.otg.CaptureState.State.Enum\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\"\x85\x01\n\nRouteState\x12\r\n\x05names\x18\x01 \x03(\t\x12)\n\x05state\x18\x02 \x01(\x0e\x32\x1a.otg.RouteState.State.Enum\x1a=\n\x05State\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08withdraw\x10\x01\x12\r\n\tadvertise\x10\x02\"t\n\rProtocolState\x12,\n\x05state\x18\x01 \x01(\x0e\x32\x1d.otg.ProtocolState.State.Enum\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\"\xd1\x01\n\x0b\x44\x65viceState\x12\x31\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1c.otg.DeviceState.Choice.EnumH\x00\x88\x01\x01\x12\x34\n\x11lacp_member_state\x18\x02 \x01(\x0b\x32\x14.otg.LacpMemberStateH\x01\x88\x01\x01\x1a\x38\n\x06\x43hoice\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x15\n\x11lacp_member_state\x10\x01\x42\t\n\x07_choiceB\x14\n\x12_lacp_member_state\"\x85\x01\n\rStatePortLink\x12\x12\n\nport_names\x18\x01 \x03(\t\x12,\n\x05state\x18\x02 \x01(\x0e\x32\x1d.otg.StatePortLink.State.Enum\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\"\x8e\x01\n\x10StatePortCapture\x12\x12\n\nport_names\x18\x01 \x03(\t\x12/\n\x05state\x18\x02 \x01(\x0e\x32 .otg.StatePortCapture.State.Enum\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\"\xc4\x01\n\x18StateTrafficFlowTransmit\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12<\n\x05state\x18\x02 \x01(\x0e\x32(.otg.StateTrafficFlowTransmit.State.EnumH\x00\x88\x01\x01\x1aL\n\x05State\"C\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x12\t\n\x05pause\x10\x03\x12\n\n\x06resume\x10\x04\x42\x08\n\x06_state\"z\n\x10StateProtocolAll\x12/\n\x05state\x18\x01 \x01(\x0e\x32 .otg.StateProtocolAll.State.Enum\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\"\x95\x01\n\x12StateProtocolRoute\x12\r\n\x05names\x18\x01 \x03(\t\x12\x31\n\x05state\x18\x02 \x01(\x0e\x32\".otg.StateProtocolRoute.State.Enum\x1a=\n\x05State\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08withdraw\x10\x01\x12\r\n\tadvertise\x10\x02\"\xb0\x01\n\x11StateProtocolLacp\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.StateProtocolLacp.Choice.Enum\x12/\n\x05\x61\x64min\x18\x02 \x01(\x0b\x32\x1b.otg.StateProtocolLacpAdminH\x00\x88\x01\x01\x1a,\n\x06\x43hoice\"\"\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x61\x64min\x10\x01\x42\x08\n\x06_admin\"\xac\x01\n\x16StateProtocolLacpAdmin\x12\x18\n\x10lag_member_names\x18\x01 \x03(\t\x12:\n\x05state\x18\x02 \x01(\x0e\x32&.otg.StateProtocolLacpAdmin.State.EnumH\x00\x88\x01\x01\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x08\n\x06_state\"\x94\x01\n\x0fLacpMemberState\x12\x1d\n\x15lag_member_port_names\x18\x01 \x03(\t\x12.\n\x05state\x18\x02 \x01(\x0e\x32\x1f.otg.LacpMemberState.State.Enum\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\"\xa9\x01\n\rControlAction\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.ControlAction.Choice.Enum\x12*\n\x08protocol\x18\x02 \x01(\x0b\x32\x13.otg.ActionProtocolH\x00\x88\x01\x01\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08protocol\x10\x01\x42\x0b\n\t_protocol\"b\n\x15\x43ontrolActionResponse\x12\x10\n\x08warnings\x18\x01 \x03(\t\x12*\n\x08response\x18\x02 \x01(\x0b\x32\x13.otg.ActionResponseH\x00\x88\x01\x01\x42\x0b\n\t_response\"\xb3\x01\n\x0e\x41\x63tionResponse\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.ActionResponse.Choice.Enum\x12\x32\n\x08protocol\x18\x02 \x01(\x0b\x32\x1b.otg.ActionResponseProtocolH\x00\x88\x01\x01\x1a/\n\x06\x43hoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08protocol\x10\x01\x42\x0b\n\t_protocol\"\x9d\x02\n\x0e\x41\x63tionProtocol\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.ActionProtocol.Choice.Enum\x12*\n\x04ipv4\x18\x02 \x01(\x0b\x32\x17.otg.ActionProtocolIpv4H\x00\x88\x01\x01\x12*\n\x04ipv6\x18\x03 \x01(\x0b\x32\x17.otg.ActionProtocolIpv6H\x01\x88\x01\x01\x12(\n\x03\x62gp\x18\x04 \x01(\x0b\x32\x16.otg.ActionProtocolBgpH\x02\x88\x01\x01\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x12\x07\n\x03\x62gp\x10\x03\x42\x07\n\x05_ipv4B\x07\n\x05_ipv6B\x06\n\x04_bgp\"\x82\x02\n\x16\x41\x63tionResponseProtocol\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.ActionResponseProtocol.Choice.Enum\x12\x32\n\x04ipv4\x18\x02 \x01(\x0b\x32\x1f.otg.ActionResponseProtocolIpv4H\x00\x88\x01\x01\x12\x32\n\x04ipv6\x18\x03 \x01(\x0b\x32\x1f.otg.ActionResponseProtocolIpv6H\x01\x88\x01\x01\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x07\n\x05_ipv4B\x07\n\x05_ipv6\"\xaf\x01\n\x12\x41\x63tionProtocolIpv4\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.ActionProtocolIpv4.Choice.Enum\x12.\n\x04ping\x18\x02 \x01(\x0b\x32\x1b.otg.ActionProtocolIpv4PingH\x00\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\x07\n\x05_ping\"\xc7\x01\n\x1a\x41\x63tionResponseProtocolIpv4\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.ActionResponseProtocolIpv4.Choice.Enum\x12\x36\n\x04ping\x18\x02 \x01(\x0b\x32#.otg.ActionResponseProtocolIpv4PingH\x00\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\x07\n\x05_ping\"N\n\x16\x41\x63tionProtocolIpv4Ping\x12\x34\n\x08requests\x18\x01 \x03(\x0b\x32\".otg.ActionProtocolIpv4PingRequest\"c\n\x1d\x41\x63tionProtocolIpv4PingRequest\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"`\n\x1e\x41\x63tionResponseProtocolIpv4Ping\x12>\n\tresponses\x18\x01 \x03(\x0b\x32+.otg.ActionResponseProtocolIpv4PingResponse\"\xd1\x01\n&ActionResponseProtocolIpv4PingResponse\x12\x10\n\x08src_name\x18\x01 \x01(\t\x12\x0e\n\x06\x64st_ip\x18\x02 \x01(\t\x12G\n\x06result\x18\x03 \x01(\x0e\x32\x37.otg.ActionResponseProtocolIpv4PingResponse.Result.Enum\x1a<\n\x06Result\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsucceeded\x10\x01\x12\n\n\x06\x66\x61iled\x10\x02\"\xaf\x01\n\x12\x41\x63tionProtocolIpv6\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.ActionProtocolIpv6.Choice.Enum\x12.\n\x04ping\x18\x02 \x01(\x0b\x32\x1b.otg.ActionProtocolIpv6PingH\x00\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\x07\n\x05_ping\"\xc7\x01\n\x1a\x41\x63tionResponseProtocolIpv6\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.ActionResponseProtocolIpv6.Choice.Enum\x12\x36\n\x04ping\x18\x02 \x01(\x0b\x32#.otg.ActionResponseProtocolIpv6PingH\x00\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ping\x10\x01\x42\x07\n\x05_ping\"N\n\x16\x41\x63tionProtocolIpv6Ping\x12\x34\n\x08requests\x18\x01 \x03(\x0b\x32\".otg.ActionProtocolIpv6PingRequest\"c\n\x1d\x41\x63tionProtocolIpv6PingRequest\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"`\n\x1e\x41\x63tionResponseProtocolIpv6Ping\x12>\n\tresponses\x18\x01 \x03(\x0b\x32+.otg.ActionResponseProtocolIpv6PingResponse\"\xd1\x01\n&ActionResponseProtocolIpv6PingResponse\x12\x10\n\x08src_name\x18\x01 \x01(\t\x12\x0e\n\x06\x64st_ip\x18\x02 \x01(\t\x12G\n\x06result\x18\x03 \x01(\x0e\x32\x37.otg.ActionResponseProtocolIpv6PingResponse.Result.Enum\x1a<\n\x06Result\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsucceeded\x10\x01\x12\n\n\x06\x66\x61iled\x10\x02\"\xe0\x02\n\x11\x41\x63tionProtocolBgp\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.ActionProtocolBgp.Choice.Enum\x12=\n\x0cnotification\x18\x02 \x01(\x0b\x32\".otg.ActionProtocolBgpNotificationH\x00\x88\x01\x01\x12U\n\x19initiate_graceful_restart\x18\x03 \x01(\x0b\x32-.otg.ActionProtocolBgpInitiateGracefulRestartH\x01\x88\x01\x01\x1aR\n\x06\x43hoice\"H\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cnotification\x10\x01\x12\x1d\n\x19initiate_graceful_restart\x10\x02\x42\x0f\n\r_notificationB\x1c\n\x1a_initiate_graceful_restart\"\x8c\x07\n\x1d\x41\x63tionProtocolBgpNotification\x12\r\n\x05names\x18\x01 \x03(\t\x12\x43\n\x06\x63hoice\x18\x02 \x01(\x0e\x32..otg.ActionProtocolBgpNotification.Choice.EnumH\x00\x88\x01\x01\x12,\n\x05\x63\x65\x61se\x18\x03 \x01(\x0b\x32\x18.otg.DeviceBgpCeaseErrorH\x01\x88\x01\x01\x12\x43\n\x14message_header_error\x18\x04 \x01(\x0b\x32 .otg.DeviceBgpMessageHeaderErrorH\x02\x88\x01\x01\x12?\n\x12open_message_error\x18\x05 \x01(\x0b\x32\x1e.otg.DeviceBgpOpenMessageErrorH\x03\x88\x01\x01\x12\x43\n\x14update_message_error\x18\x06 \x01(\x0b\x32 .otg.DeviceBgpUpdateMessageErrorH\x04\x88\x01\x01\x12?\n\x12hold_timer_expired\x18\x07 \x01(\x0b\x32\x1e.otg.DeviceBgpHoldTimerExpiredH\x05\x88\x01\x01\x12N\n\x1a\x66inite_state_machine_error\x18\x08 \x01(\x0b\x32%.otg.DeviceBgpFiniteStateMachineErrorH\x06\x88\x01\x01\x12.\n\x06\x63ustom\x18\t \x01(\x0b\x32\x19.otg.DeviceBgpCustomErrorH\x07\x88\x01\x01\x1a\xbd\x01\n\x06\x43hoice\"\xb2\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x63\x65\x61se\x10\x01\x12\x18\n\x14message_header_error\x10\x02\x12\x16\n\x12open_message_error\x10\x03\x12\x18\n\x14update_message_error\x10\x04\x12\x16\n\x12hold_timer_expired\x10\x05\x12\x1e\n\x1a\x66inite_state_machine_error\x10\x06\x12\n\n\x06\x63ustom\x10\x07\x42\t\n\x07_choiceB\x08\n\x06_ceaseB\x17\n\x15_message_header_errorB\x15\n\x13_open_message_errorB\x17\n\x15_update_message_errorB\x15\n\x13_hold_timer_expiredB\x1d\n\x1b_finite_state_machine_errorB\t\n\x07_custom\"l\n(ActionProtocolBgpInitiateGracefulRestart\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12\x1a\n\rrestart_delay\x18\x02 \x01(\rH\x00\x88\x01\x01\x42\x10\n\x0e_restart_delay\"\xca\x01\n\x04Ping\x12*\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x15.otg.Ping.Choice.EnumH\x00\x88\x01\x01\x12 \n\x04ipv4\x18\x02 \x01(\x0b\x32\r.otg.PingIpv4H\x01\x88\x01\x01\x12 \n\x04ipv6\x18\x03 \x01(\x0b\x32\r.otg.PingIpv6H\x02\x88\x01\x01\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_ipv4B\x07\n\x05_ipv6\"N\n\x08PingIpv4\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"N\n\x08PingIpv6\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"+\n\x0bPingRequest\x12\x1c\n\tendpoints\x18\x01 \x03(\x0b\x32\t.otg.Ping\"0\n\x0cPingResponse\x12 \n\tresponses\x18\x01 \x03(\x0b\x32\r.otg.Response\"\xc6\x01\n\x08Response\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12.\n\x06result\x18\x03 \x01(\x0e\x32\x19.otg.Response.Result.EnumH\x02\x88\x01\x01\x1a;\n\x06Result\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07success\x10\x01\x12\x0b\n\x07\x66\x61ilure\x10\x02\x42\x0b\n\t_src_nameB\t\n\x07_dst_ipB\t\n\x07_result\"\xaf\x05\n\x0eMetricsRequest\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.MetricsRequest.Choice.EnumH\x00\x88\x01\x01\x12*\n\x04port\x18\x02 \x01(\x0b\x32\x17.otg.PortMetricsRequestH\x01\x88\x01\x01\x12*\n\x04\x66low\x18\x03 \x01(\x0b\x32\x17.otg.FlowMetricsRequestH\x02\x88\x01\x01\x12,\n\x05\x62gpv4\x18\x04 \x01(\x0b\x32\x18.otg.Bgpv4MetricsRequestH\x03\x88\x01\x01\x12,\n\x05\x62gpv6\x18\x05 \x01(\x0b\x32\x18.otg.Bgpv6MetricsRequestH\x04\x88\x01\x01\x12*\n\x04isis\x18\x06 \x01(\x0b\x32\x17.otg.IsisMetricsRequestH\x05\x88\x01\x01\x12(\n\x03lag\x18\x07 \x01(\x0b\x32\x16.otg.LagMetricsRequestH\x06\x88\x01\x01\x12*\n\x04lacp\x18\x08 \x01(\x0b\x32\x17.otg.LacpMetricsRequestH\x07\x88\x01\x01\x12*\n\x04lldp\x18\t \x01(\x0b\x32\x17.otg.LldpMetricsRequestH\x08\x88\x01\x01\x12*\n\x04rsvp\x18\n \x01(\x0b\x32\x17.otg.RsvpMetricsRequestH\t\x88\x01\x01\x1a|\n\x06\x43hoice\"r\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\x08\n\x04\x66low\x10\x02\x12\t\n\x05\x62gpv4\x10\x03\x12\t\n\x05\x62gpv6\x10\x04\x12\x08\n\x04isis\x10\x05\x12\x07\n\x03lag\x10\x06\x12\x08\n\x04lacp\x10\x07\x12\x08\n\x04lldp\x10\x08\x12\x08\n\x04rsvp\x10\tB\t\n\x07_choiceB\x07\n\x05_portB\x07\n\x05_flowB\x08\n\x06_bgpv4B\x08\n\x06_bgpv6B\x07\n\x05_isisB\x06\n\x04_lagB\x07\n\x05_lacpB\x07\n\x05_lldpB\x07\n\x05_rsvp\"\xfc\x04\n\x0fMetricsResponse\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.MetricsResponse.Choice.EnumH\x00\x88\x01\x01\x12%\n\x0cport_metrics\x18\x02 \x03(\x0b\x32\x0f.otg.PortMetric\x12%\n\x0c\x66low_metrics\x18\x03 \x03(\x0b\x32\x0f.otg.FlowMetric\x12\'\n\rbgpv4_metrics\x18\x04 \x03(\x0b\x32\x10.otg.Bgpv4Metric\x12\'\n\rbgpv6_metrics\x18\x05 \x03(\x0b\x32\x10.otg.Bgpv6Metric\x12%\n\x0cisis_metrics\x18\x06 \x03(\x0b\x32\x0f.otg.IsisMetric\x12#\n\x0blag_metrics\x18\x07 \x03(\x0b\x32\x0e.otg.LagMetric\x12%\n\x0clacp_metrics\x18\x08 \x03(\x0b\x32\x0f.otg.LacpMetric\x12%\n\x0clldp_metrics\x18\t \x03(\x0b\x32\x0f.otg.LldpMetric\x12%\n\x0crsvp_metrics\x18\n \x03(\x0b\x32\x0f.otg.RsvpMetric\x1a\xc5\x01\n\x06\x43hoice\"\xba\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x66low_metrics\x10\x01\x12\x10\n\x0cport_metrics\x10\x02\x12\x11\n\rbgpv4_metrics\x10\x03\x12\x11\n\rbgpv6_metrics\x10\x04\x12\x10\n\x0cisis_metrics\x10\x05\x12\x0f\n\x0blag_metrics\x10\x06\x12\x10\n\x0clacp_metrics\x10\x07\x12\x10\n\x0clldp_metrics\x10\x08\x12\x10\n\x0crsvp_metrics\x10\tB\t\n\x07_choice\"\xcd\x02\n\x12PortMetricsRequest\x12\x12\n\nport_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.PortMetricsRequest.ColumnNames.Enum\x1a\xe2\x01\n\x0b\x43olumnNames\"\xd2\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\x0c\n\x08location\x10\x02\x12\x08\n\x04link\x10\x03\x12\x0b\n\x07\x63\x61pture\x10\x04\x12\r\n\tframes_tx\x10\x05\x12\r\n\tframes_rx\x10\x06\x12\x0c\n\x08\x62ytes_tx\x10\x07\x12\x0c\n\x08\x62ytes_rx\x10\x08\x12\x12\n\x0e\x66rames_tx_rate\x10\t\x12\x12\n\x0e\x66rames_rx_rate\x10\n\x12\x11\n\rbytes_tx_rate\x10\x0b\x12\x11\n\rbytes_rx_rate\x10\x0c\"\x86\x06\n\nPortMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08location\x18\x02 \x01(\tH\x01\x88\x01\x01\x12,\n\x04link\x18\x03 \x01(\x0e\x32\x19.otg.PortMetric.Link.EnumH\x02\x88\x01\x01\x12\x32\n\x07\x63\x61pture\x18\x04 \x01(\x0e\x32\x1c.otg.PortMetric.Capture.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x06 \x01(\x03H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x07 \x01(\x03H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x08 \x01(\x03H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\n \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rbytes_tx_rate\x18\x0b \x01(\x02H\n\x88\x01\x01\x12\x1a\n\rbytes_rx_rate\x18\x0c \x01(\x02H\x0b\x88\x01\x01\x12\x34\n\x08transmit\x18\r \x01(\x0e\x32\x1d.otg.PortMetric.Transmit.EnumH\x0c\x88\x01\x01\x1a\x31\n\x04Link\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a<\n\x07\x43\x61pture\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x1a=\n\x08Transmit\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x42\x07\n\x05_nameB\x0b\n\t_locationB\x07\n\x05_linkB\n\n\x08_captureB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x10\n\x0e_bytes_tx_rateB\x10\n\x0e_bytes_rx_rateB\x0b\n\t_transmit\"\xd0\x02\n\x12\x46lowMetricsRequest\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12>\n\x0cmetric_names\x18\x03 \x03(\x0e\x32(.otg.FlowMetricsRequest.MetricNames.Enum\x12\x39\n\x0etagged_metrics\x18\x04 \x01(\x0b\x32\x1c.otg.FlowTaggedMetricsFilterH\x00\x88\x01\x01\x1a\x97\x01\n\x0bMetricNames\"\x87\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\r\n\tframes_tx\x10\x02\x12\r\n\tframes_rx\x10\x03\x12\x0c\n\x08\x62ytes_tx\x10\x04\x12\x0c\n\x08\x62ytes_rx\x10\x05\x12\x12\n\x0e\x66rames_tx_rate\x10\x06\x12\x12\n\x0e\x66rames_rx_rate\x10\x07\x42\x11\n\x0f_tagged_metrics\"\xf4\x02\n\x17\x46lowTaggedMetricsFilter\x12\x14\n\x07include\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15include_empty_metrics\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x43\n\x0cmetric_names\x18\x03 \x03(\x0e\x32-.otg.FlowTaggedMetricsFilter.MetricNames.Enum\x12)\n\x07\x66ilters\x18\x04 \x03(\x0b\x32\x18.otg.FlowMetricTagFilter\x1a\x88\x01\n\x0bMetricNames\"y\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tframes_tx\x10\x01\x12\r\n\tframes_rx\x10\x02\x12\x0c\n\x08\x62ytes_tx\x10\x03\x12\x0c\n\x08\x62ytes_rx\x10\x04\x12\x12\n\x0e\x66rames_tx_rate\x10\x05\x12\x12\n\x0e\x66rames_rx_rate\x10\x06\x42\n\n\x08_includeB\x18\n\x16_include_empty_metrics\"A\n\x13\x46lowMetricTagFilter\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x06values\x18\x02 \x03(\tB\x07\n\x05_name\"\xad\x05\n\nFlowMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07port_tx\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07port_rx\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x34\n\x08transmit\x18\x05 \x01(\x0e\x32\x1d.otg.FlowMetric.Transmit.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x06 \x01(\x03H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x07 \x01(\x03H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x08 \x01(\x03H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\t \x01(\x03H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\n \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\x0b \x01(\x02H\t\x88\x01\x01\x12\x11\n\x04loss\x18\x0c \x01(\x02H\n\x88\x01\x01\x12-\n\ntimestamps\x18\r \x01(\x0b\x32\x14.otg.MetricTimestampH\x0b\x88\x01\x01\x12(\n\x07latency\x18\x0e \x01(\x0b\x32\x12.otg.MetricLatencyH\x0c\x88\x01\x01\x12-\n\x0etagged_metrics\x18\x0f \x03(\x0b\x32\x15.otg.FlowTaggedMetric\x1aI\n\x08Transmit\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x12\n\n\x06paused\x10\x03\x42\x07\n\x05_nameB\n\n\x08_port_txB\n\n\x08_port_rxB\x0b\n\t_transmitB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x07\n\x05_lossB\r\n\x0b_timestampsB\n\n\x08_latency\"\xb8\x03\n\x10\x46lowTaggedMetric\x12 \n\x04tags\x18\x01 \x03(\x0b\x32\x12.otg.FlowMetricTag\x12\x16\n\tframes_tx\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x16\n\tframes_rx\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x04 \x01(\x04H\x02\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x05 \x01(\x04H\x03\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\x06 \x01(\x02H\x04\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\x07 \x01(\x02H\x05\x88\x01\x01\x12\x11\n\x04loss\x18\x08 \x01(\x02H\x06\x88\x01\x01\x12-\n\ntimestamps\x18\t \x01(\x0b\x32\x14.otg.MetricTimestampH\x07\x88\x01\x01\x12(\n\x07latency\x18\n \x01(\x0b\x32\x12.otg.MetricLatencyH\x08\x88\x01\x01\x42\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x07\n\x05_lossB\r\n\x0b_timestampsB\n\n\x08_latency\"b\n\rFlowMetricTag\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x17.otg.FlowMetricTagValueH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\"\xc2\x01\n\x12\x46lowMetricTagValue\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.FlowMetricTagValue.Choice.EnumH\x00\x88\x01\x01\x12\x10\n\x03hex\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03str\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\x33\n\x06\x43hoice\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03hex\x10\x01\x12\x07\n\x03str\x10\x02\x42\t\n\x07_choiceB\x06\n\x04_hexB\x06\n\x04_str\"\x7f\n\x0fMetricTimestamp\x12\x1f\n\x12\x66irst_timestamp_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1e\n\x11last_timestamp_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x42\x15\n\x13_first_timestamp_nsB\x14\n\x12_last_timestamp_ns\"\x87\x01\n\rMetricLatency\x12\x17\n\nminimum_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x17\n\nmaximum_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x17\n\naverage_ns\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\r\n\x0b_minimum_nsB\r\n\x0b_maximum_nsB\r\n\x0b_average_ns\"\xf9\x03\n\x13\x42gpv4MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv4MetricsRequest.ColumnNames.Enum\x1a\x8c\x03\n\x0b\x43olumnNames\"\xfc\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\x12\r\n\tfsm_state\x10\x0f\x12\x17\n\x13\x65nd_of_rib_received\x10\x10\"\xea\x08\n\x0b\x42gpv4Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv4Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x05H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x05H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x12\x36\n\tfsm_state\x18\x10 \x01(\x0e\x32\x1e.otg.Bgpv4Metric.FsmState.EnumH\x0f\x88\x01\x01\x12 \n\x13\x65nd_of_rib_received\x18\x11 \x01(\x04H\x10\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1av\n\x08\x46smState\"j\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04idle\x10\x01\x12\x0b\n\x07\x63onnect\x10\x02\x12\n\n\x06\x61\x63tive\x10\x03\x12\x0c\n\x08opensent\x10\x04\x12\x0f\n\x0bopenconfirm\x10\x05\x12\x0f\n\x0b\x65stablished\x10\x06\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_receivedB\x0c\n\n_fsm_stateB\x16\n\x14_end_of_rib_received\"\xf9\x03\n\x13\x42gpv6MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv6MetricsRequest.ColumnNames.Enum\x1a\x8c\x03\n\x0b\x43olumnNames\"\xfc\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\x12\r\n\tfsm_state\x10\x0f\x12\x17\n\x13\x65nd_of_rib_received\x10\x10\"\xea\x08\n\x0b\x42gpv6Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv6Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x05H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x05H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x12\x36\n\tfsm_state\x18\x10 \x01(\x0e\x32\x1e.otg.Bgpv6Metric.FsmState.EnumH\x0f\x88\x01\x01\x12 \n\x13\x65nd_of_rib_received\x18\x11 \x01(\x04H\x10\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1av\n\x08\x46smState\"j\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04idle\x10\x01\x12\x0b\n\x07\x63onnect\x10\x02\x12\n\n\x06\x61\x63tive\x10\x03\x12\x0c\n\x08opensent\x10\x04\x12\x0f\n\x0bopenconfirm\x10\x05\x12\x0f\n\x0b\x65stablished\x10\x06\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_receivedB\x0c\n\n_fsm_stateB\x16\n\x14_end_of_rib_received\"\x92\x06\n\x12IsisMetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.IsisMetricsRequest.ColumnNames.Enum\x1a\xa5\x05\n\x0b\x43olumnNames\"\x95\x05\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0el1_sessions_up\x10\x01\x12\x13\n\x0fl1_session_flap\x10\x02\x12\x14\n\x10l1_database_size\x10\x03\x12\x1c\n\x18l1_broadcast_hellos_sent\x10\x04\x12 \n\x1cl1_broadcast_hellos_received\x10\x05\x12!\n\x1dl1_point_to_point_hellos_sent\x10\x06\x12%\n!l1_point_to_point_hellos_received\x10\x07\x12\x10\n\x0cl1_psnp_sent\x10\x08\x12\x14\n\x10l1_psnp_received\x10\t\x12\x10\n\x0cl1_csnp_sent\x10\n\x12\x14\n\x10l1_csnp_received\x10\x0b\x12\x0f\n\x0bl1_lsp_sent\x10\x0c\x12\x13\n\x0fl1_lsp_received\x10\r\x12\x12\n\x0el2_sessions_up\x10\x0e\x12\x13\n\x0fl2_session_flap\x10\x0f\x12\x14\n\x10l2_database_size\x10\x10\x12\x1c\n\x18l2_broadcast_hellos_sent\x10\x11\x12 \n\x1cl2_broadcast_hellos_received\x10\x12\x12!\n\x1dl2_point_to_point_hellos_sent\x10\x13\x12%\n!l2_point_to_point_hellos_received\x10\x14\x12\x10\n\x0cl2_psnp_sent\x10\x15\x12\x14\n\x10l2_psnp_received\x10\x16\x12\x10\n\x0cl2_csnp_sent\x10\x17\x12\x14\n\x10l2_csnp_received\x10\x18\x12\x0f\n\x0bl2_lsp_sent\x10\x19\x12\x13\n\x0fl2_lsp_received\x10\x1a\"\xf4\x0b\n\nIsisMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0el1_sessions_up\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1c\n\x0fl1_session_flap\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12%\n\x18l1_broadcast_hellos_sent\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12)\n\x1cl1_broadcast_hellos_received\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12*\n\x1dl1_point_to_point_hellos_sent\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12.\n!l1_point_to_point_hellos_received\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x1d\n\x10l1_database_size\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x19\n\x0cl1_psnp_sent\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x1d\n\x10l1_psnp_received\x18\n \x01(\x05H\t\x88\x01\x01\x12\x19\n\x0cl1_csnp_sent\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1d\n\x10l1_csnp_received\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12\x18\n\x0bl1_lsp_sent\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1c\n\x0fl1_lsp_received\x18\x0e \x01(\x05H\r\x88\x01\x01\x12\x1b\n\x0el2_sessions_up\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x12\x1c\n\x0fl2_session_flap\x18\x10 \x01(\x05H\x0f\x88\x01\x01\x12%\n\x18l2_broadcast_hellos_sent\x18\x11 \x01(\x05H\x10\x88\x01\x01\x12)\n\x1cl2_broadcast_hellos_received\x18\x12 \x01(\x05H\x11\x88\x01\x01\x12*\n\x1dl2_point_to_point_hellos_sent\x18\x13 \x01(\x05H\x12\x88\x01\x01\x12.\n!l2_point_to_point_hellos_received\x18\x14 \x01(\x05H\x13\x88\x01\x01\x12\x1d\n\x10l2_database_size\x18\x15 \x01(\x05H\x14\x88\x01\x01\x12\x19\n\x0cl2_psnp_sent\x18\x16 \x01(\x05H\x15\x88\x01\x01\x12\x1d\n\x10l2_psnp_received\x18\x17 \x01(\x05H\x16\x88\x01\x01\x12\x19\n\x0cl2_csnp_sent\x18\x18 \x01(\x05H\x17\x88\x01\x01\x12\x1d\n\x10l2_csnp_received\x18\x19 \x01(\x05H\x18\x88\x01\x01\x12\x18\n\x0bl2_lsp_sent\x18\x1a \x01(\x05H\x19\x88\x01\x01\x12\x1c\n\x0fl2_lsp_received\x18\x1b \x01(\x05H\x1a\x88\x01\x01\x42\x07\n\x05_nameB\x11\n\x0f_l1_sessions_upB\x12\n\x10_l1_session_flapB\x1b\n\x19_l1_broadcast_hellos_sentB\x1f\n\x1d_l1_broadcast_hellos_receivedB \n\x1e_l1_point_to_point_hellos_sentB$\n\"_l1_point_to_point_hellos_receivedB\x13\n\x11_l1_database_sizeB\x0f\n\r_l1_psnp_sentB\x13\n\x11_l1_psnp_receivedB\x0f\n\r_l1_csnp_sentB\x13\n\x11_l1_csnp_receivedB\x0e\n\x0c_l1_lsp_sentB\x12\n\x10_l1_lsp_receivedB\x11\n\x0f_l2_sessions_upB\x12\n\x10_l2_session_flapB\x1b\n\x19_l2_broadcast_hellos_sentB\x1f\n\x1d_l2_broadcast_hellos_receivedB \n\x1e_l2_point_to_point_hellos_sentB$\n\"_l2_point_to_point_hellos_receivedB\x13\n\x11_l2_database_sizeB\x0f\n\r_l2_psnp_sentB\x13\n\x11_l2_psnp_receivedB\x0f\n\r_l2_csnp_sentB\x13\n\x11_l2_csnp_receivedB\x0e\n\x0c_l2_lsp_sentB\x12\n\x10_l2_lsp_received\"\xbd\x02\n\x11LagMetricsRequest\x12\x11\n\tlag_names\x18\x01 \x03(\t\x12=\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32\'.otg.LagMetricsRequest.ColumnNames.Enum\x1a\xd5\x01\n\x0b\x43olumnNames\"\xc5\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0f\n\x0boper_status\x10\x01\x12\x13\n\x0fmember_ports_up\x10\x02\x12\r\n\tframes_tx\x10\x03\x12\r\n\tframes_rx\x10\x04\x12\x0c\n\x08\x62ytes_tx\x10\x05\x12\x0c\n\x08\x62ytes_rx\x10\x06\x12\x12\n\x0e\x66rames_tx_rate\x10\x07\x12\x12\n\x0e\x66rames_rx_rate\x10\x08\x12\x11\n\rbytes_tx_rate\x10\t\x12\x11\n\rbytes_rx_rate\x10\n\"\xac\x04\n\tLagMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x38\n\x0boper_status\x18\x02 \x01(\x0e\x32\x1e.otg.LagMetric.OperStatus.EnumH\x01\x88\x01\x01\x12\x1c\n\x0fmember_ports_up\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x16\n\tframes_tx\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x16\n\tframes_rx\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x06 \x01(\x03H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x07 \x01(\x03H\x06\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\x08 \x01(\x02H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x1a\n\rbytes_tx_rate\x18\n \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rbytes_rx_rate\x18\x0b \x01(\x02H\n\x88\x01\x01\x1a\x37\n\nOperStatus\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x0e\n\x0c_oper_statusB\x12\n\x10_member_ports_upB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x10\n\x0e_bytes_tx_rateB\x10\n\x0e_bytes_rx_rate\"\xb4\x03\n\x12LacpMetricsRequest\x12\x11\n\tlag_names\x18\x01 \x03(\t\x12\x1d\n\x15lag_member_port_names\x18\x02 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x03 \x03(\x0e\x32(.otg.LacpMetricsRequest.ColumnNames.Enum\x1a\xab\x02\n\x0b\x43olumnNames\"\x9b\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x13\n\x0flacp_packets_rx\x10\x01\x12\x13\n\x0flacp_packets_tx\x10\x02\x12\x12\n\x0elacp_rx_errors\x10\x03\x12\x0c\n\x08\x61\x63tivity\x10\x04\x12\x0b\n\x07timeout\x10\x05\x12\x13\n\x0fsynchronization\x10\x06\x12\x10\n\x0c\x61ggregatable\x10\x07\x12\x0e\n\ncollecting\x10\x08\x12\x10\n\x0c\x64istributing\x10\t\x12\r\n\tsystem_id\x10\n\x12\x0c\n\x08oper_key\x10\x0b\x12\x0e\n\npartner_id\x10\x0c\x12\x0f\n\x0bpartner_key\x10\r\x12\x0c\n\x08port_num\x10\x0e\x12\x14\n\x10partner_port_num\x10\x0f\"\x8d\x08\n\nLacpMetric\x12\x15\n\x08lag_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12!\n\x14lag_member_port_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0flacp_packets_rx\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x1c\n\x0flacp_packets_tx\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x1b\n\x0elacp_rx_errors\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x34\n\x08\x61\x63tivity\x18\x06 \x01(\x0e\x32\x1d.otg.LacpMetric.Activity.EnumH\x05\x88\x01\x01\x12\x32\n\x07timeout\x18\x07 \x01(\x0e\x32\x1c.otg.LacpMetric.Timeout.EnumH\x06\x88\x01\x01\x12\x42\n\x0fsynchronization\x18\x08 \x01(\x0e\x32$.otg.LacpMetric.Synchronization.EnumH\x07\x88\x01\x01\x12\x19\n\x0c\x61ggregatable\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x17\n\ncollecting\x18\n \x01(\x08H\t\x88\x01\x01\x12\x19\n\x0c\x64istributing\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x16\n\tsystem_id\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x15\n\x08oper_key\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x17\n\npartner_id\x18\x0e \x01(\tH\r\x88\x01\x01\x12\x18\n\x0bpartner_key\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x12\x15\n\x08port_num\x18\x10 \x01(\x05H\x0f\x88\x01\x01\x12\x1d\n\x10partner_port_num\x18\x11 \x01(\x05H\x10\x88\x01\x01\x1a<\n\x08\x41\x63tivity\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61\x63tive\x10\x01\x12\x0b\n\x07passive\x10\x02\x1a\x37\n\x07Timeout\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05short\x10\x01\x12\x08\n\x04long\x10\x02\x1a\x45\n\x0fSynchronization\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07in_sync\x10\x01\x12\x0c\n\x08out_sync\x10\x02\x42\x0b\n\t_lag_nameB\x17\n\x15_lag_member_port_nameB\x12\n\x10_lacp_packets_rxB\x12\n\x10_lacp_packets_txB\x11\n\x0f_lacp_rx_errorsB\x0b\n\t_activityB\n\n\x08_timeoutB\x12\n\x10_synchronizationB\x0f\n\r_aggregatableB\r\n\x0b_collectingB\x0f\n\r_distributingB\x0c\n\n_system_idB\x0b\n\t_oper_keyB\r\n\x0b_partner_idB\x0e\n\x0c_partner_keyB\x0b\n\t_port_numB\x13\n\x11_partner_port_num\"\xfd\x01\n\x12LldpMetricsRequest\x12\x12\n\nlldp_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.LldpMetricsRequest.ColumnNames.Enum\x1a\x92\x01\n\x0b\x43olumnNames\"\x82\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tframes_rx\x10\x01\x12\r\n\tframes_tx\x10\x02\x12\x13\n\x0f\x66rames_error_rx\x10\x03\x12\x12\n\x0e\x66rames_discard\x10\x04\x12\x10\n\x0ctlvs_discard\x10\x05\x12\x10\n\x0ctlvs_unknown\x10\x06\"\xae\x02\n\nLldpMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tframes_rx\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x16\n\tframes_tx\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x1c\n\x0f\x66rames_error_rx\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x1b\n\x0e\x66rames_discard\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x19\n\x0ctlvs_discard\x18\x06 \x01(\x03H\x05\x88\x01\x01\x12\x19\n\x0ctlvs_unknown\x18\x07 \x01(\x03H\x06\x88\x01\x01\x42\x07\n\x05_nameB\x0c\n\n_frames_rxB\x0c\n\n_frames_txB\x12\n\x10_frames_error_rxB\x11\n\x0f_frames_discardB\x0f\n\r_tlvs_discardB\x0f\n\r_tlvs_unknown\"\xc2\x05\n\x12RsvpMetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.RsvpMetricsRequest.ColumnNames.Enum\x1a\xd5\x04\n\x0b\x43olumnNames\"\xc5\x04\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1f\n\x1bingress_p2p_lsps_configured\x10\x01\x12\x17\n\x13ingress_p2p_lsps_up\x10\x02\x12\x16\n\x12\x65gress_p2p_lsps_up\x10\x03\x12\x12\n\x0elsp_flap_count\x10\x04\x12\x0c\n\x08paths_tx\x10\x05\x12\x0c\n\x08paths_rx\x10\x06\x12\x0c\n\x08resvs_tx\x10\x07\x12\x0c\n\x08resvs_rx\x10\x08\x12\x11\n\rpath_tears_tx\x10\t\x12\x11\n\rpath_tears_rx\x10\n\x12\x11\n\rresv_tears_tx\x10\x0b\x12\x11\n\rresv_tears_rx\x10\x0c\x12\x12\n\x0epath_errors_tx\x10\r\x12\x12\n\x0epath_errors_rx\x10\x0e\x12\x12\n\x0eresv_errors_tx\x10\x0f\x12\x12\n\x0eresv_errors_rx\x10\x10\x12\x10\n\x0cresv_conf_tx\x10\x11\x12\x10\n\x0cresv_conf_rx\x10\x12\x12\r\n\thellos_tx\x10\x13\x12\r\n\thellos_rx\x10\x14\x12\x0b\n\x07\x61\x63ks_tx\x10\x15\x12\x0b\n\x07\x61\x63ks_rx\x10\x16\x12\x0c\n\x08nacks_tx\x10\x17\x12\x0c\n\x08nacks_rx\x10\x18\x12\x0f\n\x0bsrefresh_tx\x10\x19\x12\x0f\n\x0bsrefresh_rx\x10\x1a\x12\r\n\tbundle_tx\x10\x1b\x12\r\n\tbundle_rx\x10\x1c\x12 \n\x1cpath_reevaluation_request_tx\x10\x1d\x12\x18\n\x14path_reoptimizations\x10\x1e\"\xf4\n\n\nRsvpMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12(\n\x1bingress_p2p_lsps_configured\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12 \n\x13ingress_p2p_lsps_up\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1f\n\x12\x65gress_p2p_lsps_up\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1b\n\x0elsp_flap_count\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x15\n\x08paths_tx\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x15\n\x08paths_rx\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x15\n\x08resvs_tx\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x15\n\x08resvs_rx\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x1a\n\rpath_tears_tx\x18\n \x01(\x05H\t\x88\x01\x01\x12\x1a\n\rpath_tears_rx\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1a\n\rresv_tears_tx\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12\x1a\n\rresv_tears_rx\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1b\n\x0epath_errors_tx\x18\x0e \x01(\x05H\r\x88\x01\x01\x12\x1b\n\x0epath_errors_rx\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x12\x1b\n\x0eresv_errors_tx\x18\x10 \x01(\x05H\x0f\x88\x01\x01\x12\x1b\n\x0eresv_errors_rx\x18\x11 \x01(\x05H\x10\x88\x01\x01\x12\x19\n\x0cresv_conf_tx\x18\x12 \x01(\x05H\x11\x88\x01\x01\x12\x19\n\x0cresv_conf_rx\x18\x13 \x01(\x05H\x12\x88\x01\x01\x12\x16\n\thellos_tx\x18\x14 \x01(\x05H\x13\x88\x01\x01\x12\x16\n\thellos_rx\x18\x15 \x01(\x05H\x14\x88\x01\x01\x12\x14\n\x07\x61\x63ks_tx\x18\x16 \x01(\x05H\x15\x88\x01\x01\x12\x14\n\x07\x61\x63ks_rx\x18\x17 \x01(\x05H\x16\x88\x01\x01\x12\x15\n\x08nacks_tx\x18\x18 \x01(\x05H\x17\x88\x01\x01\x12\x15\n\x08nacks_rx\x18\x19 \x01(\x05H\x18\x88\x01\x01\x12\x18\n\x0bsrefresh_tx\x18\x1a \x01(\x05H\x19\x88\x01\x01\x12\x18\n\x0bsrefresh_rx\x18\x1b \x01(\x05H\x1a\x88\x01\x01\x12\x16\n\tbundle_tx\x18\x1c \x01(\x05H\x1b\x88\x01\x01\x12\x16\n\tbundle_rx\x18\x1d \x01(\x05H\x1c\x88\x01\x01\x12)\n\x1cpath_reevaluation_request_tx\x18\x1e \x01(\x05H\x1d\x88\x01\x01\x12!\n\x14path_reoptimizations\x18\x1f \x01(\x05H\x1e\x88\x01\x01\x42\x07\n\x05_nameB\x1e\n\x1c_ingress_p2p_lsps_configuredB\x16\n\x14_ingress_p2p_lsps_upB\x15\n\x13_egress_p2p_lsps_upB\x11\n\x0f_lsp_flap_countB\x0b\n\t_paths_txB\x0b\n\t_paths_rxB\x0b\n\t_resvs_txB\x0b\n\t_resvs_rxB\x10\n\x0e_path_tears_txB\x10\n\x0e_path_tears_rxB\x10\n\x0e_resv_tears_txB\x10\n\x0e_resv_tears_rxB\x11\n\x0f_path_errors_txB\x11\n\x0f_path_errors_rxB\x11\n\x0f_resv_errors_txB\x11\n\x0f_resv_errors_rxB\x0f\n\r_resv_conf_txB\x0f\n\r_resv_conf_rxB\x0c\n\n_hellos_txB\x0c\n\n_hellos_rxB\n\n\x08_acks_txB\n\n\x08_acks_rxB\x0b\n\t_nacks_txB\x0b\n\t_nacks_rxB\x0e\n\x0c_srefresh_txB\x0e\n\x0c_srefresh_rxB\x0c\n\n_bundle_txB\x0c\n\n_bundle_rxB\x1f\n\x1d_path_reevaluation_request_txB\x17\n\x15_path_reoptimizations\"\x98\x05\n\rStatesRequest\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.StatesRequest.Choice.EnumH\x00\x88\x01\x01\x12:\n\x0eipv4_neighbors\x18\x02 \x01(\x0b\x32\x1d.otg.Neighborsv4StatesRequestH\x01\x88\x01\x01\x12:\n\x0eipv6_neighbors\x18\x03 \x01(\x0b\x32\x1d.otg.Neighborsv6StatesRequestH\x02\x88\x01\x01\x12\x35\n\x0c\x62gp_prefixes\x18\x04 \x01(\x0b\x32\x1a.otg.BgpPrefixStateRequestH\x03\x88\x01\x01\x12\x31\n\tisis_lsps\x18\x05 \x01(\x0b\x32\x19.otg.IsisLspsStateRequestH\x04\x88\x01\x01\x12;\n\x0elldp_neighbors\x18\x06 \x01(\x0b\x32\x1e.otg.LldpNeighborsStateRequestH\x05\x88\x01\x01\x12\x31\n\trsvp_lsps\x18\x07 \x01(\x0b\x32\x19.otg.RsvpLspsStateRequestH\x06\x88\x01\x01\x1a\x8e\x01\n\x06\x43hoice\"\x83\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x12\x10\n\x0c\x62gp_prefixes\x10\x03\x12\r\n\tisis_lsps\x10\x04\x12\x12\n\x0elldp_neighbors\x10\x05\x12\r\n\trsvp_lsps\x10\x06\x42\t\n\x07_choiceB\x11\n\x0f_ipv4_neighborsB\x11\n\x0f_ipv6_neighborsB\x0f\n\r_bgp_prefixesB\x0c\n\n_isis_lspsB\x11\n\x0f_lldp_neighborsB\x0c\n\n_rsvp_lsps\"\xec\x03\n\x0eStatesResponse\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.StatesResponse.Choice.EnumH\x00\x88\x01\x01\x12-\n\x0eipv4_neighbors\x18\x02 \x03(\x0b\x32\x15.otg.Neighborsv4State\x12-\n\x0eipv6_neighbors\x18\x03 \x03(\x0b\x32\x15.otg.Neighborsv6State\x12+\n\x0c\x62gp_prefixes\x18\x04 \x03(\x0b\x32\x15.otg.BgpPrefixesState\x12%\n\tisis_lsps\x18\x05 \x03(\x0b\x32\x12.otg.IsisLspsState\x12/\n\x0elldp_neighbors\x18\x06 \x03(\x0b\x32\x17.otg.LldpNeighborsState\x12%\n\trsvp_lsps\x18\x07 \x03(\x0b\x32\x12.otg.RsvpLspsState\x1a\x8e\x01\n\x06\x43hoice\"\x83\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x12\x10\n\x0c\x62gp_prefixes\x10\x03\x12\r\n\tisis_lsps\x10\x04\x12\x12\n\x0elldp_neighbors\x10\x05\x12\r\n\trsvp_lsps\x10\x06\x42\t\n\x07_choice\"2\n\x18Neighborsv4StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"w\n\x10Neighborsv4State\x12\x15\n\rethernet_name\x18\x01 \x01(\t\x12\x14\n\x0cipv4_address\x18\x02 \x01(\t\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x15\n\x13_link_layer_address\"2\n\x18Neighborsv6StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"w\n\x10Neighborsv6State\x12\x15\n\rethernet_name\x18\x01 \x01(\t\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x15\n\x13_link_layer_address\"\xc2\x02\n\x15\x42gpPrefixStateRequest\x12\x16\n\x0e\x62gp_peer_names\x18\x01 \x03(\t\x12\x45\n\x0eprefix_filters\x18\x02 \x03(\x0e\x32-.otg.BgpPrefixStateRequest.PrefixFilters.Enum\x12=\n\x14ipv4_unicast_filters\x18\x03 \x03(\x0b\x32\x1f.otg.BgpPrefixIpv4UnicastFilter\x12=\n\x14ipv6_unicast_filters\x18\x04 \x03(\x0b\x32\x1f.otg.BgpPrefixIpv6UnicastFilter\x1aL\n\rPrefixFilters\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0cipv4_unicast\x10\x01\x12\x10\n\x0cipv6_unicast\x10\x02\"\x91\x02\n\x1a\x42gpPrefixIpv4UnicastFilter\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x1a\n\rprefix_length\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12@\n\x06origin\x18\x03 \x01(\x0e\x32+.otg.BgpPrefixIpv4UnicastFilter.Origin.EnumH\x01\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\x05H\x02\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_id\"\x91\x02\n\x1a\x42gpPrefixIpv6UnicastFilter\x12\x11\n\taddresses\x18\x01 \x03(\t\x12\x1a\n\rprefix_length\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12@\n\x06origin\x18\x03 \x01(\x0e\x32+.otg.BgpPrefixIpv6UnicastFilter.Origin.EnumH\x01\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\x05H\x02\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_id\"\xbe\x01\n\x10\x42gpPrefixesState\x12\x1a\n\rbgp_peer_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12=\n\x15ipv4_unicast_prefixes\x18\x02 \x03(\x0b\x32\x1e.otg.BgpPrefixIpv4UnicastState\x12=\n\x15ipv6_unicast_prefixes\x18\x03 \x03(\x0b\x32\x1e.otg.BgpPrefixIpv6UnicastStateB\x10\n\x0e_bgp_peer_name\"\xe2\x04\n\x19\x42gpPrefixIpv4UnicastState\x12\x19\n\x0cipv4_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12?\n\x06origin\x18\x03 \x01(\x0e\x32*.otg.BgpPrefixIpv4UnicastState.Origin.EnumH\x02\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1a\n\ripv4_next_hop\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\ripv6_next_hop\x18\x06 \x01(\tH\x05\x88\x01\x01\x12,\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x17.otg.ResultBgpCommunity\x12*\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x14.otg.ResultBgpAsPathH\x06\x88\x01\x01\x12\x1d\n\x10local_preference\x18\t \x01(\rH\x07\x88\x01\x01\x12%\n\x18multi_exit_discriminator\x18\n \x01(\rH\x08\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_idB\x10\n\x0e_ipv4_next_hopB\x10\n\x0e_ipv6_next_hopB\n\n\x08_as_pathB\x13\n\x11_local_preferenceB\x1b\n\x19_multi_exit_discriminator\"\xe2\x04\n\x19\x42gpPrefixIpv6UnicastState\x12\x19\n\x0cipv6_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12?\n\x06origin\x18\x03 \x01(\x0e\x32*.otg.BgpPrefixIpv6UnicastState.Origin.EnumH\x02\x88\x01\x01\x12\x14\n\x07path_id\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1a\n\ripv4_next_hop\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1a\n\ripv6_next_hop\x18\x06 \x01(\tH\x05\x88\x01\x01\x12,\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x17.otg.ResultBgpCommunity\x12*\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x14.otg.ResultBgpAsPathH\x06\x88\x01\x01\x12\x1d\n\x10local_preference\x18\t \x01(\rH\x07\x88\x01\x01\x12%\n\x18multi_exit_discriminator\x18\n \x01(\rH\x08\x88\x01\x01\x1a\x43\n\x06Origin\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x12\x0e\n\nincomplete\x10\x03\x42\x0f\n\r_ipv6_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_originB\n\n\x08_path_idB\x10\n\x0e_ipv4_next_hopB\x10\n\x0e_ipv6_next_hopB\n\n\x08_as_pathB\x13\n\x11_local_preferenceB\x1b\n\x19_multi_exit_discriminator\"\xb0\x02\n\x12ResultBgpCommunity\x12\x34\n\x04type\x18\x01 \x01(\x0e\x32!.otg.ResultBgpCommunity.Type.EnumH\x00\x88\x01\x01\x12\x16\n\tas_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\tas_custom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a\x8e\x01\n\x04Type\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10manual_as_number\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\x07\n\x05_typeB\x0c\n\n_as_numberB\x0c\n\n_as_custom\"@\n\x0fResultBgpAsPath\x12-\n\x08segments\x18\x01 \x03(\x0b\x32\x1b.otg.ResultBgpAsPathSegment\"\xce\x01\n\x16ResultBgpAsPathSegment\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32%.otg.ResultBgpAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\x03\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\"1\n\x14IsisLspsStateRequest\x12\x19\n\x11isis_router_names\x18\x01 \x03(\t\"d\n\rIsisLspsState\x12\x1d\n\x10isis_router_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x04lsps\x18\x02 \x03(\x0b\x32\x11.otg.IsisLspStateB\x13\n\x11_isis_router_name\"\xb3\x03\n\x0cIsisLspState\x12\x0e\n\x06lsp_id\x18\x01 \x01(\t\x12\x35\n\x08pdu_type\x18\x02 \x01(\x0e\x32\x1e.otg.IsisLspState.PduType.EnumH\x00\x88\x01\x01\x12\x1f\n\x12remaining_lifetime\x18\x03 \x01(\x03H\x01\x88\x01\x01\x12\x1c\n\x0fsequence_number\x18\x04 \x01(\x03H\x02\x88\x01\x01\x12\x17\n\npdu_length\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12%\n\x05\x66lags\x18\x06 \x01(\x0b\x32\x11.otg.IsisLspFlagsH\x04\x88\x01\x01\x12\x14\n\x07is_type\x18\x07 \x01(\x05H\x05\x88\x01\x01\x12#\n\x04tlvs\x18\x08 \x01(\x0b\x32\x10.otg.IsisLspTlvsH\x06\x88\x01\x01\x1a<\n\x07PduType\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x42\x0b\n\t_pdu_typeB\x15\n\x13_remaining_lifetimeB\x12\n\x10_sequence_numberB\r\n\x0b_pdu_lengthB\x08\n\x06_flagsB\n\n\x08_is_typeB\x07\n\x05_tlvs\"\xfc\x03\n\x0bIsisLspTlvs\x12+\n\rhostname_tlvs\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspHostname\x12;\n\x14is_reachability_tlvs\x18\x02 \x03(\x0b\x32\x1d.otg.IsisLspIsReachabilityTlv\x12L\n\x1d\x65xtended_is_reachability_tlvs\x18\x03 \x03(\x0b\x32%.otg.IsisLspExtendedIsReachabilityTlv\x12P\n\x1fipv4_internal_reachability_tlvs\x18\x04 \x03(\x0b\x32\'.otg.IsisLspIpv4InternalReachabilityTlv\x12P\n\x1fipv4_external_reachability_tlvs\x18\x05 \x03(\x0b\x32\'.otg.IsisLspIpv4ExternalReachabilityTlv\x12P\n\x1f\x65xtended_ipv4_reachability_tlvs\x18\x06 \x03(\x0b\x32\'.otg.IsisLspExtendedIpv4ReachabilityTlv\x12?\n\x16ipv6_reachability_tlvs\x18\x07 \x03(\x0b\x32\x1f.otg.IsisLspIpv6ReachabilityTlv\"5\n\x0fIsisLspHostname\x12\x15\n\x08hostname\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_hostname\"\xae\x02\n\x0cIsisLspFlags\x12\x1d\n\x10partition_repair\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0e\x61ttached_error\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1d\n\x10\x61ttached_expense\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1b\n\x0e\x61ttached_delay\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1d\n\x10\x61ttached_default\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08overload\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\x13\n\x11_partition_repairB\x11\n\x0f_attached_errorB\x13\n\x11_attached_expenseB\x11\n\x0f_attached_delayB\x13\n\x11_attached_defaultB\x0b\n\t_overload\"C\n\x18IsisLspIsReachabilityTlv\x12\'\n\tneighbors\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspneighbor\"K\n IsisLspExtendedIsReachabilityTlv\x12\'\n\tneighbors\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspneighbor\"7\n\x0fIsisLspneighbor\x12\x16\n\tsystem_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_system_id\"L\n\"IsisLspIpv4InternalReachabilityTlv\x12&\n\x08prefixes\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspV4Prefix\"L\n\"IsisLspIpv4ExternalReachabilityTlv\x12&\n\x08prefixes\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspV4Prefix\"\xd7\x03\n\x0fIsisLspV4Prefix\x12\x19\n\x0cipv4_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12N\n\x13redistribution_type\x18\x03 \x01(\x0e\x32,.otg.IsisLspV4Prefix.RedistributionType.EnumH\x02\x88\x01\x01\x12\x1b\n\x0e\x64\x65\x66\x61ult_metric\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12>\n\x0borigin_type\x18\x05 \x01(\x0e\x32$.otg.IsisLspV4Prefix.OriginType.EnumH\x04\x88\x01\x01\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x42\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\x16\n\x14_redistribution_typeB\x11\n\x0f_default_metricB\x0e\n\x0c_origin_type\"T\n\"IsisLspExtendedIpv4ReachabilityTlv\x12.\n\x08prefixes\x18\x01 \x03(\x0b\x32\x1c.otg.IsisLspExtendedV4Prefix\"\x98\x03\n\x17IsisLspExtendedV4Prefix\x12\x19\n\x0cipv4_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12V\n\x13redistribution_type\x18\x04 \x01(\x0e\x32\x34.otg.IsisLspExtendedV4Prefix.RedistributionType.EnumH\x03\x88\x01\x01\x12<\n\x11prefix_attributes\x18\x05 \x01(\x0b\x32\x1c.otg.IsisLspPrefixAttributesH\x04\x88\x01\x01\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0f\n\r_ipv4_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_metricB\x16\n\x14_redistribution_typeB\x14\n\x12_prefix_attributes\"D\n\x1aIsisLspIpv6ReachabilityTlv\x12&\n\x08prefixes\x18\x01 \x03(\x0b\x32\x14.otg.IsisLspV6Prefix\"\x9b\x04\n\x0fIsisLspV6Prefix\x12\x19\n\x0cipv6_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rprefix_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x13\n\x06metric\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12N\n\x13redistribution_type\x18\x04 \x01(\x0e\x32,.otg.IsisLspV6Prefix.RedistributionType.EnumH\x03\x88\x01\x01\x12>\n\x0borigin_type\x18\x05 \x01(\x0e\x32$.otg.IsisLspV6Prefix.OriginType.EnumH\x04\x88\x01\x01\x12<\n\x11prefix_attributes\x18\x06 \x01(\x0b\x32\x1c.otg.IsisLspPrefixAttributesH\x05\x88\x01\x01\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x42\x0f\n\r_ipv6_addressB\x10\n\x0e_prefix_lengthB\t\n\x07_metricB\x16\n\x14_redistribution_typeB\x0e\n\x0c_origin_typeB\x14\n\x12_prefix_attributes\"y\n\x17IsisLspPrefixAttributes\x12\x13\n\x06x_flag\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06r_flag\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06n_flag\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"L\n\x19LldpNeighborsStateRequest\x12\x12\n\nlldp_names\x18\x01 \x03(\t\x12\x1b\n\x13neighbor_id_filters\x18\x02 \x03(\t\"\x8b\t\n\x12LldpNeighborsState\x12\x16\n\tlldp_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bsystem_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12system_description\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nchassis_id\x18\x04 \x01(\tH\x03\x88\x01\x01\x12H\n\x0f\x63hassis_id_type\x18\x05 \x01(\x0e\x32*.otg.LldpNeighborsState.ChassisIdType.EnumH\x04\x88\x01\x01\x12\x18\n\x0bneighbor_id\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x10\n\x03\x61ge\x18\x07 \x01(\x03H\x06\x88\x01\x01\x12\x18\n\x0blast_update\x18\x08 \x01(\x03H\x07\x88\x01\x01\x12\x10\n\x03ttl\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x14\n\x07port_id\x18\n \x01(\tH\t\x88\x01\x01\x12\x42\n\x0cport_id_type\x18\x0b \x01(\x0e\x32\'.otg.LldpNeighborsState.PortIdType.EnumH\n\x88\x01\x01\x12\x1d\n\x10port_description\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x1f\n\x12management_address\x18\r \x01(\tH\x0c\x88\x01\x01\x12$\n\x17management_address_type\x18\x0e \x01(\tH\r\x88\x01\x01\x12,\n\x0b\x63ustom_tlvs\x18\x0f \x03(\x0b\x32\x17.otg.LldpCustomTLVState\x12.\n\x0c\x63\x61pabilities\x18\x10 \x03(\x0b\x32\x18.otg.LldpCapabilityState\x1a\xae\x01\n\rChassisIdType\"\x9c\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eport_component\x10\x01\x12\x13\n\x0fnetwork_address\x10\x02\x12\x15\n\x11\x63hassis_component\x10\x03\x12\x0f\n\x0bmac_address\x10\x04\x12\x12\n\x0einterface_name\x10\x05\x12\t\n\x05local\x10\x06\x12\x13\n\x0finterface_alias\x10\x07\x1a\xaa\x01\n\nPortIdType\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eport_component\x10\x01\x12\x13\n\x0fnetwork_address\x10\x02\x12\x14\n\x10\x61gent_circuit_id\x10\x03\x12\x0f\n\x0bmac_address\x10\x04\x12\x12\n\x0einterface_name\x10\x05\x12\t\n\x05local\x10\x06\x12\x13\n\x0finterface_alias\x10\x07\x42\x0c\n\n_lldp_nameB\x0e\n\x0c_system_nameB\x15\n\x13_system_descriptionB\r\n\x0b_chassis_idB\x12\n\x10_chassis_id_typeB\x0e\n\x0c_neighbor_idB\x06\n\x04_ageB\x0e\n\x0c_last_updateB\x06\n\x04_ttlB\n\n\x08_port_idB\x0f\n\r_port_id_typeB\x13\n\x11_port_descriptionB\x15\n\x13_management_addressB\x1a\n\x18_management_address_type\"\x82\x01\n\x12LldpCustomTLVState\x12\x18\n\x0b\x63ustom_type\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03oui\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0boui_subtype\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0e\n\x0c_custom_typeB\x06\n\x04_ouiB\x0e\n\x0c_oui_subtype\"\x90\x03\n\x13LldpCapabilityState\x12J\n\x0f\x63\x61pability_name\x18\x01 \x01(\x0e\x32,.otg.LldpCapabilityState.CapabilityName.EnumH\x00\x88\x01\x01\x12\x1f\n\x12\x63\x61pability_enabled\x18\x02 \x01(\x08H\x01\x88\x01\x01\x1a\xe0\x01\n\x0e\x43\x61pabilityName\"\xcd\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nmac_bridge\x10\x01\x12\x16\n\x12two_port_mac_relay\x10\x02\x12\x0c\n\x08repeater\x10\x03\x12\x17\n\x13\x64ocsis_cable_device\x10\x04\x12\n\n\x06s_vlan\x10\x05\x12\r\n\ttelephone\x10\x06\x12\t\n\x05other\x10\x07\x12\n\n\x06router\x10\x08\x12\n\n\x06\x63_vlan\x10\t\x12\x10\n\x0cstation_only\x10\n\x12\x15\n\x11wlan_access_point\x10\x0b\x42\x12\n\x10_capability_nameB\x15\n\x13_capability_enabled\"1\n\x14RsvpLspsStateRequest\x12\x19\n\x11rsvp_router_names\x18\x01 \x03(\t\"m\n\rRsvpLspsState\x12\x1d\n\x10rsvp_router_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12(\n\tipv4_lsps\x18\x02 \x03(\x0b\x32\x15.otg.RsvpIPv4LspStateB\x13\n\x11_rsvp_router_name\"\xef\x01\n\x10RsvpIPv4LspState\x12\x1b\n\x0esource_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x13\x64\x65stination_address\x18\x02 \x01(\tH\x01\x88\x01\x01\x12#\n\x03lsp\x18\x03 \x01(\x0b\x32\x11.otg.RsvpLspStateH\x02\x88\x01\x01\x12!\n\x04rros\x18\x04 \x03(\x0b\x32\x13.otg.RsvpLspIpv4Rro\x12!\n\x04\x65ros\x18\x05 \x03(\x0b\x32\x13.otg.RsvpLspIpv4EroB\x11\n\x0f_source_addressB\x16\n\x14_destination_addressB\x06\n\x04_lsp\"\xb4\x04\n\x0cRsvpLspState\x12\x16\n\ttunnel_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06lsp_id\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x0csession_name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x15\n\x08label_in\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x16\n\tlabel_out\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x41\n\x0esession_status\x18\x06 \x01(\x0e\x32$.otg.RsvpLspState.SessionStatus.EnumH\x05\x88\x01\x01\x12\x44\n\x10last_flap_reason\x18\x07 \x01(\x0e\x32%.otg.RsvpLspState.LastFlapReason.EnumH\x06\x88\x01\x01\x12\x14\n\x07up_time\x18\x08 \x01(\x03H\x07\x88\x01\x01\x1a:\n\rSessionStatus\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1aY\n\x0eLastFlapReason\"G\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tresv_tear\x10\x01\x12\r\n\tpath_tear\x10\x02\x12\x10\n\x0cpath_timeout\x10\x03\x42\x0c\n\n_tunnel_idB\t\n\x07_lsp_idB\x0f\n\r_session_nameB\x0b\n\t_label_inB\x0c\n\n_label_outB\x11\n\x0f_session_statusB\x13\n\x11_last_flap_reasonB\n\n\x08_up_time\"b\n\x0eRsvpLspIpv4Rro\x12\x14\n\x07\x61\x64\x64ress\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0ereported_label\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\n\n\x08_addressB\x11\n\x0f_reported_label\"\xf2\x01\n\x0eRsvpLspIpv4Ero\x12\x13\n\x06prefix\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03\x61sn\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x30\n\x04type\x18\x03 \x01(\x0e\x32\x1d.otg.RsvpLspIpv4Ero.Type.EnumH\x02\x88\x01\x01\x1ak\n\x04Type\"c\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x12\x07\n\x03\x61sn\x10\x03\x12\x08\n\x04\x61sn4\x10\x04\x12\t\n\x05label\x10\x05\x12\x18\n\x14unnumbered_interface\x10\x06\x42\t\n\x07_prefixB\x06\n\x04_asnB\x07\n\x05_type\"#\n\x0e\x43\x61ptureRequest\x12\x11\n\tport_name\x18\x01 \x01(\t\"w\n\x1dPatternFlowEthernetDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowEthernetDstMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xdc\x03\n\x16PatternFlowEthernetDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x11\n\x04\x61uto\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x07 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounterH\x04\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32$.otg.PatternFlowEthernetDstMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowEthernetSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowEthernetSrcMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowEthernetSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowEthernetSrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowEthernetEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowEthernetEtherTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xfa\x03\n\x1cPatternFlowEthernetEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12@\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounterH\x04\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32*.otg.PatternFlowEthernetEtherTypeMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowEthernetPfcQueueCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"t\n$PatternFlowEthernetPfcQueueMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowEthernetPfcQueue\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPfcQueue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounterH\x02\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounterH\x03\x88\x01\x01\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowEthernetPfcQueueMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowVlanPriorityCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowVlanPriorityMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowVlanPriority\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowVlanPriority.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowVlanPriorityMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowVlanCfiCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"k\n\x1bPatternFlowVlanCfiMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xa2\x03\n\x12PatternFlowVlanCfi\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowVlanCfi.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounterH\x02\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounterH\x03\x88\x01\x01\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowVlanCfiMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"r\n\x18PatternFlowVlanIdCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"j\n\x1aPatternFlowVlanIdMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\x9d\x03\n\x11PatternFlowVlanId\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.PatternFlowVlanId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounterH\x02\x88\x01\x01\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounterH\x03\x88\x01\x01\x12\x34\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x1f.otg.PatternFlowVlanIdMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"t\n\x1aPatternFlowVlanTpidCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"l\n\x1cPatternFlowVlanTpidMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xa7\x03\n\x13PatternFlowVlanTpid\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVlanTpid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounterH\x02\x88\x01\x01\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounterH\x03\x88\x01\x01\x12\x36\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32!.otg.PatternFlowVlanTpidMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowVxlanFlagsCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowVxlanFlagsMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowVxlanFlags\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowVxlanFlags.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowVxlanFlagsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowVxlanReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"r\n\"PatternFlowVxlanReserved0MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc5\x03\n\x19PatternFlowVxlanReserved0\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0CounterH\x02\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0CounterH\x03\x88\x01\x01\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowVxlanReserved0MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"t\n\x1aPatternFlowVxlanVniCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"l\n\x1cPatternFlowVxlanVniMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xcd\x03\n\x13PatternFlowVxlanVni\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVxlanVni.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x37\n\tincrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounterH\x03\x88\x01\x01\x12\x37\n\tdecrement\x18\x07 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounterH\x04\x88\x01\x01\x12\x36\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32!.otg.PatternFlowVxlanVniMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowVxlanReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"r\n\"PatternFlowVxlanReserved1MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc5\x03\n\x19PatternFlowVxlanReserved1\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1CounterH\x02\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1CounterH\x03\x88\x01\x01\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowVxlanReserved1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv4VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowIpv4VersionMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowIpv4Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv4VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowIpv4HeaderLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"t\n$PatternFlowIpv4HeaderLengthMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xf5\x03\n\x1bPatternFlowIpv4HeaderLength\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4HeaderLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12?\n\tincrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x07 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounterH\x04\x88\x01\x01\x12>\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32).otg.PatternFlowIpv4HeaderLengthMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowIpv4TotalLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"s\n#PatternFlowIpv4TotalLengthMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xf0\x03\n\x1aPatternFlowIpv4TotalLength\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TotalLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12>\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounterH\x04\x88\x01\x01\x12=\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32(.otg.PatternFlowIpv4TotalLengthMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowIpv4IdentificationCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"v\n&PatternFlowIpv4IdentificationMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd9\x03\n\x1dPatternFlowIpv4Identification\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4Identification.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounterH\x02\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounterH\x03\x88\x01\x01\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIpv4IdentificationMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv4ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowIpv4ReservedMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowIpv4Reserved\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIpv4ReservedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowIpv4DontFragmentCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"t\n$PatternFlowIpv4DontFragmentMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowIpv4DontFragment\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4DontFragment.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounterH\x02\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounterH\x03\x88\x01\x01\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowIpv4DontFragmentMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv4MoreFragmentsCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowIpv4MoreFragmentsMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowIpv4MoreFragments\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4MoreFragments.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounterH\x02\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounterH\x03\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowIpv4MoreFragmentsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowIpv4FragmentOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"v\n&PatternFlowIpv4FragmentOffsetMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd9\x03\n\x1dPatternFlowIpv4FragmentOffset\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4FragmentOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounterH\x02\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounterH\x03\x88\x01\x01\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIpv4FragmentOffsetMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIpv4TimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"r\n\"PatternFlowIpv4TimeToLiveMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc5\x03\n\x19PatternFlowIpv4TimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv4TimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounterH\x02\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounterH\x03\x88\x01\x01\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowIpv4TimeToLiveMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv4ProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowIpv4ProtocolMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xe1\x03\n\x17PatternFlowIpv4Protocol\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Protocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12;\n\tincrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x07 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounterH\x04\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32%.otg.PatternFlowIpv4ProtocolMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xdf\x02\n\x1dPatternFlowIpv4HeaderChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4HeaderChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIpv4HeaderChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"s\n\x19PatternFlowIpv4SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"k\n\x1bPatternFlowIpv4SrcMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xa2\x03\n\x12PatternFlowIpv4Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounterH\x02\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounterH\x03\x88\x01\x01\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv4SrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowIpv4DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"k\n\x1bPatternFlowIpv4DstMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xa2\x03\n\x12PatternFlowIpv4Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounterH\x02\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounterH\x03\x88\x01\x01\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv4DstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowIpv4PriorityRawCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"s\n#PatternFlowIpv4PriorityRawMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xca\x03\n\x1aPatternFlowIpv4PriorityRaw\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4PriorityRaw.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounterH\x02\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounterH\x03\x88\x01\x01\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowIpv4PriorityRawMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv4DscpPhbCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowIpv4DscpPhbMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowIpv4DscpPhb\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpPhb.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv4DscpPhbMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv4DscpEcnCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowIpv4DscpEcnMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowIpv4DscpEcn\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpEcn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv4DscpEcnMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv4TosPrecedenceCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowIpv4TosPrecedenceMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowIpv4TosPrecedence\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosPrecedence.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounterH\x02\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounterH\x03\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowIpv4TosPrecedenceMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv4TosDelayCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowIpv4TosDelayMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowIpv4TosDelay\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4TosDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIpv4TosDelayMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv4TosThroughputCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowIpv4TosThroughputMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowIpv4TosThroughput\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosThroughput.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounterH\x02\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounterH\x03\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowIpv4TosThroughputMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowIpv4TosReliabilityCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"v\n&PatternFlowIpv4TosReliabilityMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd9\x03\n\x1dPatternFlowIpv4TosReliability\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4TosReliability.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounterH\x02\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounterH\x03\x88\x01\x01\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIpv4TosReliabilityMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowIpv4TosMonetaryCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"s\n#PatternFlowIpv4TosMonetaryMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xca\x03\n\x1aPatternFlowIpv4TosMonetary\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TosMonetary.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounterH\x02\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounterH\x03\x88\x01\x01\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowIpv4TosMonetaryMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowIpv4TosUnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"q\n!PatternFlowIpv4TosUnusedMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc0\x03\n\x18PatternFlowIpv4TosUnused\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv4TosUnused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounterH\x02\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounterH\x03\x88\x01\x01\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowIpv4TosUnusedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv6VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowIpv6VersionMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowIpv6Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv6Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowIpv6VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowIpv6TrafficClassCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"t\n$PatternFlowIpv6TrafficClassMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowIpv6TrafficClass\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv6TrafficClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounterH\x02\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounterH\x03\x88\x01\x01\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowIpv6TrafficClassMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowIpv6FlowLabelCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"q\n!PatternFlowIpv6FlowLabelMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc0\x03\n\x18PatternFlowIpv6FlowLabel\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv6FlowLabel.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounterH\x02\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounterH\x03\x88\x01\x01\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowIpv6FlowLabelMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv6PayloadLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowIpv6PayloadLengthMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xfa\x03\n\x1cPatternFlowIpv6PayloadLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv6PayloadLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12@\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounterH\x04\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32*.otg.PatternFlowIpv6PayloadLengthMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIpv6NextHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"r\n\"PatternFlowIpv6NextHeaderMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xeb\x03\n\x19PatternFlowIpv6NextHeader\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv6NextHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12=\n\tincrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x07 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounterH\x04\x88\x01\x01\x12<\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32\'.otg.PatternFlowIpv6NextHeaderMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv6HopLimitCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowIpv6HopLimitMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowIpv6HopLimit\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv6HopLimit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIpv6HopLimitMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowIpv6SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"k\n\x1bPatternFlowIpv6SrcMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xa2\x03\n\x12PatternFlowIpv6Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounterH\x02\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounterH\x03\x88\x01\x01\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv6SrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowIpv6DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"k\n\x1bPatternFlowIpv6DstMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xa2\x03\n\x12PatternFlowIpv6Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounterH\x02\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounterH\x03\x88\x01\x01\x12\x35\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32 .otg.PatternFlowIpv6DstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowPfcPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowPfcPauseDstMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowPfcPauseDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowPfcPauseDstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowPfcPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowPfcPauseSrcMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowPfcPauseSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowPfcPauseSrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowPfcPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowPfcPauseEtherTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowPfcPauseEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowPfcPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounterH\x02\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounterH\x03\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowPfcPauseEtherTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowPfcPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n)PatternFlowPfcPauseControlOpCodeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xe8\x03\n PatternFlowPfcPauseControlOpCode\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowPfcPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounterH\x02\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounterH\x03\x88\x01\x01\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowPfcPauseControlOpCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x85\x01\n+PatternFlowPfcPauseClassEnableVectorCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"}\n-PatternFlowPfcPauseClassEnableVectorMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xfc\x03\n$PatternFlowPfcPauseClassEnableVector\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowPfcPauseClassEnableVector.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12H\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounterH\x02\x88\x01\x01\x12H\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounterH\x03\x88\x01\x01\x12G\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x32.otg.PatternFlowPfcPauseClassEnableVectorMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass0Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"w\n\'PatternFlowPfcPausePauseClass0MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xde\x03\n\x1ePatternFlowPfcPausePauseClass0\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0CounterH\x02\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0CounterH\x03\x88\x01\x01\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass0MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"w\n\'PatternFlowPfcPausePauseClass1MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xde\x03\n\x1ePatternFlowPfcPausePauseClass1\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1CounterH\x02\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1CounterH\x03\x88\x01\x01\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass2Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"w\n\'PatternFlowPfcPausePauseClass2MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xde\x03\n\x1ePatternFlowPfcPausePauseClass2\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2CounterH\x02\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2CounterH\x03\x88\x01\x01\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass2MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass3Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"w\n\'PatternFlowPfcPausePauseClass3MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xde\x03\n\x1ePatternFlowPfcPausePauseClass3\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass3.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3CounterH\x02\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3CounterH\x03\x88\x01\x01\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass3MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass4Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"w\n\'PatternFlowPfcPausePauseClass4MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xde\x03\n\x1ePatternFlowPfcPausePauseClass4\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass4.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4CounterH\x02\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4CounterH\x03\x88\x01\x01\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass4MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass5Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"w\n\'PatternFlowPfcPausePauseClass5MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xde\x03\n\x1ePatternFlowPfcPausePauseClass5\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass5.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5CounterH\x02\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5CounterH\x03\x88\x01\x01\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass5MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass6Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"w\n\'PatternFlowPfcPausePauseClass6MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xde\x03\n\x1ePatternFlowPfcPausePauseClass6\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass6.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6CounterH\x02\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6CounterH\x03\x88\x01\x01\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass6MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass7Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"w\n\'PatternFlowPfcPausePauseClass7MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xde\x03\n\x1ePatternFlowPfcPausePauseClass7\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass7.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7CounterH\x02\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7CounterH\x03\x88\x01\x01\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowPfcPausePauseClass7MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowEthernetPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"t\n$PatternFlowEthernetPauseDstMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowEthernetPauseDst\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounterH\x02\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounterH\x03\x88\x01\x01\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowEthernetPauseDstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowEthernetPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"t\n$PatternFlowEthernetPauseSrcMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowEthernetPauseSrc\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounterH\x02\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounterH\x03\x88\x01\x01\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowEthernetPauseSrcMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x82\x01\n(PatternFlowEthernetPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"z\n*PatternFlowEthernetPauseEtherTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xed\x03\n!PatternFlowEthernetPauseEtherType\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowEthernetPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounterH\x02\x88\x01\x01\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounterH\x03\x88\x01\x01\x12\x44\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32/.otg.PatternFlowEthernetPauseEtherTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x86\x01\n,PatternFlowEthernetPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"~\n.PatternFlowEthernetPauseControlOpCodeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\x81\x04\n%PatternFlowEthernetPauseControlOpCode\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.PatternFlowEthernetPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12I\n\tincrement\x18\x05 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounterH\x02\x88\x01\x01\x12I\n\tdecrement\x18\x06 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounterH\x03\x88\x01\x01\x12H\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x33.otg.PatternFlowEthernetPauseControlOpCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowEthernetPauseTimeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowEthernetPauseTimeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowEthernetPauseTime\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetPauseTime.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounterH\x02\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounterH\x03\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowEthernetPauseTimeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowTcpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowTcpSrcPortMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowTcpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowTcpSrcPortMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowTcpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowTcpDstPortMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowTcpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowTcpDstPortMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpSeqNumCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpSeqNumMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpSeqNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpSeqNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpSeqNumMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpAckNumCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpAckNumMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpAckNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpAckNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpAckNumMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowTcpDataOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"q\n!PatternFlowTcpDataOffsetMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc0\x03\n\x18PatternFlowTcpDataOffset\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowTcpDataOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounterH\x02\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounterH\x03\x88\x01\x01\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowTcpDataOffsetMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"t\n\x1aPatternFlowTcpEcnNsCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"l\n\x1cPatternFlowTcpEcnNsMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xa7\x03\n\x13PatternFlowTcpEcnNs\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowTcpEcnNs.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounterH\x02\x88\x01\x01\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounterH\x03\x88\x01\x01\x12\x36\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32!.otg.PatternFlowTcpEcnNsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpEcnCwrCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpEcnCwrMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpEcnCwr\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpEcnCwr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpEcnCwrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowTcpEcnEchoCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowTcpEcnEchoMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowTcpEcnEcho\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpEcnEcho.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowTcpEcnEchoMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlUrgCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpCtlUrgMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpCtlUrg\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlUrg.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlUrgMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlAckCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpCtlAckMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpCtlAck\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlAck.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlAckMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlPshCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpCtlPshMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpCtlPsh\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlPsh.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlPshMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlRstCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpCtlRstMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpCtlRst\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlRst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlRstMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlSynCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpCtlSynMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpCtlSyn\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlSyn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlSynMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlFinCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpCtlFinMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpCtlFin\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlFin.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpCtlFinMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpWindowCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowTcpWindowMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowTcpWindow\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpWindow.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowTcpWindowMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowUdpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowUdpSrcPortMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowUdpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowUdpSrcPortMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowUdpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowUdpDstPortMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowUdpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowUdpDstPortMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowUdpLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowUdpLengthMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowUdpLength\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowUdpLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowUdpLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xca\x02\n\x16PatternFlowUdpChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowUdpChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowUdpChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowGreChecksumPresentCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"v\n&PatternFlowGreChecksumPresentMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd9\x03\n\x1dPatternFlowGreChecksumPresent\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGreChecksumPresent.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounterH\x02\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounterH\x03\x88\x01\x01\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGreChecksumPresentMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowGreReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowGreReserved0MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowGreReserved0\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved0CounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved0CounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGreReserved0MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowGreVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowGreVersionMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowGreVersion\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGreVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowGreVersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGreProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowGreProtocolMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowGreProtocol\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreProtocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGreProtocolMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xca\x02\n\x16PatternFlowGreChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowGreChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"x\n\x1ePatternFlowGreReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowGreReserved1MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowGreReserved1\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved1CounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved1CounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGreReserved1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowGtpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowGtpv1VersionMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowGtpv1Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGtpv1VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowGtpv1ProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowGtpv1ProtocolTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowGtpv1ProtocolType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowGtpv1ProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounterH\x02\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounterH\x03\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowGtpv1ProtocolTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowGtpv1ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"q\n!PatternFlowGtpv1ReservedMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc0\x03\n\x18PatternFlowGtpv1Reserved\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv1Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounterH\x02\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounterH\x03\x88\x01\x01\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowGtpv1ReservedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowGtpv1EFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowGtpv1EFlagMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowGtpv1EFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1EFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowGtpv1EFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowGtpv1SFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowGtpv1SFlagMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowGtpv1SFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1SFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowGtpv1SFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGtpv1PnFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowGtpv1PnFlagMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowGtpv1PnFlag\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv1PnFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGtpv1PnFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowGtpv1MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"t\n$PatternFlowGtpv1MessageTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowGtpv1MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv1MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounterH\x02\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounterH\x03\x88\x01\x01\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowGtpv1MessageTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowGtpv1MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"v\n&PatternFlowGtpv1MessageLengthMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd9\x03\n\x1dPatternFlowGtpv1MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounterH\x02\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounterH\x03\x88\x01\x01\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGtpv1MessageLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowGtpv1TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowGtpv1TeidMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowGtpv1Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv1Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowGtpv1TeidMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowGtpv1SquenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"v\n&PatternFlowGtpv1SquenceNumberMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd9\x03\n\x1dPatternFlowGtpv1SquenceNumber\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1SquenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounterH\x02\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounterH\x03\x88\x01\x01\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGtpv1SquenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowGtpv1NPduNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"s\n#PatternFlowGtpv1NPduNumberMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xca\x03\n\x1aPatternFlowGtpv1NPduNumber\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowGtpv1NPduNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounterH\x02\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounterH\x03\x88\x01\x01\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowGtpv1NPduNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x88\x01\n.PatternFlowGtpv1NextExtensionHeaderTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n0PatternFlowGtpv1NextExtensionHeaderTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\x8b\x04\n\'PatternFlowGtpv1NextExtensionHeaderType\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowGtpv1NextExtensionHeaderType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounterH\x02\x88\x01\x01\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounterH\x03\x88\x01\x01\x12J\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x35.otg.PatternFlowGtpv1NextExtensionHeaderTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x87\x01\n-PatternFlowGtpExtensionExtensionLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x7f\n/PatternFlowGtpExtensionExtensionLengthMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\x86\x04\n&PatternFlowGtpExtensionExtensionLength\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.PatternFlowGtpExtensionExtensionLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12J\n\tincrement\x18\x05 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounterH\x02\x88\x01\x01\x12J\n\tdecrement\x18\x06 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounterH\x03\x88\x01\x01\x12I\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x34.otg.PatternFlowGtpExtensionExtensionLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x80\x01\n&PatternFlowGtpExtensionContentsCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"x\n(PatternFlowGtpExtensionContentsMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xe3\x03\n\x1fPatternFlowGtpExtensionContents\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowGtpExtensionContents.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounterH\x02\x88\x01\x01\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounterH\x03\x88\x01\x01\x12\x42\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32-.otg.PatternFlowGtpExtensionContentsMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x8b\x01\n1PatternFlowGtpExtensionNextExtensionHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x83\x01\n3PatternFlowGtpExtensionNextExtensionHeaderMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\x9a\x04\n*PatternFlowGtpExtensionNextExtensionHeader\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.PatternFlowGtpExtensionNextExtensionHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12N\n\tincrement\x18\x05 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounterH\x02\x88\x01\x01\x12N\n\tdecrement\x18\x06 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounterH\x03\x88\x01\x01\x12M\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x38.otg.PatternFlowGtpExtensionNextExtensionHeaderMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowGtpv2VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowGtpv2VersionMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowGtpv2Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv2Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowGtpv2VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowGtpv2PiggybackingFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n)PatternFlowGtpv2PiggybackingFlagMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xe8\x03\n PatternFlowGtpv2PiggybackingFlag\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowGtpv2PiggybackingFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounterH\x02\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounterH\x03\x88\x01\x01\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowGtpv2PiggybackingFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowGtpv2TeidFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"q\n!PatternFlowGtpv2TeidFlagMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc0\x03\n\x18PatternFlowGtpv2TeidFlag\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv2TeidFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounterH\x02\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounterH\x03\x88\x01\x01\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowGtpv2TeidFlagMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGtpv2Spare1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowGtpv2Spare1MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowGtpv2Spare1\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1CounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1CounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGtpv2Spare1MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowGtpv2MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"t\n$PatternFlowGtpv2MessageTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowGtpv2MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv2MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounterH\x02\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounterH\x03\x88\x01\x01\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowGtpv2MessageTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowGtpv2MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"v\n&PatternFlowGtpv2MessageLengthMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd9\x03\n\x1dPatternFlowGtpv2MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv2MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounterH\x02\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounterH\x03\x88\x01\x01\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowGtpv2MessageLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowGtpv2TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowGtpv2TeidMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xac\x03\n\x14PatternFlowGtpv2Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv2Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounterH\x02\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounterH\x03\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\".otg.PatternFlowGtpv2TeidMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowGtpv2SequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"w\n\'PatternFlowGtpv2SequenceNumberMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xde\x03\n\x1ePatternFlowGtpv2SequenceNumber\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowGtpv2SequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounterH\x02\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounterH\x03\x88\x01\x01\x12\x41\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32,.otg.PatternFlowGtpv2SequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGtpv2Spare2Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"o\n\x1fPatternFlowGtpv2Spare2MetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb6\x03\n\x16PatternFlowGtpv2Spare2\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2CounterH\x02\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2CounterH\x03\x88\x01\x01\x12\x39\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32$.otg.PatternFlowGtpv2Spare2MetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowArpHardwareTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"s\n#PatternFlowArpHardwareTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xca\x03\n\x1aPatternFlowArpHardwareType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpHardwareType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounterH\x02\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounterH\x03\x88\x01\x01\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowArpHardwareTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowArpProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"s\n#PatternFlowArpProtocolTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xca\x03\n\x1aPatternFlowArpProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounterH\x02\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounterH\x03\x88\x01\x01\x12=\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32(.otg.PatternFlowArpProtocolTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowArpHardwareLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowArpHardwareLengthMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowArpHardwareLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpHardwareLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounterH\x02\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounterH\x03\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowArpHardwareLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowArpProtocolLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowArpProtocolLengthMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd4\x03\n\x1cPatternFlowArpProtocolLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpProtocolLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounterH\x02\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounterH\x03\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32*.otg.PatternFlowArpProtocolLengthMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowArpOperationCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowArpOperationMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowArpOperation\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowArpOperation.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowArpOperationMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpSenderHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n)PatternFlowArpSenderHardwareAddrMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xe8\x03\n PatternFlowArpSenderHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounterH\x02\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounterH\x03\x88\x01\x01\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpSenderHardwareAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpSenderProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n)PatternFlowArpSenderProtocolAddrMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xe8\x03\n PatternFlowArpSenderProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounterH\x02\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounterH\x03\x88\x01\x01\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpSenderProtocolAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpTargetHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n)PatternFlowArpTargetHardwareAddrMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xe8\x03\n PatternFlowArpTargetHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounterH\x02\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounterH\x03\x88\x01\x01\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpTargetHardwareAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpTargetProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"y\n)PatternFlowArpTargetProtocolAddrMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xe8\x03\n PatternFlowArpTargetProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounterH\x02\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounterH\x03\x88\x01\x01\x12\x43\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32..otg.PatternFlowArpTargetProtocolAddrMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIcmpEchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowIcmpEchoTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowIcmpEchoType\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIcmpEchoTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIcmpEchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowIcmpEchoCodeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowIcmpEchoCode\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIcmpEchoCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xd9\x02\n\x1bPatternFlowIcmpEchoChecksum\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIcmpEchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12G\n\tgenerated\x18\x02 \x01(\x0e\x32/.otg.PatternFlowIcmpEchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIcmpEchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"v\n&PatternFlowIcmpEchoIdentifierMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd9\x03\n\x1dPatternFlowIcmpEchoIdentifier\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpEchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounterH\x02\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounterH\x03\x88\x01\x01\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIcmpEchoIdentifierMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x82\x01\n(PatternFlowIcmpEchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"z\n*PatternFlowIcmpEchoSequenceNumberMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xed\x03\n!PatternFlowIcmpEchoSequenceNumber\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowIcmpEchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounterH\x02\x88\x01\x01\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounterH\x03\x88\x01\x01\x12\x44\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32/.otg.PatternFlowIcmpEchoSequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xdf\x02\n\x1dPatternFlowIcmpCommonChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpCommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpCommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\x84\x01\n*PatternFlowIcmpNextFieldsIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n,PatternFlowIcmpNextFieldsIdentifierMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xf7\x03\n#PatternFlowIcmpNextFieldsIdentifier\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpNextFieldsIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12G\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounterH\x02\x88\x01\x01\x12G\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounterH\x03\x88\x01\x01\x12\x46\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x31.otg.PatternFlowIcmpNextFieldsIdentifierMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x88\x01\n.PatternFlowIcmpNextFieldsSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x80\x01\n0PatternFlowIcmpNextFieldsSequenceNumberMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\x8b\x04\n\'PatternFlowIcmpNextFieldsSequenceNumber\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounterH\x02\x88\x01\x01\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounterH\x03\x88\x01\x01\x12J\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x35.otg.PatternFlowIcmpNextFieldsSequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIcmpv6EchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"r\n\"PatternFlowIcmpv6EchoTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc5\x03\n\x19PatternFlowIcmpv6EchoType\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounterH\x02\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounterH\x03\x88\x01\x01\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowIcmpv6EchoTypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIcmpv6EchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"r\n\"PatternFlowIcmpv6EchoCodeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc5\x03\n\x19PatternFlowIcmpv6EchoCode\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounterH\x02\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounterH\x03\x88\x01\x01\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowIcmpv6EchoCodeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x80\x01\n&PatternFlowIcmpv6EchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"x\n(PatternFlowIcmpv6EchoIdentifierMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xe3\x03\n\x1fPatternFlowIcmpv6EchoIdentifier\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6EchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounterH\x02\x88\x01\x01\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounterH\x03\x88\x01\x01\x12\x42\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32-.otg.PatternFlowIcmpv6EchoIdentifierMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x84\x01\n*PatternFlowIcmpv6EchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"|\n,PatternFlowIcmpv6EchoSequenceNumberMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xf7\x03\n#PatternFlowIcmpv6EchoSequenceNumber\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpv6EchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12G\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounterH\x02\x88\x01\x01\x12G\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounterH\x03\x88\x01\x01\x12\x46\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\x31.otg.PatternFlowIcmpv6EchoSequenceNumberMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xdf\x02\n\x1dPatternFlowIcmpv6EchoChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpv6EchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpv6EchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\xe5\x02\n\x1fPatternFlowIcmpv6CommonChecksum\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6CommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12K\n\tgenerated\x18\x02 \x01(\x0e\x32\x33.otg.PatternFlowIcmpv6CommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"v\n\x1cPatternFlowPppAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowPppAddressMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowPppAddress\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowPppAddressMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowPppControlCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowPppControlMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowPppControl\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppControl.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppControlCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppControlCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowPppControlMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowPppProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"s\n#PatternFlowPppProtocolTypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xf0\x03\n\x1aPatternFlowPppProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowPppProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12>\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounterH\x04\x88\x01\x01\x12=\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32(.otg.PatternFlowPppProtocolTypeMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowIgmpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"q\n!PatternFlowIgmpv1VersionMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc0\x03\n\x18PatternFlowIgmpv1Version\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIgmpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounterH\x02\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounterH\x03\x88\x01\x01\x12;\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32&.otg.PatternFlowIgmpv1VersionMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowIgmpv1TypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"n\n\x1ePatternFlowIgmpv1TypeMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xb1\x03\n\x15PatternFlowIgmpv1Type\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowIgmpv1Type.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounterH\x02\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounterH\x03\x88\x01\x01\x12\x38\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32#.otg.PatternFlowIgmpv1TypeMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIgmpv1UnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"p\n PatternFlowIgmpv1UnusedMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xbb\x03\n\x17PatternFlowIgmpv1Unused\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIgmpv1Unused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounterH\x02\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounterH\x03\x88\x01\x01\x12:\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32%.otg.PatternFlowIgmpv1UnusedMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xd3\x02\n\x19PatternFlowIgmpv1Checksum\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIgmpv1Checksum.Choice.EnumH\x00\x88\x01\x01\x12\x45\n\tgenerated\x18\x02 \x01(\x0e\x32-.otg.PatternFlowIgmpv1Checksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIgmpv1GroupAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"v\n&PatternFlowIgmpv1GroupAddressMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd9\x03\n\x1dPatternFlowIgmpv1GroupAddress\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIgmpv1GroupAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounterH\x02\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounterH\x03\x88\x01\x01\x12@\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32+.otg.PatternFlowIgmpv1GroupAddressMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowMplsLabelCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"m\n\x1dPatternFlowMplsLabelMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xd2\x03\n\x14PatternFlowMplsLabel\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowMplsLabel.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowMplsLabelCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x07 \x01(\x0b\x32 .otg.PatternFlowMplsLabelCounterH\x04\x88\x01\x01\x12\x37\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32\".otg.PatternFlowMplsLabelMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowMplsTrafficClassCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"t\n$PatternFlowMplsTrafficClassMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xcf\x03\n\x1bPatternFlowMplsTrafficClass\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowMplsTrafficClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowMplsTrafficClassCounterH\x02\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowMplsTrafficClassCounterH\x03\x88\x01\x01\x12>\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32).otg.PatternFlowMplsTrafficClassMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowMplsBottomOfStackCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"u\n%PatternFlowMplsBottomOfStackMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xfa\x03\n\x1cPatternFlowMplsBottomOfStack\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowMplsBottomOfStack.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12@\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowMplsBottomOfStackCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowMplsBottomOfStackCounterH\x04\x88\x01\x01\x12?\n\x0bmetric_tags\x18\x08 \x03(\x0b\x32*.otg.PatternFlowMplsBottomOfStackMetricTag\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\x08\n\x04\x61uto\x10\x01\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowMplsTimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"r\n\"PatternFlowMplsTimeToLiveMetricTag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x06offset\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x13\n\x06length\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\t\n\x07_offsetB\t\n\x07_length\"\xc5\x03\n\x19PatternFlowMplsTimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowMplsTimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowMplsTimeToLiveCounterH\x02\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowMplsTimeToLiveCounterH\x03\x88\x01\x01\x12<\n\x0bmetric_tags\x18\x07 \x03(\x0b\x32\'.otg.PatternFlowMplsTimeToLiveMetricTag\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x02\x12\n\n\x06values\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x91\x01\n\x07Version\x12\x1d\n\x10\x61pi_spec_version\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bsdk_version\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0b\x61pp_version\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x13\n\x11_api_spec_versionB\x0e\n\x0c_sdk_versionB\x0e\n\x0c_app_version\"(\n\x07Success\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"$\n\x07\x46\x61ilure\x12\x19\n\x05\x65rror\x18\x01 \x01(\x0b\x32\n.otg.Error\"/\n\x10SetConfigRequest\x12\x1b\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0b.otg.Config\"?\n\x13UpdateConfigRequest\x12(\n\rconfig_update\x18\x01 \x01(\x0b\x32\x11.otg.ConfigUpdate\"2\n\x11SetConfigResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"0\n\x11GetConfigResponse\x12\x1b\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0b.otg.Config\"5\n\x14UpdateConfigResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"B\n\x16SetControlStateRequest\x12(\n\rcontrol_state\x18\x01 \x01(\x0b\x32\x11.otg.ControlState\"8\n\x17SetControlStateResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"E\n\x17SetControlActionRequest\x12*\n\x0e\x63ontrol_action\x18\x01 \x01(\x0b\x32\x12.otg.ControlAction\"W\n\x18SetControlActionResponse\x12;\n\x17\x63ontrol_action_response\x18\x01 \x01(\x0b\x32\x1a.otg.ControlActionResponse\"E\n\x17SetTransmitStateRequest\x12*\n\x0etransmit_state\x18\x01 \x01(\x0b\x32\x12.otg.TransmitState\"9\n\x18SetTransmitStateResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"9\n\x13SetLinkStateRequest\x12\"\n\nlink_state\x18\x01 \x01(\x0b\x32\x0e.otg.LinkState\"5\n\x14SetLinkStateResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"B\n\x16SetCaptureStateRequest\x12(\n\rcapture_state\x18\x01 \x01(\x0b\x32\x11.otg.CaptureState\"8\n\x17SetCaptureStateResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"<\n\x12UpdateFlowsRequest\x12&\n\x0c\x66lows_update\x18\x01 \x01(\x0b\x32\x10.otg.FlowsUpdate\"2\n\x13UpdateFlowsResponse\x12\x1b\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0b.otg.Config\"<\n\x14SetRouteStateRequest\x12$\n\x0broute_state\x18\x01 \x01(\x0b\x32\x0f.otg.RouteState\"6\n\x15SetRouteStateResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"9\n\x0fSendPingRequest\x12&\n\x0cping_request\x18\x01 \x01(\x0b\x32\x10.otg.PingRequest\"<\n\x10SendPingResponse\x12(\n\rping_response\x18\x01 \x01(\x0b\x32\x11.otg.PingResponse\"E\n\x17SetProtocolStateRequest\x12*\n\x0eprotocol_state\x18\x01 \x01(\x0b\x32\x12.otg.ProtocolState\"9\n\x18SetProtocolStateResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"?\n\x15SetDeviceStateRequest\x12&\n\x0c\x64\x65vice_state\x18\x01 \x01(\x0b\x32\x10.otg.DeviceState\"7\n\x16SetDeviceStateResponse\x12\x1d\n\x07warning\x18\x01 \x01(\x0b\x32\x0c.otg.Warning\"A\n\x11GetMetricsRequest\x12,\n\x0fmetrics_request\x18\x01 \x01(\x0b\x32\x13.otg.MetricsRequest\"D\n\x12GetMetricsResponse\x12.\n\x10metrics_response\x18\x01 \x01(\x0b\x32\x14.otg.MetricsResponse\">\n\x10GetStatesRequest\x12*\n\x0estates_request\x18\x01 \x01(\x0b\x32\x12.otg.StatesRequest\"A\n\x11GetStatesResponse\x12,\n\x0fstates_response\x18\x01 \x01(\x0b\x32\x13.otg.StatesResponse\"A\n\x11GetCaptureRequest\x12,\n\x0f\x63\x61pture_request\x18\x01 \x01(\x0b\x32\x13.otg.CaptureRequest\",\n\x12GetCaptureResponse\x12\x16\n\x0eresponse_bytes\x18\x01 \x01(\x0c\"3\n\x12GetVersionResponse\x12\x1d\n\x07version\x18\x01 \x01(\x0b\x32\x0c.otg.Version2\xa2\t\n\x07Openapi\x12:\n\tSetConfig\x12\x15.otg.SetConfigRequest\x1a\x16.otg.SetConfigResponse\x12;\n\tGetConfig\x12\x16.google.protobuf.Empty\x1a\x16.otg.GetConfigResponse\x12\x43\n\x0cUpdateConfig\x12\x18.otg.UpdateConfigRequest\x1a\x19.otg.UpdateConfigResponse\x12L\n\x0fSetControlState\x12\x1b.otg.SetControlStateRequest\x1a\x1c.otg.SetControlStateResponse\x12O\n\x10SetControlAction\x12\x1c.otg.SetControlActionRequest\x1a\x1d.otg.SetControlActionResponse\x12O\n\x10SetTransmitState\x12\x1c.otg.SetTransmitStateRequest\x1a\x1d.otg.SetTransmitStateResponse\x12\x43\n\x0cSetLinkState\x12\x18.otg.SetLinkStateRequest\x1a\x19.otg.SetLinkStateResponse\x12L\n\x0fSetCaptureState\x12\x1b.otg.SetCaptureStateRequest\x1a\x1c.otg.SetCaptureStateResponse\x12@\n\x0bUpdateFlows\x12\x17.otg.UpdateFlowsRequest\x1a\x18.otg.UpdateFlowsResponse\x12\x46\n\rSetRouteState\x12\x19.otg.SetRouteStateRequest\x1a\x1a.otg.SetRouteStateResponse\x12\x37\n\x08SendPing\x12\x14.otg.SendPingRequest\x1a\x15.otg.SendPingResponse\x12O\n\x10SetProtocolState\x12\x1c.otg.SetProtocolStateRequest\x1a\x1d.otg.SetProtocolStateResponse\x12I\n\x0eSetDeviceState\x12\x1a.otg.SetDeviceStateRequest\x1a\x1b.otg.SetDeviceStateResponse\x12=\n\nGetMetrics\x12\x16.otg.GetMetricsRequest\x1a\x17.otg.GetMetricsResponse\x12:\n\tGetStates\x12\x15.otg.GetStatesRequest\x1a\x16.otg.GetStatesResponse\x12=\n\nGetCapture\x12\x16.otg.GetCaptureRequest\x1a\x17.otg.GetCaptureResponse\x12=\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a\x17.otg.GetVersionResponseB\x0bZ\t./otg;otgb\x06proto3')



_CONFIG = DESCRIPTOR.message_types_by_name['Config']
_CONFIGOPTIONS = DESCRIPTOR.message_types_by_name['ConfigOptions']
_PORT = DESCRIPTOR.message_types_by_name['Port']
_PORTOPTIONS = DESCRIPTOR.message_types_by_name['PortOptions']
_LAG = DESCRIPTOR.message_types_by_name['Lag']
_LAGPORT = DESCRIPTOR.message_types_by_name['LagPort']
_LAGPROTOCOL = DESCRIPTOR.message_types_by_name['LagProtocol']
_LAGPROTOCOL_CHOICE = _LAGPROTOCOL.nested_types_by_name['Choice']
_LAGPROTOCOLSTATIC = DESCRIPTOR.message_types_by_name['LagProtocolStatic']
_LAGPROTOCOLLACP = DESCRIPTOR.message_types_by_name['LagProtocolLacp']
_LAGPORTLACP = DESCRIPTOR.message_types_by_name['LagPortLacp']
_LAGPORTLACP_ACTORACTIVITY = _LAGPORTLACP.nested_types_by_name['ActorActivity']
_DEVICEETHERNETBASE = DESCRIPTOR.message_types_by_name['DeviceEthernetBase']
_DEVICEETHERNET = DESCRIPTOR.message_types_by_name['DeviceEthernet']
_ETHERNETCONNECTION = DESCRIPTOR.message_types_by_name['EthernetConnection']
_ETHERNETCONNECTION_CHOICE = _ETHERNETCONNECTION.nested_types_by_name['Choice']
_DEVICEVLAN = DESCRIPTOR.message_types_by_name['DeviceVlan']
_DEVICEVLAN_TPID = _DEVICEVLAN.nested_types_by_name['Tpid']
_DEVICEIPV4 = DESCRIPTOR.message_types_by_name['DeviceIpv4']
_DEVICEIPV4LOOPBACK = DESCRIPTOR.message_types_by_name['DeviceIpv4Loopback']
_DEVICEIPV4GATEWAYMAC = DESCRIPTOR.message_types_by_name['DeviceIpv4GatewayMAC']
_DEVICEIPV4GATEWAYMAC_CHOICE = _DEVICEIPV4GATEWAYMAC.nested_types_by_name['Choice']
_DEVICEIPV6 = DESCRIPTOR.message_types_by_name['DeviceIpv6']
_DEVICEIPV6LOOPBACK = DESCRIPTOR.message_types_by_name['DeviceIpv6Loopback']
_DEVICEIPV6GATEWAYMAC = DESCRIPTOR.message_types_by_name['DeviceIpv6GatewayMAC']
_DEVICEIPV6GATEWAYMAC_CHOICE = _DEVICEIPV6GATEWAYMAC.nested_types_by_name['Choice']
_LAYER1 = DESCRIPTOR.message_types_by_name['Layer1']
_LAYER1_SPEED = _LAYER1.nested_types_by_name['Speed']
_LAYER1_MEDIA = _LAYER1.nested_types_by_name['Media']
_LAYER1AUTONEGOTIATION = DESCRIPTOR.message_types_by_name['Layer1AutoNegotiation']
_LAYER1FLOWCONTROL = DESCRIPTOR.message_types_by_name['Layer1FlowControl']
_LAYER1FLOWCONTROL_CHOICE = _LAYER1FLOWCONTROL.nested_types_by_name['Choice']
_LAYER1IEEE8023X = DESCRIPTOR.message_types_by_name['Layer1Ieee8023x']
_LAYER1IEEE8021QBB = DESCRIPTOR.message_types_by_name['Layer1Ieee8021qbb']
_CAPTURE = DESCRIPTOR.message_types_by_name['Capture']
_CAPTURE_FORMAT = _CAPTURE.nested_types_by_name['Format']
_CAPTUREFILTER = DESCRIPTOR.message_types_by_name['CaptureFilter']
_CAPTUREFILTER_CHOICE = _CAPTUREFILTER.nested_types_by_name['Choice']
_CAPTURECUSTOM = DESCRIPTOR.message_types_by_name['CaptureCustom']
_CAPTUREFIELD = DESCRIPTOR.message_types_by_name['CaptureField']
_CAPTUREETHERNET = DESCRIPTOR.message_types_by_name['CaptureEthernet']
_CAPTUREVLAN = DESCRIPTOR.message_types_by_name['CaptureVlan']
_CAPTUREIPV4 = DESCRIPTOR.message_types_by_name['CaptureIpv4']
_CAPTUREIPV6 = DESCRIPTOR.message_types_by_name['CaptureIpv6']
_DEVICE = DESCRIPTOR.message_types_by_name['Device']
_PROTOCOLOPTIONS = DESCRIPTOR.message_types_by_name['ProtocolOptions']
_DEVICEISISROUTER = DESCRIPTOR.message_types_by_name['DeviceIsisRouter']
_DEVICEISISMULTIINSTANCE = DESCRIPTOR.message_types_by_name['DeviceIsisMultiInstance']
_ISISINTERFACE = DESCRIPTOR.message_types_by_name['IsisInterface']
_ISISINTERFACE_NETWORKTYPE = _ISISINTERFACE.nested_types_by_name['NetworkType']
_ISISINTERFACE_LEVELTYPE = _ISISINTERFACE.nested_types_by_name['LevelType']
_ISISINTERFACELEVEL = DESCRIPTOR.message_types_by_name['IsisInterfaceLevel']
_ISISMT = DESCRIPTOR.message_types_by_name['IsisMT']
_LINKSTATETE = DESCRIPTOR.message_types_by_name['LinkStateTE']
_LINKSTATEPRIORITYBANDWIDTHS = DESCRIPTOR.message_types_by_name['LinkStatepriorityBandwidths']
_ISISINTERFACEAUTHENTICATION = DESCRIPTOR.message_types_by_name['IsisInterfaceAuthentication']
_ISISINTERFACEAUTHENTICATION_AUTHTYPE = _ISISINTERFACEAUTHENTICATION.nested_types_by_name['AuthType']
_ISISINTERFACEADVANCED = DESCRIPTOR.message_types_by_name['IsisInterfaceAdvanced']
_ISISINTERFACELINKPROTECTION = DESCRIPTOR.message_types_by_name['IsisInterfaceLinkProtection']
_ISISBASIC = DESCRIPTOR.message_types_by_name['IsisBasic']
_ISISADVANCED = DESCRIPTOR.message_types_by_name['IsisAdvanced']
_ISISAUTHENTICATION = DESCRIPTOR.message_types_by_name['IsisAuthentication']
_ISISAUTHENTICATIONBASE = DESCRIPTOR.message_types_by_name['IsisAuthenticationBase']
_ISISAUTHENTICATIONBASE_AUTHTYPE = _ISISAUTHENTICATIONBASE.nested_types_by_name['AuthType']
_ISISV4ROUTERANGE = DESCRIPTOR.message_types_by_name['IsisV4RouteRange']
_ISISV4ROUTERANGE_ORIGINTYPE = _ISISV4ROUTERANGE.nested_types_by_name['OriginType']
_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE = _ISISV4ROUTERANGE.nested_types_by_name['RedistributionType']
_V4ROUTEADDRESS = DESCRIPTOR.message_types_by_name['V4RouteAddress']
_V6ROUTEADDRESS = DESCRIPTOR.message_types_by_name['V6RouteAddress']
_MACROUTEADDRESS = DESCRIPTOR.message_types_by_name['MACRouteAddress']
_ISISV6ROUTERANGE = DESCRIPTOR.message_types_by_name['IsisV6RouteRange']
_ISISV6ROUTERANGE_ORIGINTYPE = _ISISV6ROUTERANGE.nested_types_by_name['OriginType']
_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE = _ISISV6ROUTERANGE.nested_types_by_name['RedistributionType']
_DEVICEBGPROUTER = DESCRIPTOR.message_types_by_name['DeviceBgpRouter']
_DEVICEBGPMESSAGEHEADERERROR = DESCRIPTOR.message_types_by_name['DeviceBgpMessageHeaderError']
_DEVICEBGPMESSAGEHEADERERROR_SUBCODE = _DEVICEBGPMESSAGEHEADERERROR.nested_types_by_name['Subcode']
_DEVICEBGPOPENMESSAGEERROR = DESCRIPTOR.message_types_by_name['DeviceBgpOpenMessageError']
_DEVICEBGPOPENMESSAGEERROR_SUBCODE = _DEVICEBGPOPENMESSAGEERROR.nested_types_by_name['Subcode']
_DEVICEBGPUPDATEMESSAGEERROR = DESCRIPTOR.message_types_by_name['DeviceBgpUpdateMessageError']
_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE = _DEVICEBGPUPDATEMESSAGEERROR.nested_types_by_name['Subcode']
_DEVICEBGPHOLDTIMEREXPIRED = DESCRIPTOR.message_types_by_name['DeviceBgpHoldTimerExpired']
_DEVICEBGPFINITESTATEMACHINEERROR = DESCRIPTOR.message_types_by_name['DeviceBgpFiniteStateMachineError']
_DEVICEBGPCEASEERROR = DESCRIPTOR.message_types_by_name['DeviceBgpCeaseError']
_DEVICEBGPCEASEERROR_SUBCODE = _DEVICEBGPCEASEERROR.nested_types_by_name['Subcode']
_DEVICEBGPCUSTOMERROR = DESCRIPTOR.message_types_by_name['DeviceBgpCustomError']
_BGPV4PEER = DESCRIPTOR.message_types_by_name['BgpV4Peer']
_BGPV4PEER_ASTYPE = _BGPV4PEER.nested_types_by_name['AsType']
_BGPV4PEER_ASNUMBERWIDTH = _BGPV4PEER.nested_types_by_name['AsNumberWidth']
_BGPV4INTERFACE = DESCRIPTOR.message_types_by_name['BgpV4Interface']
_BGPV4ETHERNETSEGMENT = DESCRIPTOR.message_types_by_name['BgpV4EthernetSegment']
_BGPV4ETHERNETSEGMENT_ACTIVEMODE = _BGPV4ETHERNETSEGMENT.nested_types_by_name['ActiveMode']
_BGPETHERNETSEGMENTDFELECTION = DESCRIPTOR.message_types_by_name['BgpEthernetSegmentDfElection']
_BGPROUTEADVANCED = DESCRIPTOR.message_types_by_name['BgpRouteAdvanced']
_BGPROUTEADVANCED_ORIGIN = _BGPROUTEADVANCED.nested_types_by_name['Origin']
_BGPCOMMUNITY = DESCRIPTOR.message_types_by_name['BgpCommunity']
_BGPCOMMUNITY_TYPE = _BGPCOMMUNITY.nested_types_by_name['Type']
_BGPEXTCOMMUNITY = DESCRIPTOR.message_types_by_name['BgpExtCommunity']
_BGPEXTCOMMUNITY_TYPE = _BGPEXTCOMMUNITY.nested_types_by_name['Type']
_BGPEXTCOMMUNITY_SUBTYPE = _BGPEXTCOMMUNITY.nested_types_by_name['Subtype']
_BGPASPATH = DESCRIPTOR.message_types_by_name['BgpAsPath']
_BGPASPATH_ASSETMODE = _BGPASPATH.nested_types_by_name['AsSetMode']
_BGPASPATHSEGMENT = DESCRIPTOR.message_types_by_name['BgpAsPathSegment']
_BGPASPATHSEGMENT_TYPE = _BGPASPATHSEGMENT.nested_types_by_name['Type']
_BGPV4EVPNEVIS = DESCRIPTOR.message_types_by_name['BgpV4EvpnEvis']
_BGPV4EVPNEVIS_CHOICE = _BGPV4EVPNEVIS.nested_types_by_name['Choice']
_BGPV4EVIVXLAN = DESCRIPTOR.message_types_by_name['BgpV4EviVxlan']
_BGPV4EVIVXLAN_REPLICATIONTYPE = _BGPV4EVIVXLAN.nested_types_by_name['ReplicationType']
_BGPV4EVIVXLANBROADCASTDOMAIN = DESCRIPTOR.message_types_by_name['BgpV4EviVxlanBroadcastDomain']
_BGPCMACIPRANGE = DESCRIPTOR.message_types_by_name['BgpCMacIpRange']
_BGPROUTEDISTINGUISHER = DESCRIPTOR.message_types_by_name['BgpRouteDistinguisher']
_BGPROUTEDISTINGUISHER_RDTYPE = _BGPROUTEDISTINGUISHER.nested_types_by_name['RdType']
_BGPROUTETARGET = DESCRIPTOR.message_types_by_name['BgpRouteTarget']
_BGPROUTETARGET_RTTYPE = _BGPROUTETARGET.nested_types_by_name['RtType']
_BGPADVANCED = DESCRIPTOR.message_types_by_name['BgpAdvanced']
_BGPCAPABILITY = DESCRIPTOR.message_types_by_name['BgpCapability']
_BGPLEARNEDINFORMATIONFILTER = DESCRIPTOR.message_types_by_name['BgpLearnedInformationFilter']
_BGPV4ROUTERANGE = DESCRIPTOR.message_types_by_name['BgpV4RouteRange']
_BGPV4ROUTERANGE_NEXTHOPMODE = _BGPV4ROUTERANGE.nested_types_by_name['NextHopMode']
_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE = _BGPV4ROUTERANGE.nested_types_by_name['NextHopAddressType']
_BGPADDPATH = DESCRIPTOR.message_types_by_name['BgpAddPath']
_BGPV6ROUTERANGE = DESCRIPTOR.message_types_by_name['BgpV6RouteRange']
_BGPV6ROUTERANGE_NEXTHOPMODE = _BGPV6ROUTERANGE.nested_types_by_name['NextHopMode']
_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE = _BGPV6ROUTERANGE.nested_types_by_name['NextHopAddressType']
_BGPSRTEV4POLICY = DESCRIPTOR.message_types_by_name['BgpSrteV4Policy']
_BGPSRTEV4POLICY_NEXTHOPMODE = _BGPSRTEV4POLICY.nested_types_by_name['NextHopMode']
_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE = _BGPSRTEV4POLICY.nested_types_by_name['NextHopAddressType']
_BGPSRTEV4TUNNELTLV = DESCRIPTOR.message_types_by_name['BgpSrteV4TunnelTlv']
_BGPSRTEREMOTEENDPOINTSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteRemoteEndpointSubTlv']
_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY = _BGPSRTEREMOTEENDPOINTSUBTLV.nested_types_by_name['AddressFamily']
_BGPSRTECOLORSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteColorSubTlv']
_BGPSRTEBINDINGSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteBindingSubTlv']
_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE = _BGPSRTEBINDINGSUBTLV.nested_types_by_name['BindingSidType']
_BGPSRTEPREFERENCESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrtePreferenceSubTlv']
_BGPSRTEPOLICYPRIORITYSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrtePolicyPrioritySubTlv']
_BGPSRTEPOLICYNAMESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrtePolicyNameSubTlv']
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteExplicitNullLabelPolicySubTlv']
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV.nested_types_by_name['ExplicitNullLabelPolicy']
_BGPSRTESEGMENTLIST = DESCRIPTOR.message_types_by_name['BgpSrteSegmentList']
_BGPSRTESEGMENT = DESCRIPTOR.message_types_by_name['BgpSrteSegment']
_BGPSRTESEGMENT_SEGMENTTYPE = _BGPSRTESEGMENT.nested_types_by_name['SegmentType']
_BGPSRTESRMPLSSID = DESCRIPTOR.message_types_by_name['BgpSrteSrMplsSid']
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE = DESCRIPTOR.message_types_by_name['BgpSrteSRv6SIDEndpointBehaviorAndStructure']
_BGPSRTESEGMENTATYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentATypeSubTlv']
_BGPSRTESEGMENTBTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentBTypeSubTlv']
_BGPSRTESEGMENTCTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentCTypeSubTlv']
_BGPSRTESEGMENTDTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentDTypeSubTlv']
_BGPSRTESEGMENTETYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentETypeSubTlv']
_BGPSRTESEGMENTFTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentFTypeSubTlv']
_BGPSRTESEGMENTGTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentGTypeSubTlv']
_BGPSRTESEGMENTHTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentHTypeSubTlv']
_BGPSRTESEGMENTITYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentITypeSubTlv']
_BGPSRTESEGMENTJTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentJTypeSubTlv']
_BGPSRTESEGMENTKTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentKTypeSubTlv']
_BGPSRTEV6POLICY = DESCRIPTOR.message_types_by_name['BgpSrteV6Policy']
_BGPSRTEV6POLICY_NEXTHOPMODE = _BGPSRTEV6POLICY.nested_types_by_name['NextHopMode']
_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE = _BGPSRTEV6POLICY.nested_types_by_name['NextHopAddressType']
_BGPSRTEV6TUNNELTLV = DESCRIPTOR.message_types_by_name['BgpSrteV6TunnelTlv']
_BGPGRACEFULRESTART = DESCRIPTOR.message_types_by_name['BgpGracefulRestart']
_BGPV6PEER = DESCRIPTOR.message_types_by_name['BgpV6Peer']
_BGPV6PEER_ASTYPE = _BGPV6PEER.nested_types_by_name['AsType']
_BGPV6PEER_ASNUMBERWIDTH = _BGPV6PEER.nested_types_by_name['AsNumberWidth']
_BGPV6INTERFACE = DESCRIPTOR.message_types_by_name['BgpV6Interface']
_BGPV6SEGMENTROUTING = DESCRIPTOR.message_types_by_name['BgpV6SegmentRouting']
_BGPV6ETHERNETSEGMENT = DESCRIPTOR.message_types_by_name['BgpV6EthernetSegment']
_BGPV6ETHERNETSEGMENT_ACTIVEMODE = _BGPV6ETHERNETSEGMENT.nested_types_by_name['ActiveMode']
_BGPV6EVPNEVIS = DESCRIPTOR.message_types_by_name['BgpV6EvpnEvis']
_BGPV6EVPNEVIS_CHOICE = _BGPV6EVPNEVIS.nested_types_by_name['Choice']
_BGPV6EVIVXLAN = DESCRIPTOR.message_types_by_name['BgpV6EviVxlan']
_BGPV6EVIVXLAN_REPLICATIONTYPE = _BGPV6EVIVXLAN.nested_types_by_name['ReplicationType']
_BGPV6EVIVXLANBROADCASTDOMAIN = DESCRIPTOR.message_types_by_name['BgpV6EviVxlanBroadcastDomain']
_DEVICEVXLAN = DESCRIPTOR.message_types_by_name['DeviceVxlan']
_VXLANV4TUNNEL = DESCRIPTOR.message_types_by_name['VxlanV4Tunnel']
_VXLANV6TUNNEL = DESCRIPTOR.message_types_by_name['VxlanV6Tunnel']
_VXLANV4TUNNELDESTINATIONIPMODE = DESCRIPTOR.message_types_by_name['VxlanV4TunnelDestinationIPMode']
_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE = _VXLANV4TUNNELDESTINATIONIPMODE.nested_types_by_name['Choice']
_VXLANV6TUNNELDESTINATIONIPMODE = DESCRIPTOR.message_types_by_name['VxlanV6TunnelDestinationIPMode']
_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE = _VXLANV6TUNNELDESTINATIONIPMODE.nested_types_by_name['Choice']
_VXLANV4TUNNELDESTINATIONIPMODEUNICAST = DESCRIPTOR.message_types_by_name['VxlanV4TunnelDestinationIPModeUnicast']
_VXLANV6TUNNELDESTINATIONIPMODEUNICAST = DESCRIPTOR.message_types_by_name['VxlanV6TunnelDestinationIPModeUnicast']
_VXLANTUNNELDESTINATIONIPMODEUNICASTARPSUPPRESSIONCACHE = DESCRIPTOR.message_types_by_name['VxlanTunnelDestinationIPModeUnicastArpSuppressionCache']
_VXLANV4TUNNELDESTINATIONIPMODEUNICASTVTEP = DESCRIPTOR.message_types_by_name['VxlanV4TunnelDestinationIPModeUnicastVtep']
_VXLANV6TUNNELDESTINATIONIPMODEUNICASTVTEP = DESCRIPTOR.message_types_by_name['VxlanV6TunnelDestinationIPModeUnicastVtep']
_VXLANV4TUNNELDESTINATIONIPMODEMULTICAST = DESCRIPTOR.message_types_by_name['VxlanV4TunnelDestinationIPModeMulticast']
_VXLANV6TUNNELDESTINATIONIPMODEMULTICAST = DESCRIPTOR.message_types_by_name['VxlanV6TunnelDestinationIPModeMulticast']
_DEVICERSVP = DESCRIPTOR.message_types_by_name['DeviceRsvp']
_RSVPIPV4INTERFACE = DESCRIPTOR.message_types_by_name['RsvpIpv4Interface']
_RSVPLSPIPV4INTERFACE = DESCRIPTOR.message_types_by_name['RsvpLspIpv4Interface']
_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP = DESCRIPTOR.message_types_by_name['RsvpLspIpv4InterfaceP2PEgressIpv4Lsp']
_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE = _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP.nested_types_by_name['ReservationStyle']
_RSVPLSPIPV4INTERFACEP2PINGRESSIPV4LSP = DESCRIPTOR.message_types_by_name['RsvpLspIpv4InterfaceP2PIngressIpv4Lsp']
_RSVPSESSIONATTRIBUTE = DESCRIPTOR.message_types_by_name['RsvpSessionAttribute']
_RSVPRESOURCEAFFINITIES = DESCRIPTOR.message_types_by_name['RsvpResourceAffinities']
_RSVPTSPEC = DESCRIPTOR.message_types_by_name['RsvpTspec']
_RSVPFASTREROUTE = DESCRIPTOR.message_types_by_name['RsvpFastReroute']
_RSVPERO = DESCRIPTOR.message_types_by_name['RsvpEro']
_RSVPERO_PREPENDNEIGHBORIP = _RSVPERO.nested_types_by_name['PrependNeighborIp']
_RSVPEROSUBOBJECT = DESCRIPTOR.message_types_by_name['RsvpEroSubobject']
_RSVPEROSUBOBJECT_TYPE = _RSVPEROSUBOBJECT.nested_types_by_name['Type']
_RSVPEROSUBOBJECT_HOPTYPE = _RSVPEROSUBOBJECT.nested_types_by_name['HopType']
_FLOW = DESCRIPTOR.message_types_by_name['Flow']
_FLOWTXRX = DESCRIPTOR.message_types_by_name['FlowTxRx']
_FLOWTXRX_CHOICE = _FLOWTXRX.nested_types_by_name['Choice']
_FLOWPORT = DESCRIPTOR.message_types_by_name['FlowPort']
_FLOWROUTER = DESCRIPTOR.message_types_by_name['FlowRouter']
_FLOWROUTER_MODE = _FLOWROUTER.nested_types_by_name['Mode']
_FLOWHEADER = DESCRIPTOR.message_types_by_name['FlowHeader']
_FLOWHEADER_CHOICE = _FLOWHEADER.nested_types_by_name['Choice']
_FLOWCUSTOM = DESCRIPTOR.message_types_by_name['FlowCustom']
_FLOWCUSTOMMETRICTAG = DESCRIPTOR.message_types_by_name['FlowCustomMetricTag']
_FLOWETHERNET = DESCRIPTOR.message_types_by_name['FlowEthernet']
_FLOWVLAN = DESCRIPTOR.message_types_by_name['FlowVlan']
_FLOWVXLAN = DESCRIPTOR.message_types_by_name['FlowVxlan']
_FLOWIPV4 = DESCRIPTOR.message_types_by_name['FlowIpv4']
_FLOWIPV4PRIORITY = DESCRIPTOR.message_types_by_name['FlowIpv4Priority']
_FLOWIPV4PRIORITY_CHOICE = _FLOWIPV4PRIORITY.nested_types_by_name['Choice']
_FLOWIPV4DSCP = DESCRIPTOR.message_types_by_name['FlowIpv4Dscp']
_FLOWIPV4TOS = DESCRIPTOR.message_types_by_name['FlowIpv4Tos']
_FLOWIPV6 = DESCRIPTOR.message_types_by_name['FlowIpv6']
_FLOWPFCPAUSE = DESCRIPTOR.message_types_by_name['FlowPfcPause']
_FLOWETHERNETPAUSE = DESCRIPTOR.message_types_by_name['FlowEthernetPause']
_FLOWTCP = DESCRIPTOR.message_types_by_name['FlowTcp']
_FLOWUDP = DESCRIPTOR.message_types_by_name['FlowUdp']
_FLOWGRE = DESCRIPTOR.message_types_by_name['FlowGre']
_FLOWGTPV1 = DESCRIPTOR.message_types_by_name['FlowGtpv1']
_FLOWGTPEXTENSION = DESCRIPTOR.message_types_by_name['FlowGtpExtension']
_FLOWGTPV2 = DESCRIPTOR.message_types_by_name['FlowGtpv2']
_FLOWARP = DESCRIPTOR.message_types_by_name['FlowArp']
_FLOWICMP = DESCRIPTOR.message_types_by_name['FlowIcmp']
_FLOWICMP_CHOICE = _FLOWICMP.nested_types_by_name['Choice']
_FLOWICMPECHO = DESCRIPTOR.message_types_by_name['FlowIcmpEcho']
_FLOWICMPV6 = DESCRIPTOR.message_types_by_name['FlowIcmpv6']
_FLOWICMPV6_CHOICE = _FLOWICMPV6.nested_types_by_name['Choice']
_FLOWICMPV6ECHO = DESCRIPTOR.message_types_by_name['FlowIcmpv6Echo']
_FLOWPPP = DESCRIPTOR.message_types_by_name['FlowPpp']
_FLOWIGMPV1 = DESCRIPTOR.message_types_by_name['FlowIgmpv1']
_FLOWMPLS = DESCRIPTOR.message_types_by_name['FlowMpls']
_FLOWSIZE = DESCRIPTOR.message_types_by_name['FlowSize']
_FLOWSIZE_CHOICE = _FLOWSIZE.nested_types_by_name['Choice']
_FLOWSIZEINCREMENT = DESCRIPTOR.message_types_by_name['FlowSizeIncrement']
_FLOWSIZERANDOM = DESCRIPTOR.message_types_by_name['FlowSizeRandom']
_FLOWSIZEWEIGHTPAIRS = DESCRIPTOR.message_types_by_name['FlowSizeWeightPairs']
_FLOWSIZEWEIGHTPAIRS_CHOICE = _FLOWSIZEWEIGHTPAIRS.nested_types_by_name['Choice']
_FLOWSIZEWEIGHTPAIRS_PREDEFINED = _FLOWSIZEWEIGHTPAIRS.nested_types_by_name['Predefined']
_FLOWSIZEWEIGHTPAIRSCUSTOM = DESCRIPTOR.message_types_by_name['FlowSizeWeightPairsCustom']
_FLOWRATE = DESCRIPTOR.message_types_by_name['FlowRate']
_FLOWRATE_CHOICE = _FLOWRATE.nested_types_by_name['Choice']
_FLOWDURATION = DESCRIPTOR.message_types_by_name['FlowDuration']
_FLOWDURATION_CHOICE = _FLOWDURATION.nested_types_by_name['Choice']
_FLOWCONTINUOUS = DESCRIPTOR.message_types_by_name['FlowContinuous']
_FLOWDELAY = DESCRIPTOR.message_types_by_name['FlowDelay']
_FLOWDELAY_CHOICE = _FLOWDELAY.nested_types_by_name['Choice']
_FLOWFIXEDPACKETS = DESCRIPTOR.message_types_by_name['FlowFixedPackets']
_FLOWFIXEDSECONDS = DESCRIPTOR.message_types_by_name['FlowFixedSeconds']
_FLOWBURST = DESCRIPTOR.message_types_by_name['FlowBurst']
_FLOWDURATIONINTERBURSTGAP = DESCRIPTOR.message_types_by_name['FlowDurationInterBurstGap']
_FLOWDURATIONINTERBURSTGAP_CHOICE = _FLOWDURATIONINTERBURSTGAP.nested_types_by_name['Choice']
_FLOWMETRICS = DESCRIPTOR.message_types_by_name['FlowMetrics']
_FLOWLATENCYMETRICS = DESCRIPTOR.message_types_by_name['FlowLatencyMetrics']
_FLOWLATENCYMETRICS_MODE = _FLOWLATENCYMETRICS.nested_types_by_name['Mode']
_FLOWPREDEFINEDTAGS = DESCRIPTOR.message_types_by_name['FlowPredefinedTags']
_FLOWRXTXRATIO = DESCRIPTOR.message_types_by_name['FlowRxTxRatio']
_FLOWRXTXRATIO_CHOICE = _FLOWRXTXRATIO.nested_types_by_name['Choice']
_FLOWRXTXRATIORXCOUNT = DESCRIPTOR.message_types_by_name['FlowRxTxRatioRxCount']
_EVENT = DESCRIPTOR.message_types_by_name['Event']
_EVENTRXRATETHRESHOLD = DESCRIPTOR.message_types_by_name['EventRxRateThreshold']
_EVENTLINK = DESCRIPTOR.message_types_by_name['EventLink']
_EVENTROUTEADVERTISEWITHDRAW = DESCRIPTOR.message_types_by_name['EventRouteAdvertiseWithdraw']
_EVENTREQUEST = DESCRIPTOR.message_types_by_name['EventRequest']
_EVENTREQUEST_TYPE = _EVENTREQUEST.nested_types_by_name['Type']
_EVENTSUBSCRIPTION = DESCRIPTOR.message_types_by_name['EventSubscription']
_LLDP = DESCRIPTOR.message_types_by_name['Lldp']
_LLDPCONNECTION = DESCRIPTOR.message_types_by_name['LldpConnection']
_LLDPCONNECTION_CHOICE = _LLDPCONNECTION.nested_types_by_name['Choice']
_LLDPCHASSISID = DESCRIPTOR.message_types_by_name['LldpChassisId']
_LLDPCHASSISID_CHOICE = _LLDPCHASSISID.nested_types_by_name['Choice']
_LLDPPORTID = DESCRIPTOR.message_types_by_name['LldpPortId']
_LLDPPORTID_CHOICE = _LLDPPORTID.nested_types_by_name['Choice']
_LLDPCHASSISMACSUBTYPE = DESCRIPTOR.message_types_by_name['LldpChassisMacSubType']
_LLDPCHASSISMACSUBTYPE_CHOICE = _LLDPCHASSISMACSUBTYPE.nested_types_by_name['Choice']
_LLDPPORTINTERFACENAMESUBTYPE = DESCRIPTOR.message_types_by_name['LldpPortInterfaceNameSubType']
_LLDPPORTINTERFACENAMESUBTYPE_CHOICE = _LLDPPORTINTERFACENAMESUBTYPE.nested_types_by_name['Choice']
_LLDPSYSTEMNAME = DESCRIPTOR.message_types_by_name['LldpSystemName']
_LLDPSYSTEMNAME_CHOICE = _LLDPSYSTEMNAME.nested_types_by_name['Choice']
_ERROR = DESCRIPTOR.message_types_by_name['Error']
_ERROR_KIND = _ERROR.nested_types_by_name['Kind']
_WARNING = DESCRIPTOR.message_types_by_name['Warning']
_CONFIGUPDATE = DESCRIPTOR.message_types_by_name['ConfigUpdate']
_CONFIGUPDATE_CHOICE = _CONFIGUPDATE.nested_types_by_name['Choice']
_FLOWSUPDATE = DESCRIPTOR.message_types_by_name['FlowsUpdate']
_FLOWSUPDATE_PROPERTYNAMES = _FLOWSUPDATE.nested_types_by_name['PropertyNames']
_CONTROLSTATE = DESCRIPTOR.message_types_by_name['ControlState']
_CONTROLSTATE_CHOICE = _CONTROLSTATE.nested_types_by_name['Choice']
_STATEPORT = DESCRIPTOR.message_types_by_name['StatePort']
_STATEPORT_CHOICE = _STATEPORT.nested_types_by_name['Choice']
_STATETRAFFIC = DESCRIPTOR.message_types_by_name['StateTraffic']
_STATETRAFFIC_CHOICE = _STATETRAFFIC.nested_types_by_name['Choice']
_STATEPROTOCOL = DESCRIPTOR.message_types_by_name['StateProtocol']
_STATEPROTOCOL_CHOICE = _STATEPROTOCOL.nested_types_by_name['Choice']
_LINKSTATE = DESCRIPTOR.message_types_by_name['LinkState']
_LINKSTATE_STATE = _LINKSTATE.nested_types_by_name['State']
_TRANSMITSTATE = DESCRIPTOR.message_types_by_name['TransmitState']
_TRANSMITSTATE_STATE = _TRANSMITSTATE.nested_types_by_name['State']
_CAPTURESTATE = DESCRIPTOR.message_types_by_name['CaptureState']
_CAPTURESTATE_STATE = _CAPTURESTATE.nested_types_by_name['State']
_ROUTESTATE = DESCRIPTOR.message_types_by_name['RouteState']
_ROUTESTATE_STATE = _ROUTESTATE.nested_types_by_name['State']
_PROTOCOLSTATE = DESCRIPTOR.message_types_by_name['ProtocolState']
_PROTOCOLSTATE_STATE = _PROTOCOLSTATE.nested_types_by_name['State']
_DEVICESTATE = DESCRIPTOR.message_types_by_name['DeviceState']
_DEVICESTATE_CHOICE = _DEVICESTATE.nested_types_by_name['Choice']
_STATEPORTLINK = DESCRIPTOR.message_types_by_name['StatePortLink']
_STATEPORTLINK_STATE = _STATEPORTLINK.nested_types_by_name['State']
_STATEPORTCAPTURE = DESCRIPTOR.message_types_by_name['StatePortCapture']
_STATEPORTCAPTURE_STATE = _STATEPORTCAPTURE.nested_types_by_name['State']
_STATETRAFFICFLOWTRANSMIT = DESCRIPTOR.message_types_by_name['StateTrafficFlowTransmit']
_STATETRAFFICFLOWTRANSMIT_STATE = _STATETRAFFICFLOWTRANSMIT.nested_types_by_name['State']
_STATEPROTOCOLALL = DESCRIPTOR.message_types_by_name['StateProtocolAll']
_STATEPROTOCOLALL_STATE = _STATEPROTOCOLALL.nested_types_by_name['State']
_STATEPROTOCOLROUTE = DESCRIPTOR.message_types_by_name['StateProtocolRoute']
_STATEPROTOCOLROUTE_STATE = _STATEPROTOCOLROUTE.nested_types_by_name['State']
_STATEPROTOCOLLACP = DESCRIPTOR.message_types_by_name['StateProtocolLacp']
_STATEPROTOCOLLACP_CHOICE = _STATEPROTOCOLLACP.nested_types_by_name['Choice']
_STATEPROTOCOLLACPADMIN = DESCRIPTOR.message_types_by_name['StateProtocolLacpAdmin']
_STATEPROTOCOLLACPADMIN_STATE = _STATEPROTOCOLLACPADMIN.nested_types_by_name['State']
_LACPMEMBERSTATE = DESCRIPTOR.message_types_by_name['LacpMemberState']
_LACPMEMBERSTATE_STATE = _LACPMEMBERSTATE.nested_types_by_name['State']
_CONTROLACTION = DESCRIPTOR.message_types_by_name['ControlAction']
_CONTROLACTION_CHOICE = _CONTROLACTION.nested_types_by_name['Choice']
_CONTROLACTIONRESPONSE = DESCRIPTOR.message_types_by_name['ControlActionResponse']
_ACTIONRESPONSE = DESCRIPTOR.message_types_by_name['ActionResponse']
_ACTIONRESPONSE_CHOICE = _ACTIONRESPONSE.nested_types_by_name['Choice']
_ACTIONPROTOCOL = DESCRIPTOR.message_types_by_name['ActionProtocol']
_ACTIONPROTOCOL_CHOICE = _ACTIONPROTOCOL.nested_types_by_name['Choice']
_ACTIONRESPONSEPROTOCOL = DESCRIPTOR.message_types_by_name['ActionResponseProtocol']
_ACTIONRESPONSEPROTOCOL_CHOICE = _ACTIONRESPONSEPROTOCOL.nested_types_by_name['Choice']
_ACTIONPROTOCOLIPV4 = DESCRIPTOR.message_types_by_name['ActionProtocolIpv4']
_ACTIONPROTOCOLIPV4_CHOICE = _ACTIONPROTOCOLIPV4.nested_types_by_name['Choice']
_ACTIONRESPONSEPROTOCOLIPV4 = DESCRIPTOR.message_types_by_name['ActionResponseProtocolIpv4']
_ACTIONRESPONSEPROTOCOLIPV4_CHOICE = _ACTIONRESPONSEPROTOCOLIPV4.nested_types_by_name['Choice']
_ACTIONPROTOCOLIPV4PING = DESCRIPTOR.message_types_by_name['ActionProtocolIpv4Ping']
_ACTIONPROTOCOLIPV4PINGREQUEST = DESCRIPTOR.message_types_by_name['ActionProtocolIpv4PingRequest']
_ACTIONRESPONSEPROTOCOLIPV4PING = DESCRIPTOR.message_types_by_name['ActionResponseProtocolIpv4Ping']
_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE = DESCRIPTOR.message_types_by_name['ActionResponseProtocolIpv4PingResponse']
_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT = _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE.nested_types_by_name['Result']
_ACTIONPROTOCOLIPV6 = DESCRIPTOR.message_types_by_name['ActionProtocolIpv6']
_ACTIONPROTOCOLIPV6_CHOICE = _ACTIONPROTOCOLIPV6.nested_types_by_name['Choice']
_ACTIONRESPONSEPROTOCOLIPV6 = DESCRIPTOR.message_types_by_name['ActionResponseProtocolIpv6']
_ACTIONRESPONSEPROTOCOLIPV6_CHOICE = _ACTIONRESPONSEPROTOCOLIPV6.nested_types_by_name['Choice']
_ACTIONPROTOCOLIPV6PING = DESCRIPTOR.message_types_by_name['ActionProtocolIpv6Ping']
_ACTIONPROTOCOLIPV6PINGREQUEST = DESCRIPTOR.message_types_by_name['ActionProtocolIpv6PingRequest']
_ACTIONRESPONSEPROTOCOLIPV6PING = DESCRIPTOR.message_types_by_name['ActionResponseProtocolIpv6Ping']
_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE = DESCRIPTOR.message_types_by_name['ActionResponseProtocolIpv6PingResponse']
_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT = _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE.nested_types_by_name['Result']
_ACTIONPROTOCOLBGP = DESCRIPTOR.message_types_by_name['ActionProtocolBgp']
_ACTIONPROTOCOLBGP_CHOICE = _ACTIONPROTOCOLBGP.nested_types_by_name['Choice']
_ACTIONPROTOCOLBGPNOTIFICATION = DESCRIPTOR.message_types_by_name['ActionProtocolBgpNotification']
_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE = _ACTIONPROTOCOLBGPNOTIFICATION.nested_types_by_name['Choice']
_ACTIONPROTOCOLBGPINITIATEGRACEFULRESTART = DESCRIPTOR.message_types_by_name['ActionProtocolBgpInitiateGracefulRestart']
_PING = DESCRIPTOR.message_types_by_name['Ping']
_PING_CHOICE = _PING.nested_types_by_name['Choice']
_PINGIPV4 = DESCRIPTOR.message_types_by_name['PingIpv4']
_PINGIPV6 = DESCRIPTOR.message_types_by_name['PingIpv6']
_PINGREQUEST = DESCRIPTOR.message_types_by_name['PingRequest']
_PINGRESPONSE = DESCRIPTOR.message_types_by_name['PingResponse']
_RESPONSE = DESCRIPTOR.message_types_by_name['Response']
_RESPONSE_RESULT = _RESPONSE.nested_types_by_name['Result']
_METRICSREQUEST = DESCRIPTOR.message_types_by_name['MetricsRequest']
_METRICSREQUEST_CHOICE = _METRICSREQUEST.nested_types_by_name['Choice']
_METRICSRESPONSE = DESCRIPTOR.message_types_by_name['MetricsResponse']
_METRICSRESPONSE_CHOICE = _METRICSRESPONSE.nested_types_by_name['Choice']
_PORTMETRICSREQUEST = DESCRIPTOR.message_types_by_name['PortMetricsRequest']
_PORTMETRICSREQUEST_COLUMNNAMES = _PORTMETRICSREQUEST.nested_types_by_name['ColumnNames']
_PORTMETRIC = DESCRIPTOR.message_types_by_name['PortMetric']
_PORTMETRIC_LINK = _PORTMETRIC.nested_types_by_name['Link']
_PORTMETRIC_CAPTURE = _PORTMETRIC.nested_types_by_name['Capture']
_PORTMETRIC_TRANSMIT = _PORTMETRIC.nested_types_by_name['Transmit']
_FLOWMETRICSREQUEST = DESCRIPTOR.message_types_by_name['FlowMetricsRequest']
_FLOWMETRICSREQUEST_METRICNAMES = _FLOWMETRICSREQUEST.nested_types_by_name['MetricNames']
_FLOWTAGGEDMETRICSFILTER = DESCRIPTOR.message_types_by_name['FlowTaggedMetricsFilter']
_FLOWTAGGEDMETRICSFILTER_METRICNAMES = _FLOWTAGGEDMETRICSFILTER.nested_types_by_name['MetricNames']
_FLOWMETRICTAGFILTER = DESCRIPTOR.message_types_by_name['FlowMetricTagFilter']
_FLOWMETRIC = DESCRIPTOR.message_types_by_name['FlowMetric']
_FLOWMETRIC_TRANSMIT = _FLOWMETRIC.nested_types_by_name['Transmit']
_FLOWTAGGEDMETRIC = DESCRIPTOR.message_types_by_name['FlowTaggedMetric']
_FLOWMETRICTAG = DESCRIPTOR.message_types_by_name['FlowMetricTag']
_FLOWMETRICTAGVALUE = DESCRIPTOR.message_types_by_name['FlowMetricTagValue']
_FLOWMETRICTAGVALUE_CHOICE = _FLOWMETRICTAGVALUE.nested_types_by_name['Choice']
_METRICTIMESTAMP = DESCRIPTOR.message_types_by_name['MetricTimestamp']
_METRICLATENCY = DESCRIPTOR.message_types_by_name['MetricLatency']
_BGPV4METRICSREQUEST = DESCRIPTOR.message_types_by_name['Bgpv4MetricsRequest']
_BGPV4METRICSREQUEST_COLUMNNAMES = _BGPV4METRICSREQUEST.nested_types_by_name['ColumnNames']
_BGPV4METRIC = DESCRIPTOR.message_types_by_name['Bgpv4Metric']
_BGPV4METRIC_SESSIONSTATE = _BGPV4METRIC.nested_types_by_name['SessionState']
_BGPV4METRIC_FSMSTATE = _BGPV4METRIC.nested_types_by_name['FsmState']
_BGPV6METRICSREQUEST = DESCRIPTOR.message_types_by_name['Bgpv6MetricsRequest']
_BGPV6METRICSREQUEST_COLUMNNAMES = _BGPV6METRICSREQUEST.nested_types_by_name['ColumnNames']
_BGPV6METRIC = DESCRIPTOR.message_types_by_name['Bgpv6Metric']
_BGPV6METRIC_SESSIONSTATE = _BGPV6METRIC.nested_types_by_name['SessionState']
_BGPV6METRIC_FSMSTATE = _BGPV6METRIC.nested_types_by_name['FsmState']
_ISISMETRICSREQUEST = DESCRIPTOR.message_types_by_name['IsisMetricsRequest']
_ISISMETRICSREQUEST_COLUMNNAMES = _ISISMETRICSREQUEST.nested_types_by_name['ColumnNames']
_ISISMETRIC = DESCRIPTOR.message_types_by_name['IsisMetric']
_LAGMETRICSREQUEST = DESCRIPTOR.message_types_by_name['LagMetricsRequest']
_LAGMETRICSREQUEST_COLUMNNAMES = _LAGMETRICSREQUEST.nested_types_by_name['ColumnNames']
_LAGMETRIC = DESCRIPTOR.message_types_by_name['LagMetric']
_LAGMETRIC_OPERSTATUS = _LAGMETRIC.nested_types_by_name['OperStatus']
_LACPMETRICSREQUEST = DESCRIPTOR.message_types_by_name['LacpMetricsRequest']
_LACPMETRICSREQUEST_COLUMNNAMES = _LACPMETRICSREQUEST.nested_types_by_name['ColumnNames']
_LACPMETRIC = DESCRIPTOR.message_types_by_name['LacpMetric']
_LACPMETRIC_ACTIVITY = _LACPMETRIC.nested_types_by_name['Activity']
_LACPMETRIC_TIMEOUT = _LACPMETRIC.nested_types_by_name['Timeout']
_LACPMETRIC_SYNCHRONIZATION = _LACPMETRIC.nested_types_by_name['Synchronization']
_LLDPMETRICSREQUEST = DESCRIPTOR.message_types_by_name['LldpMetricsRequest']
_LLDPMETRICSREQUEST_COLUMNNAMES = _LLDPMETRICSREQUEST.nested_types_by_name['ColumnNames']
_LLDPMETRIC = DESCRIPTOR.message_types_by_name['LldpMetric']
_RSVPMETRICSREQUEST = DESCRIPTOR.message_types_by_name['RsvpMetricsRequest']
_RSVPMETRICSREQUEST_COLUMNNAMES = _RSVPMETRICSREQUEST.nested_types_by_name['ColumnNames']
_RSVPMETRIC = DESCRIPTOR.message_types_by_name['RsvpMetric']
_STATESREQUEST = DESCRIPTOR.message_types_by_name['StatesRequest']
_STATESREQUEST_CHOICE = _STATESREQUEST.nested_types_by_name['Choice']
_STATESRESPONSE = DESCRIPTOR.message_types_by_name['StatesResponse']
_STATESRESPONSE_CHOICE = _STATESRESPONSE.nested_types_by_name['Choice']
_NEIGHBORSV4STATESREQUEST = DESCRIPTOR.message_types_by_name['Neighborsv4StatesRequest']
_NEIGHBORSV4STATE = DESCRIPTOR.message_types_by_name['Neighborsv4State']
_NEIGHBORSV6STATESREQUEST = DESCRIPTOR.message_types_by_name['Neighborsv6StatesRequest']
_NEIGHBORSV6STATE = DESCRIPTOR.message_types_by_name['Neighborsv6State']
_BGPPREFIXSTATEREQUEST = DESCRIPTOR.message_types_by_name['BgpPrefixStateRequest']
_BGPPREFIXSTATEREQUEST_PREFIXFILTERS = _BGPPREFIXSTATEREQUEST.nested_types_by_name['PrefixFilters']
_BGPPREFIXIPV4UNICASTFILTER = DESCRIPTOR.message_types_by_name['BgpPrefixIpv4UnicastFilter']
_BGPPREFIXIPV4UNICASTFILTER_ORIGIN = _BGPPREFIXIPV4UNICASTFILTER.nested_types_by_name['Origin']
_BGPPREFIXIPV6UNICASTFILTER = DESCRIPTOR.message_types_by_name['BgpPrefixIpv6UnicastFilter']
_BGPPREFIXIPV6UNICASTFILTER_ORIGIN = _BGPPREFIXIPV6UNICASTFILTER.nested_types_by_name['Origin']
_BGPPREFIXESSTATE = DESCRIPTOR.message_types_by_name['BgpPrefixesState']
_BGPPREFIXIPV4UNICASTSTATE = DESCRIPTOR.message_types_by_name['BgpPrefixIpv4UnicastState']
_BGPPREFIXIPV4UNICASTSTATE_ORIGIN = _BGPPREFIXIPV4UNICASTSTATE.nested_types_by_name['Origin']
_BGPPREFIXIPV6UNICASTSTATE = DESCRIPTOR.message_types_by_name['BgpPrefixIpv6UnicastState']
_BGPPREFIXIPV6UNICASTSTATE_ORIGIN = _BGPPREFIXIPV6UNICASTSTATE.nested_types_by_name['Origin']
_RESULTBGPCOMMUNITY = DESCRIPTOR.message_types_by_name['ResultBgpCommunity']
_RESULTBGPCOMMUNITY_TYPE = _RESULTBGPCOMMUNITY.nested_types_by_name['Type']
_RESULTBGPASPATH = DESCRIPTOR.message_types_by_name['ResultBgpAsPath']
_RESULTBGPASPATHSEGMENT = DESCRIPTOR.message_types_by_name['ResultBgpAsPathSegment']
_RESULTBGPASPATHSEGMENT_TYPE = _RESULTBGPASPATHSEGMENT.nested_types_by_name['Type']
_ISISLSPSSTATEREQUEST = DESCRIPTOR.message_types_by_name['IsisLspsStateRequest']
_ISISLSPSSTATE = DESCRIPTOR.message_types_by_name['IsisLspsState']
_ISISLSPSTATE = DESCRIPTOR.message_types_by_name['IsisLspState']
_ISISLSPSTATE_PDUTYPE = _ISISLSPSTATE.nested_types_by_name['PduType']
_ISISLSPTLVS = DESCRIPTOR.message_types_by_name['IsisLspTlvs']
_ISISLSPHOSTNAME = DESCRIPTOR.message_types_by_name['IsisLspHostname']
_ISISLSPFLAGS = DESCRIPTOR.message_types_by_name['IsisLspFlags']
_ISISLSPISREACHABILITYTLV = DESCRIPTOR.message_types_by_name['IsisLspIsReachabilityTlv']
_ISISLSPEXTENDEDISREACHABILITYTLV = DESCRIPTOR.message_types_by_name['IsisLspExtendedIsReachabilityTlv']
_ISISLSPNEIGHBOR = DESCRIPTOR.message_types_by_name['IsisLspneighbor']
_ISISLSPIPV4INTERNALREACHABILITYTLV = DESCRIPTOR.message_types_by_name['IsisLspIpv4InternalReachabilityTlv']
_ISISLSPIPV4EXTERNALREACHABILITYTLV = DESCRIPTOR.message_types_by_name['IsisLspIpv4ExternalReachabilityTlv']
_ISISLSPV4PREFIX = DESCRIPTOR.message_types_by_name['IsisLspV4Prefix']
_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE = _ISISLSPV4PREFIX.nested_types_by_name['RedistributionType']
_ISISLSPV4PREFIX_ORIGINTYPE = _ISISLSPV4PREFIX.nested_types_by_name['OriginType']
_ISISLSPEXTENDEDIPV4REACHABILITYTLV = DESCRIPTOR.message_types_by_name['IsisLspExtendedIpv4ReachabilityTlv']
_ISISLSPEXTENDEDV4PREFIX = DESCRIPTOR.message_types_by_name['IsisLspExtendedV4Prefix']
_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE = _ISISLSPEXTENDEDV4PREFIX.nested_types_by_name['RedistributionType']
_ISISLSPIPV6REACHABILITYTLV = DESCRIPTOR.message_types_by_name['IsisLspIpv6ReachabilityTlv']
_ISISLSPV6PREFIX = DESCRIPTOR.message_types_by_name['IsisLspV6Prefix']
_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE = _ISISLSPV6PREFIX.nested_types_by_name['RedistributionType']
_ISISLSPV6PREFIX_ORIGINTYPE = _ISISLSPV6PREFIX.nested_types_by_name['OriginType']
_ISISLSPPREFIXATTRIBUTES = DESCRIPTOR.message_types_by_name['IsisLspPrefixAttributes']
_LLDPNEIGHBORSSTATEREQUEST = DESCRIPTOR.message_types_by_name['LldpNeighborsStateRequest']
_LLDPNEIGHBORSSTATE = DESCRIPTOR.message_types_by_name['LldpNeighborsState']
_LLDPNEIGHBORSSTATE_CHASSISIDTYPE = _LLDPNEIGHBORSSTATE.nested_types_by_name['ChassisIdType']
_LLDPNEIGHBORSSTATE_PORTIDTYPE = _LLDPNEIGHBORSSTATE.nested_types_by_name['PortIdType']
_LLDPCUSTOMTLVSTATE = DESCRIPTOR.message_types_by_name['LldpCustomTLVState']
_LLDPCAPABILITYSTATE = DESCRIPTOR.message_types_by_name['LldpCapabilityState']
_LLDPCAPABILITYSTATE_CAPABILITYNAME = _LLDPCAPABILITYSTATE.nested_types_by_name['CapabilityName']
_RSVPLSPSSTATEREQUEST = DESCRIPTOR.message_types_by_name['RsvpLspsStateRequest']
_RSVPLSPSSTATE = DESCRIPTOR.message_types_by_name['RsvpLspsState']
_RSVPIPV4LSPSTATE = DESCRIPTOR.message_types_by_name['RsvpIPv4LspState']
_RSVPLSPSTATE = DESCRIPTOR.message_types_by_name['RsvpLspState']
_RSVPLSPSTATE_SESSIONSTATUS = _RSVPLSPSTATE.nested_types_by_name['SessionStatus']
_RSVPLSPSTATE_LASTFLAPREASON = _RSVPLSPSTATE.nested_types_by_name['LastFlapReason']
_RSVPLSPIPV4RRO = DESCRIPTOR.message_types_by_name['RsvpLspIpv4Rro']
_RSVPLSPIPV4ERO = DESCRIPTOR.message_types_by_name['RsvpLspIpv4Ero']
_RSVPLSPIPV4ERO_TYPE = _RSVPLSPIPV4ERO.nested_types_by_name['Type']
_CAPTUREREQUEST = DESCRIPTOR.message_types_by_name['CaptureRequest']
_PATTERNFLOWETHERNETDSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetDstCounter']
_PATTERNFLOWETHERNETDSTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowEthernetDstMetricTag']
_PATTERNFLOWETHERNETDST = DESCRIPTOR.message_types_by_name['PatternFlowEthernetDst']
_PATTERNFLOWETHERNETDST_CHOICE = _PATTERNFLOWETHERNETDST.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETSRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetSrcCounter']
_PATTERNFLOWETHERNETSRCMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowEthernetSrcMetricTag']
_PATTERNFLOWETHERNETSRC = DESCRIPTOR.message_types_by_name['PatternFlowEthernetSrc']
_PATTERNFLOWETHERNETSRC_CHOICE = _PATTERNFLOWETHERNETSRC.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETETHERTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetEtherTypeCounter']
_PATTERNFLOWETHERNETETHERTYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowEthernetEtherTypeMetricTag']
_PATTERNFLOWETHERNETETHERTYPE = DESCRIPTOR.message_types_by_name['PatternFlowEthernetEtherType']
_PATTERNFLOWETHERNETETHERTYPE_CHOICE = _PATTERNFLOWETHERNETETHERTYPE.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPFCQUEUECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPfcQueueCounter']
_PATTERNFLOWETHERNETPFCQUEUEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPfcQueueMetricTag']
_PATTERNFLOWETHERNETPFCQUEUE = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPfcQueue']
_PATTERNFLOWETHERNETPFCQUEUE_CHOICE = _PATTERNFLOWETHERNETPFCQUEUE.nested_types_by_name['Choice']
_PATTERNFLOWVLANPRIORITYCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVlanPriorityCounter']
_PATTERNFLOWVLANPRIORITYMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowVlanPriorityMetricTag']
_PATTERNFLOWVLANPRIORITY = DESCRIPTOR.message_types_by_name['PatternFlowVlanPriority']
_PATTERNFLOWVLANPRIORITY_CHOICE = _PATTERNFLOWVLANPRIORITY.nested_types_by_name['Choice']
_PATTERNFLOWVLANCFICOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVlanCfiCounter']
_PATTERNFLOWVLANCFIMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowVlanCfiMetricTag']
_PATTERNFLOWVLANCFI = DESCRIPTOR.message_types_by_name['PatternFlowVlanCfi']
_PATTERNFLOWVLANCFI_CHOICE = _PATTERNFLOWVLANCFI.nested_types_by_name['Choice']
_PATTERNFLOWVLANIDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVlanIdCounter']
_PATTERNFLOWVLANIDMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowVlanIdMetricTag']
_PATTERNFLOWVLANID = DESCRIPTOR.message_types_by_name['PatternFlowVlanId']
_PATTERNFLOWVLANID_CHOICE = _PATTERNFLOWVLANID.nested_types_by_name['Choice']
_PATTERNFLOWVLANTPIDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVlanTpidCounter']
_PATTERNFLOWVLANTPIDMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowVlanTpidMetricTag']
_PATTERNFLOWVLANTPID = DESCRIPTOR.message_types_by_name['PatternFlowVlanTpid']
_PATTERNFLOWVLANTPID_CHOICE = _PATTERNFLOWVLANTPID.nested_types_by_name['Choice']
_PATTERNFLOWVXLANFLAGSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVxlanFlagsCounter']
_PATTERNFLOWVXLANFLAGSMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowVxlanFlagsMetricTag']
_PATTERNFLOWVXLANFLAGS = DESCRIPTOR.message_types_by_name['PatternFlowVxlanFlags']
_PATTERNFLOWVXLANFLAGS_CHOICE = _PATTERNFLOWVXLANFLAGS.nested_types_by_name['Choice']
_PATTERNFLOWVXLANRESERVED0COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved0Counter']
_PATTERNFLOWVXLANRESERVED0METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved0MetricTag']
_PATTERNFLOWVXLANRESERVED0 = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved0']
_PATTERNFLOWVXLANRESERVED0_CHOICE = _PATTERNFLOWVXLANRESERVED0.nested_types_by_name['Choice']
_PATTERNFLOWVXLANVNICOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVxlanVniCounter']
_PATTERNFLOWVXLANVNIMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowVxlanVniMetricTag']
_PATTERNFLOWVXLANVNI = DESCRIPTOR.message_types_by_name['PatternFlowVxlanVni']
_PATTERNFLOWVXLANVNI_CHOICE = _PATTERNFLOWVXLANVNI.nested_types_by_name['Choice']
_PATTERNFLOWVXLANRESERVED1COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved1Counter']
_PATTERNFLOWVXLANRESERVED1METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved1MetricTag']
_PATTERNFLOWVXLANRESERVED1 = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved1']
_PATTERNFLOWVXLANRESERVED1_CHOICE = _PATTERNFLOWVXLANRESERVED1.nested_types_by_name['Choice']
_PATTERNFLOWIPV4VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4VersionCounter']
_PATTERNFLOWIPV4VERSIONMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4VersionMetricTag']
_PATTERNFLOWIPV4VERSION = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Version']
_PATTERNFLOWIPV4VERSION_CHOICE = _PATTERNFLOWIPV4VERSION.nested_types_by_name['Choice']
_PATTERNFLOWIPV4HEADERLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderLengthCounter']
_PATTERNFLOWIPV4HEADERLENGTHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderLengthMetricTag']
_PATTERNFLOWIPV4HEADERLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderLength']
_PATTERNFLOWIPV4HEADERLENGTH_CHOICE = _PATTERNFLOWIPV4HEADERLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOTALLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TotalLengthCounter']
_PATTERNFLOWIPV4TOTALLENGTHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TotalLengthMetricTag']
_PATTERNFLOWIPV4TOTALLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TotalLength']
_PATTERNFLOWIPV4TOTALLENGTH_CHOICE = _PATTERNFLOWIPV4TOTALLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4IdentificationCounter']
_PATTERNFLOWIPV4IDENTIFICATIONMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4IdentificationMetricTag']
_PATTERNFLOWIPV4IDENTIFICATION = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Identification']
_PATTERNFLOWIPV4IDENTIFICATION_CHOICE = _PATTERNFLOWIPV4IDENTIFICATION.nested_types_by_name['Choice']
_PATTERNFLOWIPV4RESERVEDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4ReservedCounter']
_PATTERNFLOWIPV4RESERVEDMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4ReservedMetricTag']
_PATTERNFLOWIPV4RESERVED = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Reserved']
_PATTERNFLOWIPV4RESERVED_CHOICE = _PATTERNFLOWIPV4RESERVED.nested_types_by_name['Choice']
_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DontFragmentCounter']
_PATTERNFLOWIPV4DONTFRAGMENTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DontFragmentMetricTag']
_PATTERNFLOWIPV4DONTFRAGMENT = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DontFragment']
_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE = _PATTERNFLOWIPV4DONTFRAGMENT.nested_types_by_name['Choice']
_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4MoreFragmentsCounter']
_PATTERNFLOWIPV4MOREFRAGMENTSMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4MoreFragmentsMetricTag']
_PATTERNFLOWIPV4MOREFRAGMENTS = DESCRIPTOR.message_types_by_name['PatternFlowIpv4MoreFragments']
_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE = _PATTERNFLOWIPV4MOREFRAGMENTS.nested_types_by_name['Choice']
_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4FragmentOffsetCounter']
_PATTERNFLOWIPV4FRAGMENTOFFSETMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4FragmentOffsetMetricTag']
_PATTERNFLOWIPV4FRAGMENTOFFSET = DESCRIPTOR.message_types_by_name['PatternFlowIpv4FragmentOffset']
_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE = _PATTERNFLOWIPV4FRAGMENTOFFSET.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TIMETOLIVECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TimeToLiveCounter']
_PATTERNFLOWIPV4TIMETOLIVEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TimeToLiveMetricTag']
_PATTERNFLOWIPV4TIMETOLIVE = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TimeToLive']
_PATTERNFLOWIPV4TIMETOLIVE_CHOICE = _PATTERNFLOWIPV4TIMETOLIVE.nested_types_by_name['Choice']
_PATTERNFLOWIPV4PROTOCOLCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4ProtocolCounter']
_PATTERNFLOWIPV4PROTOCOLMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4ProtocolMetricTag']
_PATTERNFLOWIPV4PROTOCOL = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Protocol']
_PATTERNFLOWIPV4PROTOCOL_CHOICE = _PATTERNFLOWIPV4PROTOCOL.nested_types_by_name['Choice']
_PATTERNFLOWIPV4HEADERCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderChecksum']
_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE = _PATTERNFLOWIPV4HEADERCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED = _PATTERNFLOWIPV4HEADERCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWIPV4SRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4SrcCounter']
_PATTERNFLOWIPV4SRCMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4SrcMetricTag']
_PATTERNFLOWIPV4SRC = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Src']
_PATTERNFLOWIPV4SRC_CHOICE = _PATTERNFLOWIPV4SRC.nested_types_by_name['Choice']
_PATTERNFLOWIPV4DSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DstCounter']
_PATTERNFLOWIPV4DSTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DstMetricTag']
_PATTERNFLOWIPV4DST = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Dst']
_PATTERNFLOWIPV4DST_CHOICE = _PATTERNFLOWIPV4DST.nested_types_by_name['Choice']
_PATTERNFLOWIPV4PRIORITYRAWCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4PriorityRawCounter']
_PATTERNFLOWIPV4PRIORITYRAWMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4PriorityRawMetricTag']
_PATTERNFLOWIPV4PRIORITYRAW = DESCRIPTOR.message_types_by_name['PatternFlowIpv4PriorityRaw']
_PATTERNFLOWIPV4PRIORITYRAW_CHOICE = _PATTERNFLOWIPV4PRIORITYRAW.nested_types_by_name['Choice']
_PATTERNFLOWIPV4DSCPPHBCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpPhbCounter']
_PATTERNFLOWIPV4DSCPPHBMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpPhbMetricTag']
_PATTERNFLOWIPV4DSCPPHB = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpPhb']
_PATTERNFLOWIPV4DSCPPHB_CHOICE = _PATTERNFLOWIPV4DSCPPHB.nested_types_by_name['Choice']
_PATTERNFLOWIPV4DSCPECNCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpEcnCounter']
_PATTERNFLOWIPV4DSCPECNMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpEcnMetricTag']
_PATTERNFLOWIPV4DSCPECN = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpEcn']
_PATTERNFLOWIPV4DSCPECN_CHOICE = _PATTERNFLOWIPV4DSCPECN.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosPrecedenceCounter']
_PATTERNFLOWIPV4TOSPRECEDENCEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosPrecedenceMetricTag']
_PATTERNFLOWIPV4TOSPRECEDENCE = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosPrecedence']
_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE = _PATTERNFLOWIPV4TOSPRECEDENCE.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSDELAYCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosDelayCounter']
_PATTERNFLOWIPV4TOSDELAYMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosDelayMetricTag']
_PATTERNFLOWIPV4TOSDELAY = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosDelay']
_PATTERNFLOWIPV4TOSDELAY_CHOICE = _PATTERNFLOWIPV4TOSDELAY.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosThroughputCounter']
_PATTERNFLOWIPV4TOSTHROUGHPUTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosThroughputMetricTag']
_PATTERNFLOWIPV4TOSTHROUGHPUT = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosThroughput']
_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE = _PATTERNFLOWIPV4TOSTHROUGHPUT.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosReliabilityCounter']
_PATTERNFLOWIPV4TOSRELIABILITYMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosReliabilityMetricTag']
_PATTERNFLOWIPV4TOSRELIABILITY = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosReliability']
_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE = _PATTERNFLOWIPV4TOSRELIABILITY.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSMONETARYCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosMonetaryCounter']
_PATTERNFLOWIPV4TOSMONETARYMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosMonetaryMetricTag']
_PATTERNFLOWIPV4TOSMONETARY = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosMonetary']
_PATTERNFLOWIPV4TOSMONETARY_CHOICE = _PATTERNFLOWIPV4TOSMONETARY.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSUNUSEDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosUnusedCounter']
_PATTERNFLOWIPV4TOSUNUSEDMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosUnusedMetricTag']
_PATTERNFLOWIPV4TOSUNUSED = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosUnused']
_PATTERNFLOWIPV4TOSUNUSED_CHOICE = _PATTERNFLOWIPV4TOSUNUSED.nested_types_by_name['Choice']
_PATTERNFLOWIPV6VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6VersionCounter']
_PATTERNFLOWIPV6VERSIONMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv6VersionMetricTag']
_PATTERNFLOWIPV6VERSION = DESCRIPTOR.message_types_by_name['PatternFlowIpv6Version']
_PATTERNFLOWIPV6VERSION_CHOICE = _PATTERNFLOWIPV6VERSION.nested_types_by_name['Choice']
_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6TrafficClassCounter']
_PATTERNFLOWIPV6TRAFFICCLASSMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv6TrafficClassMetricTag']
_PATTERNFLOWIPV6TRAFFICCLASS = DESCRIPTOR.message_types_by_name['PatternFlowIpv6TrafficClass']
_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE = _PATTERNFLOWIPV6TRAFFICCLASS.nested_types_by_name['Choice']
_PATTERNFLOWIPV6FLOWLABELCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6FlowLabelCounter']
_PATTERNFLOWIPV6FLOWLABELMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv6FlowLabelMetricTag']
_PATTERNFLOWIPV6FLOWLABEL = DESCRIPTOR.message_types_by_name['PatternFlowIpv6FlowLabel']
_PATTERNFLOWIPV6FLOWLABEL_CHOICE = _PATTERNFLOWIPV6FLOWLABEL.nested_types_by_name['Choice']
_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6PayloadLengthCounter']
_PATTERNFLOWIPV6PAYLOADLENGTHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv6PayloadLengthMetricTag']
_PATTERNFLOWIPV6PAYLOADLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowIpv6PayloadLength']
_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE = _PATTERNFLOWIPV6PAYLOADLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWIPV6NEXTHEADERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6NextHeaderCounter']
_PATTERNFLOWIPV6NEXTHEADERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv6NextHeaderMetricTag']
_PATTERNFLOWIPV6NEXTHEADER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6NextHeader']
_PATTERNFLOWIPV6NEXTHEADER_CHOICE = _PATTERNFLOWIPV6NEXTHEADER.nested_types_by_name['Choice']
_PATTERNFLOWIPV6HOPLIMITCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6HopLimitCounter']
_PATTERNFLOWIPV6HOPLIMITMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv6HopLimitMetricTag']
_PATTERNFLOWIPV6HOPLIMIT = DESCRIPTOR.message_types_by_name['PatternFlowIpv6HopLimit']
_PATTERNFLOWIPV6HOPLIMIT_CHOICE = _PATTERNFLOWIPV6HOPLIMIT.nested_types_by_name['Choice']
_PATTERNFLOWIPV6SRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6SrcCounter']
_PATTERNFLOWIPV6SRCMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv6SrcMetricTag']
_PATTERNFLOWIPV6SRC = DESCRIPTOR.message_types_by_name['PatternFlowIpv6Src']
_PATTERNFLOWIPV6SRC_CHOICE = _PATTERNFLOWIPV6SRC.nested_types_by_name['Choice']
_PATTERNFLOWIPV6DSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6DstCounter']
_PATTERNFLOWIPV6DSTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIpv6DstMetricTag']
_PATTERNFLOWIPV6DST = DESCRIPTOR.message_types_by_name['PatternFlowIpv6Dst']
_PATTERNFLOWIPV6DST_CHOICE = _PATTERNFLOWIPV6DST.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEDSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseDstCounter']
_PATTERNFLOWPFCPAUSEDSTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseDstMetricTag']
_PATTERNFLOWPFCPAUSEDST = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseDst']
_PATTERNFLOWPFCPAUSEDST_CHOICE = _PATTERNFLOWPFCPAUSEDST.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSESRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseSrcCounter']
_PATTERNFLOWPFCPAUSESRCMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseSrcMetricTag']
_PATTERNFLOWPFCPAUSESRC = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseSrc']
_PATTERNFLOWPFCPAUSESRC_CHOICE = _PATTERNFLOWPFCPAUSESRC.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseEtherTypeCounter']
_PATTERNFLOWPFCPAUSEETHERTYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseEtherTypeMetricTag']
_PATTERNFLOWPFCPAUSEETHERTYPE = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseEtherType']
_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE = _PATTERNFLOWPFCPAUSEETHERTYPE.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseControlOpCodeCounter']
_PATTERNFLOWPFCPAUSECONTROLOPCODEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseControlOpCodeMetricTag']
_PATTERNFLOWPFCPAUSECONTROLOPCODE = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseControlOpCode']
_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE = _PATTERNFLOWPFCPAUSECONTROLOPCODE.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseClassEnableVectorCounter']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTORMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseClassEnableVectorMetricTag']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseClassEnableVector']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass0Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS0METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass0MetricTag']
_PATTERNFLOWPFCPAUSEPAUSECLASS0 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass0']
_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS0.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass1Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS1METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass1MetricTag']
_PATTERNFLOWPFCPAUSEPAUSECLASS1 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass1']
_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS1.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass2Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS2METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass2MetricTag']
_PATTERNFLOWPFCPAUSEPAUSECLASS2 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass2']
_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS2.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass3Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS3METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass3MetricTag']
_PATTERNFLOWPFCPAUSEPAUSECLASS3 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass3']
_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS3.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass4Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS4METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass4MetricTag']
_PATTERNFLOWPFCPAUSEPAUSECLASS4 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass4']
_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS4.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass5Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS5METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass5MetricTag']
_PATTERNFLOWPFCPAUSEPAUSECLASS5 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass5']
_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS5.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass6Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS6METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass6MetricTag']
_PATTERNFLOWPFCPAUSEPAUSECLASS6 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass6']
_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS6.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass7Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS7METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass7MetricTag']
_PATTERNFLOWPFCPAUSEPAUSECLASS7 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass7']
_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS7.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSEDSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseDstCounter']
_PATTERNFLOWETHERNETPAUSEDSTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseDstMetricTag']
_PATTERNFLOWETHERNETPAUSEDST = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseDst']
_PATTERNFLOWETHERNETPAUSEDST_CHOICE = _PATTERNFLOWETHERNETPAUSEDST.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSESRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseSrcCounter']
_PATTERNFLOWETHERNETPAUSESRCMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseSrcMetricTag']
_PATTERNFLOWETHERNETPAUSESRC = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseSrc']
_PATTERNFLOWETHERNETPAUSESRC_CHOICE = _PATTERNFLOWETHERNETPAUSESRC.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseEtherTypeCounter']
_PATTERNFLOWETHERNETPAUSEETHERTYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseEtherTypeMetricTag']
_PATTERNFLOWETHERNETPAUSEETHERTYPE = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseEtherType']
_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE = _PATTERNFLOWETHERNETPAUSEETHERTYPE.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseControlOpCodeCounter']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseControlOpCodeMetricTag']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseControlOpCode']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSETIMECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseTimeCounter']
_PATTERNFLOWETHERNETPAUSETIMEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseTimeMetricTag']
_PATTERNFLOWETHERNETPAUSETIME = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseTime']
_PATTERNFLOWETHERNETPAUSETIME_CHOICE = _PATTERNFLOWETHERNETPAUSETIME.nested_types_by_name['Choice']
_PATTERNFLOWTCPSRCPORTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpSrcPortCounter']
_PATTERNFLOWTCPSRCPORTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpSrcPortMetricTag']
_PATTERNFLOWTCPSRCPORT = DESCRIPTOR.message_types_by_name['PatternFlowTcpSrcPort']
_PATTERNFLOWTCPSRCPORT_CHOICE = _PATTERNFLOWTCPSRCPORT.nested_types_by_name['Choice']
_PATTERNFLOWTCPDSTPORTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpDstPortCounter']
_PATTERNFLOWTCPDSTPORTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpDstPortMetricTag']
_PATTERNFLOWTCPDSTPORT = DESCRIPTOR.message_types_by_name['PatternFlowTcpDstPort']
_PATTERNFLOWTCPDSTPORT_CHOICE = _PATTERNFLOWTCPDSTPORT.nested_types_by_name['Choice']
_PATTERNFLOWTCPSEQNUMCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpSeqNumCounter']
_PATTERNFLOWTCPSEQNUMMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpSeqNumMetricTag']
_PATTERNFLOWTCPSEQNUM = DESCRIPTOR.message_types_by_name['PatternFlowTcpSeqNum']
_PATTERNFLOWTCPSEQNUM_CHOICE = _PATTERNFLOWTCPSEQNUM.nested_types_by_name['Choice']
_PATTERNFLOWTCPACKNUMCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpAckNumCounter']
_PATTERNFLOWTCPACKNUMMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpAckNumMetricTag']
_PATTERNFLOWTCPACKNUM = DESCRIPTOR.message_types_by_name['PatternFlowTcpAckNum']
_PATTERNFLOWTCPACKNUM_CHOICE = _PATTERNFLOWTCPACKNUM.nested_types_by_name['Choice']
_PATTERNFLOWTCPDATAOFFSETCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpDataOffsetCounter']
_PATTERNFLOWTCPDATAOFFSETMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpDataOffsetMetricTag']
_PATTERNFLOWTCPDATAOFFSET = DESCRIPTOR.message_types_by_name['PatternFlowTcpDataOffset']
_PATTERNFLOWTCPDATAOFFSET_CHOICE = _PATTERNFLOWTCPDATAOFFSET.nested_types_by_name['Choice']
_PATTERNFLOWTCPECNNSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnNsCounter']
_PATTERNFLOWTCPECNNSMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnNsMetricTag']
_PATTERNFLOWTCPECNNS = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnNs']
_PATTERNFLOWTCPECNNS_CHOICE = _PATTERNFLOWTCPECNNS.nested_types_by_name['Choice']
_PATTERNFLOWTCPECNCWRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnCwrCounter']
_PATTERNFLOWTCPECNCWRMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnCwrMetricTag']
_PATTERNFLOWTCPECNCWR = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnCwr']
_PATTERNFLOWTCPECNCWR_CHOICE = _PATTERNFLOWTCPECNCWR.nested_types_by_name['Choice']
_PATTERNFLOWTCPECNECHOCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnEchoCounter']
_PATTERNFLOWTCPECNECHOMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnEchoMetricTag']
_PATTERNFLOWTCPECNECHO = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnEcho']
_PATTERNFLOWTCPECNECHO_CHOICE = _PATTERNFLOWTCPECNECHO.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLURGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlUrgCounter']
_PATTERNFLOWTCPCTLURGMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlUrgMetricTag']
_PATTERNFLOWTCPCTLURG = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlUrg']
_PATTERNFLOWTCPCTLURG_CHOICE = _PATTERNFLOWTCPCTLURG.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLACKCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlAckCounter']
_PATTERNFLOWTCPCTLACKMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlAckMetricTag']
_PATTERNFLOWTCPCTLACK = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlAck']
_PATTERNFLOWTCPCTLACK_CHOICE = _PATTERNFLOWTCPCTLACK.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLPSHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlPshCounter']
_PATTERNFLOWTCPCTLPSHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlPshMetricTag']
_PATTERNFLOWTCPCTLPSH = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlPsh']
_PATTERNFLOWTCPCTLPSH_CHOICE = _PATTERNFLOWTCPCTLPSH.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLRSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlRstCounter']
_PATTERNFLOWTCPCTLRSTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlRstMetricTag']
_PATTERNFLOWTCPCTLRST = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlRst']
_PATTERNFLOWTCPCTLRST_CHOICE = _PATTERNFLOWTCPCTLRST.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLSYNCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlSynCounter']
_PATTERNFLOWTCPCTLSYNMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlSynMetricTag']
_PATTERNFLOWTCPCTLSYN = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlSyn']
_PATTERNFLOWTCPCTLSYN_CHOICE = _PATTERNFLOWTCPCTLSYN.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLFINCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlFinCounter']
_PATTERNFLOWTCPCTLFINMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlFinMetricTag']
_PATTERNFLOWTCPCTLFIN = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlFin']
_PATTERNFLOWTCPCTLFIN_CHOICE = _PATTERNFLOWTCPCTLFIN.nested_types_by_name['Choice']
_PATTERNFLOWTCPWINDOWCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpWindowCounter']
_PATTERNFLOWTCPWINDOWMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowTcpWindowMetricTag']
_PATTERNFLOWTCPWINDOW = DESCRIPTOR.message_types_by_name['PatternFlowTcpWindow']
_PATTERNFLOWTCPWINDOW_CHOICE = _PATTERNFLOWTCPWINDOW.nested_types_by_name['Choice']
_PATTERNFLOWUDPSRCPORTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowUdpSrcPortCounter']
_PATTERNFLOWUDPSRCPORTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowUdpSrcPortMetricTag']
_PATTERNFLOWUDPSRCPORT = DESCRIPTOR.message_types_by_name['PatternFlowUdpSrcPort']
_PATTERNFLOWUDPSRCPORT_CHOICE = _PATTERNFLOWUDPSRCPORT.nested_types_by_name['Choice']
_PATTERNFLOWUDPDSTPORTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowUdpDstPortCounter']
_PATTERNFLOWUDPDSTPORTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowUdpDstPortMetricTag']
_PATTERNFLOWUDPDSTPORT = DESCRIPTOR.message_types_by_name['PatternFlowUdpDstPort']
_PATTERNFLOWUDPDSTPORT_CHOICE = _PATTERNFLOWUDPDSTPORT.nested_types_by_name['Choice']
_PATTERNFLOWUDPLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowUdpLengthCounter']
_PATTERNFLOWUDPLENGTHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowUdpLengthMetricTag']
_PATTERNFLOWUDPLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowUdpLength']
_PATTERNFLOWUDPLENGTH_CHOICE = _PATTERNFLOWUDPLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWUDPCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowUdpChecksum']
_PATTERNFLOWUDPCHECKSUM_CHOICE = _PATTERNFLOWUDPCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWUDPCHECKSUM_GENERATED = _PATTERNFLOWUDPCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreChecksumPresentCounter']
_PATTERNFLOWGRECHECKSUMPRESENTMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGreChecksumPresentMetricTag']
_PATTERNFLOWGRECHECKSUMPRESENT = DESCRIPTOR.message_types_by_name['PatternFlowGreChecksumPresent']
_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE = _PATTERNFLOWGRECHECKSUMPRESENT.nested_types_by_name['Choice']
_PATTERNFLOWGRERESERVED0COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved0Counter']
_PATTERNFLOWGRERESERVED0METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved0MetricTag']
_PATTERNFLOWGRERESERVED0 = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved0']
_PATTERNFLOWGRERESERVED0_CHOICE = _PATTERNFLOWGRERESERVED0.nested_types_by_name['Choice']
_PATTERNFLOWGREVERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreVersionCounter']
_PATTERNFLOWGREVERSIONMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGreVersionMetricTag']
_PATTERNFLOWGREVERSION = DESCRIPTOR.message_types_by_name['PatternFlowGreVersion']
_PATTERNFLOWGREVERSION_CHOICE = _PATTERNFLOWGREVERSION.nested_types_by_name['Choice']
_PATTERNFLOWGREPROTOCOLCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreProtocolCounter']
_PATTERNFLOWGREPROTOCOLMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGreProtocolMetricTag']
_PATTERNFLOWGREPROTOCOL = DESCRIPTOR.message_types_by_name['PatternFlowGreProtocol']
_PATTERNFLOWGREPROTOCOL_CHOICE = _PATTERNFLOWGREPROTOCOL.nested_types_by_name['Choice']
_PATTERNFLOWGRECHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowGreChecksum']
_PATTERNFLOWGRECHECKSUM_CHOICE = _PATTERNFLOWGRECHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWGRECHECKSUM_GENERATED = _PATTERNFLOWGRECHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWGRERESERVED1COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved1Counter']
_PATTERNFLOWGRERESERVED1METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved1MetricTag']
_PATTERNFLOWGRERESERVED1 = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved1']
_PATTERNFLOWGRERESERVED1_CHOICE = _PATTERNFLOWGRERESERVED1.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1VersionCounter']
_PATTERNFLOWGTPV1VERSIONMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1VersionMetricTag']
_PATTERNFLOWGTPV1VERSION = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1Version']
_PATTERNFLOWGTPV1VERSION_CHOICE = _PATTERNFLOWGTPV1VERSION.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ProtocolTypeCounter']
_PATTERNFLOWGTPV1PROTOCOLTYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ProtocolTypeMetricTag']
_PATTERNFLOWGTPV1PROTOCOLTYPE = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ProtocolType']
_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE = _PATTERNFLOWGTPV1PROTOCOLTYPE.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1RESERVEDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ReservedCounter']
_PATTERNFLOWGTPV1RESERVEDMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ReservedMetricTag']
_PATTERNFLOWGTPV1RESERVED = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1Reserved']
_PATTERNFLOWGTPV1RESERVED_CHOICE = _PATTERNFLOWGTPV1RESERVED.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1EFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1EFlagCounter']
_PATTERNFLOWGTPV1EFLAGMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1EFlagMetricTag']
_PATTERNFLOWGTPV1EFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1EFlag']
_PATTERNFLOWGTPV1EFLAG_CHOICE = _PATTERNFLOWGTPV1EFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1SFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SFlagCounter']
_PATTERNFLOWGTPV1SFLAGMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SFlagMetricTag']
_PATTERNFLOWGTPV1SFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SFlag']
_PATTERNFLOWGTPV1SFLAG_CHOICE = _PATTERNFLOWGTPV1SFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1PNFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1PnFlagCounter']
_PATTERNFLOWGTPV1PNFLAGMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1PnFlagMetricTag']
_PATTERNFLOWGTPV1PNFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1PnFlag']
_PATTERNFLOWGTPV1PNFLAG_CHOICE = _PATTERNFLOWGTPV1PNFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1MESSAGETYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageTypeCounter']
_PATTERNFLOWGTPV1MESSAGETYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageTypeMetricTag']
_PATTERNFLOWGTPV1MESSAGETYPE = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageType']
_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE = _PATTERNFLOWGTPV1MESSAGETYPE.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageLengthCounter']
_PATTERNFLOWGTPV1MESSAGELENGTHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageLengthMetricTag']
_PATTERNFLOWGTPV1MESSAGELENGTH = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageLength']
_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE = _PATTERNFLOWGTPV1MESSAGELENGTH.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1TEIDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1TeidCounter']
_PATTERNFLOWGTPV1TEIDMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1TeidMetricTag']
_PATTERNFLOWGTPV1TEID = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1Teid']
_PATTERNFLOWGTPV1TEID_CHOICE = _PATTERNFLOWGTPV1TEID.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SquenceNumberCounter']
_PATTERNFLOWGTPV1SQUENCENUMBERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SquenceNumberMetricTag']
_PATTERNFLOWGTPV1SQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SquenceNumber']
_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE = _PATTERNFLOWGTPV1SQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NPduNumberCounter']
_PATTERNFLOWGTPV1NPDUNUMBERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NPduNumberMetricTag']
_PATTERNFLOWGTPV1NPDUNUMBER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NPduNumber']
_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE = _PATTERNFLOWGTPV1NPDUNUMBER.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NextExtensionHeaderTypeCounter']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NextExtensionHeaderTypeMetricTag']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NextExtensionHeaderType']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.nested_types_by_name['Choice']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionExtensionLengthCounter']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionExtensionLengthMetricTag']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionExtensionLength']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionContentsCounter']
_PATTERNFLOWGTPEXTENSIONCONTENTSMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionContentsMetricTag']
_PATTERNFLOWGTPEXTENSIONCONTENTS = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionContents']
_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE = _PATTERNFLOWGTPEXTENSIONCONTENTS.nested_types_by_name['Choice']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionNextExtensionHeaderCounter']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionNextExtensionHeaderMetricTag']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionNextExtensionHeader']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2VersionCounter']
_PATTERNFLOWGTPV2VERSIONMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2VersionMetricTag']
_PATTERNFLOWGTPV2VERSION = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Version']
_PATTERNFLOWGTPV2VERSION_CHOICE = _PATTERNFLOWGTPV2VERSION.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2PiggybackingFlagCounter']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAGMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2PiggybackingFlagMetricTag']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2PiggybackingFlag']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2TEIDFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidFlagCounter']
_PATTERNFLOWGTPV2TEIDFLAGMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidFlagMetricTag']
_PATTERNFLOWGTPV2TEIDFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidFlag']
_PATTERNFLOWGTPV2TEIDFLAG_CHOICE = _PATTERNFLOWGTPV2TEIDFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2SPARE1COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare1Counter']
_PATTERNFLOWGTPV2SPARE1METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare1MetricTag']
_PATTERNFLOWGTPV2SPARE1 = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare1']
_PATTERNFLOWGTPV2SPARE1_CHOICE = _PATTERNFLOWGTPV2SPARE1.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2MESSAGETYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageTypeCounter']
_PATTERNFLOWGTPV2MESSAGETYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageTypeMetricTag']
_PATTERNFLOWGTPV2MESSAGETYPE = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageType']
_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE = _PATTERNFLOWGTPV2MESSAGETYPE.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageLengthCounter']
_PATTERNFLOWGTPV2MESSAGELENGTHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageLengthMetricTag']
_PATTERNFLOWGTPV2MESSAGELENGTH = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageLength']
_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE = _PATTERNFLOWGTPV2MESSAGELENGTH.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2TEIDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidCounter']
_PATTERNFLOWGTPV2TEIDMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidMetricTag']
_PATTERNFLOWGTPV2TEID = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Teid']
_PATTERNFLOWGTPV2TEID_CHOICE = _PATTERNFLOWGTPV2TEID.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2SequenceNumberCounter']
_PATTERNFLOWGTPV2SEQUENCENUMBERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2SequenceNumberMetricTag']
_PATTERNFLOWGTPV2SEQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2SequenceNumber']
_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE = _PATTERNFLOWGTPV2SEQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2SPARE2COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare2Counter']
_PATTERNFLOWGTPV2SPARE2METRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare2MetricTag']
_PATTERNFLOWGTPV2SPARE2 = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare2']
_PATTERNFLOWGTPV2SPARE2_CHOICE = _PATTERNFLOWGTPV2SPARE2.nested_types_by_name['Choice']
_PATTERNFLOWARPHARDWARETYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareTypeCounter']
_PATTERNFLOWARPHARDWARETYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareTypeMetricTag']
_PATTERNFLOWARPHARDWARETYPE = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareType']
_PATTERNFLOWARPHARDWARETYPE_CHOICE = _PATTERNFLOWARPHARDWARETYPE.nested_types_by_name['Choice']
_PATTERNFLOWARPPROTOCOLTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolTypeCounter']
_PATTERNFLOWARPPROTOCOLTYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolTypeMetricTag']
_PATTERNFLOWARPPROTOCOLTYPE = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolType']
_PATTERNFLOWARPPROTOCOLTYPE_CHOICE = _PATTERNFLOWARPPROTOCOLTYPE.nested_types_by_name['Choice']
_PATTERNFLOWARPHARDWARELENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareLengthCounter']
_PATTERNFLOWARPHARDWARELENGTHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareLengthMetricTag']
_PATTERNFLOWARPHARDWARELENGTH = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareLength']
_PATTERNFLOWARPHARDWARELENGTH_CHOICE = _PATTERNFLOWARPHARDWARELENGTH.nested_types_by_name['Choice']
_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolLengthCounter']
_PATTERNFLOWARPPROTOCOLLENGTHMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolLengthMetricTag']
_PATTERNFLOWARPPROTOCOLLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolLength']
_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE = _PATTERNFLOWARPPROTOCOLLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWARPOPERATIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpOperationCounter']
_PATTERNFLOWARPOPERATIONMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowArpOperationMetricTag']
_PATTERNFLOWARPOPERATION = DESCRIPTOR.message_types_by_name['PatternFlowArpOperation']
_PATTERNFLOWARPOPERATION_CHOICE = _PATTERNFLOWARPOPERATION.nested_types_by_name['Choice']
_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderHardwareAddrCounter']
_PATTERNFLOWARPSENDERHARDWAREADDRMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderHardwareAddrMetricTag']
_PATTERNFLOWARPSENDERHARDWAREADDR = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderHardwareAddr']
_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE = _PATTERNFLOWARPSENDERHARDWAREADDR.nested_types_by_name['Choice']
_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderProtocolAddrCounter']
_PATTERNFLOWARPSENDERPROTOCOLADDRMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderProtocolAddrMetricTag']
_PATTERNFLOWARPSENDERPROTOCOLADDR = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderProtocolAddr']
_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE = _PATTERNFLOWARPSENDERPROTOCOLADDR.nested_types_by_name['Choice']
_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetHardwareAddrCounter']
_PATTERNFLOWARPTARGETHARDWAREADDRMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetHardwareAddrMetricTag']
_PATTERNFLOWARPTARGETHARDWAREADDR = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetHardwareAddr']
_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE = _PATTERNFLOWARPTARGETHARDWAREADDR.nested_types_by_name['Choice']
_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetProtocolAddrCounter']
_PATTERNFLOWARPTARGETPROTOCOLADDRMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetProtocolAddrMetricTag']
_PATTERNFLOWARPTARGETPROTOCOLADDR = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetProtocolAddr']
_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE = _PATTERNFLOWARPTARGETPROTOCOLADDR.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoTypeCounter']
_PATTERNFLOWICMPECHOTYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoTypeMetricTag']
_PATTERNFLOWICMPECHOTYPE = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoType']
_PATTERNFLOWICMPECHOTYPE_CHOICE = _PATTERNFLOWICMPECHOTYPE.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOCODECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoCodeCounter']
_PATTERNFLOWICMPECHOCODEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoCodeMetricTag']
_PATTERNFLOWICMPECHOCODE = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoCode']
_PATTERNFLOWICMPECHOCODE_CHOICE = _PATTERNFLOWICMPECHOCODE.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoChecksum']
_PATTERNFLOWICMPECHOCHECKSUM_CHOICE = _PATTERNFLOWICMPECHOCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOCHECKSUM_GENERATED = _PATTERNFLOWICMPECHOCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoIdentifierCounter']
_PATTERNFLOWICMPECHOIDENTIFIERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoIdentifierMetricTag']
_PATTERNFLOWICMPECHOIDENTIFIER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoIdentifier']
_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE = _PATTERNFLOWICMPECHOIDENTIFIER.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoSequenceNumberCounter']
_PATTERNFLOWICMPECHOSEQUENCENUMBERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoSequenceNumberMetricTag']
_PATTERNFLOWICMPECHOSEQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoSequenceNumber']
_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE = _PATTERNFLOWICMPECHOSEQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWICMPCOMMONCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIcmpCommonChecksum']
_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE = _PATTERNFLOWICMPCOMMONCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED = _PATTERNFLOWICMPCOMMONCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsIdentifierCounter']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsIdentifierMetricTag']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsIdentifier']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.nested_types_by_name['Choice']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsSequenceNumberCounter']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsSequenceNumberMetricTag']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsSequenceNumber']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoTypeCounter']
_PATTERNFLOWICMPV6ECHOTYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoTypeMetricTag']
_PATTERNFLOWICMPV6ECHOTYPE = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoType']
_PATTERNFLOWICMPV6ECHOTYPE_CHOICE = _PATTERNFLOWICMPV6ECHOTYPE.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOCODECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoCodeCounter']
_PATTERNFLOWICMPV6ECHOCODEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoCodeMetricTag']
_PATTERNFLOWICMPV6ECHOCODE = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoCode']
_PATTERNFLOWICMPV6ECHOCODE_CHOICE = _PATTERNFLOWICMPV6ECHOCODE.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoIdentifierCounter']
_PATTERNFLOWICMPV6ECHOIDENTIFIERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoIdentifierMetricTag']
_PATTERNFLOWICMPV6ECHOIDENTIFIER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoIdentifier']
_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE = _PATTERNFLOWICMPV6ECHOIDENTIFIER.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoSequenceNumberCounter']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoSequenceNumberMetricTag']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoSequenceNumber']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoChecksum']
_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE = _PATTERNFLOWICMPV6ECHOCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED = _PATTERNFLOWICMPV6ECHOCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWICMPV6COMMONCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6CommonChecksum']
_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE = _PATTERNFLOWICMPV6COMMONCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED = _PATTERNFLOWICMPV6COMMONCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWPPPADDRESSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPppAddressCounter']
_PATTERNFLOWPPPADDRESSMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPppAddressMetricTag']
_PATTERNFLOWPPPADDRESS = DESCRIPTOR.message_types_by_name['PatternFlowPppAddress']
_PATTERNFLOWPPPADDRESS_CHOICE = _PATTERNFLOWPPPADDRESS.nested_types_by_name['Choice']
_PATTERNFLOWPPPCONTROLCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPppControlCounter']
_PATTERNFLOWPPPCONTROLMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPppControlMetricTag']
_PATTERNFLOWPPPCONTROL = DESCRIPTOR.message_types_by_name['PatternFlowPppControl']
_PATTERNFLOWPPPCONTROL_CHOICE = _PATTERNFLOWPPPCONTROL.nested_types_by_name['Choice']
_PATTERNFLOWPPPPROTOCOLTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPppProtocolTypeCounter']
_PATTERNFLOWPPPPROTOCOLTYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowPppProtocolTypeMetricTag']
_PATTERNFLOWPPPPROTOCOLTYPE = DESCRIPTOR.message_types_by_name['PatternFlowPppProtocolType']
_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE = _PATTERNFLOWPPPPROTOCOLTYPE.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1VersionCounter']
_PATTERNFLOWIGMPV1VERSIONMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1VersionMetricTag']
_PATTERNFLOWIGMPV1VERSION = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Version']
_PATTERNFLOWIGMPV1VERSION_CHOICE = _PATTERNFLOWIGMPV1VERSION.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1TYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1TypeCounter']
_PATTERNFLOWIGMPV1TYPEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1TypeMetricTag']
_PATTERNFLOWIGMPV1TYPE = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Type']
_PATTERNFLOWIGMPV1TYPE_CHOICE = _PATTERNFLOWIGMPV1TYPE.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1UNUSEDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1UnusedCounter']
_PATTERNFLOWIGMPV1UNUSEDMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1UnusedMetricTag']
_PATTERNFLOWIGMPV1UNUSED = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Unused']
_PATTERNFLOWIGMPV1UNUSED_CHOICE = _PATTERNFLOWIGMPV1UNUSED.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1CHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Checksum']
_PATTERNFLOWIGMPV1CHECKSUM_CHOICE = _PATTERNFLOWIGMPV1CHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1CHECKSUM_GENERATED = _PATTERNFLOWIGMPV1CHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1GroupAddressCounter']
_PATTERNFLOWIGMPV1GROUPADDRESSMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1GroupAddressMetricTag']
_PATTERNFLOWIGMPV1GROUPADDRESS = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1GroupAddress']
_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE = _PATTERNFLOWIGMPV1GROUPADDRESS.nested_types_by_name['Choice']
_PATTERNFLOWMPLSLABELCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowMplsLabelCounter']
_PATTERNFLOWMPLSLABELMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowMplsLabelMetricTag']
_PATTERNFLOWMPLSLABEL = DESCRIPTOR.message_types_by_name['PatternFlowMplsLabel']
_PATTERNFLOWMPLSLABEL_CHOICE = _PATTERNFLOWMPLSLABEL.nested_types_by_name['Choice']
_PATTERNFLOWMPLSTRAFFICCLASSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowMplsTrafficClassCounter']
_PATTERNFLOWMPLSTRAFFICCLASSMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowMplsTrafficClassMetricTag']
_PATTERNFLOWMPLSTRAFFICCLASS = DESCRIPTOR.message_types_by_name['PatternFlowMplsTrafficClass']
_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE = _PATTERNFLOWMPLSTRAFFICCLASS.nested_types_by_name['Choice']
_PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowMplsBottomOfStackCounter']
_PATTERNFLOWMPLSBOTTOMOFSTACKMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowMplsBottomOfStackMetricTag']
_PATTERNFLOWMPLSBOTTOMOFSTACK = DESCRIPTOR.message_types_by_name['PatternFlowMplsBottomOfStack']
_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE = _PATTERNFLOWMPLSBOTTOMOFSTACK.nested_types_by_name['Choice']
_PATTERNFLOWMPLSTIMETOLIVECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowMplsTimeToLiveCounter']
_PATTERNFLOWMPLSTIMETOLIVEMETRICTAG = DESCRIPTOR.message_types_by_name['PatternFlowMplsTimeToLiveMetricTag']
_PATTERNFLOWMPLSTIMETOLIVE = DESCRIPTOR.message_types_by_name['PatternFlowMplsTimeToLive']
_PATTERNFLOWMPLSTIMETOLIVE_CHOICE = _PATTERNFLOWMPLSTIMETOLIVE.nested_types_by_name['Choice']
_VERSION = DESCRIPTOR.message_types_by_name['Version']
_SUCCESS = DESCRIPTOR.message_types_by_name['Success']
_FAILURE = DESCRIPTOR.message_types_by_name['Failure']
_SETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetConfigRequest']
_UPDATECONFIGREQUEST = DESCRIPTOR.message_types_by_name['UpdateConfigRequest']
_SETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['SetConfigResponse']
_GETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['GetConfigResponse']
_UPDATECONFIGRESPONSE = DESCRIPTOR.message_types_by_name['UpdateConfigResponse']
_SETCONTROLSTATEREQUEST = DESCRIPTOR.message_types_by_name['SetControlStateRequest']
_SETCONTROLSTATERESPONSE = DESCRIPTOR.message_types_by_name['SetControlStateResponse']
_SETCONTROLACTIONREQUEST = DESCRIPTOR.message_types_by_name['SetControlActionRequest']
_SETCONTROLACTIONRESPONSE = DESCRIPTOR.message_types_by_name['SetControlActionResponse']
_SETTRANSMITSTATEREQUEST = DESCRIPTOR.message_types_by_name['SetTransmitStateRequest']
_SETTRANSMITSTATERESPONSE = DESCRIPTOR.message_types_by_name['SetTransmitStateResponse']
_SETLINKSTATEREQUEST = DESCRIPTOR.message_types_by_name['SetLinkStateRequest']
_SETLINKSTATERESPONSE = DESCRIPTOR.message_types_by_name['SetLinkStateResponse']
_SETCAPTURESTATEREQUEST = DESCRIPTOR.message_types_by_name['SetCaptureStateRequest']
_SETCAPTURESTATERESPONSE = DESCRIPTOR.message_types_by_name['SetCaptureStateResponse']
_UPDATEFLOWSREQUEST = DESCRIPTOR.message_types_by_name['UpdateFlowsRequest']
_UPDATEFLOWSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFlowsResponse']
_SETROUTESTATEREQUEST = DESCRIPTOR.message_types_by_name['SetRouteStateRequest']
_SETROUTESTATERESPONSE = DESCRIPTOR.message_types_by_name['SetRouteStateResponse']
_SENDPINGREQUEST = DESCRIPTOR.message_types_by_name['SendPingRequest']
_SENDPINGRESPONSE = DESCRIPTOR.message_types_by_name['SendPingResponse']
_SETPROTOCOLSTATEREQUEST = DESCRIPTOR.message_types_by_name['SetProtocolStateRequest']
_SETPROTOCOLSTATERESPONSE = DESCRIPTOR.message_types_by_name['SetProtocolStateResponse']
_SETDEVICESTATEREQUEST = DESCRIPTOR.message_types_by_name['SetDeviceStateRequest']
_SETDEVICESTATERESPONSE = DESCRIPTOR.message_types_by_name['SetDeviceStateResponse']
_GETMETRICSREQUEST = DESCRIPTOR.message_types_by_name['GetMetricsRequest']
_GETMETRICSRESPONSE = DESCRIPTOR.message_types_by_name['GetMetricsResponse']
_GETSTATESREQUEST = DESCRIPTOR.message_types_by_name['GetStatesRequest']
_GETSTATESRESPONSE = DESCRIPTOR.message_types_by_name['GetStatesResponse']
_GETCAPTUREREQUEST = DESCRIPTOR.message_types_by_name['GetCaptureRequest']
_GETCAPTURERESPONSE = DESCRIPTOR.message_types_by_name['GetCaptureResponse']
_GETVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['GetVersionResponse']
_LAGPROTOCOL_CHOICE_ENUM = _LAGPROTOCOL_CHOICE.enum_types_by_name['Enum']
_LAGPORTLACP_ACTORACTIVITY_ENUM = _LAGPORTLACP_ACTORACTIVITY.enum_types_by_name['Enum']
_ETHERNETCONNECTION_CHOICE_ENUM = _ETHERNETCONNECTION_CHOICE.enum_types_by_name['Enum']
_DEVICEVLAN_TPID_ENUM = _DEVICEVLAN_TPID.enum_types_by_name['Enum']
_DEVICEIPV4GATEWAYMAC_CHOICE_ENUM = _DEVICEIPV4GATEWAYMAC_CHOICE.enum_types_by_name['Enum']
_DEVICEIPV6GATEWAYMAC_CHOICE_ENUM = _DEVICEIPV6GATEWAYMAC_CHOICE.enum_types_by_name['Enum']
_LAYER1_SPEED_ENUM = _LAYER1_SPEED.enum_types_by_name['Enum']
_LAYER1_MEDIA_ENUM = _LAYER1_MEDIA.enum_types_by_name['Enum']
_LAYER1FLOWCONTROL_CHOICE_ENUM = _LAYER1FLOWCONTROL_CHOICE.enum_types_by_name['Enum']
_CAPTURE_FORMAT_ENUM = _CAPTURE_FORMAT.enum_types_by_name['Enum']
_CAPTUREFILTER_CHOICE_ENUM = _CAPTUREFILTER_CHOICE.enum_types_by_name['Enum']
_ISISINTERFACE_NETWORKTYPE_ENUM = _ISISINTERFACE_NETWORKTYPE.enum_types_by_name['Enum']
_ISISINTERFACE_LEVELTYPE_ENUM = _ISISINTERFACE_LEVELTYPE.enum_types_by_name['Enum']
_ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM = _ISISINTERFACEAUTHENTICATION_AUTHTYPE.enum_types_by_name['Enum']
_ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM = _ISISAUTHENTICATIONBASE_AUTHTYPE.enum_types_by_name['Enum']
_ISISV4ROUTERANGE_ORIGINTYPE_ENUM = _ISISV4ROUTERANGE_ORIGINTYPE.enum_types_by_name['Enum']
_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM = _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE.enum_types_by_name['Enum']
_ISISV6ROUTERANGE_ORIGINTYPE_ENUM = _ISISV6ROUTERANGE_ORIGINTYPE.enum_types_by_name['Enum']
_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM = _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE.enum_types_by_name['Enum']
_DEVICEBGPMESSAGEHEADERERROR_SUBCODE_ENUM = _DEVICEBGPMESSAGEHEADERERROR_SUBCODE.enum_types_by_name['Enum']
_DEVICEBGPOPENMESSAGEERROR_SUBCODE_ENUM = _DEVICEBGPOPENMESSAGEERROR_SUBCODE.enum_types_by_name['Enum']
_DEVICEBGPUPDATEMESSAGEERROR_SUBCODE_ENUM = _DEVICEBGPUPDATEMESSAGEERROR_SUBCODE.enum_types_by_name['Enum']
_DEVICEBGPCEASEERROR_SUBCODE_ENUM = _DEVICEBGPCEASEERROR_SUBCODE.enum_types_by_name['Enum']
_BGPV4PEER_ASTYPE_ENUM = _BGPV4PEER_ASTYPE.enum_types_by_name['Enum']
_BGPV4PEER_ASNUMBERWIDTH_ENUM = _BGPV4PEER_ASNUMBERWIDTH.enum_types_by_name['Enum']
_BGPV4ETHERNETSEGMENT_ACTIVEMODE_ENUM = _BGPV4ETHERNETSEGMENT_ACTIVEMODE.enum_types_by_name['Enum']
_BGPROUTEADVANCED_ORIGIN_ENUM = _BGPROUTEADVANCED_ORIGIN.enum_types_by_name['Enum']
_BGPCOMMUNITY_TYPE_ENUM = _BGPCOMMUNITY_TYPE.enum_types_by_name['Enum']
_BGPEXTCOMMUNITY_TYPE_ENUM = _BGPEXTCOMMUNITY_TYPE.enum_types_by_name['Enum']
_BGPEXTCOMMUNITY_SUBTYPE_ENUM = _BGPEXTCOMMUNITY_SUBTYPE.enum_types_by_name['Enum']
_BGPASPATH_ASSETMODE_ENUM = _BGPASPATH_ASSETMODE.enum_types_by_name['Enum']
_BGPASPATHSEGMENT_TYPE_ENUM = _BGPASPATHSEGMENT_TYPE.enum_types_by_name['Enum']
_BGPV4EVPNEVIS_CHOICE_ENUM = _BGPV4EVPNEVIS_CHOICE.enum_types_by_name['Enum']
_BGPV4EVIVXLAN_REPLICATIONTYPE_ENUM = _BGPV4EVIVXLAN_REPLICATIONTYPE.enum_types_by_name['Enum']
_BGPROUTEDISTINGUISHER_RDTYPE_ENUM = _BGPROUTEDISTINGUISHER_RDTYPE.enum_types_by_name['Enum']
_BGPROUTETARGET_RTTYPE_ENUM = _BGPROUTETARGET_RTTYPE.enum_types_by_name['Enum']
_BGPV4ROUTERANGE_NEXTHOPMODE_ENUM = _BGPV4ROUTERANGE_NEXTHOPMODE.enum_types_by_name['Enum']
_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM = _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE.enum_types_by_name['Enum']
_BGPV6ROUTERANGE_NEXTHOPMODE_ENUM = _BGPV6ROUTERANGE_NEXTHOPMODE.enum_types_by_name['Enum']
_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM = _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE.enum_types_by_name['Enum']
_BGPSRTEV4POLICY_NEXTHOPMODE_ENUM = _BGPSRTEV4POLICY_NEXTHOPMODE.enum_types_by_name['Enum']
_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM = _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE.enum_types_by_name['Enum']
_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM = _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY.enum_types_by_name['Enum']
_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM = _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE.enum_types_by_name['Enum']
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY.enum_types_by_name['Enum']
_BGPSRTESEGMENT_SEGMENTTYPE_ENUM = _BGPSRTESEGMENT_SEGMENTTYPE.enum_types_by_name['Enum']
_BGPSRTEV6POLICY_NEXTHOPMODE_ENUM = _BGPSRTEV6POLICY_NEXTHOPMODE.enum_types_by_name['Enum']
_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM = _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE.enum_types_by_name['Enum']
_BGPV6PEER_ASTYPE_ENUM = _BGPV6PEER_ASTYPE.enum_types_by_name['Enum']
_BGPV6PEER_ASNUMBERWIDTH_ENUM = _BGPV6PEER_ASNUMBERWIDTH.enum_types_by_name['Enum']
_BGPV6ETHERNETSEGMENT_ACTIVEMODE_ENUM = _BGPV6ETHERNETSEGMENT_ACTIVEMODE.enum_types_by_name['Enum']
_BGPV6EVPNEVIS_CHOICE_ENUM = _BGPV6EVPNEVIS_CHOICE.enum_types_by_name['Enum']
_BGPV6EVIVXLAN_REPLICATIONTYPE_ENUM = _BGPV6EVIVXLAN_REPLICATIONTYPE.enum_types_by_name['Enum']
_VXLANV4TUNNELDESTINATIONIPMODE_CHOICE_ENUM = _VXLANV4TUNNELDESTINATIONIPMODE_CHOICE.enum_types_by_name['Enum']
_VXLANV6TUNNELDESTINATIONIPMODE_CHOICE_ENUM = _VXLANV6TUNNELDESTINATIONIPMODE_CHOICE.enum_types_by_name['Enum']
_RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE_ENUM = _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE.enum_types_by_name['Enum']
_RSVPERO_PREPENDNEIGHBORIP_ENUM = _RSVPERO_PREPENDNEIGHBORIP.enum_types_by_name['Enum']
_RSVPEROSUBOBJECT_TYPE_ENUM = _RSVPEROSUBOBJECT_TYPE.enum_types_by_name['Enum']
_RSVPEROSUBOBJECT_HOPTYPE_ENUM = _RSVPEROSUBOBJECT_HOPTYPE.enum_types_by_name['Enum']
_FLOWTXRX_CHOICE_ENUM = _FLOWTXRX_CHOICE.enum_types_by_name['Enum']
_FLOWROUTER_MODE_ENUM = _FLOWROUTER_MODE.enum_types_by_name['Enum']
_FLOWHEADER_CHOICE_ENUM = _FLOWHEADER_CHOICE.enum_types_by_name['Enum']
_FLOWIPV4PRIORITY_CHOICE_ENUM = _FLOWIPV4PRIORITY_CHOICE.enum_types_by_name['Enum']
_FLOWICMP_CHOICE_ENUM = _FLOWICMP_CHOICE.enum_types_by_name['Enum']
_FLOWICMPV6_CHOICE_ENUM = _FLOWICMPV6_CHOICE.enum_types_by_name['Enum']
_FLOWSIZE_CHOICE_ENUM = _FLOWSIZE_CHOICE.enum_types_by_name['Enum']
_FLOWSIZEWEIGHTPAIRS_CHOICE_ENUM = _FLOWSIZEWEIGHTPAIRS_CHOICE.enum_types_by_name['Enum']
_FLOWSIZEWEIGHTPAIRS_PREDEFINED_ENUM = _FLOWSIZEWEIGHTPAIRS_PREDEFINED.enum_types_by_name['Enum']
_FLOWRATE_CHOICE_ENUM = _FLOWRATE_CHOICE.enum_types_by_name['Enum']
_FLOWDURATION_CHOICE_ENUM = _FLOWDURATION_CHOICE.enum_types_by_name['Enum']
_FLOWDELAY_CHOICE_ENUM = _FLOWDELAY_CHOICE.enum_types_by_name['Enum']
_FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM = _FLOWDURATIONINTERBURSTGAP_CHOICE.enum_types_by_name['Enum']
_FLOWLATENCYMETRICS_MODE_ENUM = _FLOWLATENCYMETRICS_MODE.enum_types_by_name['Enum']
_FLOWRXTXRATIO_CHOICE_ENUM = _FLOWRXTXRATIO_CHOICE.enum_types_by_name['Enum']
_EVENTREQUEST_TYPE_ENUM = _EVENTREQUEST_TYPE.enum_types_by_name['Enum']
_LLDPCONNECTION_CHOICE_ENUM = _LLDPCONNECTION_CHOICE.enum_types_by_name['Enum']
_LLDPCHASSISID_CHOICE_ENUM = _LLDPCHASSISID_CHOICE.enum_types_by_name['Enum']
_LLDPPORTID_CHOICE_ENUM = _LLDPPORTID_CHOICE.enum_types_by_name['Enum']
_LLDPCHASSISMACSUBTYPE_CHOICE_ENUM = _LLDPCHASSISMACSUBTYPE_CHOICE.enum_types_by_name['Enum']
_LLDPPORTINTERFACENAMESUBTYPE_CHOICE_ENUM = _LLDPPORTINTERFACENAMESUBTYPE_CHOICE.enum_types_by_name['Enum']
_LLDPSYSTEMNAME_CHOICE_ENUM = _LLDPSYSTEMNAME_CHOICE.enum_types_by_name['Enum']
_ERROR_KIND_ENUM = _ERROR_KIND.enum_types_by_name['Enum']
_CONFIGUPDATE_CHOICE_ENUM = _CONFIGUPDATE_CHOICE.enum_types_by_name['Enum']
_FLOWSUPDATE_PROPERTYNAMES_ENUM = _FLOWSUPDATE_PROPERTYNAMES.enum_types_by_name['Enum']
_CONTROLSTATE_CHOICE_ENUM = _CONTROLSTATE_CHOICE.enum_types_by_name['Enum']
_STATEPORT_CHOICE_ENUM = _STATEPORT_CHOICE.enum_types_by_name['Enum']
_STATETRAFFIC_CHOICE_ENUM = _STATETRAFFIC_CHOICE.enum_types_by_name['Enum']
_STATEPROTOCOL_CHOICE_ENUM = _STATEPROTOCOL_CHOICE.enum_types_by_name['Enum']
_LINKSTATE_STATE_ENUM = _LINKSTATE_STATE.enum_types_by_name['Enum']
_TRANSMITSTATE_STATE_ENUM = _TRANSMITSTATE_STATE.enum_types_by_name['Enum']
_CAPTURESTATE_STATE_ENUM = _CAPTURESTATE_STATE.enum_types_by_name['Enum']
_ROUTESTATE_STATE_ENUM = _ROUTESTATE_STATE.enum_types_by_name['Enum']
_PROTOCOLSTATE_STATE_ENUM = _PROTOCOLSTATE_STATE.enum_types_by_name['Enum']
_DEVICESTATE_CHOICE_ENUM = _DEVICESTATE_CHOICE.enum_types_by_name['Enum']
_STATEPORTLINK_STATE_ENUM = _STATEPORTLINK_STATE.enum_types_by_name['Enum']
_STATEPORTCAPTURE_STATE_ENUM = _STATEPORTCAPTURE_STATE.enum_types_by_name['Enum']
_STATETRAFFICFLOWTRANSMIT_STATE_ENUM = _STATETRAFFICFLOWTRANSMIT_STATE.enum_types_by_name['Enum']
_STATEPROTOCOLALL_STATE_ENUM = _STATEPROTOCOLALL_STATE.enum_types_by_name['Enum']
_STATEPROTOCOLROUTE_STATE_ENUM = _STATEPROTOCOLROUTE_STATE.enum_types_by_name['Enum']
_STATEPROTOCOLLACP_CHOICE_ENUM = _STATEPROTOCOLLACP_CHOICE.enum_types_by_name['Enum']
_STATEPROTOCOLLACPADMIN_STATE_ENUM = _STATEPROTOCOLLACPADMIN_STATE.enum_types_by_name['Enum']
_LACPMEMBERSTATE_STATE_ENUM = _LACPMEMBERSTATE_STATE.enum_types_by_name['Enum']
_CONTROLACTION_CHOICE_ENUM = _CONTROLACTION_CHOICE.enum_types_by_name['Enum']
_ACTIONRESPONSE_CHOICE_ENUM = _ACTIONRESPONSE_CHOICE.enum_types_by_name['Enum']
_ACTIONPROTOCOL_CHOICE_ENUM = _ACTIONPROTOCOL_CHOICE.enum_types_by_name['Enum']
_ACTIONRESPONSEPROTOCOL_CHOICE_ENUM = _ACTIONRESPONSEPROTOCOL_CHOICE.enum_types_by_name['Enum']
_ACTIONPROTOCOLIPV4_CHOICE_ENUM = _ACTIONPROTOCOLIPV4_CHOICE.enum_types_by_name['Enum']
_ACTIONRESPONSEPROTOCOLIPV4_CHOICE_ENUM = _ACTIONRESPONSEPROTOCOLIPV4_CHOICE.enum_types_by_name['Enum']
_ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT_ENUM = _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT.enum_types_by_name['Enum']
_ACTIONPROTOCOLIPV6_CHOICE_ENUM = _ACTIONPROTOCOLIPV6_CHOICE.enum_types_by_name['Enum']
_ACTIONRESPONSEPROTOCOLIPV6_CHOICE_ENUM = _ACTIONRESPONSEPROTOCOLIPV6_CHOICE.enum_types_by_name['Enum']
_ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT_ENUM = _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT.enum_types_by_name['Enum']
_ACTIONPROTOCOLBGP_CHOICE_ENUM = _ACTIONPROTOCOLBGP_CHOICE.enum_types_by_name['Enum']
_ACTIONPROTOCOLBGPNOTIFICATION_CHOICE_ENUM = _ACTIONPROTOCOLBGPNOTIFICATION_CHOICE.enum_types_by_name['Enum']
_PING_CHOICE_ENUM = _PING_CHOICE.enum_types_by_name['Enum']
_RESPONSE_RESULT_ENUM = _RESPONSE_RESULT.enum_types_by_name['Enum']
_METRICSREQUEST_CHOICE_ENUM = _METRICSREQUEST_CHOICE.enum_types_by_name['Enum']
_METRICSRESPONSE_CHOICE_ENUM = _METRICSRESPONSE_CHOICE.enum_types_by_name['Enum']
_PORTMETRICSREQUEST_COLUMNNAMES_ENUM = _PORTMETRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_PORTMETRIC_LINK_ENUM = _PORTMETRIC_LINK.enum_types_by_name['Enum']
_PORTMETRIC_CAPTURE_ENUM = _PORTMETRIC_CAPTURE.enum_types_by_name['Enum']
_PORTMETRIC_TRANSMIT_ENUM = _PORTMETRIC_TRANSMIT.enum_types_by_name['Enum']
_FLOWMETRICSREQUEST_METRICNAMES_ENUM = _FLOWMETRICSREQUEST_METRICNAMES.enum_types_by_name['Enum']
_FLOWTAGGEDMETRICSFILTER_METRICNAMES_ENUM = _FLOWTAGGEDMETRICSFILTER_METRICNAMES.enum_types_by_name['Enum']
_FLOWMETRIC_TRANSMIT_ENUM = _FLOWMETRIC_TRANSMIT.enum_types_by_name['Enum']
_FLOWMETRICTAGVALUE_CHOICE_ENUM = _FLOWMETRICTAGVALUE_CHOICE.enum_types_by_name['Enum']
_BGPV4METRICSREQUEST_COLUMNNAMES_ENUM = _BGPV4METRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_BGPV4METRIC_SESSIONSTATE_ENUM = _BGPV4METRIC_SESSIONSTATE.enum_types_by_name['Enum']
_BGPV4METRIC_FSMSTATE_ENUM = _BGPV4METRIC_FSMSTATE.enum_types_by_name['Enum']
_BGPV6METRICSREQUEST_COLUMNNAMES_ENUM = _BGPV6METRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_BGPV6METRIC_SESSIONSTATE_ENUM = _BGPV6METRIC_SESSIONSTATE.enum_types_by_name['Enum']
_BGPV6METRIC_FSMSTATE_ENUM = _BGPV6METRIC_FSMSTATE.enum_types_by_name['Enum']
_ISISMETRICSREQUEST_COLUMNNAMES_ENUM = _ISISMETRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_LAGMETRICSREQUEST_COLUMNNAMES_ENUM = _LAGMETRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_LAGMETRIC_OPERSTATUS_ENUM = _LAGMETRIC_OPERSTATUS.enum_types_by_name['Enum']
_LACPMETRICSREQUEST_COLUMNNAMES_ENUM = _LACPMETRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_LACPMETRIC_ACTIVITY_ENUM = _LACPMETRIC_ACTIVITY.enum_types_by_name['Enum']
_LACPMETRIC_TIMEOUT_ENUM = _LACPMETRIC_TIMEOUT.enum_types_by_name['Enum']
_LACPMETRIC_SYNCHRONIZATION_ENUM = _LACPMETRIC_SYNCHRONIZATION.enum_types_by_name['Enum']
_LLDPMETRICSREQUEST_COLUMNNAMES_ENUM = _LLDPMETRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_RSVPMETRICSREQUEST_COLUMNNAMES_ENUM = _RSVPMETRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_STATESREQUEST_CHOICE_ENUM = _STATESREQUEST_CHOICE.enum_types_by_name['Enum']
_STATESRESPONSE_CHOICE_ENUM = _STATESRESPONSE_CHOICE.enum_types_by_name['Enum']
_BGPPREFIXSTATEREQUEST_PREFIXFILTERS_ENUM = _BGPPREFIXSTATEREQUEST_PREFIXFILTERS.enum_types_by_name['Enum']
_BGPPREFIXIPV4UNICASTFILTER_ORIGIN_ENUM = _BGPPREFIXIPV4UNICASTFILTER_ORIGIN.enum_types_by_name['Enum']
_BGPPREFIXIPV6UNICASTFILTER_ORIGIN_ENUM = _BGPPREFIXIPV6UNICASTFILTER_ORIGIN.enum_types_by_name['Enum']
_BGPPREFIXIPV4UNICASTSTATE_ORIGIN_ENUM = _BGPPREFIXIPV4UNICASTSTATE_ORIGIN.enum_types_by_name['Enum']
_BGPPREFIXIPV6UNICASTSTATE_ORIGIN_ENUM = _BGPPREFIXIPV6UNICASTSTATE_ORIGIN.enum_types_by_name['Enum']
_RESULTBGPCOMMUNITY_TYPE_ENUM = _RESULTBGPCOMMUNITY_TYPE.enum_types_by_name['Enum']
_RESULTBGPASPATHSEGMENT_TYPE_ENUM = _RESULTBGPASPATHSEGMENT_TYPE.enum_types_by_name['Enum']
_ISISLSPSTATE_PDUTYPE_ENUM = _ISISLSPSTATE_PDUTYPE.enum_types_by_name['Enum']
_ISISLSPV4PREFIX_REDISTRIBUTIONTYPE_ENUM = _ISISLSPV4PREFIX_REDISTRIBUTIONTYPE.enum_types_by_name['Enum']
_ISISLSPV4PREFIX_ORIGINTYPE_ENUM = _ISISLSPV4PREFIX_ORIGINTYPE.enum_types_by_name['Enum']
_ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE_ENUM = _ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE.enum_types_by_name['Enum']
_ISISLSPV6PREFIX_REDISTRIBUTIONTYPE_ENUM = _ISISLSPV6PREFIX_REDISTRIBUTIONTYPE.enum_types_by_name['Enum']
_ISISLSPV6PREFIX_ORIGINTYPE_ENUM = _ISISLSPV6PREFIX_ORIGINTYPE.enum_types_by_name['Enum']
_LLDPNEIGHBORSSTATE_CHASSISIDTYPE_ENUM = _LLDPNEIGHBORSSTATE_CHASSISIDTYPE.enum_types_by_name['Enum']
_LLDPNEIGHBORSSTATE_PORTIDTYPE_ENUM = _LLDPNEIGHBORSSTATE_PORTIDTYPE.enum_types_by_name['Enum']
_LLDPCAPABILITYSTATE_CAPABILITYNAME_ENUM = _LLDPCAPABILITYSTATE_CAPABILITYNAME.enum_types_by_name['Enum']
_RSVPLSPSTATE_SESSIONSTATUS_ENUM = _RSVPLSPSTATE_SESSIONSTATUS.enum_types_by_name['Enum']
_RSVPLSPSTATE_LASTFLAPREASON_ENUM = _RSVPLSPSTATE_LASTFLAPREASON.enum_types_by_name['Enum']
_RSVPLSPIPV4ERO_TYPE_ENUM = _RSVPLSPIPV4ERO_TYPE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETDST_CHOICE_ENUM = _PATTERNFLOWETHERNETDST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETSRC_CHOICE_ENUM = _PATTERNFLOWETHERNETSRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM = _PATTERNFLOWETHERNETETHERTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM = _PATTERNFLOWETHERNETPFCQUEUE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVLANPRIORITY_CHOICE_ENUM = _PATTERNFLOWVLANPRIORITY_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVLANCFI_CHOICE_ENUM = _PATTERNFLOWVLANCFI_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVLANID_CHOICE_ENUM = _PATTERNFLOWVLANID_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVLANTPID_CHOICE_ENUM = _PATTERNFLOWVLANTPID_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVXLANFLAGS_CHOICE_ENUM = _PATTERNFLOWVXLANFLAGS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM = _PATTERNFLOWVXLANRESERVED0_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVXLANVNI_CHOICE_ENUM = _PATTERNFLOWVXLANVNI_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM = _PATTERNFLOWVXLANRESERVED1_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4VERSION_CHOICE_ENUM = _PATTERNFLOWIPV4VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM = _PATTERNFLOWIPV4HEADERLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM = _PATTERNFLOWIPV4TOTALLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM = _PATTERNFLOWIPV4IDENTIFICATION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4RESERVED_CHOICE_ENUM = _PATTERNFLOWIPV4RESERVED_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM = _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM = _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM = _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM = _PATTERNFLOWIPV4TIMETOLIVE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM = _PATTERNFLOWIPV4PROTOCOL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM = _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM = _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWIPV4SRC_CHOICE_ENUM = _PATTERNFLOWIPV4SRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4DST_CHOICE_ENUM = _PATTERNFLOWIPV4DST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM = _PATTERNFLOWIPV4PRIORITYRAW_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM = _PATTERNFLOWIPV4DSCPPHB_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM = _PATTERNFLOWIPV4DSCPECN_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM = _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM = _PATTERNFLOWIPV4TOSDELAY_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM = _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM = _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM = _PATTERNFLOWIPV4TOSMONETARY_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM = _PATTERNFLOWIPV4TOSUNUSED_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6VERSION_CHOICE_ENUM = _PATTERNFLOWIPV6VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM = _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM = _PATTERNFLOWIPV6FLOWLABEL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM = _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM = _PATTERNFLOWIPV6NEXTHEADER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM = _PATTERNFLOWIPV6HOPLIMIT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6SRC_CHOICE_ENUM = _PATTERNFLOWIPV6SRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6DST_CHOICE_ENUM = _PATTERNFLOWIPV6DST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEDST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM = _PATTERNFLOWPFCPAUSESRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM = _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSEDST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSESRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSETIME_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPSRCPORT_CHOICE_ENUM = _PATTERNFLOWTCPSRCPORT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPDSTPORT_CHOICE_ENUM = _PATTERNFLOWTCPDSTPORT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPSEQNUM_CHOICE_ENUM = _PATTERNFLOWTCPSEQNUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPACKNUM_CHOICE_ENUM = _PATTERNFLOWTCPACKNUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM = _PATTERNFLOWTCPDATAOFFSET_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPECNNS_CHOICE_ENUM = _PATTERNFLOWTCPECNNS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPECNCWR_CHOICE_ENUM = _PATTERNFLOWTCPECNCWR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPECNECHO_CHOICE_ENUM = _PATTERNFLOWTCPECNECHO_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLURG_CHOICE_ENUM = _PATTERNFLOWTCPCTLURG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLACK_CHOICE_ENUM = _PATTERNFLOWTCPCTLACK_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLPSH_CHOICE_ENUM = _PATTERNFLOWTCPCTLPSH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLRST_CHOICE_ENUM = _PATTERNFLOWTCPCTLRST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLSYN_CHOICE_ENUM = _PATTERNFLOWTCPCTLSYN_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLFIN_CHOICE_ENUM = _PATTERNFLOWTCPCTLFIN_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPWINDOW_CHOICE_ENUM = _PATTERNFLOWTCPWINDOW_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPSRCPORT_CHOICE_ENUM = _PATTERNFLOWUDPSRCPORT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPDSTPORT_CHOICE_ENUM = _PATTERNFLOWUDPDSTPORT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPLENGTH_CHOICE_ENUM = _PATTERNFLOWUDPLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM = _PATTERNFLOWUDPCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM = _PATTERNFLOWUDPCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM = _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGRERESERVED0_CHOICE_ENUM = _PATTERNFLOWGRERESERVED0_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGREVERSION_CHOICE_ENUM = _PATTERNFLOWGREVERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGREPROTOCOL_CHOICE_ENUM = _PATTERNFLOWGREPROTOCOL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGRECHECKSUM_CHOICE_ENUM = _PATTERNFLOWGRECHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGRECHECKSUM_GENERATED_ENUM = _PATTERNFLOWGRECHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWGRERESERVED1_CHOICE_ENUM = _PATTERNFLOWGRERESERVED1_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1VERSION_CHOICE_ENUM = _PATTERNFLOWGTPV1VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM = _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM = _PATTERNFLOWGTPV1RESERVED_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV1EFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV1SFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV1PNFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM = _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM = _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1TEID_CHOICE_ENUM = _PATTERNFLOWGTPV1TEID_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM = _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM = _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2VERSION_CHOICE_ENUM = _PATTERNFLOWGTPV2VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV2TEIDFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM = _PATTERNFLOWGTPV2SPARE1_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM = _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM = _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2TEID_CHOICE_ENUM = _PATTERNFLOWGTPV2TEID_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM = _PATTERNFLOWGTPV2SPARE2_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM = _PATTERNFLOWARPHARDWARETYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM = _PATTERNFLOWARPPROTOCOLTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM = _PATTERNFLOWARPHARDWARELENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM = _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPOPERATION_CHOICE_ENUM = _PATTERNFLOWARPOPERATION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM = _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM = _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM = _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM = _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM = _PATTERNFLOWICMPECHOTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOCODE_CHOICE_ENUM = _PATTERNFLOWICMPECHOCODE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM = _PATTERNFLOWICMPECHOCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM = _PATTERNFLOWICMPECHOCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM = _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM = _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM = _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOCODE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM = _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM = _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM = _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWPPPADDRESS_CHOICE_ENUM = _PATTERNFLOWPPPADDRESS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPPPCONTROL_CHOICE_ENUM = _PATTERNFLOWPPPCONTROL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM = _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM = _PATTERNFLOWIGMPV1VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM = _PATTERNFLOWIGMPV1TYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM = _PATTERNFLOWIGMPV1UNUSED_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM = _PATTERNFLOWIGMPV1CHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM = _PATTERNFLOWIGMPV1CHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM = _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWMPLSLABEL_CHOICE_ENUM = _PATTERNFLOWMPLSLABEL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM = _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM = _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM = _PATTERNFLOWMPLSTIMETOLIVE_CHOICE.enum_types_by_name['Enum']
Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Config)
  })
_sym_db.RegisterMessage(Config)

ConfigOptions = _reflection.GeneratedProtocolMessageType('ConfigOptions', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGOPTIONS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ConfigOptions)
  })
_sym_db.RegisterMessage(ConfigOptions)

Port = _reflection.GeneratedProtocolMessageType('Port', (_message.Message,), {
  'DESCRIPTOR' : _PORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Port)
  })
_sym_db.RegisterMessage(Port)

PortOptions = _reflection.GeneratedProtocolMessageType('PortOptions', (_message.Message,), {
  'DESCRIPTOR' : _PORTOPTIONS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PortOptions)
  })
_sym_db.RegisterMessage(PortOptions)

Lag = _reflection.GeneratedProtocolMessageType('Lag', (_message.Message,), {
  'DESCRIPTOR' : _LAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Lag)
  })
_sym_db.RegisterMessage(Lag)

LagPort = _reflection.GeneratedProtocolMessageType('LagPort', (_message.Message,), {
  'DESCRIPTOR' : _LAGPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagPort)
  })
_sym_db.RegisterMessage(LagPort)

LagProtocol = _reflection.GeneratedProtocolMessageType('LagProtocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LAGPROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LagProtocol.Choice)
    })
  ,
  'DESCRIPTOR' : _LAGPROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagProtocol)
  })
_sym_db.RegisterMessage(LagProtocol)
_sym_db.RegisterMessage(LagProtocol.Choice)

LagProtocolStatic = _reflection.GeneratedProtocolMessageType('LagProtocolStatic', (_message.Message,), {
  'DESCRIPTOR' : _LAGPROTOCOLSTATIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagProtocolStatic)
  })
_sym_db.RegisterMessage(LagProtocolStatic)

LagProtocolLacp = _reflection.GeneratedProtocolMessageType('LagProtocolLacp', (_message.Message,), {
  'DESCRIPTOR' : _LAGPROTOCOLLACP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagProtocolLacp)
  })
_sym_db.RegisterMessage(LagProtocolLacp)

LagPortLacp = _reflection.GeneratedProtocolMessageType('LagPortLacp', (_message.Message,), {

  'ActorActivity' : _reflection.GeneratedProtocolMessageType('ActorActivity', (_message.Message,), {
    'DESCRIPTOR' : _LAGPORTLACP_ACTORACTIVITY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LagPortLacp.ActorActivity)
    })
  ,
  'DESCRIPTOR' : _LAGPORTLACP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagPortLacp)
  })
_sym_db.RegisterMessage(LagPortLacp)
_sym_db.RegisterMessage(LagPortLacp.ActorActivity)

DeviceEthernetBase = _reflection.GeneratedProtocolMessageType('DeviceEthernetBase', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEETHERNETBASE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceEthernetBase)
  })
_sym_db.RegisterMessage(DeviceEthernetBase)

DeviceEthernet = _reflection.GeneratedProtocolMessageType('DeviceEthernet', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEETHERNET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceEthernet)
  })
_sym_db.RegisterMessage(DeviceEthernet)

EthernetConnection = _reflection.GeneratedProtocolMessageType('EthernetConnection', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ETHERNETCONNECTION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.EthernetConnection.Choice)
    })
  ,
  'DESCRIPTOR' : _ETHERNETCONNECTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EthernetConnection)
  })
_sym_db.RegisterMessage(EthernetConnection)
_sym_db.RegisterMessage(EthernetConnection.Choice)

DeviceVlan = _reflection.GeneratedProtocolMessageType('DeviceVlan', (_message.Message,), {

  'Tpid' : _reflection.GeneratedProtocolMessageType('Tpid', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEVLAN_TPID,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceVlan.Tpid)
    })
  ,
  'DESCRIPTOR' : _DEVICEVLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceVlan)
  })
_sym_db.RegisterMessage(DeviceVlan)
_sym_db.RegisterMessage(DeviceVlan.Tpid)

DeviceIpv4 = _reflection.GeneratedProtocolMessageType('DeviceIpv4', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv4)
  })
_sym_db.RegisterMessage(DeviceIpv4)

DeviceIpv4Loopback = _reflection.GeneratedProtocolMessageType('DeviceIpv4Loopback', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV4LOOPBACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv4Loopback)
  })
_sym_db.RegisterMessage(DeviceIpv4Loopback)

DeviceIpv4GatewayMAC = _reflection.GeneratedProtocolMessageType('DeviceIpv4GatewayMAC', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEIPV4GATEWAYMAC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceIpv4GatewayMAC.Choice)
    })
  ,
  'DESCRIPTOR' : _DEVICEIPV4GATEWAYMAC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv4GatewayMAC)
  })
_sym_db.RegisterMessage(DeviceIpv4GatewayMAC)
_sym_db.RegisterMessage(DeviceIpv4GatewayMAC.Choice)

DeviceIpv6 = _reflection.GeneratedProtocolMessageType('DeviceIpv6', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv6)
  })
_sym_db.RegisterMessage(DeviceIpv6)

DeviceIpv6Loopback = _reflection.GeneratedProtocolMessageType('DeviceIpv6Loopback', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV6LOOPBACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv6Loopback)
  })
_sym_db.RegisterMessage(DeviceIpv6Loopback)

DeviceIpv6GatewayMAC = _reflection.GeneratedProtocolMessageType('DeviceIpv6GatewayMAC', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEIPV6GATEWAYMAC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceIpv6GatewayMAC.Choice)
    })
  ,
  'DESCRIPTOR' : _DEVICEIPV6GATEWAYMAC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv6GatewayMAC)
  })
_sym_db.RegisterMessage(DeviceIpv6GatewayMAC)
_sym_db.RegisterMessage(DeviceIpv6GatewayMAC.Choice)

Layer1 = _reflection.GeneratedProtocolMessageType('Layer1', (_message.Message,), {

  'Speed' : _reflection.GeneratedProtocolMessageType('Speed', (_message.Message,), {
    'DESCRIPTOR' : _LAYER1_SPEED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Layer1.Speed)
    })
  ,

  'Media' : _reflection.GeneratedProtocolMessageType('Media', (_message.Message,), {
    'DESCRIPTOR' : _LAYER1_MEDIA,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Layer1.Media)
    })
  ,
  'DESCRIPTOR' : _LAYER1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1)
  })
_sym_db.RegisterMessage(Layer1)
_sym_db.RegisterMessage(Layer1.Speed)
_sym_db.RegisterMessage(Layer1.Media)

Layer1AutoNegotiation = _reflection.GeneratedProtocolMessageType('Layer1AutoNegotiation', (_message.Message,), {
  'DESCRIPTOR' : _LAYER1AUTONEGOTIATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1AutoNegotiation)
  })
_sym_db.RegisterMessage(Layer1AutoNegotiation)

Layer1FlowControl = _reflection.GeneratedProtocolMessageType('Layer1FlowControl', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LAYER1FLOWCONTROL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Layer1FlowControl.Choice)
    })
  ,
  'DESCRIPTOR' : _LAYER1FLOWCONTROL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1FlowControl)
  })
_sym_db.RegisterMessage(Layer1FlowControl)
_sym_db.RegisterMessage(Layer1FlowControl.Choice)

Layer1Ieee8023x = _reflection.GeneratedProtocolMessageType('Layer1Ieee8023x', (_message.Message,), {
  'DESCRIPTOR' : _LAYER1IEEE8023X,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1Ieee8023x)
  })
_sym_db.RegisterMessage(Layer1Ieee8023x)

Layer1Ieee8021qbb = _reflection.GeneratedProtocolMessageType('Layer1Ieee8021qbb', (_message.Message,), {
  'DESCRIPTOR' : _LAYER1IEEE8021QBB,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1Ieee8021qbb)
  })
_sym_db.RegisterMessage(Layer1Ieee8021qbb)

Capture = _reflection.GeneratedProtocolMessageType('Capture', (_message.Message,), {

  'Format' : _reflection.GeneratedProtocolMessageType('Format', (_message.Message,), {
    'DESCRIPTOR' : _CAPTURE_FORMAT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Capture.Format)
    })
  ,
  'DESCRIPTOR' : _CAPTURE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Capture)
  })
_sym_db.RegisterMessage(Capture)
_sym_db.RegisterMessage(Capture.Format)

CaptureFilter = _reflection.GeneratedProtocolMessageType('CaptureFilter', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _CAPTUREFILTER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.CaptureFilter.Choice)
    })
  ,
  'DESCRIPTOR' : _CAPTUREFILTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureFilter)
  })
_sym_db.RegisterMessage(CaptureFilter)
_sym_db.RegisterMessage(CaptureFilter.Choice)

CaptureCustom = _reflection.GeneratedProtocolMessageType('CaptureCustom', (_message.Message,), {
  'DESCRIPTOR' : _CAPTURECUSTOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureCustom)
  })
_sym_db.RegisterMessage(CaptureCustom)

CaptureField = _reflection.GeneratedProtocolMessageType('CaptureField', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREFIELD,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureField)
  })
_sym_db.RegisterMessage(CaptureField)

CaptureEthernet = _reflection.GeneratedProtocolMessageType('CaptureEthernet', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREETHERNET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureEthernet)
  })
_sym_db.RegisterMessage(CaptureEthernet)

CaptureVlan = _reflection.GeneratedProtocolMessageType('CaptureVlan', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREVLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureVlan)
  })
_sym_db.RegisterMessage(CaptureVlan)

CaptureIpv4 = _reflection.GeneratedProtocolMessageType('CaptureIpv4', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureIpv4)
  })
_sym_db.RegisterMessage(CaptureIpv4)

CaptureIpv6 = _reflection.GeneratedProtocolMessageType('CaptureIpv6', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureIpv6)
  })
_sym_db.RegisterMessage(CaptureIpv6)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Device)
  })
_sym_db.RegisterMessage(Device)

ProtocolOptions = _reflection.GeneratedProtocolMessageType('ProtocolOptions', (_message.Message,), {
  'DESCRIPTOR' : _PROTOCOLOPTIONS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ProtocolOptions)
  })
_sym_db.RegisterMessage(ProtocolOptions)

DeviceIsisRouter = _reflection.GeneratedProtocolMessageType('DeviceIsisRouter', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISISROUTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIsisRouter)
  })
_sym_db.RegisterMessage(DeviceIsisRouter)

DeviceIsisMultiInstance = _reflection.GeneratedProtocolMessageType('DeviceIsisMultiInstance', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISISMULTIINSTANCE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIsisMultiInstance)
  })
_sym_db.RegisterMessage(DeviceIsisMultiInstance)

IsisInterface = _reflection.GeneratedProtocolMessageType('IsisInterface', (_message.Message,), {

  'NetworkType' : _reflection.GeneratedProtocolMessageType('NetworkType', (_message.Message,), {
    'DESCRIPTOR' : _ISISINTERFACE_NETWORKTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisInterface.NetworkType)
    })
  ,

  'LevelType' : _reflection.GeneratedProtocolMessageType('LevelType', (_message.Message,), {
    'DESCRIPTOR' : _ISISINTERFACE_LEVELTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisInterface.LevelType)
    })
  ,
  'DESCRIPTOR' : _ISISINTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterface)
  })
_sym_db.RegisterMessage(IsisInterface)
_sym_db.RegisterMessage(IsisInterface.NetworkType)
_sym_db.RegisterMessage(IsisInterface.LevelType)

IsisInterfaceLevel = _reflection.GeneratedProtocolMessageType('IsisInterfaceLevel', (_message.Message,), {
  'DESCRIPTOR' : _ISISINTERFACELEVEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceLevel)
  })
_sym_db.RegisterMessage(IsisInterfaceLevel)

IsisMT = _reflection.GeneratedProtocolMessageType('IsisMT', (_message.Message,), {
  'DESCRIPTOR' : _ISISMT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisMT)
  })
_sym_db.RegisterMessage(IsisMT)

LinkStateTE = _reflection.GeneratedProtocolMessageType('LinkStateTE', (_message.Message,), {
  'DESCRIPTOR' : _LINKSTATETE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LinkStateTE)
  })
_sym_db.RegisterMessage(LinkStateTE)

LinkStatepriorityBandwidths = _reflection.GeneratedProtocolMessageType('LinkStatepriorityBandwidths', (_message.Message,), {
  'DESCRIPTOR' : _LINKSTATEPRIORITYBANDWIDTHS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LinkStatepriorityBandwidths)
  })
_sym_db.RegisterMessage(LinkStatepriorityBandwidths)

IsisInterfaceAuthentication = _reflection.GeneratedProtocolMessageType('IsisInterfaceAuthentication', (_message.Message,), {

  'AuthType' : _reflection.GeneratedProtocolMessageType('AuthType', (_message.Message,), {
    'DESCRIPTOR' : _ISISINTERFACEAUTHENTICATION_AUTHTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisInterfaceAuthentication.AuthType)
    })
  ,
  'DESCRIPTOR' : _ISISINTERFACEAUTHENTICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceAuthentication)
  })
_sym_db.RegisterMessage(IsisInterfaceAuthentication)
_sym_db.RegisterMessage(IsisInterfaceAuthentication.AuthType)

IsisInterfaceAdvanced = _reflection.GeneratedProtocolMessageType('IsisInterfaceAdvanced', (_message.Message,), {
  'DESCRIPTOR' : _ISISINTERFACEADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceAdvanced)
  })
_sym_db.RegisterMessage(IsisInterfaceAdvanced)

IsisInterfaceLinkProtection = _reflection.GeneratedProtocolMessageType('IsisInterfaceLinkProtection', (_message.Message,), {
  'DESCRIPTOR' : _ISISINTERFACELINKPROTECTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceLinkProtection)
  })
_sym_db.RegisterMessage(IsisInterfaceLinkProtection)

IsisBasic = _reflection.GeneratedProtocolMessageType('IsisBasic', (_message.Message,), {
  'DESCRIPTOR' : _ISISBASIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisBasic)
  })
_sym_db.RegisterMessage(IsisBasic)

IsisAdvanced = _reflection.GeneratedProtocolMessageType('IsisAdvanced', (_message.Message,), {
  'DESCRIPTOR' : _ISISADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisAdvanced)
  })
_sym_db.RegisterMessage(IsisAdvanced)

IsisAuthentication = _reflection.GeneratedProtocolMessageType('IsisAuthentication', (_message.Message,), {
  'DESCRIPTOR' : _ISISAUTHENTICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisAuthentication)
  })
_sym_db.RegisterMessage(IsisAuthentication)

IsisAuthenticationBase = _reflection.GeneratedProtocolMessageType('IsisAuthenticationBase', (_message.Message,), {

  'AuthType' : _reflection.GeneratedProtocolMessageType('AuthType', (_message.Message,), {
    'DESCRIPTOR' : _ISISAUTHENTICATIONBASE_AUTHTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisAuthenticationBase.AuthType)
    })
  ,
  'DESCRIPTOR' : _ISISAUTHENTICATIONBASE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisAuthenticationBase)
  })
_sym_db.RegisterMessage(IsisAuthenticationBase)
_sym_db.RegisterMessage(IsisAuthenticationBase.AuthType)

IsisV4RouteRange = _reflection.GeneratedProtocolMessageType('IsisV4RouteRange', (_message.Message,), {

  'OriginType' : _reflection.GeneratedProtocolMessageType('OriginType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV4ROUTERANGE_ORIGINTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV4RouteRange.OriginType)
    })
  ,

  'RedistributionType' : _reflection.GeneratedProtocolMessageType('RedistributionType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV4RouteRange.RedistributionType)
    })
  ,
  'DESCRIPTOR' : _ISISV4ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisV4RouteRange)
  })
_sym_db.RegisterMessage(IsisV4RouteRange)
_sym_db.RegisterMessage(IsisV4RouteRange.OriginType)
_sym_db.RegisterMessage(IsisV4RouteRange.RedistributionType)

V4RouteAddress = _reflection.GeneratedProtocolMessageType('V4RouteAddress', (_message.Message,), {
  'DESCRIPTOR' : _V4ROUTEADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.V4RouteAddress)
  })
_sym_db.RegisterMessage(V4RouteAddress)

V6RouteAddress = _reflection.GeneratedProtocolMessageType('V6RouteAddress', (_message.Message,), {
  'DESCRIPTOR' : _V6ROUTEADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.V6RouteAddress)
  })
_sym_db.RegisterMessage(V6RouteAddress)

MACRouteAddress = _reflection.GeneratedProtocolMessageType('MACRouteAddress', (_message.Message,), {
  'DESCRIPTOR' : _MACROUTEADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MACRouteAddress)
  })
_sym_db.RegisterMessage(MACRouteAddress)

IsisV6RouteRange = _reflection.GeneratedProtocolMessageType('IsisV6RouteRange', (_message.Message,), {

  'OriginType' : _reflection.GeneratedProtocolMessageType('OriginType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV6ROUTERANGE_ORIGINTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV6RouteRange.OriginType)
    })
  ,

  'RedistributionType' : _reflection.GeneratedProtocolMessageType('RedistributionType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV6RouteRange.RedistributionType)
    })
  ,
  'DESCRIPTOR' : _ISISV6ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisV6RouteRange)
  })
_sym_db.RegisterMessage(IsisV6RouteRange)
_sym_db.RegisterMessage(IsisV6RouteRange.OriginType)
_sym_db.RegisterMessage(IsisV6RouteRange.RedistributionType)

DeviceBgpRouter = _reflection.GeneratedProtocolMessageType('DeviceBgpRouter', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEBGPROUTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpRouter)
  })
_sym_db.RegisterMessage(DeviceBgpRouter)

DeviceBgpMessageHeaderError = _reflection.GeneratedProtocolMessageType('DeviceBgpMessageHeaderError', (_message.Message,), {

  'Subcode' : _reflection.GeneratedProtocolMessageType('Subcode', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEBGPMESSAGEHEADERERROR_SUBCODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceBgpMessageHeaderError.Subcode)
    })
  ,
  'DESCRIPTOR' : _DEVICEBGPMESSAGEHEADERERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpMessageHeaderError)
  })
_sym_db.RegisterMessage(DeviceBgpMessageHeaderError)
_sym_db.RegisterMessage(DeviceBgpMessageHeaderError.Subcode)

DeviceBgpOpenMessageError = _reflection.GeneratedProtocolMessageType('DeviceBgpOpenMessageError', (_message.Message,), {

  'Subcode' : _reflection.GeneratedProtocolMessageType('Subcode', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEBGPOPENMESSAGEERROR_SUBCODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceBgpOpenMessageError.Subcode)
    })
  ,
  'DESCRIPTOR' : _DEVICEBGPOPENMESSAGEERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpOpenMessageError)
  })
_sym_db.RegisterMessage(DeviceBgpOpenMessageError)
_sym_db.RegisterMessage(DeviceBgpOpenMessageError.Subcode)

DeviceBgpUpdateMessageError = _reflection.GeneratedProtocolMessageType('DeviceBgpUpdateMessageError', (_message.Message,), {

  'Subcode' : _reflection.GeneratedProtocolMessageType('Subcode', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEBGPUPDATEMESSAGEERROR_SUBCODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceBgpUpdateMessageError.Subcode)
    })
  ,
  'DESCRIPTOR' : _DEVICEBGPUPDATEMESSAGEERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpUpdateMessageError)
  })
_sym_db.RegisterMessage(DeviceBgpUpdateMessageError)
_sym_db.RegisterMessage(DeviceBgpUpdateMessageError.Subcode)

DeviceBgpHoldTimerExpired = _reflection.GeneratedProtocolMessageType('DeviceBgpHoldTimerExpired', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEBGPHOLDTIMEREXPIRED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpHoldTimerExpired)
  })
_sym_db.RegisterMessage(DeviceBgpHoldTimerExpired)

DeviceBgpFiniteStateMachineError = _reflection.GeneratedProtocolMessageType('DeviceBgpFiniteStateMachineError', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEBGPFINITESTATEMACHINEERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpFiniteStateMachineError)
  })
_sym_db.RegisterMessage(DeviceBgpFiniteStateMachineError)

DeviceBgpCeaseError = _reflection.GeneratedProtocolMessageType('DeviceBgpCeaseError', (_message.Message,), {

  'Subcode' : _reflection.GeneratedProtocolMessageType('Subcode', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEBGPCEASEERROR_SUBCODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceBgpCeaseError.Subcode)
    })
  ,
  'DESCRIPTOR' : _DEVICEBGPCEASEERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpCeaseError)
  })
_sym_db.RegisterMessage(DeviceBgpCeaseError)
_sym_db.RegisterMessage(DeviceBgpCeaseError.Subcode)

DeviceBgpCustomError = _reflection.GeneratedProtocolMessageType('DeviceBgpCustomError', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEBGPCUSTOMERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpCustomError)
  })
_sym_db.RegisterMessage(DeviceBgpCustomError)

BgpV4Peer = _reflection.GeneratedProtocolMessageType('BgpV4Peer', (_message.Message,), {

  'AsType' : _reflection.GeneratedProtocolMessageType('AsType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4PEER_ASTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4Peer.AsType)
    })
  ,

  'AsNumberWidth' : _reflection.GeneratedProtocolMessageType('AsNumberWidth', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4PEER_ASNUMBERWIDTH,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4Peer.AsNumberWidth)
    })
  ,
  'DESCRIPTOR' : _BGPV4PEER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4Peer)
  })
_sym_db.RegisterMessage(BgpV4Peer)
_sym_db.RegisterMessage(BgpV4Peer.AsType)
_sym_db.RegisterMessage(BgpV4Peer.AsNumberWidth)

BgpV4Interface = _reflection.GeneratedProtocolMessageType('BgpV4Interface', (_message.Message,), {
  'DESCRIPTOR' : _BGPV4INTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4Interface)
  })
_sym_db.RegisterMessage(BgpV4Interface)

BgpV4EthernetSegment = _reflection.GeneratedProtocolMessageType('BgpV4EthernetSegment', (_message.Message,), {

  'ActiveMode' : _reflection.GeneratedProtocolMessageType('ActiveMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4ETHERNETSEGMENT_ACTIVEMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4EthernetSegment.ActiveMode)
    })
  ,
  'DESCRIPTOR' : _BGPV4ETHERNETSEGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4EthernetSegment)
  })
_sym_db.RegisterMessage(BgpV4EthernetSegment)
_sym_db.RegisterMessage(BgpV4EthernetSegment.ActiveMode)

BgpEthernetSegmentDfElection = _reflection.GeneratedProtocolMessageType('BgpEthernetSegmentDfElection', (_message.Message,), {
  'DESCRIPTOR' : _BGPETHERNETSEGMENTDFELECTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpEthernetSegmentDfElection)
  })
_sym_db.RegisterMessage(BgpEthernetSegmentDfElection)

BgpRouteAdvanced = _reflection.GeneratedProtocolMessageType('BgpRouteAdvanced', (_message.Message,), {

  'Origin' : _reflection.GeneratedProtocolMessageType('Origin', (_message.Message,), {
    'DESCRIPTOR' : _BGPROUTEADVANCED_ORIGIN,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpRouteAdvanced.Origin)
    })
  ,
  'DESCRIPTOR' : _BGPROUTEADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpRouteAdvanced)
  })
_sym_db.RegisterMessage(BgpRouteAdvanced)
_sym_db.RegisterMessage(BgpRouteAdvanced.Origin)

BgpCommunity = _reflection.GeneratedProtocolMessageType('BgpCommunity', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _BGPCOMMUNITY_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpCommunity.Type)
    })
  ,
  'DESCRIPTOR' : _BGPCOMMUNITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpCommunity)
  })
_sym_db.RegisterMessage(BgpCommunity)
_sym_db.RegisterMessage(BgpCommunity.Type)

BgpExtCommunity = _reflection.GeneratedProtocolMessageType('BgpExtCommunity', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _BGPEXTCOMMUNITY_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpExtCommunity.Type)
    })
  ,

  'Subtype' : _reflection.GeneratedProtocolMessageType('Subtype', (_message.Message,), {
    'DESCRIPTOR' : _BGPEXTCOMMUNITY_SUBTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpExtCommunity.Subtype)
    })
  ,
  'DESCRIPTOR' : _BGPEXTCOMMUNITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpExtCommunity)
  })
_sym_db.RegisterMessage(BgpExtCommunity)
_sym_db.RegisterMessage(BgpExtCommunity.Type)
_sym_db.RegisterMessage(BgpExtCommunity.Subtype)

BgpAsPath = _reflection.GeneratedProtocolMessageType('BgpAsPath', (_message.Message,), {

  'AsSetMode' : _reflection.GeneratedProtocolMessageType('AsSetMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPASPATH_ASSETMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpAsPath.AsSetMode)
    })
  ,
  'DESCRIPTOR' : _BGPASPATH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAsPath)
  })
_sym_db.RegisterMessage(BgpAsPath)
_sym_db.RegisterMessage(BgpAsPath.AsSetMode)

BgpAsPathSegment = _reflection.GeneratedProtocolMessageType('BgpAsPathSegment', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _BGPASPATHSEGMENT_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpAsPathSegment.Type)
    })
  ,
  'DESCRIPTOR' : _BGPASPATHSEGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAsPathSegment)
  })
_sym_db.RegisterMessage(BgpAsPathSegment)
_sym_db.RegisterMessage(BgpAsPathSegment.Type)

BgpV4EvpnEvis = _reflection.GeneratedProtocolMessageType('BgpV4EvpnEvis', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4EVPNEVIS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4EvpnEvis.Choice)
    })
  ,
  'DESCRIPTOR' : _BGPV4EVPNEVIS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4EvpnEvis)
  })
_sym_db.RegisterMessage(BgpV4EvpnEvis)
_sym_db.RegisterMessage(BgpV4EvpnEvis.Choice)

BgpV4EviVxlan = _reflection.GeneratedProtocolMessageType('BgpV4EviVxlan', (_message.Message,), {

  'ReplicationType' : _reflection.GeneratedProtocolMessageType('ReplicationType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4EVIVXLAN_REPLICATIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4EviVxlan.ReplicationType)
    })
  ,
  'DESCRIPTOR' : _BGPV4EVIVXLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4EviVxlan)
  })
_sym_db.RegisterMessage(BgpV4EviVxlan)
_sym_db.RegisterMessage(BgpV4EviVxlan.ReplicationType)

BgpV4EviVxlanBroadcastDomain = _reflection.GeneratedProtocolMessageType('BgpV4EviVxlanBroadcastDomain', (_message.Message,), {
  'DESCRIPTOR' : _BGPV4EVIVXLANBROADCASTDOMAIN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4EviVxlanBroadcastDomain)
  })
_sym_db.RegisterMessage(BgpV4EviVxlanBroadcastDomain)

BgpCMacIpRange = _reflection.GeneratedProtocolMessageType('BgpCMacIpRange', (_message.Message,), {
  'DESCRIPTOR' : _BGPCMACIPRANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpCMacIpRange)
  })
_sym_db.RegisterMessage(BgpCMacIpRange)

BgpRouteDistinguisher = _reflection.GeneratedProtocolMessageType('BgpRouteDistinguisher', (_message.Message,), {

  'RdType' : _reflection.GeneratedProtocolMessageType('RdType', (_message.Message,), {
    'DESCRIPTOR' : _BGPROUTEDISTINGUISHER_RDTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpRouteDistinguisher.RdType)
    })
  ,
  'DESCRIPTOR' : _BGPROUTEDISTINGUISHER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpRouteDistinguisher)
  })
_sym_db.RegisterMessage(BgpRouteDistinguisher)
_sym_db.RegisterMessage(BgpRouteDistinguisher.RdType)

BgpRouteTarget = _reflection.GeneratedProtocolMessageType('BgpRouteTarget', (_message.Message,), {

  'RtType' : _reflection.GeneratedProtocolMessageType('RtType', (_message.Message,), {
    'DESCRIPTOR' : _BGPROUTETARGET_RTTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpRouteTarget.RtType)
    })
  ,
  'DESCRIPTOR' : _BGPROUTETARGET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpRouteTarget)
  })
_sym_db.RegisterMessage(BgpRouteTarget)
_sym_db.RegisterMessage(BgpRouteTarget.RtType)

BgpAdvanced = _reflection.GeneratedProtocolMessageType('BgpAdvanced', (_message.Message,), {
  'DESCRIPTOR' : _BGPADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAdvanced)
  })
_sym_db.RegisterMessage(BgpAdvanced)

BgpCapability = _reflection.GeneratedProtocolMessageType('BgpCapability', (_message.Message,), {
  'DESCRIPTOR' : _BGPCAPABILITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpCapability)
  })
_sym_db.RegisterMessage(BgpCapability)

BgpLearnedInformationFilter = _reflection.GeneratedProtocolMessageType('BgpLearnedInformationFilter', (_message.Message,), {
  'DESCRIPTOR' : _BGPLEARNEDINFORMATIONFILTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpLearnedInformationFilter)
  })
_sym_db.RegisterMessage(BgpLearnedInformationFilter)

BgpV4RouteRange = _reflection.GeneratedProtocolMessageType('BgpV4RouteRange', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4ROUTERANGE_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4RouteRange.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4RouteRange.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPV4ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4RouteRange)
  })
_sym_db.RegisterMessage(BgpV4RouteRange)
_sym_db.RegisterMessage(BgpV4RouteRange.NextHopMode)
_sym_db.RegisterMessage(BgpV4RouteRange.NextHopAddressType)

BgpAddPath = _reflection.GeneratedProtocolMessageType('BgpAddPath', (_message.Message,), {
  'DESCRIPTOR' : _BGPADDPATH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAddPath)
  })
_sym_db.RegisterMessage(BgpAddPath)

BgpV6RouteRange = _reflection.GeneratedProtocolMessageType('BgpV6RouteRange', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6ROUTERANGE_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6RouteRange.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6RouteRange.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPV6ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6RouteRange)
  })
_sym_db.RegisterMessage(BgpV6RouteRange)
_sym_db.RegisterMessage(BgpV6RouteRange.NextHopMode)
_sym_db.RegisterMessage(BgpV6RouteRange.NextHopAddressType)

BgpSrteV4Policy = _reflection.GeneratedProtocolMessageType('BgpSrteV4Policy', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV4POLICY_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV4Policy.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV4Policy.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEV4POLICY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV4Policy)
  })
_sym_db.RegisterMessage(BgpSrteV4Policy)
_sym_db.RegisterMessage(BgpSrteV4Policy.NextHopMode)
_sym_db.RegisterMessage(BgpSrteV4Policy.NextHopAddressType)

BgpSrteV4TunnelTlv = _reflection.GeneratedProtocolMessageType('BgpSrteV4TunnelTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEV4TUNNELTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV4TunnelTlv)
  })
_sym_db.RegisterMessage(BgpSrteV4TunnelTlv)

BgpSrteRemoteEndpointSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteRemoteEndpointSubTlv', (_message.Message,), {

  'AddressFamily' : _reflection.GeneratedProtocolMessageType('AddressFamily', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteRemoteEndpointSubTlv.AddressFamily)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEREMOTEENDPOINTSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteRemoteEndpointSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteRemoteEndpointSubTlv)
_sym_db.RegisterMessage(BgpSrteRemoteEndpointSubTlv.AddressFamily)

BgpSrteColorSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteColorSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTECOLORSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteColorSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteColorSubTlv)

BgpSrteBindingSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteBindingSubTlv', (_message.Message,), {

  'BindingSidType' : _reflection.GeneratedProtocolMessageType('BindingSidType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteBindingSubTlv.BindingSidType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEBINDINGSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteBindingSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteBindingSubTlv)
_sym_db.RegisterMessage(BgpSrteBindingSubTlv.BindingSidType)

BgpSrtePreferenceSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrtePreferenceSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEPREFERENCESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrtePreferenceSubTlv)
  })
_sym_db.RegisterMessage(BgpSrtePreferenceSubTlv)

BgpSrtePolicyPrioritySubTlv = _reflection.GeneratedProtocolMessageType('BgpSrtePolicyPrioritySubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEPOLICYPRIORITYSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrtePolicyPrioritySubTlv)
  })
_sym_db.RegisterMessage(BgpSrtePolicyPrioritySubTlv)

BgpSrtePolicyNameSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrtePolicyNameSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEPOLICYNAMESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrtePolicyNameSubTlv)
  })
_sym_db.RegisterMessage(BgpSrtePolicyNameSubTlv)

BgpSrteExplicitNullLabelPolicySubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteExplicitNullLabelPolicySubTlv', (_message.Message,), {

  'ExplicitNullLabelPolicy' : _reflection.GeneratedProtocolMessageType('ExplicitNullLabelPolicy', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteExplicitNullLabelPolicySubTlv)
  })
_sym_db.RegisterMessage(BgpSrteExplicitNullLabelPolicySubTlv)
_sym_db.RegisterMessage(BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy)

BgpSrteSegmentList = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentList', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTLIST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentList)
  })
_sym_db.RegisterMessage(BgpSrteSegmentList)

BgpSrteSegment = _reflection.GeneratedProtocolMessageType('BgpSrteSegment', (_message.Message,), {

  'SegmentType' : _reflection.GeneratedProtocolMessageType('SegmentType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTESEGMENT_SEGMENTTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteSegment.SegmentType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTESEGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegment)
  })
_sym_db.RegisterMessage(BgpSrteSegment)
_sym_db.RegisterMessage(BgpSrteSegment.SegmentType)

BgpSrteSrMplsSid = _reflection.GeneratedProtocolMessageType('BgpSrteSrMplsSid', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESRMPLSSID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSrMplsSid)
  })
_sym_db.RegisterMessage(BgpSrteSrMplsSid)

BgpSrteSRv6SIDEndpointBehaviorAndStructure = _reflection.GeneratedProtocolMessageType('BgpSrteSRv6SIDEndpointBehaviorAndStructure', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure)
  })
_sym_db.RegisterMessage(BgpSrteSRv6SIDEndpointBehaviorAndStructure)

BgpSrteSegmentATypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentATypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTATYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentATypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentATypeSubTlv)

BgpSrteSegmentBTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentBTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTBTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentBTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentBTypeSubTlv)

BgpSrteSegmentCTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentCTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTCTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentCTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentCTypeSubTlv)

BgpSrteSegmentDTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentDTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTDTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentDTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentDTypeSubTlv)

BgpSrteSegmentETypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentETypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTETYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentETypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentETypeSubTlv)

BgpSrteSegmentFTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentFTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTFTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentFTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentFTypeSubTlv)

BgpSrteSegmentGTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentGTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTGTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentGTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentGTypeSubTlv)

BgpSrteSegmentHTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentHTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTHTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentHTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentHTypeSubTlv)

BgpSrteSegmentITypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentITypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTITYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentITypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentITypeSubTlv)

BgpSrteSegmentJTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentJTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTJTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentJTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentJTypeSubTlv)

BgpSrteSegmentKTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentKTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTKTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentKTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentKTypeSubTlv)

BgpSrteV6Policy = _reflection.GeneratedProtocolMessageType('BgpSrteV6Policy', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV6POLICY_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV6Policy.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV6Policy.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEV6POLICY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV6Policy)
  })
_sym_db.RegisterMessage(BgpSrteV6Policy)
_sym_db.RegisterMessage(BgpSrteV6Policy.NextHopMode)
_sym_db.RegisterMessage(BgpSrteV6Policy.NextHopAddressType)

BgpSrteV6TunnelTlv = _reflection.GeneratedProtocolMessageType('BgpSrteV6TunnelTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEV6TUNNELTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV6TunnelTlv)
  })
_sym_db.RegisterMessage(BgpSrteV6TunnelTlv)

BgpGracefulRestart = _reflection.GeneratedProtocolMessageType('BgpGracefulRestart', (_message.Message,), {
  'DESCRIPTOR' : _BGPGRACEFULRESTART,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpGracefulRestart)
  })
_sym_db.RegisterMessage(BgpGracefulRestart)

BgpV6Peer = _reflection.GeneratedProtocolMessageType('BgpV6Peer', (_message.Message,), {

  'AsType' : _reflection.GeneratedProtocolMessageType('AsType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6PEER_ASTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6Peer.AsType)
    })
  ,

  'AsNumberWidth' : _reflection.GeneratedProtocolMessageType('AsNumberWidth', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6PEER_ASNUMBERWIDTH,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6Peer.AsNumberWidth)
    })
  ,
  'DESCRIPTOR' : _BGPV6PEER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6Peer)
  })
_sym_db.RegisterMessage(BgpV6Peer)
_sym_db.RegisterMessage(BgpV6Peer.AsType)
_sym_db.RegisterMessage(BgpV6Peer.AsNumberWidth)

BgpV6Interface = _reflection.GeneratedProtocolMessageType('BgpV6Interface', (_message.Message,), {
  'DESCRIPTOR' : _BGPV6INTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6Interface)
  })
_sym_db.RegisterMessage(BgpV6Interface)

BgpV6SegmentRouting = _reflection.GeneratedProtocolMessageType('BgpV6SegmentRouting', (_message.Message,), {
  'DESCRIPTOR' : _BGPV6SEGMENTROUTING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6SegmentRouting)
  })
_sym_db.RegisterMessage(BgpV6SegmentRouting)

BgpV6EthernetSegment = _reflection.GeneratedProtocolMessageType('BgpV6EthernetSegment', (_message.Message,), {

  'ActiveMode' : _reflection.GeneratedProtocolMessageType('ActiveMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6ETHERNETSEGMENT_ACTIVEMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6EthernetSegment.ActiveMode)
    })
  ,
  'DESCRIPTOR' : _BGPV6ETHERNETSEGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6EthernetSegment)
  })
_sym_db.RegisterMessage(BgpV6EthernetSegment)
_sym_db.RegisterMessage(BgpV6EthernetSegment.ActiveMode)

BgpV6EvpnEvis = _reflection.GeneratedProtocolMessageType('BgpV6EvpnEvis', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6EVPNEVIS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6EvpnEvis.Choice)
    })
  ,
  'DESCRIPTOR' : _BGPV6EVPNEVIS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6EvpnEvis)
  })
_sym_db.RegisterMessage(BgpV6EvpnEvis)
_sym_db.RegisterMessage(BgpV6EvpnEvis.Choice)

BgpV6EviVxlan = _reflection.GeneratedProtocolMessageType('BgpV6EviVxlan', (_message.Message,), {

  'ReplicationType' : _reflection.GeneratedProtocolMessageType('ReplicationType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6EVIVXLAN_REPLICATIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6EviVxlan.ReplicationType)
    })
  ,
  'DESCRIPTOR' : _BGPV6EVIVXLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6EviVxlan)
  })
_sym_db.RegisterMessage(BgpV6EviVxlan)
_sym_db.RegisterMessage(BgpV6EviVxlan.ReplicationType)

BgpV6EviVxlanBroadcastDomain = _reflection.GeneratedProtocolMessageType('BgpV6EviVxlanBroadcastDomain', (_message.Message,), {
  'DESCRIPTOR' : _BGPV6EVIVXLANBROADCASTDOMAIN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6EviVxlanBroadcastDomain)
  })
_sym_db.RegisterMessage(BgpV6EviVxlanBroadcastDomain)

DeviceVxlan = _reflection.GeneratedProtocolMessageType('DeviceVxlan', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEVXLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceVxlan)
  })
_sym_db.RegisterMessage(DeviceVxlan)

VxlanV4Tunnel = _reflection.GeneratedProtocolMessageType('VxlanV4Tunnel', (_message.Message,), {
  'DESCRIPTOR' : _VXLANV4TUNNEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV4Tunnel)
  })
_sym_db.RegisterMessage(VxlanV4Tunnel)

VxlanV6Tunnel = _reflection.GeneratedProtocolMessageType('VxlanV6Tunnel', (_message.Message,), {
  'DESCRIPTOR' : _VXLANV6TUNNEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV6Tunnel)
  })
_sym_db.RegisterMessage(VxlanV6Tunnel)

VxlanV4TunnelDestinationIPMode = _reflection.GeneratedProtocolMessageType('VxlanV4TunnelDestinationIPMode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _VXLANV4TUNNELDESTINATIONIPMODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.VxlanV4TunnelDestinationIPMode.Choice)
    })
  ,
  'DESCRIPTOR' : _VXLANV4TUNNELDESTINATIONIPMODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV4TunnelDestinationIPMode)
  })
_sym_db.RegisterMessage(VxlanV4TunnelDestinationIPMode)
_sym_db.RegisterMessage(VxlanV4TunnelDestinationIPMode.Choice)

VxlanV6TunnelDestinationIPMode = _reflection.GeneratedProtocolMessageType('VxlanV6TunnelDestinationIPMode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _VXLANV6TUNNELDESTINATIONIPMODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.VxlanV6TunnelDestinationIPMode.Choice)
    })
  ,
  'DESCRIPTOR' : _VXLANV6TUNNELDESTINATIONIPMODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV6TunnelDestinationIPMode)
  })
_sym_db.RegisterMessage(VxlanV6TunnelDestinationIPMode)
_sym_db.RegisterMessage(VxlanV6TunnelDestinationIPMode.Choice)

VxlanV4TunnelDestinationIPModeUnicast = _reflection.GeneratedProtocolMessageType('VxlanV4TunnelDestinationIPModeUnicast', (_message.Message,), {
  'DESCRIPTOR' : _VXLANV4TUNNELDESTINATIONIPMODEUNICAST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV4TunnelDestinationIPModeUnicast)
  })
_sym_db.RegisterMessage(VxlanV4TunnelDestinationIPModeUnicast)

VxlanV6TunnelDestinationIPModeUnicast = _reflection.GeneratedProtocolMessageType('VxlanV6TunnelDestinationIPModeUnicast', (_message.Message,), {
  'DESCRIPTOR' : _VXLANV6TUNNELDESTINATIONIPMODEUNICAST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV6TunnelDestinationIPModeUnicast)
  })
_sym_db.RegisterMessage(VxlanV6TunnelDestinationIPModeUnicast)

VxlanTunnelDestinationIPModeUnicastArpSuppressionCache = _reflection.GeneratedProtocolMessageType('VxlanTunnelDestinationIPModeUnicastArpSuppressionCache', (_message.Message,), {
  'DESCRIPTOR' : _VXLANTUNNELDESTINATIONIPMODEUNICASTARPSUPPRESSIONCACHE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanTunnelDestinationIPModeUnicastArpSuppressionCache)
  })
_sym_db.RegisterMessage(VxlanTunnelDestinationIPModeUnicastArpSuppressionCache)

VxlanV4TunnelDestinationIPModeUnicastVtep = _reflection.GeneratedProtocolMessageType('VxlanV4TunnelDestinationIPModeUnicastVtep', (_message.Message,), {
  'DESCRIPTOR' : _VXLANV4TUNNELDESTINATIONIPMODEUNICASTVTEP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV4TunnelDestinationIPModeUnicastVtep)
  })
_sym_db.RegisterMessage(VxlanV4TunnelDestinationIPModeUnicastVtep)

VxlanV6TunnelDestinationIPModeUnicastVtep = _reflection.GeneratedProtocolMessageType('VxlanV6TunnelDestinationIPModeUnicastVtep', (_message.Message,), {
  'DESCRIPTOR' : _VXLANV6TUNNELDESTINATIONIPMODEUNICASTVTEP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV6TunnelDestinationIPModeUnicastVtep)
  })
_sym_db.RegisterMessage(VxlanV6TunnelDestinationIPModeUnicastVtep)

VxlanV4TunnelDestinationIPModeMulticast = _reflection.GeneratedProtocolMessageType('VxlanV4TunnelDestinationIPModeMulticast', (_message.Message,), {
  'DESCRIPTOR' : _VXLANV4TUNNELDESTINATIONIPMODEMULTICAST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV4TunnelDestinationIPModeMulticast)
  })
_sym_db.RegisterMessage(VxlanV4TunnelDestinationIPModeMulticast)

VxlanV6TunnelDestinationIPModeMulticast = _reflection.GeneratedProtocolMessageType('VxlanV6TunnelDestinationIPModeMulticast', (_message.Message,), {
  'DESCRIPTOR' : _VXLANV6TUNNELDESTINATIONIPMODEMULTICAST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.VxlanV6TunnelDestinationIPModeMulticast)
  })
_sym_db.RegisterMessage(VxlanV6TunnelDestinationIPModeMulticast)

DeviceRsvp = _reflection.GeneratedProtocolMessageType('DeviceRsvp', (_message.Message,), {
  'DESCRIPTOR' : _DEVICERSVP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceRsvp)
  })
_sym_db.RegisterMessage(DeviceRsvp)

RsvpIpv4Interface = _reflection.GeneratedProtocolMessageType('RsvpIpv4Interface', (_message.Message,), {
  'DESCRIPTOR' : _RSVPIPV4INTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpIpv4Interface)
  })
_sym_db.RegisterMessage(RsvpIpv4Interface)

RsvpLspIpv4Interface = _reflection.GeneratedProtocolMessageType('RsvpLspIpv4Interface', (_message.Message,), {
  'DESCRIPTOR' : _RSVPLSPIPV4INTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpLspIpv4Interface)
  })
_sym_db.RegisterMessage(RsvpLspIpv4Interface)

RsvpLspIpv4InterfaceP2PEgressIpv4Lsp = _reflection.GeneratedProtocolMessageType('RsvpLspIpv4InterfaceP2PEgressIpv4Lsp', (_message.Message,), {

  'ReservationStyle' : _reflection.GeneratedProtocolMessageType('ReservationStyle', (_message.Message,), {
    'DESCRIPTOR' : _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RsvpLspIpv4InterfaceP2PEgressIpv4Lsp.ReservationStyle)
    })
  ,
  'DESCRIPTOR' : _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpLspIpv4InterfaceP2PEgressIpv4Lsp)
  })
_sym_db.RegisterMessage(RsvpLspIpv4InterfaceP2PEgressIpv4Lsp)
_sym_db.RegisterMessage(RsvpLspIpv4InterfaceP2PEgressIpv4Lsp.ReservationStyle)

RsvpLspIpv4InterfaceP2PIngressIpv4Lsp = _reflection.GeneratedProtocolMessageType('RsvpLspIpv4InterfaceP2PIngressIpv4Lsp', (_message.Message,), {
  'DESCRIPTOR' : _RSVPLSPIPV4INTERFACEP2PINGRESSIPV4LSP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpLspIpv4InterfaceP2PIngressIpv4Lsp)
  })
_sym_db.RegisterMessage(RsvpLspIpv4InterfaceP2PIngressIpv4Lsp)

RsvpSessionAttribute = _reflection.GeneratedProtocolMessageType('RsvpSessionAttribute', (_message.Message,), {
  'DESCRIPTOR' : _RSVPSESSIONATTRIBUTE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpSessionAttribute)
  })
_sym_db.RegisterMessage(RsvpSessionAttribute)

RsvpResourceAffinities = _reflection.GeneratedProtocolMessageType('RsvpResourceAffinities', (_message.Message,), {
  'DESCRIPTOR' : _RSVPRESOURCEAFFINITIES,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpResourceAffinities)
  })
_sym_db.RegisterMessage(RsvpResourceAffinities)

RsvpTspec = _reflection.GeneratedProtocolMessageType('RsvpTspec', (_message.Message,), {
  'DESCRIPTOR' : _RSVPTSPEC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpTspec)
  })
_sym_db.RegisterMessage(RsvpTspec)

RsvpFastReroute = _reflection.GeneratedProtocolMessageType('RsvpFastReroute', (_message.Message,), {
  'DESCRIPTOR' : _RSVPFASTREROUTE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpFastReroute)
  })
_sym_db.RegisterMessage(RsvpFastReroute)

RsvpEro = _reflection.GeneratedProtocolMessageType('RsvpEro', (_message.Message,), {

  'PrependNeighborIp' : _reflection.GeneratedProtocolMessageType('PrependNeighborIp', (_message.Message,), {
    'DESCRIPTOR' : _RSVPERO_PREPENDNEIGHBORIP,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RsvpEro.PrependNeighborIp)
    })
  ,
  'DESCRIPTOR' : _RSVPERO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpEro)
  })
_sym_db.RegisterMessage(RsvpEro)
_sym_db.RegisterMessage(RsvpEro.PrependNeighborIp)

RsvpEroSubobject = _reflection.GeneratedProtocolMessageType('RsvpEroSubobject', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _RSVPEROSUBOBJECT_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RsvpEroSubobject.Type)
    })
  ,

  'HopType' : _reflection.GeneratedProtocolMessageType('HopType', (_message.Message,), {
    'DESCRIPTOR' : _RSVPEROSUBOBJECT_HOPTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RsvpEroSubobject.HopType)
    })
  ,
  'DESCRIPTOR' : _RSVPEROSUBOBJECT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpEroSubobject)
  })
_sym_db.RegisterMessage(RsvpEroSubobject)
_sym_db.RegisterMessage(RsvpEroSubobject.Type)
_sym_db.RegisterMessage(RsvpEroSubobject.HopType)

Flow = _reflection.GeneratedProtocolMessageType('Flow', (_message.Message,), {
  'DESCRIPTOR' : _FLOW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Flow)
  })
_sym_db.RegisterMessage(Flow)

FlowTxRx = _reflection.GeneratedProtocolMessageType('FlowTxRx', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWTXRX_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowTxRx.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWTXRX,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowTxRx)
  })
_sym_db.RegisterMessage(FlowTxRx)
_sym_db.RegisterMessage(FlowTxRx.Choice)

FlowPort = _reflection.GeneratedProtocolMessageType('FlowPort', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPort)
  })
_sym_db.RegisterMessage(FlowPort)

FlowRouter = _reflection.GeneratedProtocolMessageType('FlowRouter', (_message.Message,), {

  'Mode' : _reflection.GeneratedProtocolMessageType('Mode', (_message.Message,), {
    'DESCRIPTOR' : _FLOWROUTER_MODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowRouter.Mode)
    })
  ,
  'DESCRIPTOR' : _FLOWROUTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowRouter)
  })
_sym_db.RegisterMessage(FlowRouter)
_sym_db.RegisterMessage(FlowRouter.Mode)

FlowHeader = _reflection.GeneratedProtocolMessageType('FlowHeader', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWHEADER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowHeader.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWHEADER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowHeader)
  })
_sym_db.RegisterMessage(FlowHeader)
_sym_db.RegisterMessage(FlowHeader.Choice)

FlowCustom = _reflection.GeneratedProtocolMessageType('FlowCustom', (_message.Message,), {
  'DESCRIPTOR' : _FLOWCUSTOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowCustom)
  })
_sym_db.RegisterMessage(FlowCustom)

FlowCustomMetricTag = _reflection.GeneratedProtocolMessageType('FlowCustomMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _FLOWCUSTOMMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowCustomMetricTag)
  })
_sym_db.RegisterMessage(FlowCustomMetricTag)

FlowEthernet = _reflection.GeneratedProtocolMessageType('FlowEthernet', (_message.Message,), {
  'DESCRIPTOR' : _FLOWETHERNET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowEthernet)
  })
_sym_db.RegisterMessage(FlowEthernet)

FlowVlan = _reflection.GeneratedProtocolMessageType('FlowVlan', (_message.Message,), {
  'DESCRIPTOR' : _FLOWVLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowVlan)
  })
_sym_db.RegisterMessage(FlowVlan)

FlowVxlan = _reflection.GeneratedProtocolMessageType('FlowVxlan', (_message.Message,), {
  'DESCRIPTOR' : _FLOWVXLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowVxlan)
  })
_sym_db.RegisterMessage(FlowVxlan)

FlowIpv4 = _reflection.GeneratedProtocolMessageType('FlowIpv4', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4)
  })
_sym_db.RegisterMessage(FlowIpv4)

FlowIpv4Priority = _reflection.GeneratedProtocolMessageType('FlowIpv4Priority', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWIPV4PRIORITY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowIpv4Priority.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWIPV4PRIORITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4Priority)
  })
_sym_db.RegisterMessage(FlowIpv4Priority)
_sym_db.RegisterMessage(FlowIpv4Priority.Choice)

FlowIpv4Dscp = _reflection.GeneratedProtocolMessageType('FlowIpv4Dscp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV4DSCP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4Dscp)
  })
_sym_db.RegisterMessage(FlowIpv4Dscp)

FlowIpv4Tos = _reflection.GeneratedProtocolMessageType('FlowIpv4Tos', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV4TOS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4Tos)
  })
_sym_db.RegisterMessage(FlowIpv4Tos)

FlowIpv6 = _reflection.GeneratedProtocolMessageType('FlowIpv6', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv6)
  })
_sym_db.RegisterMessage(FlowIpv6)

FlowPfcPause = _reflection.GeneratedProtocolMessageType('FlowPfcPause', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPFCPAUSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPfcPause)
  })
_sym_db.RegisterMessage(FlowPfcPause)

FlowEthernetPause = _reflection.GeneratedProtocolMessageType('FlowEthernetPause', (_message.Message,), {
  'DESCRIPTOR' : _FLOWETHERNETPAUSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowEthernetPause)
  })
_sym_db.RegisterMessage(FlowEthernetPause)

FlowTcp = _reflection.GeneratedProtocolMessageType('FlowTcp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWTCP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowTcp)
  })
_sym_db.RegisterMessage(FlowTcp)

FlowUdp = _reflection.GeneratedProtocolMessageType('FlowUdp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWUDP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowUdp)
  })
_sym_db.RegisterMessage(FlowUdp)

FlowGre = _reflection.GeneratedProtocolMessageType('FlowGre', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGRE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGre)
  })
_sym_db.RegisterMessage(FlowGre)

FlowGtpv1 = _reflection.GeneratedProtocolMessageType('FlowGtpv1', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGTPV1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGtpv1)
  })
_sym_db.RegisterMessage(FlowGtpv1)

FlowGtpExtension = _reflection.GeneratedProtocolMessageType('FlowGtpExtension', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGTPEXTENSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGtpExtension)
  })
_sym_db.RegisterMessage(FlowGtpExtension)

FlowGtpv2 = _reflection.GeneratedProtocolMessageType('FlowGtpv2', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGTPV2,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGtpv2)
  })
_sym_db.RegisterMessage(FlowGtpv2)

FlowArp = _reflection.GeneratedProtocolMessageType('FlowArp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWARP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowArp)
  })
_sym_db.RegisterMessage(FlowArp)

FlowIcmp = _reflection.GeneratedProtocolMessageType('FlowIcmp', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWICMP_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowIcmp.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWICMP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmp)
  })
_sym_db.RegisterMessage(FlowIcmp)
_sym_db.RegisterMessage(FlowIcmp.Choice)

FlowIcmpEcho = _reflection.GeneratedProtocolMessageType('FlowIcmpEcho', (_message.Message,), {
  'DESCRIPTOR' : _FLOWICMPECHO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmpEcho)
  })
_sym_db.RegisterMessage(FlowIcmpEcho)

FlowIcmpv6 = _reflection.GeneratedProtocolMessageType('FlowIcmpv6', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWICMPV6_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowIcmpv6.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWICMPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmpv6)
  })
_sym_db.RegisterMessage(FlowIcmpv6)
_sym_db.RegisterMessage(FlowIcmpv6.Choice)

FlowIcmpv6Echo = _reflection.GeneratedProtocolMessageType('FlowIcmpv6Echo', (_message.Message,), {
  'DESCRIPTOR' : _FLOWICMPV6ECHO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmpv6Echo)
  })
_sym_db.RegisterMessage(FlowIcmpv6Echo)

FlowPpp = _reflection.GeneratedProtocolMessageType('FlowPpp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPPP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPpp)
  })
_sym_db.RegisterMessage(FlowPpp)

FlowIgmpv1 = _reflection.GeneratedProtocolMessageType('FlowIgmpv1', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIGMPV1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIgmpv1)
  })
_sym_db.RegisterMessage(FlowIgmpv1)

FlowMpls = _reflection.GeneratedProtocolMessageType('FlowMpls', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMPLS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMpls)
  })
_sym_db.RegisterMessage(FlowMpls)

FlowSize = _reflection.GeneratedProtocolMessageType('FlowSize', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWSIZE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowSize.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWSIZE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSize)
  })
_sym_db.RegisterMessage(FlowSize)
_sym_db.RegisterMessage(FlowSize.Choice)

FlowSizeIncrement = _reflection.GeneratedProtocolMessageType('FlowSizeIncrement', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSIZEINCREMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSizeIncrement)
  })
_sym_db.RegisterMessage(FlowSizeIncrement)

FlowSizeRandom = _reflection.GeneratedProtocolMessageType('FlowSizeRandom', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSIZERANDOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSizeRandom)
  })
_sym_db.RegisterMessage(FlowSizeRandom)

FlowSizeWeightPairs = _reflection.GeneratedProtocolMessageType('FlowSizeWeightPairs', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWSIZEWEIGHTPAIRS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowSizeWeightPairs.Choice)
    })
  ,

  'Predefined' : _reflection.GeneratedProtocolMessageType('Predefined', (_message.Message,), {
    'DESCRIPTOR' : _FLOWSIZEWEIGHTPAIRS_PREDEFINED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowSizeWeightPairs.Predefined)
    })
  ,
  'DESCRIPTOR' : _FLOWSIZEWEIGHTPAIRS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSizeWeightPairs)
  })
_sym_db.RegisterMessage(FlowSizeWeightPairs)
_sym_db.RegisterMessage(FlowSizeWeightPairs.Choice)
_sym_db.RegisterMessage(FlowSizeWeightPairs.Predefined)

FlowSizeWeightPairsCustom = _reflection.GeneratedProtocolMessageType('FlowSizeWeightPairsCustom', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSIZEWEIGHTPAIRSCUSTOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSizeWeightPairsCustom)
  })
_sym_db.RegisterMessage(FlowSizeWeightPairsCustom)

FlowRate = _reflection.GeneratedProtocolMessageType('FlowRate', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWRATE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowRate.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWRATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowRate)
  })
_sym_db.RegisterMessage(FlowRate)
_sym_db.RegisterMessage(FlowRate.Choice)

FlowDuration = _reflection.GeneratedProtocolMessageType('FlowDuration', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWDURATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowDuration.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWDURATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowDuration)
  })
_sym_db.RegisterMessage(FlowDuration)
_sym_db.RegisterMessage(FlowDuration.Choice)

FlowContinuous = _reflection.GeneratedProtocolMessageType('FlowContinuous', (_message.Message,), {
  'DESCRIPTOR' : _FLOWCONTINUOUS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowContinuous)
  })
_sym_db.RegisterMessage(FlowContinuous)

FlowDelay = _reflection.GeneratedProtocolMessageType('FlowDelay', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWDELAY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowDelay.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWDELAY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowDelay)
  })
_sym_db.RegisterMessage(FlowDelay)
_sym_db.RegisterMessage(FlowDelay.Choice)

FlowFixedPackets = _reflection.GeneratedProtocolMessageType('FlowFixedPackets', (_message.Message,), {
  'DESCRIPTOR' : _FLOWFIXEDPACKETS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowFixedPackets)
  })
_sym_db.RegisterMessage(FlowFixedPackets)

FlowFixedSeconds = _reflection.GeneratedProtocolMessageType('FlowFixedSeconds', (_message.Message,), {
  'DESCRIPTOR' : _FLOWFIXEDSECONDS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowFixedSeconds)
  })
_sym_db.RegisterMessage(FlowFixedSeconds)

FlowBurst = _reflection.GeneratedProtocolMessageType('FlowBurst', (_message.Message,), {
  'DESCRIPTOR' : _FLOWBURST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowBurst)
  })
_sym_db.RegisterMessage(FlowBurst)

FlowDurationInterBurstGap = _reflection.GeneratedProtocolMessageType('FlowDurationInterBurstGap', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWDURATIONINTERBURSTGAP_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowDurationInterBurstGap.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWDURATIONINTERBURSTGAP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowDurationInterBurstGap)
  })
_sym_db.RegisterMessage(FlowDurationInterBurstGap)
_sym_db.RegisterMessage(FlowDurationInterBurstGap.Choice)

FlowMetrics = _reflection.GeneratedProtocolMessageType('FlowMetrics', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMETRICS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetrics)
  })
_sym_db.RegisterMessage(FlowMetrics)

FlowLatencyMetrics = _reflection.GeneratedProtocolMessageType('FlowLatencyMetrics', (_message.Message,), {

  'Mode' : _reflection.GeneratedProtocolMessageType('Mode', (_message.Message,), {
    'DESCRIPTOR' : _FLOWLATENCYMETRICS_MODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowLatencyMetrics.Mode)
    })
  ,
  'DESCRIPTOR' : _FLOWLATENCYMETRICS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowLatencyMetrics)
  })
_sym_db.RegisterMessage(FlowLatencyMetrics)
_sym_db.RegisterMessage(FlowLatencyMetrics.Mode)

FlowPredefinedTags = _reflection.GeneratedProtocolMessageType('FlowPredefinedTags', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPREDEFINEDTAGS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPredefinedTags)
  })
_sym_db.RegisterMessage(FlowPredefinedTags)

FlowRxTxRatio = _reflection.GeneratedProtocolMessageType('FlowRxTxRatio', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWRXTXRATIO_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowRxTxRatio.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWRXTXRATIO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowRxTxRatio)
  })
_sym_db.RegisterMessage(FlowRxTxRatio)
_sym_db.RegisterMessage(FlowRxTxRatio.Choice)

FlowRxTxRatioRxCount = _reflection.GeneratedProtocolMessageType('FlowRxTxRatioRxCount', (_message.Message,), {
  'DESCRIPTOR' : _FLOWRXTXRATIORXCOUNT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowRxTxRatioRxCount)
  })
_sym_db.RegisterMessage(FlowRxTxRatioRxCount)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Event)
  })
_sym_db.RegisterMessage(Event)

EventRxRateThreshold = _reflection.GeneratedProtocolMessageType('EventRxRateThreshold', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRXRATETHRESHOLD,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventRxRateThreshold)
  })
_sym_db.RegisterMessage(EventRxRateThreshold)

EventLink = _reflection.GeneratedProtocolMessageType('EventLink', (_message.Message,), {
  'DESCRIPTOR' : _EVENTLINK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventLink)
  })
_sym_db.RegisterMessage(EventLink)

EventRouteAdvertiseWithdraw = _reflection.GeneratedProtocolMessageType('EventRouteAdvertiseWithdraw', (_message.Message,), {
  'DESCRIPTOR' : _EVENTROUTEADVERTISEWITHDRAW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventRouteAdvertiseWithdraw)
  })
_sym_db.RegisterMessage(EventRouteAdvertiseWithdraw)

EventRequest = _reflection.GeneratedProtocolMessageType('EventRequest', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _EVENTREQUEST_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.EventRequest.Type)
    })
  ,
  'DESCRIPTOR' : _EVENTREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventRequest)
  })
_sym_db.RegisterMessage(EventRequest)
_sym_db.RegisterMessage(EventRequest.Type)

EventSubscription = _reflection.GeneratedProtocolMessageType('EventSubscription', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBSCRIPTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventSubscription)
  })
_sym_db.RegisterMessage(EventSubscription)

Lldp = _reflection.GeneratedProtocolMessageType('Lldp', (_message.Message,), {
  'DESCRIPTOR' : _LLDP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Lldp)
  })
_sym_db.RegisterMessage(Lldp)

LldpConnection = _reflection.GeneratedProtocolMessageType('LldpConnection', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LLDPCONNECTION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpConnection.Choice)
    })
  ,
  'DESCRIPTOR' : _LLDPCONNECTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpConnection)
  })
_sym_db.RegisterMessage(LldpConnection)
_sym_db.RegisterMessage(LldpConnection.Choice)

LldpChassisId = _reflection.GeneratedProtocolMessageType('LldpChassisId', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LLDPCHASSISID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpChassisId.Choice)
    })
  ,
  'DESCRIPTOR' : _LLDPCHASSISID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpChassisId)
  })
_sym_db.RegisterMessage(LldpChassisId)
_sym_db.RegisterMessage(LldpChassisId.Choice)

LldpPortId = _reflection.GeneratedProtocolMessageType('LldpPortId', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LLDPPORTID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpPortId.Choice)
    })
  ,
  'DESCRIPTOR' : _LLDPPORTID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpPortId)
  })
_sym_db.RegisterMessage(LldpPortId)
_sym_db.RegisterMessage(LldpPortId.Choice)

LldpChassisMacSubType = _reflection.GeneratedProtocolMessageType('LldpChassisMacSubType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LLDPCHASSISMACSUBTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpChassisMacSubType.Choice)
    })
  ,
  'DESCRIPTOR' : _LLDPCHASSISMACSUBTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpChassisMacSubType)
  })
_sym_db.RegisterMessage(LldpChassisMacSubType)
_sym_db.RegisterMessage(LldpChassisMacSubType.Choice)

LldpPortInterfaceNameSubType = _reflection.GeneratedProtocolMessageType('LldpPortInterfaceNameSubType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LLDPPORTINTERFACENAMESUBTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpPortInterfaceNameSubType.Choice)
    })
  ,
  'DESCRIPTOR' : _LLDPPORTINTERFACENAMESUBTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpPortInterfaceNameSubType)
  })
_sym_db.RegisterMessage(LldpPortInterfaceNameSubType)
_sym_db.RegisterMessage(LldpPortInterfaceNameSubType.Choice)

LldpSystemName = _reflection.GeneratedProtocolMessageType('LldpSystemName', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LLDPSYSTEMNAME_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpSystemName.Choice)
    })
  ,
  'DESCRIPTOR' : _LLDPSYSTEMNAME,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpSystemName)
  })
_sym_db.RegisterMessage(LldpSystemName)
_sym_db.RegisterMessage(LldpSystemName.Choice)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {

  'Kind' : _reflection.GeneratedProtocolMessageType('Kind', (_message.Message,), {
    'DESCRIPTOR' : _ERROR_KIND,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Error.Kind)
    })
  ,
  'DESCRIPTOR' : _ERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Error)
  })
_sym_db.RegisterMessage(Error)
_sym_db.RegisterMessage(Error.Kind)

Warning = _reflection.GeneratedProtocolMessageType('Warning', (_message.Message,), {
  'DESCRIPTOR' : _WARNING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Warning)
  })
_sym_db.RegisterMessage(Warning)

ConfigUpdate = _reflection.GeneratedProtocolMessageType('ConfigUpdate', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGUPDATE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ConfigUpdate.Choice)
    })
  ,
  'DESCRIPTOR' : _CONFIGUPDATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ConfigUpdate)
  })
_sym_db.RegisterMessage(ConfigUpdate)
_sym_db.RegisterMessage(ConfigUpdate.Choice)

FlowsUpdate = _reflection.GeneratedProtocolMessageType('FlowsUpdate', (_message.Message,), {

  'PropertyNames' : _reflection.GeneratedProtocolMessageType('PropertyNames', (_message.Message,), {
    'DESCRIPTOR' : _FLOWSUPDATE_PROPERTYNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowsUpdate.PropertyNames)
    })
  ,
  'DESCRIPTOR' : _FLOWSUPDATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowsUpdate)
  })
_sym_db.RegisterMessage(FlowsUpdate)
_sym_db.RegisterMessage(FlowsUpdate.PropertyNames)

ControlState = _reflection.GeneratedProtocolMessageType('ControlState', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLSTATE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ControlState.Choice)
    })
  ,
  'DESCRIPTOR' : _CONTROLSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ControlState)
  })
_sym_db.RegisterMessage(ControlState)
_sym_db.RegisterMessage(ControlState.Choice)

StatePort = _reflection.GeneratedProtocolMessageType('StatePort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATEPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StatePort.Choice)
    })
  ,
  'DESCRIPTOR' : _STATEPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StatePort)
  })
_sym_db.RegisterMessage(StatePort)
_sym_db.RegisterMessage(StatePort.Choice)

StateTraffic = _reflection.GeneratedProtocolMessageType('StateTraffic', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATETRAFFIC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StateTraffic.Choice)
    })
  ,
  'DESCRIPTOR' : _STATETRAFFIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StateTraffic)
  })
_sym_db.RegisterMessage(StateTraffic)
_sym_db.RegisterMessage(StateTraffic.Choice)

StateProtocol = _reflection.GeneratedProtocolMessageType('StateProtocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATEPROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StateProtocol.Choice)
    })
  ,
  'DESCRIPTOR' : _STATEPROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StateProtocol)
  })
_sym_db.RegisterMessage(StateProtocol)
_sym_db.RegisterMessage(StateProtocol.Choice)

LinkState = _reflection.GeneratedProtocolMessageType('LinkState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _LINKSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LinkState.State)
    })
  ,
  'DESCRIPTOR' : _LINKSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LinkState)
  })
_sym_db.RegisterMessage(LinkState)
_sym_db.RegisterMessage(LinkState.State)

TransmitState = _reflection.GeneratedProtocolMessageType('TransmitState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _TRANSMITSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.TransmitState.State)
    })
  ,
  'DESCRIPTOR' : _TRANSMITSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.TransmitState)
  })
_sym_db.RegisterMessage(TransmitState)
_sym_db.RegisterMessage(TransmitState.State)

CaptureState = _reflection.GeneratedProtocolMessageType('CaptureState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _CAPTURESTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.CaptureState.State)
    })
  ,
  'DESCRIPTOR' : _CAPTURESTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureState)
  })
_sym_db.RegisterMessage(CaptureState)
_sym_db.RegisterMessage(CaptureState.State)

RouteState = _reflection.GeneratedProtocolMessageType('RouteState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _ROUTESTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RouteState.State)
    })
  ,
  'DESCRIPTOR' : _ROUTESTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RouteState)
  })
_sym_db.RegisterMessage(RouteState)
_sym_db.RegisterMessage(RouteState.State)

ProtocolState = _reflection.GeneratedProtocolMessageType('ProtocolState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _PROTOCOLSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ProtocolState.State)
    })
  ,
  'DESCRIPTOR' : _PROTOCOLSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ProtocolState)
  })
_sym_db.RegisterMessage(ProtocolState)
_sym_db.RegisterMessage(ProtocolState.State)

DeviceState = _reflection.GeneratedProtocolMessageType('DeviceState', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _DEVICESTATE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceState.Choice)
    })
  ,
  'DESCRIPTOR' : _DEVICESTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceState)
  })
_sym_db.RegisterMessage(DeviceState)
_sym_db.RegisterMessage(DeviceState.Choice)

StatePortLink = _reflection.GeneratedProtocolMessageType('StatePortLink', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _STATEPORTLINK_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StatePortLink.State)
    })
  ,
  'DESCRIPTOR' : _STATEPORTLINK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StatePortLink)
  })
_sym_db.RegisterMessage(StatePortLink)
_sym_db.RegisterMessage(StatePortLink.State)

StatePortCapture = _reflection.GeneratedProtocolMessageType('StatePortCapture', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _STATEPORTCAPTURE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StatePortCapture.State)
    })
  ,
  'DESCRIPTOR' : _STATEPORTCAPTURE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StatePortCapture)
  })
_sym_db.RegisterMessage(StatePortCapture)
_sym_db.RegisterMessage(StatePortCapture.State)

StateTrafficFlowTransmit = _reflection.GeneratedProtocolMessageType('StateTrafficFlowTransmit', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _STATETRAFFICFLOWTRANSMIT_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StateTrafficFlowTransmit.State)
    })
  ,
  'DESCRIPTOR' : _STATETRAFFICFLOWTRANSMIT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StateTrafficFlowTransmit)
  })
_sym_db.RegisterMessage(StateTrafficFlowTransmit)
_sym_db.RegisterMessage(StateTrafficFlowTransmit.State)

StateProtocolAll = _reflection.GeneratedProtocolMessageType('StateProtocolAll', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _STATEPROTOCOLALL_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StateProtocolAll.State)
    })
  ,
  'DESCRIPTOR' : _STATEPROTOCOLALL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StateProtocolAll)
  })
_sym_db.RegisterMessage(StateProtocolAll)
_sym_db.RegisterMessage(StateProtocolAll.State)

StateProtocolRoute = _reflection.GeneratedProtocolMessageType('StateProtocolRoute', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _STATEPROTOCOLROUTE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StateProtocolRoute.State)
    })
  ,
  'DESCRIPTOR' : _STATEPROTOCOLROUTE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StateProtocolRoute)
  })
_sym_db.RegisterMessage(StateProtocolRoute)
_sym_db.RegisterMessage(StateProtocolRoute.State)

StateProtocolLacp = _reflection.GeneratedProtocolMessageType('StateProtocolLacp', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATEPROTOCOLLACP_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StateProtocolLacp.Choice)
    })
  ,
  'DESCRIPTOR' : _STATEPROTOCOLLACP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StateProtocolLacp)
  })
_sym_db.RegisterMessage(StateProtocolLacp)
_sym_db.RegisterMessage(StateProtocolLacp.Choice)

StateProtocolLacpAdmin = _reflection.GeneratedProtocolMessageType('StateProtocolLacpAdmin', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _STATEPROTOCOLLACPADMIN_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StateProtocolLacpAdmin.State)
    })
  ,
  'DESCRIPTOR' : _STATEPROTOCOLLACPADMIN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StateProtocolLacpAdmin)
  })
_sym_db.RegisterMessage(StateProtocolLacpAdmin)
_sym_db.RegisterMessage(StateProtocolLacpAdmin.State)

LacpMemberState = _reflection.GeneratedProtocolMessageType('LacpMemberState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _LACPMEMBERSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LacpMemberState.State)
    })
  ,
  'DESCRIPTOR' : _LACPMEMBERSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LacpMemberState)
  })
_sym_db.RegisterMessage(LacpMemberState)
_sym_db.RegisterMessage(LacpMemberState.State)

ControlAction = _reflection.GeneratedProtocolMessageType('ControlAction', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLACTION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ControlAction.Choice)
    })
  ,
  'DESCRIPTOR' : _CONTROLACTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ControlAction)
  })
_sym_db.RegisterMessage(ControlAction)
_sym_db.RegisterMessage(ControlAction.Choice)

ControlActionResponse = _reflection.GeneratedProtocolMessageType('ControlActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLACTIONRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ControlActionResponse)
  })
_sym_db.RegisterMessage(ControlActionResponse)

ActionResponse = _reflection.GeneratedProtocolMessageType('ActionResponse', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONRESPONSE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionResponse.Choice)
    })
  ,
  'DESCRIPTOR' : _ACTIONRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionResponse)
  })
_sym_db.RegisterMessage(ActionResponse)
_sym_db.RegisterMessage(ActionResponse.Choice)

ActionProtocol = _reflection.GeneratedProtocolMessageType('ActionProtocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONPROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionProtocol.Choice)
    })
  ,
  'DESCRIPTOR' : _ACTIONPROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocol)
  })
_sym_db.RegisterMessage(ActionProtocol)
_sym_db.RegisterMessage(ActionProtocol.Choice)

ActionResponseProtocol = _reflection.GeneratedProtocolMessageType('ActionResponseProtocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocol.Choice)
    })
  ,
  'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocol)
  })
_sym_db.RegisterMessage(ActionResponseProtocol)
_sym_db.RegisterMessage(ActionResponseProtocol.Choice)

ActionProtocolIpv4 = _reflection.GeneratedProtocolMessageType('ActionProtocolIpv4', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONPROTOCOLIPV4_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionProtocolIpv4.Choice)
    })
  ,
  'DESCRIPTOR' : _ACTIONPROTOCOLIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocolIpv4)
  })
_sym_db.RegisterMessage(ActionProtocolIpv4)
_sym_db.RegisterMessage(ActionProtocolIpv4.Choice)

ActionResponseProtocolIpv4 = _reflection.GeneratedProtocolMessageType('ActionResponseProtocolIpv4', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV4_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv4.Choice)
    })
  ,
  'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv4)
  })
_sym_db.RegisterMessage(ActionResponseProtocolIpv4)
_sym_db.RegisterMessage(ActionResponseProtocolIpv4.Choice)

ActionProtocolIpv4Ping = _reflection.GeneratedProtocolMessageType('ActionProtocolIpv4Ping', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONPROTOCOLIPV4PING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocolIpv4Ping)
  })
_sym_db.RegisterMessage(ActionProtocolIpv4Ping)

ActionProtocolIpv4PingRequest = _reflection.GeneratedProtocolMessageType('ActionProtocolIpv4PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONPROTOCOLIPV4PINGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocolIpv4PingRequest)
  })
_sym_db.RegisterMessage(ActionProtocolIpv4PingRequest)

ActionResponseProtocolIpv4Ping = _reflection.GeneratedProtocolMessageType('ActionResponseProtocolIpv4Ping', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV4PING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv4Ping)
  })
_sym_db.RegisterMessage(ActionResponseProtocolIpv4Ping)

ActionResponseProtocolIpv4PingResponse = _reflection.GeneratedProtocolMessageType('ActionResponseProtocolIpv4PingResponse', (_message.Message,), {

  'Result' : _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv4PingResponse.Result)
    })
  ,
  'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv4PingResponse)
  })
_sym_db.RegisterMessage(ActionResponseProtocolIpv4PingResponse)
_sym_db.RegisterMessage(ActionResponseProtocolIpv4PingResponse.Result)

ActionProtocolIpv6 = _reflection.GeneratedProtocolMessageType('ActionProtocolIpv6', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONPROTOCOLIPV6_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionProtocolIpv6.Choice)
    })
  ,
  'DESCRIPTOR' : _ACTIONPROTOCOLIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocolIpv6)
  })
_sym_db.RegisterMessage(ActionProtocolIpv6)
_sym_db.RegisterMessage(ActionProtocolIpv6.Choice)

ActionResponseProtocolIpv6 = _reflection.GeneratedProtocolMessageType('ActionResponseProtocolIpv6', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV6_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv6.Choice)
    })
  ,
  'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv6)
  })
_sym_db.RegisterMessage(ActionResponseProtocolIpv6)
_sym_db.RegisterMessage(ActionResponseProtocolIpv6.Choice)

ActionProtocolIpv6Ping = _reflection.GeneratedProtocolMessageType('ActionProtocolIpv6Ping', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONPROTOCOLIPV6PING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocolIpv6Ping)
  })
_sym_db.RegisterMessage(ActionProtocolIpv6Ping)

ActionProtocolIpv6PingRequest = _reflection.GeneratedProtocolMessageType('ActionProtocolIpv6PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONPROTOCOLIPV6PINGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocolIpv6PingRequest)
  })
_sym_db.RegisterMessage(ActionProtocolIpv6PingRequest)

ActionResponseProtocolIpv6Ping = _reflection.GeneratedProtocolMessageType('ActionResponseProtocolIpv6Ping', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV6PING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv6Ping)
  })
_sym_db.RegisterMessage(ActionResponseProtocolIpv6Ping)

ActionResponseProtocolIpv6PingResponse = _reflection.GeneratedProtocolMessageType('ActionResponseProtocolIpv6PingResponse', (_message.Message,), {

  'Result' : _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv6PingResponse.Result)
    })
  ,
  'DESCRIPTOR' : _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionResponseProtocolIpv6PingResponse)
  })
_sym_db.RegisterMessage(ActionResponseProtocolIpv6PingResponse)
_sym_db.RegisterMessage(ActionResponseProtocolIpv6PingResponse.Result)

ActionProtocolBgp = _reflection.GeneratedProtocolMessageType('ActionProtocolBgp', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONPROTOCOLBGP_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionProtocolBgp.Choice)
    })
  ,
  'DESCRIPTOR' : _ACTIONPROTOCOLBGP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocolBgp)
  })
_sym_db.RegisterMessage(ActionProtocolBgp)
_sym_db.RegisterMessage(ActionProtocolBgp.Choice)

ActionProtocolBgpNotification = _reflection.GeneratedProtocolMessageType('ActionProtocolBgpNotification', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _ACTIONPROTOCOLBGPNOTIFICATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ActionProtocolBgpNotification.Choice)
    })
  ,
  'DESCRIPTOR' : _ACTIONPROTOCOLBGPNOTIFICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocolBgpNotification)
  })
_sym_db.RegisterMessage(ActionProtocolBgpNotification)
_sym_db.RegisterMessage(ActionProtocolBgpNotification.Choice)

ActionProtocolBgpInitiateGracefulRestart = _reflection.GeneratedProtocolMessageType('ActionProtocolBgpInitiateGracefulRestart', (_message.Message,), {
  'DESCRIPTOR' : _ACTIONPROTOCOLBGPINITIATEGRACEFULRESTART,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ActionProtocolBgpInitiateGracefulRestart)
  })
_sym_db.RegisterMessage(ActionProtocolBgpInitiateGracefulRestart)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PING_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Ping.Choice)
    })
  ,
  'DESCRIPTOR' : _PING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Ping)
  })
_sym_db.RegisterMessage(Ping)
_sym_db.RegisterMessage(Ping.Choice)

PingIpv4 = _reflection.GeneratedProtocolMessageType('PingIpv4', (_message.Message,), {
  'DESCRIPTOR' : _PINGIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingIpv4)
  })
_sym_db.RegisterMessage(PingIpv4)

PingIpv6 = _reflection.GeneratedProtocolMessageType('PingIpv6', (_message.Message,), {
  'DESCRIPTOR' : _PINGIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingIpv6)
  })
_sym_db.RegisterMessage(PingIpv6)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingRequest)
  })
_sym_db.RegisterMessage(PingRequest)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingResponse)
  })
_sym_db.RegisterMessage(PingResponse)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {

  'Result' : _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_RESULT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Response.Result)
    })
  ,
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Response)
  })
_sym_db.RegisterMessage(Response)
_sym_db.RegisterMessage(Response.Result)

MetricsRequest = _reflection.GeneratedProtocolMessageType('MetricsRequest', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _METRICSREQUEST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.MetricsRequest.Choice)
    })
  ,
  'DESCRIPTOR' : _METRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricsRequest)
  })
_sym_db.RegisterMessage(MetricsRequest)
_sym_db.RegisterMessage(MetricsRequest.Choice)

MetricsResponse = _reflection.GeneratedProtocolMessageType('MetricsResponse', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _METRICSRESPONSE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.MetricsResponse.Choice)
    })
  ,
  'DESCRIPTOR' : _METRICSRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricsResponse)
  })
_sym_db.RegisterMessage(MetricsResponse)
_sym_db.RegisterMessage(MetricsResponse.Choice)

PortMetricsRequest = _reflection.GeneratedProtocolMessageType('PortMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _PORTMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PortMetricsRequest)
  })
_sym_db.RegisterMessage(PortMetricsRequest)
_sym_db.RegisterMessage(PortMetricsRequest.ColumnNames)

PortMetric = _reflection.GeneratedProtocolMessageType('PortMetric', (_message.Message,), {

  'Link' : _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRIC_LINK,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetric.Link)
    })
  ,

  'Capture' : _reflection.GeneratedProtocolMessageType('Capture', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRIC_CAPTURE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetric.Capture)
    })
  ,

  'Transmit' : _reflection.GeneratedProtocolMessageType('Transmit', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRIC_TRANSMIT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetric.Transmit)
    })
  ,
  'DESCRIPTOR' : _PORTMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PortMetric)
  })
_sym_db.RegisterMessage(PortMetric)
_sym_db.RegisterMessage(PortMetric.Link)
_sym_db.RegisterMessage(PortMetric.Capture)
_sym_db.RegisterMessage(PortMetric.Transmit)

FlowMetricsRequest = _reflection.GeneratedProtocolMessageType('FlowMetricsRequest', (_message.Message,), {

  'MetricNames' : _reflection.GeneratedProtocolMessageType('MetricNames', (_message.Message,), {
    'DESCRIPTOR' : _FLOWMETRICSREQUEST_METRICNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowMetricsRequest.MetricNames)
    })
  ,
  'DESCRIPTOR' : _FLOWMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricsRequest)
  })
_sym_db.RegisterMessage(FlowMetricsRequest)
_sym_db.RegisterMessage(FlowMetricsRequest.MetricNames)

FlowTaggedMetricsFilter = _reflection.GeneratedProtocolMessageType('FlowTaggedMetricsFilter', (_message.Message,), {

  'MetricNames' : _reflection.GeneratedProtocolMessageType('MetricNames', (_message.Message,), {
    'DESCRIPTOR' : _FLOWTAGGEDMETRICSFILTER_METRICNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowTaggedMetricsFilter.MetricNames)
    })
  ,
  'DESCRIPTOR' : _FLOWTAGGEDMETRICSFILTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowTaggedMetricsFilter)
  })
_sym_db.RegisterMessage(FlowTaggedMetricsFilter)
_sym_db.RegisterMessage(FlowTaggedMetricsFilter.MetricNames)

FlowMetricTagFilter = _reflection.GeneratedProtocolMessageType('FlowMetricTagFilter', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMETRICTAGFILTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricTagFilter)
  })
_sym_db.RegisterMessage(FlowMetricTagFilter)

FlowMetric = _reflection.GeneratedProtocolMessageType('FlowMetric', (_message.Message,), {

  'Transmit' : _reflection.GeneratedProtocolMessageType('Transmit', (_message.Message,), {
    'DESCRIPTOR' : _FLOWMETRIC_TRANSMIT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowMetric.Transmit)
    })
  ,
  'DESCRIPTOR' : _FLOWMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetric)
  })
_sym_db.RegisterMessage(FlowMetric)
_sym_db.RegisterMessage(FlowMetric.Transmit)

FlowTaggedMetric = _reflection.GeneratedProtocolMessageType('FlowTaggedMetric', (_message.Message,), {
  'DESCRIPTOR' : _FLOWTAGGEDMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowTaggedMetric)
  })
_sym_db.RegisterMessage(FlowTaggedMetric)

FlowMetricTag = _reflection.GeneratedProtocolMessageType('FlowMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricTag)
  })
_sym_db.RegisterMessage(FlowMetricTag)

FlowMetricTagValue = _reflection.GeneratedProtocolMessageType('FlowMetricTagValue', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWMETRICTAGVALUE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowMetricTagValue.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWMETRICTAGVALUE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricTagValue)
  })
_sym_db.RegisterMessage(FlowMetricTagValue)
_sym_db.RegisterMessage(FlowMetricTagValue.Choice)

MetricTimestamp = _reflection.GeneratedProtocolMessageType('MetricTimestamp', (_message.Message,), {
  'DESCRIPTOR' : _METRICTIMESTAMP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricTimestamp)
  })
_sym_db.RegisterMessage(MetricTimestamp)

MetricLatency = _reflection.GeneratedProtocolMessageType('MetricLatency', (_message.Message,), {
  'DESCRIPTOR' : _METRICLATENCY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricLatency)
  })
_sym_db.RegisterMessage(MetricLatency)

Bgpv4MetricsRequest = _reflection.GeneratedProtocolMessageType('Bgpv4MetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4METRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv4MetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _BGPV4METRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv4MetricsRequest)
  })
_sym_db.RegisterMessage(Bgpv4MetricsRequest)
_sym_db.RegisterMessage(Bgpv4MetricsRequest.ColumnNames)

Bgpv4Metric = _reflection.GeneratedProtocolMessageType('Bgpv4Metric', (_message.Message,), {

  'SessionState' : _reflection.GeneratedProtocolMessageType('SessionState', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4METRIC_SESSIONSTATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv4Metric.SessionState)
    })
  ,

  'FsmState' : _reflection.GeneratedProtocolMessageType('FsmState', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4METRIC_FSMSTATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv4Metric.FsmState)
    })
  ,
  'DESCRIPTOR' : _BGPV4METRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv4Metric)
  })
_sym_db.RegisterMessage(Bgpv4Metric)
_sym_db.RegisterMessage(Bgpv4Metric.SessionState)
_sym_db.RegisterMessage(Bgpv4Metric.FsmState)

Bgpv6MetricsRequest = _reflection.GeneratedProtocolMessageType('Bgpv6MetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6METRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv6MetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _BGPV6METRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv6MetricsRequest)
  })
_sym_db.RegisterMessage(Bgpv6MetricsRequest)
_sym_db.RegisterMessage(Bgpv6MetricsRequest.ColumnNames)

Bgpv6Metric = _reflection.GeneratedProtocolMessageType('Bgpv6Metric', (_message.Message,), {

  'SessionState' : _reflection.GeneratedProtocolMessageType('SessionState', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6METRIC_SESSIONSTATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv6Metric.SessionState)
    })
  ,

  'FsmState' : _reflection.GeneratedProtocolMessageType('FsmState', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6METRIC_FSMSTATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv6Metric.FsmState)
    })
  ,
  'DESCRIPTOR' : _BGPV6METRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv6Metric)
  })
_sym_db.RegisterMessage(Bgpv6Metric)
_sym_db.RegisterMessage(Bgpv6Metric.SessionState)
_sym_db.RegisterMessage(Bgpv6Metric.FsmState)

IsisMetricsRequest = _reflection.GeneratedProtocolMessageType('IsisMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _ISISMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _ISISMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisMetricsRequest)
  })
_sym_db.RegisterMessage(IsisMetricsRequest)
_sym_db.RegisterMessage(IsisMetricsRequest.ColumnNames)

IsisMetric = _reflection.GeneratedProtocolMessageType('IsisMetric', (_message.Message,), {
  'DESCRIPTOR' : _ISISMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisMetric)
  })
_sym_db.RegisterMessage(IsisMetric)

LagMetricsRequest = _reflection.GeneratedProtocolMessageType('LagMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _LAGMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LagMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _LAGMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagMetricsRequest)
  })
_sym_db.RegisterMessage(LagMetricsRequest)
_sym_db.RegisterMessage(LagMetricsRequest.ColumnNames)

LagMetric = _reflection.GeneratedProtocolMessageType('LagMetric', (_message.Message,), {

  'OperStatus' : _reflection.GeneratedProtocolMessageType('OperStatus', (_message.Message,), {
    'DESCRIPTOR' : _LAGMETRIC_OPERSTATUS,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LagMetric.OperStatus)
    })
  ,
  'DESCRIPTOR' : _LAGMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagMetric)
  })
_sym_db.RegisterMessage(LagMetric)
_sym_db.RegisterMessage(LagMetric.OperStatus)

LacpMetricsRequest = _reflection.GeneratedProtocolMessageType('LacpMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _LACPMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LacpMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _LACPMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LacpMetricsRequest)
  })
_sym_db.RegisterMessage(LacpMetricsRequest)
_sym_db.RegisterMessage(LacpMetricsRequest.ColumnNames)

LacpMetric = _reflection.GeneratedProtocolMessageType('LacpMetric', (_message.Message,), {

  'Activity' : _reflection.GeneratedProtocolMessageType('Activity', (_message.Message,), {
    'DESCRIPTOR' : _LACPMETRIC_ACTIVITY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LacpMetric.Activity)
    })
  ,

  'Timeout' : _reflection.GeneratedProtocolMessageType('Timeout', (_message.Message,), {
    'DESCRIPTOR' : _LACPMETRIC_TIMEOUT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LacpMetric.Timeout)
    })
  ,

  'Synchronization' : _reflection.GeneratedProtocolMessageType('Synchronization', (_message.Message,), {
    'DESCRIPTOR' : _LACPMETRIC_SYNCHRONIZATION,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LacpMetric.Synchronization)
    })
  ,
  'DESCRIPTOR' : _LACPMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LacpMetric)
  })
_sym_db.RegisterMessage(LacpMetric)
_sym_db.RegisterMessage(LacpMetric.Activity)
_sym_db.RegisterMessage(LacpMetric.Timeout)
_sym_db.RegisterMessage(LacpMetric.Synchronization)

LldpMetricsRequest = _reflection.GeneratedProtocolMessageType('LldpMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _LLDPMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _LLDPMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpMetricsRequest)
  })
_sym_db.RegisterMessage(LldpMetricsRequest)
_sym_db.RegisterMessage(LldpMetricsRequest.ColumnNames)

LldpMetric = _reflection.GeneratedProtocolMessageType('LldpMetric', (_message.Message,), {
  'DESCRIPTOR' : _LLDPMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpMetric)
  })
_sym_db.RegisterMessage(LldpMetric)

RsvpMetricsRequest = _reflection.GeneratedProtocolMessageType('RsvpMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _RSVPMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RsvpMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _RSVPMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpMetricsRequest)
  })
_sym_db.RegisterMessage(RsvpMetricsRequest)
_sym_db.RegisterMessage(RsvpMetricsRequest.ColumnNames)

RsvpMetric = _reflection.GeneratedProtocolMessageType('RsvpMetric', (_message.Message,), {
  'DESCRIPTOR' : _RSVPMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpMetric)
  })
_sym_db.RegisterMessage(RsvpMetric)

StatesRequest = _reflection.GeneratedProtocolMessageType('StatesRequest', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATESREQUEST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StatesRequest.Choice)
    })
  ,
  'DESCRIPTOR' : _STATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StatesRequest)
  })
_sym_db.RegisterMessage(StatesRequest)
_sym_db.RegisterMessage(StatesRequest.Choice)

StatesResponse = _reflection.GeneratedProtocolMessageType('StatesResponse', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATESRESPONSE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StatesResponse.Choice)
    })
  ,
  'DESCRIPTOR' : _STATESRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StatesResponse)
  })
_sym_db.RegisterMessage(StatesResponse)
_sym_db.RegisterMessage(StatesResponse.Choice)

Neighborsv4StatesRequest = _reflection.GeneratedProtocolMessageType('Neighborsv4StatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV4STATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv4StatesRequest)
  })
_sym_db.RegisterMessage(Neighborsv4StatesRequest)

Neighborsv4State = _reflection.GeneratedProtocolMessageType('Neighborsv4State', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV4STATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv4State)
  })
_sym_db.RegisterMessage(Neighborsv4State)

Neighborsv6StatesRequest = _reflection.GeneratedProtocolMessageType('Neighborsv6StatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV6STATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv6StatesRequest)
  })
_sym_db.RegisterMessage(Neighborsv6StatesRequest)

Neighborsv6State = _reflection.GeneratedProtocolMessageType('Neighborsv6State', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV6STATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv6State)
  })
_sym_db.RegisterMessage(Neighborsv6State)

BgpPrefixStateRequest = _reflection.GeneratedProtocolMessageType('BgpPrefixStateRequest', (_message.Message,), {

  'PrefixFilters' : _reflection.GeneratedProtocolMessageType('PrefixFilters', (_message.Message,), {
    'DESCRIPTOR' : _BGPPREFIXSTATEREQUEST_PREFIXFILTERS,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpPrefixStateRequest.PrefixFilters)
    })
  ,
  'DESCRIPTOR' : _BGPPREFIXSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpPrefixStateRequest)
  })
_sym_db.RegisterMessage(BgpPrefixStateRequest)
_sym_db.RegisterMessage(BgpPrefixStateRequest.PrefixFilters)

BgpPrefixIpv4UnicastFilter = _reflection.GeneratedProtocolMessageType('BgpPrefixIpv4UnicastFilter', (_message.Message,), {

  'Origin' : _reflection.GeneratedProtocolMessageType('Origin', (_message.Message,), {
    'DESCRIPTOR' : _BGPPREFIXIPV4UNICASTFILTER_ORIGIN,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpPrefixIpv4UnicastFilter.Origin)
    })
  ,
  'DESCRIPTOR' : _BGPPREFIXIPV4UNICASTFILTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpPrefixIpv4UnicastFilter)
  })
_sym_db.RegisterMessage(BgpPrefixIpv4UnicastFilter)
_sym_db.RegisterMessage(BgpPrefixIpv4UnicastFilter.Origin)

BgpPrefixIpv6UnicastFilter = _reflection.GeneratedProtocolMessageType('BgpPrefixIpv6UnicastFilter', (_message.Message,), {

  'Origin' : _reflection.GeneratedProtocolMessageType('Origin', (_message.Message,), {
    'DESCRIPTOR' : _BGPPREFIXIPV6UNICASTFILTER_ORIGIN,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpPrefixIpv6UnicastFilter.Origin)
    })
  ,
  'DESCRIPTOR' : _BGPPREFIXIPV6UNICASTFILTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpPrefixIpv6UnicastFilter)
  })
_sym_db.RegisterMessage(BgpPrefixIpv6UnicastFilter)
_sym_db.RegisterMessage(BgpPrefixIpv6UnicastFilter.Origin)

BgpPrefixesState = _reflection.GeneratedProtocolMessageType('BgpPrefixesState', (_message.Message,), {
  'DESCRIPTOR' : _BGPPREFIXESSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpPrefixesState)
  })
_sym_db.RegisterMessage(BgpPrefixesState)

BgpPrefixIpv4UnicastState = _reflection.GeneratedProtocolMessageType('BgpPrefixIpv4UnicastState', (_message.Message,), {

  'Origin' : _reflection.GeneratedProtocolMessageType('Origin', (_message.Message,), {
    'DESCRIPTOR' : _BGPPREFIXIPV4UNICASTSTATE_ORIGIN,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpPrefixIpv4UnicastState.Origin)
    })
  ,
  'DESCRIPTOR' : _BGPPREFIXIPV4UNICASTSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpPrefixIpv4UnicastState)
  })
_sym_db.RegisterMessage(BgpPrefixIpv4UnicastState)
_sym_db.RegisterMessage(BgpPrefixIpv4UnicastState.Origin)

BgpPrefixIpv6UnicastState = _reflection.GeneratedProtocolMessageType('BgpPrefixIpv6UnicastState', (_message.Message,), {

  'Origin' : _reflection.GeneratedProtocolMessageType('Origin', (_message.Message,), {
    'DESCRIPTOR' : _BGPPREFIXIPV6UNICASTSTATE_ORIGIN,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpPrefixIpv6UnicastState.Origin)
    })
  ,
  'DESCRIPTOR' : _BGPPREFIXIPV6UNICASTSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpPrefixIpv6UnicastState)
  })
_sym_db.RegisterMessage(BgpPrefixIpv6UnicastState)
_sym_db.RegisterMessage(BgpPrefixIpv6UnicastState.Origin)

ResultBgpCommunity = _reflection.GeneratedProtocolMessageType('ResultBgpCommunity', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _RESULTBGPCOMMUNITY_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ResultBgpCommunity.Type)
    })
  ,
  'DESCRIPTOR' : _RESULTBGPCOMMUNITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ResultBgpCommunity)
  })
_sym_db.RegisterMessage(ResultBgpCommunity)
_sym_db.RegisterMessage(ResultBgpCommunity.Type)

ResultBgpAsPath = _reflection.GeneratedProtocolMessageType('ResultBgpAsPath', (_message.Message,), {
  'DESCRIPTOR' : _RESULTBGPASPATH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ResultBgpAsPath)
  })
_sym_db.RegisterMessage(ResultBgpAsPath)

ResultBgpAsPathSegment = _reflection.GeneratedProtocolMessageType('ResultBgpAsPathSegment', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _RESULTBGPASPATHSEGMENT_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ResultBgpAsPathSegment.Type)
    })
  ,
  'DESCRIPTOR' : _RESULTBGPASPATHSEGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ResultBgpAsPathSegment)
  })
_sym_db.RegisterMessage(ResultBgpAsPathSegment)
_sym_db.RegisterMessage(ResultBgpAsPathSegment.Type)

IsisLspsStateRequest = _reflection.GeneratedProtocolMessageType('IsisLspsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPSSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspsStateRequest)
  })
_sym_db.RegisterMessage(IsisLspsStateRequest)

IsisLspsState = _reflection.GeneratedProtocolMessageType('IsisLspsState', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPSSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspsState)
  })
_sym_db.RegisterMessage(IsisLspsState)

IsisLspState = _reflection.GeneratedProtocolMessageType('IsisLspState', (_message.Message,), {

  'PduType' : _reflection.GeneratedProtocolMessageType('PduType', (_message.Message,), {
    'DESCRIPTOR' : _ISISLSPSTATE_PDUTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisLspState.PduType)
    })
  ,
  'DESCRIPTOR' : _ISISLSPSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspState)
  })
_sym_db.RegisterMessage(IsisLspState)
_sym_db.RegisterMessage(IsisLspState.PduType)

IsisLspTlvs = _reflection.GeneratedProtocolMessageType('IsisLspTlvs', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPTLVS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspTlvs)
  })
_sym_db.RegisterMessage(IsisLspTlvs)

IsisLspHostname = _reflection.GeneratedProtocolMessageType('IsisLspHostname', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPHOSTNAME,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspHostname)
  })
_sym_db.RegisterMessage(IsisLspHostname)

IsisLspFlags = _reflection.GeneratedProtocolMessageType('IsisLspFlags', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPFLAGS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspFlags)
  })
_sym_db.RegisterMessage(IsisLspFlags)

IsisLspIsReachabilityTlv = _reflection.GeneratedProtocolMessageType('IsisLspIsReachabilityTlv', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPISREACHABILITYTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspIsReachabilityTlv)
  })
_sym_db.RegisterMessage(IsisLspIsReachabilityTlv)

IsisLspExtendedIsReachabilityTlv = _reflection.GeneratedProtocolMessageType('IsisLspExtendedIsReachabilityTlv', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPEXTENDEDISREACHABILITYTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspExtendedIsReachabilityTlv)
  })
_sym_db.RegisterMessage(IsisLspExtendedIsReachabilityTlv)

IsisLspneighbor = _reflection.GeneratedProtocolMessageType('IsisLspneighbor', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPNEIGHBOR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspneighbor)
  })
_sym_db.RegisterMessage(IsisLspneighbor)

IsisLspIpv4InternalReachabilityTlv = _reflection.GeneratedProtocolMessageType('IsisLspIpv4InternalReachabilityTlv', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPIPV4INTERNALREACHABILITYTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspIpv4InternalReachabilityTlv)
  })
_sym_db.RegisterMessage(IsisLspIpv4InternalReachabilityTlv)

IsisLspIpv4ExternalReachabilityTlv = _reflection.GeneratedProtocolMessageType('IsisLspIpv4ExternalReachabilityTlv', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPIPV4EXTERNALREACHABILITYTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspIpv4ExternalReachabilityTlv)
  })
_sym_db.RegisterMessage(IsisLspIpv4ExternalReachabilityTlv)

IsisLspV4Prefix = _reflection.GeneratedProtocolMessageType('IsisLspV4Prefix', (_message.Message,), {

  'RedistributionType' : _reflection.GeneratedProtocolMessageType('RedistributionType', (_message.Message,), {
    'DESCRIPTOR' : _ISISLSPV4PREFIX_REDISTRIBUTIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisLspV4Prefix.RedistributionType)
    })
  ,

  'OriginType' : _reflection.GeneratedProtocolMessageType('OriginType', (_message.Message,), {
    'DESCRIPTOR' : _ISISLSPV4PREFIX_ORIGINTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisLspV4Prefix.OriginType)
    })
  ,
  'DESCRIPTOR' : _ISISLSPV4PREFIX,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspV4Prefix)
  })
_sym_db.RegisterMessage(IsisLspV4Prefix)
_sym_db.RegisterMessage(IsisLspV4Prefix.RedistributionType)
_sym_db.RegisterMessage(IsisLspV4Prefix.OriginType)

IsisLspExtendedIpv4ReachabilityTlv = _reflection.GeneratedProtocolMessageType('IsisLspExtendedIpv4ReachabilityTlv', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPEXTENDEDIPV4REACHABILITYTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspExtendedIpv4ReachabilityTlv)
  })
_sym_db.RegisterMessage(IsisLspExtendedIpv4ReachabilityTlv)

IsisLspExtendedV4Prefix = _reflection.GeneratedProtocolMessageType('IsisLspExtendedV4Prefix', (_message.Message,), {

  'RedistributionType' : _reflection.GeneratedProtocolMessageType('RedistributionType', (_message.Message,), {
    'DESCRIPTOR' : _ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisLspExtendedV4Prefix.RedistributionType)
    })
  ,
  'DESCRIPTOR' : _ISISLSPEXTENDEDV4PREFIX,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspExtendedV4Prefix)
  })
_sym_db.RegisterMessage(IsisLspExtendedV4Prefix)
_sym_db.RegisterMessage(IsisLspExtendedV4Prefix.RedistributionType)

IsisLspIpv6ReachabilityTlv = _reflection.GeneratedProtocolMessageType('IsisLspIpv6ReachabilityTlv', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPIPV6REACHABILITYTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspIpv6ReachabilityTlv)
  })
_sym_db.RegisterMessage(IsisLspIpv6ReachabilityTlv)

IsisLspV6Prefix = _reflection.GeneratedProtocolMessageType('IsisLspV6Prefix', (_message.Message,), {

  'RedistributionType' : _reflection.GeneratedProtocolMessageType('RedistributionType', (_message.Message,), {
    'DESCRIPTOR' : _ISISLSPV6PREFIX_REDISTRIBUTIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisLspV6Prefix.RedistributionType)
    })
  ,

  'OriginType' : _reflection.GeneratedProtocolMessageType('OriginType', (_message.Message,), {
    'DESCRIPTOR' : _ISISLSPV6PREFIX_ORIGINTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisLspV6Prefix.OriginType)
    })
  ,
  'DESCRIPTOR' : _ISISLSPV6PREFIX,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspV6Prefix)
  })
_sym_db.RegisterMessage(IsisLspV6Prefix)
_sym_db.RegisterMessage(IsisLspV6Prefix.RedistributionType)
_sym_db.RegisterMessage(IsisLspV6Prefix.OriginType)

IsisLspPrefixAttributes = _reflection.GeneratedProtocolMessageType('IsisLspPrefixAttributes', (_message.Message,), {
  'DESCRIPTOR' : _ISISLSPPREFIXATTRIBUTES,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisLspPrefixAttributes)
  })
_sym_db.RegisterMessage(IsisLspPrefixAttributes)

LldpNeighborsStateRequest = _reflection.GeneratedProtocolMessageType('LldpNeighborsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _LLDPNEIGHBORSSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpNeighborsStateRequest)
  })
_sym_db.RegisterMessage(LldpNeighborsStateRequest)

LldpNeighborsState = _reflection.GeneratedProtocolMessageType('LldpNeighborsState', (_message.Message,), {

  'ChassisIdType' : _reflection.GeneratedProtocolMessageType('ChassisIdType', (_message.Message,), {
    'DESCRIPTOR' : _LLDPNEIGHBORSSTATE_CHASSISIDTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpNeighborsState.ChassisIdType)
    })
  ,

  'PortIdType' : _reflection.GeneratedProtocolMessageType('PortIdType', (_message.Message,), {
    'DESCRIPTOR' : _LLDPNEIGHBORSSTATE_PORTIDTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpNeighborsState.PortIdType)
    })
  ,
  'DESCRIPTOR' : _LLDPNEIGHBORSSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpNeighborsState)
  })
_sym_db.RegisterMessage(LldpNeighborsState)
_sym_db.RegisterMessage(LldpNeighborsState.ChassisIdType)
_sym_db.RegisterMessage(LldpNeighborsState.PortIdType)

LldpCustomTLVState = _reflection.GeneratedProtocolMessageType('LldpCustomTLVState', (_message.Message,), {
  'DESCRIPTOR' : _LLDPCUSTOMTLVSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpCustomTLVState)
  })
_sym_db.RegisterMessage(LldpCustomTLVState)

LldpCapabilityState = _reflection.GeneratedProtocolMessageType('LldpCapabilityState', (_message.Message,), {

  'CapabilityName' : _reflection.GeneratedProtocolMessageType('CapabilityName', (_message.Message,), {
    'DESCRIPTOR' : _LLDPCAPABILITYSTATE_CAPABILITYNAME,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LldpCapabilityState.CapabilityName)
    })
  ,
  'DESCRIPTOR' : _LLDPCAPABILITYSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LldpCapabilityState)
  })
_sym_db.RegisterMessage(LldpCapabilityState)
_sym_db.RegisterMessage(LldpCapabilityState.CapabilityName)

RsvpLspsStateRequest = _reflection.GeneratedProtocolMessageType('RsvpLspsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _RSVPLSPSSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpLspsStateRequest)
  })
_sym_db.RegisterMessage(RsvpLspsStateRequest)

RsvpLspsState = _reflection.GeneratedProtocolMessageType('RsvpLspsState', (_message.Message,), {
  'DESCRIPTOR' : _RSVPLSPSSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpLspsState)
  })
_sym_db.RegisterMessage(RsvpLspsState)

RsvpIPv4LspState = _reflection.GeneratedProtocolMessageType('RsvpIPv4LspState', (_message.Message,), {
  'DESCRIPTOR' : _RSVPIPV4LSPSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpIPv4LspState)
  })
_sym_db.RegisterMessage(RsvpIPv4LspState)

RsvpLspState = _reflection.GeneratedProtocolMessageType('RsvpLspState', (_message.Message,), {

  'SessionStatus' : _reflection.GeneratedProtocolMessageType('SessionStatus', (_message.Message,), {
    'DESCRIPTOR' : _RSVPLSPSTATE_SESSIONSTATUS,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RsvpLspState.SessionStatus)
    })
  ,

  'LastFlapReason' : _reflection.GeneratedProtocolMessageType('LastFlapReason', (_message.Message,), {
    'DESCRIPTOR' : _RSVPLSPSTATE_LASTFLAPREASON,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RsvpLspState.LastFlapReason)
    })
  ,
  'DESCRIPTOR' : _RSVPLSPSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpLspState)
  })
_sym_db.RegisterMessage(RsvpLspState)
_sym_db.RegisterMessage(RsvpLspState.SessionStatus)
_sym_db.RegisterMessage(RsvpLspState.LastFlapReason)

RsvpLspIpv4Rro = _reflection.GeneratedProtocolMessageType('RsvpLspIpv4Rro', (_message.Message,), {
  'DESCRIPTOR' : _RSVPLSPIPV4RRO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpLspIpv4Rro)
  })
_sym_db.RegisterMessage(RsvpLspIpv4Rro)

RsvpLspIpv4Ero = _reflection.GeneratedProtocolMessageType('RsvpLspIpv4Ero', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _RSVPLSPIPV4ERO_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RsvpLspIpv4Ero.Type)
    })
  ,
  'DESCRIPTOR' : _RSVPLSPIPV4ERO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RsvpLspIpv4Ero)
  })
_sym_db.RegisterMessage(RsvpLspIpv4Ero)
_sym_db.RegisterMessage(RsvpLspIpv4Ero.Type)

CaptureRequest = _reflection.GeneratedProtocolMessageType('CaptureRequest', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureRequest)
  })
_sym_db.RegisterMessage(CaptureRequest)

PatternFlowEthernetDstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetDstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETDSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDstCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetDstCounter)

PatternFlowEthernetDstMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetDstMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETDSTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDstMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowEthernetDstMetricTag)

PatternFlowEthernetDst = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetDst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETDST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETDST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDst)
  })
_sym_db.RegisterMessage(PatternFlowEthernetDst)
_sym_db.RegisterMessage(PatternFlowEthernetDst.Choice)

PatternFlowEthernetSrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetSrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETSRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetSrcCounter)

PatternFlowEthernetSrcMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetSrcMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETSRCMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrcMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowEthernetSrcMetricTag)

PatternFlowEthernetSrc = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetSrc', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETSRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrc.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETSRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrc)
  })
_sym_db.RegisterMessage(PatternFlowEthernetSrc)
_sym_db.RegisterMessage(PatternFlowEthernetSrc.Choice)

PatternFlowEthernetEtherTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetEtherTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetEtherTypeCounter)

PatternFlowEthernetEtherTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetEtherTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowEthernetEtherTypeMetricTag)

PatternFlowEthernetEtherType = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetEtherType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherType)
  })
_sym_db.RegisterMessage(PatternFlowEthernetEtherType)
_sym_db.RegisterMessage(PatternFlowEthernetEtherType.Choice)

PatternFlowEthernetPfcQueueCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPfcQueueCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueueCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueueCounter)

PatternFlowEthernetPfcQueueMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPfcQueueMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueueMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueueMetricTag)

PatternFlowEthernetPfcQueue = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPfcQueue', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueue.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueue)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueue)
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueue.Choice)

PatternFlowVlanPriorityCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanPriorityCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriorityCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanPriorityCounter)

PatternFlowVlanPriorityMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowVlanPriorityMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITYMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriorityMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowVlanPriorityMetricTag)

PatternFlowVlanPriority = _reflection.GeneratedProtocolMessageType('PatternFlowVlanPriority', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriority.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriority)
  })
_sym_db.RegisterMessage(PatternFlowVlanPriority)
_sym_db.RegisterMessage(PatternFlowVlanPriority.Choice)

PatternFlowVlanCfiCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanCfiCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANCFICOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfiCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanCfiCounter)

PatternFlowVlanCfiMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowVlanCfiMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANCFIMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfiMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowVlanCfiMetricTag)

PatternFlowVlanCfi = _reflection.GeneratedProtocolMessageType('PatternFlowVlanCfi', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANCFI_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfi.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANCFI,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfi)
  })
_sym_db.RegisterMessage(PatternFlowVlanCfi)
_sym_db.RegisterMessage(PatternFlowVlanCfi.Choice)

PatternFlowVlanIdCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanIdCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanIdCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanIdCounter)

PatternFlowVlanIdMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowVlanIdMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANIDMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanIdMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowVlanIdMetricTag)

PatternFlowVlanId = _reflection.GeneratedProtocolMessageType('PatternFlowVlanId', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanId.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanId)
  })
_sym_db.RegisterMessage(PatternFlowVlanId)
_sym_db.RegisterMessage(PatternFlowVlanId.Choice)

PatternFlowVlanTpidCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanTpidCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANTPIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpidCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanTpidCounter)

PatternFlowVlanTpidMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowVlanTpidMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANTPIDMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpidMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowVlanTpidMetricTag)

PatternFlowVlanTpid = _reflection.GeneratedProtocolMessageType('PatternFlowVlanTpid', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANTPID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpid.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANTPID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpid)
  })
_sym_db.RegisterMessage(PatternFlowVlanTpid)
_sym_db.RegisterMessage(PatternFlowVlanTpid.Choice)

PatternFlowVxlanFlagsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanFlagsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlagsCounter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanFlagsCounter)

PatternFlowVxlanFlagsMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanFlagsMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGSMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlagsMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowVxlanFlagsMetricTag)

PatternFlowVxlanFlags = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanFlags', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlags.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlags)
  })
_sym_db.RegisterMessage(PatternFlowVxlanFlags)
_sym_db.RegisterMessage(PatternFlowVxlanFlags.Choice)

PatternFlowVxlanReserved0Counter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved0Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0Counter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved0Counter)

PatternFlowVxlanReserved0MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved0MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved0MetricTag)

PatternFlowVxlanReserved0 = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved0', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved0)
_sym_db.RegisterMessage(PatternFlowVxlanReserved0.Choice)

PatternFlowVxlanVniCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanVniCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANVNICOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVniCounter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanVniCounter)

PatternFlowVxlanVniMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanVniMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANVNIMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVniMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowVxlanVniMetricTag)

PatternFlowVxlanVni = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanVni', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANVNI_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVni.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANVNI,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVni)
  })
_sym_db.RegisterMessage(PatternFlowVxlanVni)
_sym_db.RegisterMessage(PatternFlowVxlanVni.Choice)

PatternFlowVxlanReserved1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1Counter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved1Counter)

PatternFlowVxlanReserved1MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved1MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved1MetricTag)

PatternFlowVxlanReserved1 = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved1)
_sym_db.RegisterMessage(PatternFlowVxlanReserved1.Choice)

PatternFlowIpv4VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4VersionCounter)

PatternFlowIpv4VersionMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4VersionMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4VERSIONMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4VersionMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4VersionMetricTag)

PatternFlowIpv4Version = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Version)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Version)
_sym_db.RegisterMessage(PatternFlowIpv4Version.Choice)

PatternFlowIpv4HeaderLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLengthCounter)

PatternFlowIpv4HeaderLengthMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderLengthMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLengthMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLengthMetricTag)

PatternFlowIpv4HeaderLength = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLength)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLength)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLength.Choice)

PatternFlowIpv4TotalLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TotalLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TotalLengthCounter)

PatternFlowIpv4TotalLengthMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TotalLengthMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLengthMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TotalLengthMetricTag)

PatternFlowIpv4TotalLength = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TotalLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLength)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TotalLength)
_sym_db.RegisterMessage(PatternFlowIpv4TotalLength.Choice)

PatternFlowIpv4IdentificationCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4IdentificationCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4IdentificationCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4IdentificationCounter)

PatternFlowIpv4IdentificationMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4IdentificationMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATIONMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4IdentificationMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4IdentificationMetricTag)

PatternFlowIpv4Identification = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Identification', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Identification.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Identification)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Identification)
_sym_db.RegisterMessage(PatternFlowIpv4Identification.Choice)

PatternFlowIpv4ReservedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4ReservedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4ReservedCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4ReservedCounter)

PatternFlowIpv4ReservedMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4ReservedMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVEDMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4ReservedMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4ReservedMetricTag)

PatternFlowIpv4Reserved = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Reserved', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Reserved.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Reserved)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Reserved)
_sym_db.RegisterMessage(PatternFlowIpv4Reserved.Choice)

PatternFlowIpv4DontFragmentCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DontFragmentCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragmentCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DontFragmentCounter)

PatternFlowIpv4DontFragmentMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DontFragmentMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragmentMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DontFragmentMetricTag)

PatternFlowIpv4DontFragment = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DontFragment', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragment.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragment)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DontFragment)
_sym_db.RegisterMessage(PatternFlowIpv4DontFragment.Choice)

PatternFlowIpv4MoreFragmentsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4MoreFragmentsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragmentsCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragmentsCounter)

PatternFlowIpv4MoreFragmentsMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4MoreFragmentsMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTSMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragmentsMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragmentsMetricTag)

PatternFlowIpv4MoreFragments = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4MoreFragments', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragments.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragments)
  })
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragments)
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragments.Choice)

PatternFlowIpv4FragmentOffsetCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4FragmentOffsetCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffsetCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffsetCounter)

PatternFlowIpv4FragmentOffsetMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4FragmentOffsetMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSETMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffsetMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffsetMetricTag)

PatternFlowIpv4FragmentOffset = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4FragmentOffset', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffset.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffset)
  })
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffset)
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffset.Choice)

PatternFlowIpv4TimeToLiveCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TimeToLiveCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLiveCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLiveCounter)

PatternFlowIpv4TimeToLiveMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TimeToLiveMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLiveMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLiveMetricTag)

PatternFlowIpv4TimeToLive = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TimeToLive', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLive.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLive)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLive)
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLive.Choice)

PatternFlowIpv4ProtocolCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4ProtocolCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOLCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4ProtocolCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4ProtocolCounter)

PatternFlowIpv4ProtocolMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4ProtocolMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOLMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4ProtocolMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4ProtocolMetricTag)

PatternFlowIpv4Protocol = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Protocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Protocol.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Protocol)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Protocol)
_sym_db.RegisterMessage(PatternFlowIpv4Protocol.Choice)

PatternFlowIpv4HeaderChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderChecksum)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderChecksum.Generated)

PatternFlowIpv4SrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4SrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4SRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4SrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4SrcCounter)

PatternFlowIpv4SrcMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4SrcMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4SRCMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4SrcMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4SrcMetricTag)

PatternFlowIpv4Src = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Src', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4SRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Src.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4SRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Src)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Src)
_sym_db.RegisterMessage(PatternFlowIpv4Src.Choice)

PatternFlowIpv4DstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DstCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DstCounter)

PatternFlowIpv4DstMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DstMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DstMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DstMetricTag)

PatternFlowIpv4Dst = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Dst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Dst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Dst)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Dst)
_sym_db.RegisterMessage(PatternFlowIpv4Dst.Choice)

PatternFlowIpv4PriorityRawCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4PriorityRawCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAWCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRawCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRawCounter)

PatternFlowIpv4PriorityRawMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4PriorityRawMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAWMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRawMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRawMetricTag)

PatternFlowIpv4PriorityRaw = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4PriorityRaw', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAW_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRaw.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRaw)
  })
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRaw)
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRaw.Choice)

PatternFlowIpv4DscpPhbCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpPhbCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHBCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhbCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhbCounter)

PatternFlowIpv4DscpPhbMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpPhbMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHBMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhbMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhbMetricTag)

PatternFlowIpv4DscpPhb = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpPhb', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHB_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhb.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHB,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhb)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhb)
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhb.Choice)

PatternFlowIpv4DscpEcnCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpEcnCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECNCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcnCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcnCounter)

PatternFlowIpv4DscpEcnMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpEcnMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECNMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcnMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcnMetricTag)

PatternFlowIpv4DscpEcn = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpEcn', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECN_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcn.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcn)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcn)
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcn.Choice)

PatternFlowIpv4TosPrecedenceCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosPrecedenceCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedenceCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedenceCounter)

PatternFlowIpv4TosPrecedenceMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosPrecedenceMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedenceMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedenceMetricTag)

PatternFlowIpv4TosPrecedence = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosPrecedence', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedence.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedence)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedence)
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedence.Choice)

PatternFlowIpv4TosDelayCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosDelayCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelayCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosDelayCounter)

PatternFlowIpv4TosDelayMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosDelayMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAYMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelayMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosDelayMetricTag)

PatternFlowIpv4TosDelay = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosDelay', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelay.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelay)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosDelay)
_sym_db.RegisterMessage(PatternFlowIpv4TosDelay.Choice)

PatternFlowIpv4TosThroughputCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosThroughputCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughputCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughputCounter)

PatternFlowIpv4TosThroughputMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosThroughputMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughputMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughputMetricTag)

PatternFlowIpv4TosThroughput = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosThroughput', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughput.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughput)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughput)
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughput.Choice)

PatternFlowIpv4TosReliabilityCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosReliabilityCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliabilityCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosReliabilityCounter)

PatternFlowIpv4TosReliabilityMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosReliabilityMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITYMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliabilityMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosReliabilityMetricTag)

PatternFlowIpv4TosReliability = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosReliability', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliability.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliability)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosReliability)
_sym_db.RegisterMessage(PatternFlowIpv4TosReliability.Choice)

PatternFlowIpv4TosMonetaryCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosMonetaryCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetaryCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetaryCounter)

PatternFlowIpv4TosMonetaryMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosMonetaryMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARYMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetaryMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetaryMetricTag)

PatternFlowIpv4TosMonetary = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosMonetary', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetary.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetary)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetary)
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetary.Choice)

PatternFlowIpv4TosUnusedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosUnusedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnusedCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosUnusedCounter)

PatternFlowIpv4TosUnusedMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosUnusedMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSEDMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnusedMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosUnusedMetricTag)

PatternFlowIpv4TosUnused = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosUnused', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnused.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnused)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosUnused)
_sym_db.RegisterMessage(PatternFlowIpv4TosUnused.Choice)

PatternFlowIpv6VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6VersionCounter)

PatternFlowIpv6VersionMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6VersionMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6VERSIONMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6VersionMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv6VersionMetricTag)

PatternFlowIpv6Version = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Version)
  })
_sym_db.RegisterMessage(PatternFlowIpv6Version)
_sym_db.RegisterMessage(PatternFlowIpv6Version.Choice)

PatternFlowIpv6TrafficClassCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6TrafficClassCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClassCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClassCounter)

PatternFlowIpv6TrafficClassMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6TrafficClassMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASSMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClassMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClassMetricTag)

PatternFlowIpv6TrafficClass = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6TrafficClass', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClass.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClass)
  })
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClass)
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClass.Choice)

PatternFlowIpv6FlowLabelCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6FlowLabelCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABELCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabelCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabelCounter)

PatternFlowIpv6FlowLabelMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6FlowLabelMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABELMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabelMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabelMetricTag)

PatternFlowIpv6FlowLabel = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6FlowLabel', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABEL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabel.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabel)
  })
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabel)
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabel.Choice)

PatternFlowIpv6PayloadLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6PayloadLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLengthCounter)

PatternFlowIpv6PayloadLengthMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6PayloadLengthMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLengthMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLengthMetricTag)

PatternFlowIpv6PayloadLength = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6PayloadLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLength)
  })
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLength)
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLength.Choice)

PatternFlowIpv6NextHeaderCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6NextHeaderCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeaderCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6NextHeaderCounter)

PatternFlowIpv6NextHeaderMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6NextHeaderMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeaderMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv6NextHeaderMetricTag)

PatternFlowIpv6NextHeader = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6NextHeader', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeader.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeader)
  })
_sym_db.RegisterMessage(PatternFlowIpv6NextHeader)
_sym_db.RegisterMessage(PatternFlowIpv6NextHeader.Choice)

PatternFlowIpv6HopLimitCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6HopLimitCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMITCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimitCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6HopLimitCounter)

PatternFlowIpv6HopLimitMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6HopLimitMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMITMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimitMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv6HopLimitMetricTag)

PatternFlowIpv6HopLimit = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6HopLimit', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMIT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimit.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMIT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimit)
  })
_sym_db.RegisterMessage(PatternFlowIpv6HopLimit)
_sym_db.RegisterMessage(PatternFlowIpv6HopLimit.Choice)

PatternFlowIpv6SrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6SrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6SRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6SrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6SrcCounter)

PatternFlowIpv6SrcMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6SrcMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6SRCMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6SrcMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv6SrcMetricTag)

PatternFlowIpv6Src = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6Src', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6SRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Src.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6SRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Src)
  })
_sym_db.RegisterMessage(PatternFlowIpv6Src)
_sym_db.RegisterMessage(PatternFlowIpv6Src.Choice)

PatternFlowIpv6DstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6DstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6DSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6DstCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6DstCounter)

PatternFlowIpv6DstMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6DstMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6DSTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6DstMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIpv6DstMetricTag)

PatternFlowIpv6Dst = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6Dst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6DST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Dst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6DST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Dst)
  })
_sym_db.RegisterMessage(PatternFlowIpv6Dst)
_sym_db.RegisterMessage(PatternFlowIpv6Dst.Choice)

PatternFlowPfcPauseDstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseDstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDstCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseDstCounter)

PatternFlowPfcPauseDstMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseDstMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDSTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDstMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseDstMetricTag)

PatternFlowPfcPauseDst = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseDst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDst)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseDst)
_sym_db.RegisterMessage(PatternFlowPfcPauseDst.Choice)

PatternFlowPfcPauseSrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseSrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseSrcCounter)

PatternFlowPfcPauseSrcMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseSrcMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRCMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrcMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseSrcMetricTag)

PatternFlowPfcPauseSrc = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseSrc', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrc.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrc)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseSrc)
_sym_db.RegisterMessage(PatternFlowPfcPauseSrc.Choice)

PatternFlowPfcPauseEtherTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseEtherTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherTypeCounter)

PatternFlowPfcPauseEtherTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseEtherTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherTypeMetricTag)

PatternFlowPfcPauseEtherType = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseEtherType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherType)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherType)
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherType.Choice)

PatternFlowPfcPauseControlOpCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseControlOpCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCodeCounter)

PatternFlowPfcPauseControlOpCodeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseControlOpCodeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCodeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCodeMetricTag)

PatternFlowPfcPauseControlOpCode = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseControlOpCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCode)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCode)
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCode.Choice)

PatternFlowPfcPauseClassEnableVectorCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseClassEnableVectorCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVectorCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVectorCounter)

PatternFlowPfcPauseClassEnableVectorMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseClassEnableVectorMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTORMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVectorMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVectorMetricTag)

PatternFlowPfcPauseClassEnableVector = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseClassEnableVector', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVector.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVector)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVector)
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVector.Choice)

PatternFlowPfcPausePauseClass0Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass0Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0Counter)

PatternFlowPfcPausePauseClass0MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass0MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0MetricTag)

PatternFlowPfcPausePauseClass0 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass0', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0.Choice)

PatternFlowPfcPausePauseClass1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1Counter)

PatternFlowPfcPausePauseClass1MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass1MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1MetricTag)

PatternFlowPfcPausePauseClass1 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1.Choice)

PatternFlowPfcPausePauseClass2Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass2Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2Counter)

PatternFlowPfcPausePauseClass2MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass2MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2MetricTag)

PatternFlowPfcPausePauseClass2 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass2', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2.Choice)

PatternFlowPfcPausePauseClass3Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass3Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3Counter)

PatternFlowPfcPausePauseClass3MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass3MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3MetricTag)

PatternFlowPfcPausePauseClass3 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass3', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3.Choice)

PatternFlowPfcPausePauseClass4Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass4Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4Counter)

PatternFlowPfcPausePauseClass4MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass4MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4MetricTag)

PatternFlowPfcPausePauseClass4 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass4', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4.Choice)

PatternFlowPfcPausePauseClass5Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass5Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5Counter)

PatternFlowPfcPausePauseClass5MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass5MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5MetricTag)

PatternFlowPfcPausePauseClass5 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass5', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5.Choice)

PatternFlowPfcPausePauseClass6Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass6Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6Counter)

PatternFlowPfcPausePauseClass6MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass6MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6MetricTag)

PatternFlowPfcPausePauseClass6 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass6', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6.Choice)

PatternFlowPfcPausePauseClass7Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass7Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7Counter)

PatternFlowPfcPausePauseClass7MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass7MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7MetricTag)

PatternFlowPfcPausePauseClass7 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass7', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7.Choice)

PatternFlowEthernetPauseDstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseDstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDstCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseDstCounter)

PatternFlowEthernetPauseDstMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseDstMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDSTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDstMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseDstMetricTag)

PatternFlowEthernetPauseDst = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseDst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDst)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseDst)
_sym_db.RegisterMessage(PatternFlowEthernetPauseDst.Choice)

PatternFlowEthernetPauseSrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseSrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrcCounter)

PatternFlowEthernetPauseSrcMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseSrcMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRCMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrcMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrcMetricTag)

PatternFlowEthernetPauseSrc = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseSrc', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrc.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrc)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrc)
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrc.Choice)

PatternFlowEthernetPauseEtherTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseEtherTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherTypeCounter)

PatternFlowEthernetPauseEtherTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseEtherTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherTypeMetricTag)

PatternFlowEthernetPauseEtherType = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseEtherType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherType)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherType)
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherType.Choice)

PatternFlowEthernetPauseControlOpCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseControlOpCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCodeCounter)

PatternFlowEthernetPauseControlOpCodeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseControlOpCodeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCodeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCodeMetricTag)

PatternFlowEthernetPauseControlOpCode = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseControlOpCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCode)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCode)
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCode.Choice)

PatternFlowEthernetPauseTimeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseTimeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIMECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTimeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseTimeCounter)

PatternFlowEthernetPauseTimeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseTimeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIMEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTimeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseTimeMetricTag)

PatternFlowEthernetPauseTime = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseTime', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIME_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTime.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIME,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTime)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseTime)
_sym_db.RegisterMessage(PatternFlowEthernetPauseTime.Choice)

PatternFlowTcpSrcPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSrcPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpSrcPortCounter)

PatternFlowTcpSrcPortMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSrcPortMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPortMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpSrcPortMetricTag)

PatternFlowTcpSrcPort = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSrcPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPort)
  })
_sym_db.RegisterMessage(PatternFlowTcpSrcPort)
_sym_db.RegisterMessage(PatternFlowTcpSrcPort.Choice)

PatternFlowTcpDstPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDstPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpDstPortCounter)

PatternFlowTcpDstPortMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDstPortMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPortMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpDstPortMetricTag)

PatternFlowTcpDstPort = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDstPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPort)
  })
_sym_db.RegisterMessage(PatternFlowTcpDstPort)
_sym_db.RegisterMessage(PatternFlowTcpDstPort.Choice)

PatternFlowTcpSeqNumCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSeqNumCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUMCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNumCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpSeqNumCounter)

PatternFlowTcpSeqNumMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSeqNumMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUMMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNumMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpSeqNumMetricTag)

PatternFlowTcpSeqNum = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSeqNum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNum.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNum)
  })
_sym_db.RegisterMessage(PatternFlowTcpSeqNum)
_sym_db.RegisterMessage(PatternFlowTcpSeqNum.Choice)

PatternFlowTcpAckNumCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpAckNumCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPACKNUMCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNumCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpAckNumCounter)

PatternFlowTcpAckNumMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpAckNumMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPACKNUMMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNumMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpAckNumMetricTag)

PatternFlowTcpAckNum = _reflection.GeneratedProtocolMessageType('PatternFlowTcpAckNum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPACKNUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNum.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPACKNUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNum)
  })
_sym_db.RegisterMessage(PatternFlowTcpAckNum)
_sym_db.RegisterMessage(PatternFlowTcpAckNum.Choice)

PatternFlowTcpDataOffsetCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDataOffsetCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSETCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffsetCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpDataOffsetCounter)

PatternFlowTcpDataOffsetMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDataOffsetMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSETMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffsetMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpDataOffsetMetricTag)

PatternFlowTcpDataOffset = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDataOffset', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSET_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffset.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffset)
  })
_sym_db.RegisterMessage(PatternFlowTcpDataOffset)
_sym_db.RegisterMessage(PatternFlowTcpDataOffset.Choice)

PatternFlowTcpEcnNsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnNsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNNSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNsCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnNsCounter)

PatternFlowTcpEcnNsMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnNsMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNNSMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNsMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnNsMetricTag)

PatternFlowTcpEcnNs = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnNs', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPECNNS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNs.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPECNNS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNs)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnNs)
_sym_db.RegisterMessage(PatternFlowTcpEcnNs.Choice)

PatternFlowTcpEcnCwrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnCwrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNCWRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwrCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnCwrCounter)

PatternFlowTcpEcnCwrMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnCwrMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNCWRMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwrMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnCwrMetricTag)

PatternFlowTcpEcnCwr = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnCwr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPECNCWR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPECNCWR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwr)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnCwr)
_sym_db.RegisterMessage(PatternFlowTcpEcnCwr.Choice)

PatternFlowTcpEcnEchoCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnEchoCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNECHOCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEchoCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnEchoCounter)

PatternFlowTcpEcnEchoMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnEchoMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNECHOMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEchoMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnEchoMetricTag)

PatternFlowTcpEcnEcho = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnEcho', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPECNECHO_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEcho.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPECNECHO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEcho)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnEcho)
_sym_db.RegisterMessage(PatternFlowTcpEcnEcho.Choice)

PatternFlowTcpCtlUrgCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlUrgCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLURGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrgCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlUrgCounter)

PatternFlowTcpCtlUrgMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlUrgMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLURGMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrgMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlUrgMetricTag)

PatternFlowTcpCtlUrg = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlUrg', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLURG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrg.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLURG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrg)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlUrg)
_sym_db.RegisterMessage(PatternFlowTcpCtlUrg.Choice)

PatternFlowTcpCtlAckCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlAckCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLACKCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAckCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlAckCounter)

PatternFlowTcpCtlAckMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlAckMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLACKMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAckMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlAckMetricTag)

PatternFlowTcpCtlAck = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlAck', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLACK_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAck.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAck)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlAck)
_sym_db.RegisterMessage(PatternFlowTcpCtlAck.Choice)

PatternFlowTcpCtlPshCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlPshCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPshCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlPshCounter)

PatternFlowTcpCtlPshMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlPshMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPshMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlPshMetricTag)

PatternFlowTcpCtlPsh = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlPsh', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPsh.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPsh)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlPsh)
_sym_db.RegisterMessage(PatternFlowTcpCtlPsh.Choice)

PatternFlowTcpCtlRstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlRstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLRSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRstCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlRstCounter)

PatternFlowTcpCtlRstMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlRstMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLRSTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRstMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlRstMetricTag)

PatternFlowTcpCtlRst = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlRst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLRST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLRST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRst)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlRst)
_sym_db.RegisterMessage(PatternFlowTcpCtlRst.Choice)

PatternFlowTcpCtlSynCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlSynCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYNCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSynCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlSynCounter)

PatternFlowTcpCtlSynMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlSynMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYNMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSynMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlSynMetricTag)

PatternFlowTcpCtlSyn = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlSyn', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYN_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSyn.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSyn)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlSyn)
_sym_db.RegisterMessage(PatternFlowTcpCtlSyn.Choice)

PatternFlowTcpCtlFinCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlFinCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLFINCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFinCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlFinCounter)

PatternFlowTcpCtlFinMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlFinMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLFINMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFinMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlFinMetricTag)

PatternFlowTcpCtlFin = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlFin', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLFIN_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFin.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLFIN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFin)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlFin)
_sym_db.RegisterMessage(PatternFlowTcpCtlFin.Choice)

PatternFlowTcpWindowCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpWindowCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPWINDOWCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindowCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpWindowCounter)

PatternFlowTcpWindowMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowTcpWindowMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPWINDOWMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindowMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowTcpWindowMetricTag)

PatternFlowTcpWindow = _reflection.GeneratedProtocolMessageType('PatternFlowTcpWindow', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPWINDOW_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindow.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPWINDOW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindow)
  })
_sym_db.RegisterMessage(PatternFlowTcpWindow)
_sym_db.RegisterMessage(PatternFlowTcpWindow.Choice)

PatternFlowUdpSrcPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowUdpSrcPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowUdpSrcPortCounter)

PatternFlowUdpSrcPortMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowUdpSrcPortMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPortMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowUdpSrcPortMetricTag)

PatternFlowUdpSrcPort = _reflection.GeneratedProtocolMessageType('PatternFlowUdpSrcPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPort)
  })
_sym_db.RegisterMessage(PatternFlowUdpSrcPort)
_sym_db.RegisterMessage(PatternFlowUdpSrcPort.Choice)

PatternFlowUdpDstPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowUdpDstPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowUdpDstPortCounter)

PatternFlowUdpDstPortMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowUdpDstPortMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPortMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowUdpDstPortMetricTag)

PatternFlowUdpDstPort = _reflection.GeneratedProtocolMessageType('PatternFlowUdpDstPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPort)
  })
_sym_db.RegisterMessage(PatternFlowUdpDstPort)
_sym_db.RegisterMessage(PatternFlowUdpDstPort.Choice)

PatternFlowUdpLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowUdpLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowUdpLengthCounter)

PatternFlowUdpLengthMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowUdpLengthMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPLENGTHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLengthMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowUdpLengthMetricTag)

PatternFlowUdpLength = _reflection.GeneratedProtocolMessageType('PatternFlowUdpLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLength)
  })
_sym_db.RegisterMessage(PatternFlowUdpLength)
_sym_db.RegisterMessage(PatternFlowUdpLength.Choice)

PatternFlowUdpChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowUdpChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpChecksum)
  })
_sym_db.RegisterMessage(PatternFlowUdpChecksum)
_sym_db.RegisterMessage(PatternFlowUdpChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowUdpChecksum.Generated)

PatternFlowGreChecksumPresentCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksumPresentCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresentCounter)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksumPresentCounter)

PatternFlowGreChecksumPresentMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksumPresentMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENTMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresentMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksumPresentMetricTag)

PatternFlowGreChecksumPresent = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksumPresent', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresent.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresent)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksumPresent)
_sym_db.RegisterMessage(PatternFlowGreChecksumPresent.Choice)

PatternFlowGreReserved0Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved0Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0Counter)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved0Counter)

PatternFlowGreReserved0MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved0MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved0MetricTag)

PatternFlowGreReserved0 = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved0', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved0)
_sym_db.RegisterMessage(PatternFlowGreReserved0.Choice)

PatternFlowGreVersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGreVersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGREVERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowGreVersionCounter)

PatternFlowGreVersionMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGreVersionMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGREVERSIONMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersionMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGreVersionMetricTag)

PatternFlowGreVersion = _reflection.GeneratedProtocolMessageType('PatternFlowGreVersion', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGREVERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersion.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGREVERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersion)
  })
_sym_db.RegisterMessage(PatternFlowGreVersion)
_sym_db.RegisterMessage(PatternFlowGreVersion.Choice)

PatternFlowGreProtocolCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGreProtocolCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOLCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocolCounter)
  })
_sym_db.RegisterMessage(PatternFlowGreProtocolCounter)

PatternFlowGreProtocolMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGreProtocolMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOLMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocolMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGreProtocolMetricTag)

PatternFlowGreProtocol = _reflection.GeneratedProtocolMessageType('PatternFlowGreProtocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocol.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocol)
  })
_sym_db.RegisterMessage(PatternFlowGreProtocol)
_sym_db.RegisterMessage(PatternFlowGreProtocol.Choice)

PatternFlowGreChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksum)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksum)
_sym_db.RegisterMessage(PatternFlowGreChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowGreChecksum.Generated)

PatternFlowGreReserved1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1Counter)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved1Counter)

PatternFlowGreReserved1MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved1MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved1MetricTag)

PatternFlowGreReserved1 = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved1)
_sym_db.RegisterMessage(PatternFlowGreReserved1.Choice)

PatternFlowGtpv1VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1VersionCounter)

PatternFlowGtpv1VersionMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1VersionMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSIONMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1VersionMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1VersionMetricTag)

PatternFlowGtpv1Version = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Version)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1Version)
_sym_db.RegisterMessage(PatternFlowGtpv1Version.Choice)

PatternFlowGtpv1ProtocolTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ProtocolTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolTypeCounter)

PatternFlowGtpv1ProtocolTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ProtocolTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolTypeMetricTag)

PatternFlowGtpv1ProtocolType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ProtocolType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolType)
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolType.Choice)

PatternFlowGtpv1ReservedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ReservedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ReservedCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ReservedCounter)

PatternFlowGtpv1ReservedMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ReservedMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVEDMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ReservedMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ReservedMetricTag)

PatternFlowGtpv1Reserved = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1Reserved', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Reserved.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Reserved)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1Reserved)
_sym_db.RegisterMessage(PatternFlowGtpv1Reserved.Choice)

PatternFlowGtpv1EFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1EFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1EFlagCounter)

PatternFlowGtpv1EFlagMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1EFlagMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAGMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlagMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1EFlagMetricTag)

PatternFlowGtpv1EFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1EFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1EFlag)
_sym_db.RegisterMessage(PatternFlowGtpv1EFlag.Choice)

PatternFlowGtpv1SFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SFlagCounter)

PatternFlowGtpv1SFlagMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SFlagMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAGMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlagMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SFlagMetricTag)

PatternFlowGtpv1SFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SFlag)
_sym_db.RegisterMessage(PatternFlowGtpv1SFlag.Choice)

PatternFlowGtpv1PnFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1PnFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlagCounter)

PatternFlowGtpv1PnFlagMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1PnFlagMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAGMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlagMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlagMetricTag)

PatternFlowGtpv1PnFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1PnFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlag)
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlag.Choice)

PatternFlowGtpv1MessageTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageTypeCounter)

PatternFlowGtpv1MessageTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageTypeMetricTag)

PatternFlowGtpv1MessageType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageType)
_sym_db.RegisterMessage(PatternFlowGtpv1MessageType.Choice)

PatternFlowGtpv1MessageLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLengthCounter)

PatternFlowGtpv1MessageLengthMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageLengthMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLengthMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLengthMetricTag)

PatternFlowGtpv1MessageLength = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLength)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLength)
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLength.Choice)

PatternFlowGtpv1TeidCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1TeidCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1TEIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1TeidCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1TeidCounter)

PatternFlowGtpv1TeidMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1TeidMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1TEIDMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1TeidMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1TeidMetricTag)

PatternFlowGtpv1Teid = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1Teid', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1TEID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Teid.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1TEID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Teid)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1Teid)
_sym_db.RegisterMessage(PatternFlowGtpv1Teid.Choice)

PatternFlowGtpv1SquenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SquenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumberCounter)

PatternFlowGtpv1SquenceNumberMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SquenceNumberMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumberMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumberMetricTag)

PatternFlowGtpv1SquenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SquenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumber)
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumber.Choice)

PatternFlowGtpv1NPduNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NPduNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumberCounter)

PatternFlowGtpv1NPduNumberMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NPduNumberMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumberMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumberMetricTag)

PatternFlowGtpv1NPduNumber = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NPduNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumber)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumber)
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumber.Choice)

PatternFlowGtpv1NextExtensionHeaderTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NextExtensionHeaderTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderTypeCounter)

PatternFlowGtpv1NextExtensionHeaderTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NextExtensionHeaderTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderTypeMetricTag)

PatternFlowGtpv1NextExtensionHeaderType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NextExtensionHeaderType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderType)
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderType.Choice)

PatternFlowGtpExtensionExtensionLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionExtensionLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLengthCounter)

PatternFlowGtpExtensionExtensionLengthMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionExtensionLengthMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLengthMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLengthMetricTag)

PatternFlowGtpExtensionExtensionLength = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionExtensionLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLength)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLength)
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLength.Choice)

PatternFlowGtpExtensionContentsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionContentsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContentsCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionContentsCounter)

PatternFlowGtpExtensionContentsMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionContentsMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTSMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContentsMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionContentsMetricTag)

PatternFlowGtpExtensionContents = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionContents', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContents.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContents)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionContents)
_sym_db.RegisterMessage(PatternFlowGtpExtensionContents.Choice)

PatternFlowGtpExtensionNextExtensionHeaderCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionNextExtensionHeaderCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeaderCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeaderCounter)

PatternFlowGtpExtensionNextExtensionHeaderMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionNextExtensionHeaderMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeaderMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeaderMetricTag)

PatternFlowGtpExtensionNextExtensionHeader = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionNextExtensionHeader', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeader.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeader)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeader)
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeader.Choice)

PatternFlowGtpv2VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2VersionCounter)

PatternFlowGtpv2VersionMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2VersionMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSIONMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2VersionMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2VersionMetricTag)

PatternFlowGtpv2Version = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Version)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Version)
_sym_db.RegisterMessage(PatternFlowGtpv2Version.Choice)

PatternFlowGtpv2PiggybackingFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2PiggybackingFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlagCounter)

PatternFlowGtpv2PiggybackingFlagMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2PiggybackingFlagMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAGMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlagMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlagMetricTag)

PatternFlowGtpv2PiggybackingFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2PiggybackingFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlag)
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlag.Choice)

PatternFlowGtpv2TeidFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlagCounter)

PatternFlowGtpv2TeidFlagMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidFlagMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAGMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlagMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlagMetricTag)

PatternFlowGtpv2TeidFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlag)
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlag.Choice)

PatternFlowGtpv2Spare1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1Counter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1Counter)

PatternFlowGtpv2Spare1MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare1MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1MetricTag)

PatternFlowGtpv2Spare1 = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1)
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1.Choice)

PatternFlowGtpv2MessageTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageTypeCounter)

PatternFlowGtpv2MessageTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageTypeMetricTag)

PatternFlowGtpv2MessageType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageType)
_sym_db.RegisterMessage(PatternFlowGtpv2MessageType.Choice)

PatternFlowGtpv2MessageLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLengthCounter)

PatternFlowGtpv2MessageLengthMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageLengthMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLengthMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLengthMetricTag)

PatternFlowGtpv2MessageLength = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLength)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLength)
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLength.Choice)

PatternFlowGtpv2TeidCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidCounter)

PatternFlowGtpv2TeidMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidMetricTag)

PatternFlowGtpv2Teid = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Teid', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2TEID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Teid.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Teid)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Teid)
_sym_db.RegisterMessage(PatternFlowGtpv2Teid.Choice)

PatternFlowGtpv2SequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2SequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumberCounter)

PatternFlowGtpv2SequenceNumberMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2SequenceNumberMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumberMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumberMetricTag)

PatternFlowGtpv2SequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2SequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumber)
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumber.Choice)

PatternFlowGtpv2Spare2Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare2Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2Counter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2Counter)

PatternFlowGtpv2Spare2MetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare2MetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2METRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2MetricTag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2MetricTag)

PatternFlowGtpv2Spare2 = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare2', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2)
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2.Choice)

PatternFlowArpHardwareTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareTypeCounter)

PatternFlowArpHardwareTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareTypeMetricTag)

PatternFlowArpHardwareType = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareType)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareType)
_sym_db.RegisterMessage(PatternFlowArpHardwareType.Choice)

PatternFlowArpProtocolTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolTypeCounter)

PatternFlowArpProtocolTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolTypeMetricTag)

PatternFlowArpProtocolType = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolType)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolType)
_sym_db.RegisterMessage(PatternFlowArpProtocolType.Choice)

PatternFlowArpHardwareLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareLengthCounter)

PatternFlowArpHardwareLengthMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareLengthMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLengthMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareLengthMetricTag)

PatternFlowArpHardwareLength = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLength)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareLength)
_sym_db.RegisterMessage(PatternFlowArpHardwareLength.Choice)

PatternFlowArpProtocolLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolLengthCounter)

PatternFlowArpProtocolLengthMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolLengthMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTHMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLengthMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolLengthMetricTag)

PatternFlowArpProtocolLength = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLength)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolLength)
_sym_db.RegisterMessage(PatternFlowArpProtocolLength.Choice)

PatternFlowArpOperationCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpOperationCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPOPERATIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperationCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpOperationCounter)

PatternFlowArpOperationMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowArpOperationMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPOPERATIONMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperationMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowArpOperationMetricTag)

PatternFlowArpOperation = _reflection.GeneratedProtocolMessageType('PatternFlowArpOperation', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPOPERATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperation.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPOPERATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperation)
  })
_sym_db.RegisterMessage(PatternFlowArpOperation)
_sym_db.RegisterMessage(PatternFlowArpOperation.Choice)

PatternFlowArpSenderHardwareAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderHardwareAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddrCounter)

PatternFlowArpSenderHardwareAddrMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderHardwareAddrMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDRMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddrMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddrMetricTag)

PatternFlowArpSenderHardwareAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderHardwareAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddr)
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddr.Choice)

PatternFlowArpSenderProtocolAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderProtocolAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddrCounter)

PatternFlowArpSenderProtocolAddrMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderProtocolAddrMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDRMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddrMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddrMetricTag)

PatternFlowArpSenderProtocolAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderProtocolAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddr)
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddr.Choice)

PatternFlowArpTargetHardwareAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetHardwareAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddrCounter)

PatternFlowArpTargetHardwareAddrMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetHardwareAddrMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDRMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddrMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddrMetricTag)

PatternFlowArpTargetHardwareAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetHardwareAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddr)
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddr.Choice)

PatternFlowArpTargetProtocolAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetProtocolAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddrCounter)

PatternFlowArpTargetProtocolAddrMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetProtocolAddrMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDRMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddrMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddrMetricTag)

PatternFlowArpTargetProtocolAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetProtocolAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddr)
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddr.Choice)

PatternFlowIcmpEchoTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoTypeCounter)

PatternFlowIcmpEchoTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoTypeMetricTag)

PatternFlowIcmpEchoType = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoType)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoType)
_sym_db.RegisterMessage(PatternFlowIcmpEchoType.Choice)

PatternFlowIcmpEchoCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoCodeCounter)

PatternFlowIcmpEchoCodeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoCodeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCodeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoCodeMetricTag)

PatternFlowIcmpEchoCode = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCode)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoCode)
_sym_db.RegisterMessage(PatternFlowIcmpEchoCode.Choice)

PatternFlowIcmpEchoChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpEchoChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpEchoChecksum.Generated)

PatternFlowIcmpEchoIdentifierCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoIdentifierCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifierCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifierCounter)

PatternFlowIcmpEchoIdentifierMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoIdentifierMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifierMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifierMetricTag)

PatternFlowIcmpEchoIdentifier = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoIdentifier', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifier.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifier)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifier)
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifier.Choice)

PatternFlowIcmpEchoSequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoSequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumberCounter)

PatternFlowIcmpEchoSequenceNumberMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoSequenceNumberMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumberMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumberMetricTag)

PatternFlowIcmpEchoSequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoSequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumber)
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumber.Choice)

PatternFlowIcmpCommonChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpCommonChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpCommonChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpCommonChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPCOMMONCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpCommonChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpCommonChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpCommonChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpCommonChecksum.Generated)

PatternFlowIcmpNextFieldsIdentifierCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsIdentifierCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifierCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifierCounter)

PatternFlowIcmpNextFieldsIdentifierMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsIdentifierMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifierMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifierMetricTag)

PatternFlowIcmpNextFieldsIdentifier = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsIdentifier', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifier.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifier)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifier)
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifier.Choice)

PatternFlowIcmpNextFieldsSequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsSequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumberCounter)

PatternFlowIcmpNextFieldsSequenceNumberMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsSequenceNumberMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumberMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumberMetricTag)

PatternFlowIcmpNextFieldsSequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsSequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumber)
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumber.Choice)

PatternFlowIcmpv6EchoTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoTypeCounter)

PatternFlowIcmpv6EchoTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoTypeMetricTag)

PatternFlowIcmpv6EchoType = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoType)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoType)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoType.Choice)

PatternFlowIcmpv6EchoCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCodeCounter)

PatternFlowIcmpv6EchoCodeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoCodeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCodeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCodeMetricTag)

PatternFlowIcmpv6EchoCode = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCode)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCode)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCode.Choice)

PatternFlowIcmpv6EchoIdentifierCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoIdentifierCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifierCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifierCounter)

PatternFlowIcmpv6EchoIdentifierMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoIdentifierMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifierMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifierMetricTag)

PatternFlowIcmpv6EchoIdentifier = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoIdentifier', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifier.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifier)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifier)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifier.Choice)

PatternFlowIcmpv6EchoSequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoSequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumberCounter)

PatternFlowIcmpv6EchoSequenceNumberMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoSequenceNumberMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumberMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumberMetricTag)

PatternFlowIcmpv6EchoSequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoSequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumber)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumber.Choice)

PatternFlowIcmpv6EchoChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoChecksum.Generated)

PatternFlowIcmpv6CommonChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6CommonChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6CommonChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6CommonChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6COMMONCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6CommonChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6CommonChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpv6CommonChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpv6CommonChecksum.Generated)

PatternFlowPppAddressCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPppAddressCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPADDRESSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddressCounter)
  })
_sym_db.RegisterMessage(PatternFlowPppAddressCounter)

PatternFlowPppAddressMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPppAddressMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPADDRESSMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddressMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPppAddressMetricTag)

PatternFlowPppAddress = _reflection.GeneratedProtocolMessageType('PatternFlowPppAddress', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPADDRESS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddress.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPPPADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddress)
  })
_sym_db.RegisterMessage(PatternFlowPppAddress)
_sym_db.RegisterMessage(PatternFlowPppAddress.Choice)

PatternFlowPppControlCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPppControlCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPCONTROLCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControlCounter)
  })
_sym_db.RegisterMessage(PatternFlowPppControlCounter)

PatternFlowPppControlMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPppControlMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPCONTROLMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControlMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPppControlMetricTag)

PatternFlowPppControl = _reflection.GeneratedProtocolMessageType('PatternFlowPppControl', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPCONTROL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControl.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPPPCONTROL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControl)
  })
_sym_db.RegisterMessage(PatternFlowPppControl)
_sym_db.RegisterMessage(PatternFlowPppControl.Choice)

PatternFlowPppProtocolTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPppProtocolTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowPppProtocolTypeCounter)

PatternFlowPppProtocolTypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowPppProtocolTypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolTypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowPppProtocolTypeMetricTag)

PatternFlowPppProtocolType = _reflection.GeneratedProtocolMessageType('PatternFlowPppProtocolType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolType)
  })
_sym_db.RegisterMessage(PatternFlowPppProtocolType)
_sym_db.RegisterMessage(PatternFlowPppProtocolType.Choice)

PatternFlowIgmpv1VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1VersionCounter)

PatternFlowIgmpv1VersionMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1VersionMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSIONMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1VersionMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1VersionMetricTag)

PatternFlowIgmpv1Version = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Version)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Version)
_sym_db.RegisterMessage(PatternFlowIgmpv1Version.Choice)

PatternFlowIgmpv1TypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1TypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1TypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1TypeCounter)

PatternFlowIgmpv1TypeMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1TypeMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1TypeMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1TypeMetricTag)

PatternFlowIgmpv1Type = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Type', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Type.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Type)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Type)
_sym_db.RegisterMessage(PatternFlowIgmpv1Type.Choice)

PatternFlowIgmpv1UnusedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1UnusedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1UnusedCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1UnusedCounter)

PatternFlowIgmpv1UnusedMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1UnusedMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSEDMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1UnusedMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1UnusedMetricTag)

PatternFlowIgmpv1Unused = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Unused', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Unused.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Unused)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Unused)
_sym_db.RegisterMessage(PatternFlowIgmpv1Unused.Choice)

PatternFlowIgmpv1Checksum = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Checksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1CHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Checksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1CHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Checksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1CHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Checksum)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Checksum)
_sym_db.RegisterMessage(PatternFlowIgmpv1Checksum.Choice)
_sym_db.RegisterMessage(PatternFlowIgmpv1Checksum.Generated)

PatternFlowIgmpv1GroupAddressCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1GroupAddressCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddressCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddressCounter)

PatternFlowIgmpv1GroupAddressMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1GroupAddressMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESSMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddressMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddressMetricTag)

PatternFlowIgmpv1GroupAddress = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1GroupAddress', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddress.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddress)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddress)
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddress.Choice)

PatternFlowMplsLabelCounter = _reflection.GeneratedProtocolMessageType('PatternFlowMplsLabelCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSLABELCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsLabelCounter)
  })
_sym_db.RegisterMessage(PatternFlowMplsLabelCounter)

PatternFlowMplsLabelMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowMplsLabelMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSLABELMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsLabelMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowMplsLabelMetricTag)

PatternFlowMplsLabel = _reflection.GeneratedProtocolMessageType('PatternFlowMplsLabel', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWMPLSLABEL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsLabel.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWMPLSLABEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsLabel)
  })
_sym_db.RegisterMessage(PatternFlowMplsLabel)
_sym_db.RegisterMessage(PatternFlowMplsLabel.Choice)

PatternFlowMplsTrafficClassCounter = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTrafficClassCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSTRAFFICCLASSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTrafficClassCounter)
  })
_sym_db.RegisterMessage(PatternFlowMplsTrafficClassCounter)

PatternFlowMplsTrafficClassMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTrafficClassMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSTRAFFICCLASSMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTrafficClassMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowMplsTrafficClassMetricTag)

PatternFlowMplsTrafficClass = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTrafficClass', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTrafficClass.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWMPLSTRAFFICCLASS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTrafficClass)
  })
_sym_db.RegisterMessage(PatternFlowMplsTrafficClass)
_sym_db.RegisterMessage(PatternFlowMplsTrafficClass.Choice)

PatternFlowMplsBottomOfStackCounter = _reflection.GeneratedProtocolMessageType('PatternFlowMplsBottomOfStackCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsBottomOfStackCounter)
  })
_sym_db.RegisterMessage(PatternFlowMplsBottomOfStackCounter)

PatternFlowMplsBottomOfStackMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowMplsBottomOfStackMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSBOTTOMOFSTACKMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsBottomOfStackMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowMplsBottomOfStackMetricTag)

PatternFlowMplsBottomOfStack = _reflection.GeneratedProtocolMessageType('PatternFlowMplsBottomOfStack', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsBottomOfStack.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWMPLSBOTTOMOFSTACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsBottomOfStack)
  })
_sym_db.RegisterMessage(PatternFlowMplsBottomOfStack)
_sym_db.RegisterMessage(PatternFlowMplsBottomOfStack.Choice)

PatternFlowMplsTimeToLiveCounter = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTimeToLiveCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSTIMETOLIVECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTimeToLiveCounter)
  })
_sym_db.RegisterMessage(PatternFlowMplsTimeToLiveCounter)

PatternFlowMplsTimeToLiveMetricTag = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTimeToLiveMetricTag', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSTIMETOLIVEMETRICTAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTimeToLiveMetricTag)
  })
_sym_db.RegisterMessage(PatternFlowMplsTimeToLiveMetricTag)

PatternFlowMplsTimeToLive = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTimeToLive', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWMPLSTIMETOLIVE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTimeToLive.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWMPLSTIMETOLIVE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTimeToLive)
  })
_sym_db.RegisterMessage(PatternFlowMplsTimeToLive)
_sym_db.RegisterMessage(PatternFlowMplsTimeToLive.Choice)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Version)
  })
_sym_db.RegisterMessage(Version)

Success = _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
  'DESCRIPTOR' : _SUCCESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Success)
  })
_sym_db.RegisterMessage(Success)

Failure = _reflection.GeneratedProtocolMessageType('Failure', (_message.Message,), {
  'DESCRIPTOR' : _FAILURE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Failure)
  })
_sym_db.RegisterMessage(Failure)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)

UpdateConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONFIGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.UpdateConfigRequest)
  })
_sym_db.RegisterMessage(UpdateConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)

UpdateConfigResponse = _reflection.GeneratedProtocolMessageType('UpdateConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONFIGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.UpdateConfigResponse)
  })
_sym_db.RegisterMessage(UpdateConfigResponse)

SetControlStateRequest = _reflection.GeneratedProtocolMessageType('SetControlStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONTROLSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetControlStateRequest)
  })
_sym_db.RegisterMessage(SetControlStateRequest)

SetControlStateResponse = _reflection.GeneratedProtocolMessageType('SetControlStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONTROLSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetControlStateResponse)
  })
_sym_db.RegisterMessage(SetControlStateResponse)

SetControlActionRequest = _reflection.GeneratedProtocolMessageType('SetControlActionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONTROLACTIONREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetControlActionRequest)
  })
_sym_db.RegisterMessage(SetControlActionRequest)

SetControlActionResponse = _reflection.GeneratedProtocolMessageType('SetControlActionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONTROLACTIONRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetControlActionResponse)
  })
_sym_db.RegisterMessage(SetControlActionResponse)

SetTransmitStateRequest = _reflection.GeneratedProtocolMessageType('SetTransmitStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETTRANSMITSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetTransmitStateRequest)
  })
_sym_db.RegisterMessage(SetTransmitStateRequest)

SetTransmitStateResponse = _reflection.GeneratedProtocolMessageType('SetTransmitStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETTRANSMITSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetTransmitStateResponse)
  })
_sym_db.RegisterMessage(SetTransmitStateResponse)

SetLinkStateRequest = _reflection.GeneratedProtocolMessageType('SetLinkStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETLINKSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetLinkStateRequest)
  })
_sym_db.RegisterMessage(SetLinkStateRequest)

SetLinkStateResponse = _reflection.GeneratedProtocolMessageType('SetLinkStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETLINKSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetLinkStateResponse)
  })
_sym_db.RegisterMessage(SetLinkStateResponse)

SetCaptureStateRequest = _reflection.GeneratedProtocolMessageType('SetCaptureStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCAPTURESTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetCaptureStateRequest)
  })
_sym_db.RegisterMessage(SetCaptureStateRequest)

SetCaptureStateResponse = _reflection.GeneratedProtocolMessageType('SetCaptureStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCAPTURESTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetCaptureStateResponse)
  })
_sym_db.RegisterMessage(SetCaptureStateResponse)

UpdateFlowsRequest = _reflection.GeneratedProtocolMessageType('UpdateFlowsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFLOWSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.UpdateFlowsRequest)
  })
_sym_db.RegisterMessage(UpdateFlowsRequest)

UpdateFlowsResponse = _reflection.GeneratedProtocolMessageType('UpdateFlowsResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFLOWSRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.UpdateFlowsResponse)
  })
_sym_db.RegisterMessage(UpdateFlowsResponse)

SetRouteStateRequest = _reflection.GeneratedProtocolMessageType('SetRouteStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETROUTESTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetRouteStateRequest)
  })
_sym_db.RegisterMessage(SetRouteStateRequest)

SetRouteStateResponse = _reflection.GeneratedProtocolMessageType('SetRouteStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETROUTESTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetRouteStateResponse)
  })
_sym_db.RegisterMessage(SetRouteStateResponse)

SendPingRequest = _reflection.GeneratedProtocolMessageType('SendPingRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDPINGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SendPingRequest)
  })
_sym_db.RegisterMessage(SendPingRequest)

SendPingResponse = _reflection.GeneratedProtocolMessageType('SendPingResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDPINGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SendPingResponse)
  })
_sym_db.RegisterMessage(SendPingResponse)

SetProtocolStateRequest = _reflection.GeneratedProtocolMessageType('SetProtocolStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPROTOCOLSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetProtocolStateRequest)
  })
_sym_db.RegisterMessage(SetProtocolStateRequest)

SetProtocolStateResponse = _reflection.GeneratedProtocolMessageType('SetProtocolStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETPROTOCOLSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetProtocolStateResponse)
  })
_sym_db.RegisterMessage(SetProtocolStateResponse)

SetDeviceStateRequest = _reflection.GeneratedProtocolMessageType('SetDeviceStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDEVICESTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetDeviceStateRequest)
  })
_sym_db.RegisterMessage(SetDeviceStateRequest)

SetDeviceStateResponse = _reflection.GeneratedProtocolMessageType('SetDeviceStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETDEVICESTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetDeviceStateResponse)
  })
_sym_db.RegisterMessage(SetDeviceStateResponse)

GetMetricsRequest = _reflection.GeneratedProtocolMessageType('GetMetricsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetMetricsRequest)
  })
_sym_db.RegisterMessage(GetMetricsRequest)

GetMetricsResponse = _reflection.GeneratedProtocolMessageType('GetMetricsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetMetricsResponse)
  })
_sym_db.RegisterMessage(GetMetricsResponse)

GetStatesRequest = _reflection.GeneratedProtocolMessageType('GetStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetStatesRequest)
  })
_sym_db.RegisterMessage(GetStatesRequest)

GetStatesResponse = _reflection.GeneratedProtocolMessageType('GetStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATESRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetStatesResponse)
  })
_sym_db.RegisterMessage(GetStatesResponse)

GetCaptureRequest = _reflection.GeneratedProtocolMessageType('GetCaptureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCAPTUREREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetCaptureRequest)
  })
_sym_db.RegisterMessage(GetCaptureRequest)

GetCaptureResponse = _reflection.GeneratedProtocolMessageType('GetCaptureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCAPTURERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetCaptureResponse)
  })
_sym_db.RegisterMessage(GetCaptureResponse)

GetVersionResponse = _reflection.GeneratedProtocolMessageType('GetVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVERSIONRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetVersionResponse)
  })
_sym_db.RegisterMessage(GetVersionResponse)

_OPENAPI = DESCRIPTOR.services_by_name['Openapi']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\t./otg;otg'
  _CONFIG._serialized_start=82
  _CONFIG._serialized_end=380
  _CONFIGOPTIONS._serialized_start=383
  _CONFIGOPTIONS._serialized_end=534
  _PORT._serialized_start=536
  _PORT._serialized_end=592
  _PORTOPTIONS._serialized_start=594
  _PORTOPTIONS._serialized_end=665
  _LAG._serialized_start=668
  _LAG._serialized_end=808
  _LAGPORT._serialized_start=810
  _LAGPORT._serialized_end=927
  _LAGPROTOCOL._serialized_start=930
  _LAGPROTOCOL._serialized_end=1168
  _LAGPROTOCOL_CHOICE._serialized_start=1082
  _LAGPROTOCOL_CHOICE._serialized_end=1137
  _LAGPROTOCOL_CHOICE_ENUM._serialized_start=1092
  _LAGPROTOCOL_CHOICE_ENUM._serialized_end=1137
  _LAGPROTOCOLSTATIC._serialized_start=1170
  _LAGPROTOCOLSTATIC._serialized_end=1221
  _LAGPROTOCOLLACP._serialized_start=1224
  _LAGPROTOCOLLACP._serialized_end=1391
  _LAGPORTLACP._serialized_start=1394
  _LAGPORTLACP._serialized_end=1797
  _LAGPORTLACP_ACTORACTIVITY._serialized_start=1614
  _LAGPORTLACP_ACTORACTIVITY._serialized_end=1679
  _LAGPORTLACP_ACTORACTIVITY_ENUM._serialized_start=1631
  _LAGPORTLACP_ACTORACTIVITY_ENUM._serialized_end=1679
  _DEVICEETHERNETBASE._serialized_start=1799
  _DEVICEETHERNETBASE._serialized_end=1904
  _DEVICEETHERNET._serialized_start=1907
  _DEVICEETHERNET._serialized_end=2193
  _ETHERNETCONNECTION._serialized_start=2196
  _ETHERNETCONNECTION._serialized_end=2479
  _ETHERNETCONNECTION_CHOICE._serialized_start=2348
  _ETHERNETCONNECTION_CHOICE._serialized_end=2426
  _ETHERNETCONNECTION_CHOICE_ENUM._serialized_start=2358
  _ETHERNETCONNECTION_CHOICE_ENUM._serialized_end=2426
  _DEVICEVLAN._serialized_start=2482
  _DEVICEVLAN._serialized_end=2711
  _DEVICEVLAN_TPID._serialized_start=2596
  _DEVICEVLAN_TPID._serialized_end=2682
  _DEVICEVLAN_TPID_ENUM._serialized_start=2604
  _DEVICEVLAN_TPID_ENUM._serialized_end=2682
  _DEVICEIPV4._serialized_start=2714
  _DEVICEIPV4._serialized_end=2875
  _DEVICEIPV4LOOPBACK._serialized_start=2877
  _DEVICEIPV4LOOPBACK._serialized_end=2963
  _DEVICEIPV4GATEWAYMAC._serialized_start=2966
  _DEVICEIPV4GATEWAYMAC._serialized_end=3173
  _DEVICEIPV4GATEWAYMAC_CHOICE._serialized_start=3089
  _DEVICEIPV4GATEWAYMAC_CHOICE._serialized_end=3143
  _DEVICEIPV4GATEWAYMAC_CHOICE_ENUM._serialized_start=3099
  _DEVICEIPV4GATEWAYMAC_CHOICE_ENUM._serialized_end=3143
  _DEVICEIPV6._serialized_start=3176
  _DEVICEIPV6._serialized_end=3337
  _DEVICEIPV6LOOPBACK._serialized_start=3339
  _DEVICEIPV6LOOPBACK._serialized_end=3425
  _DEVICEIPV6GATEWAYMAC._serialized_start=3428
  _DEVICEIPV6GATEWAYMAC._serialized_end=3635
  _DEVICEIPV6GATEWAYMAC_CHOICE._serialized_start=3089
  _DEVICEIPV6GATEWAYMAC_CHOICE._serialized_end=3143
  _DEVICEIPV6GATEWAYMAC_CHOICE_ENUM._serialized_start=3099
  _DEVICEIPV6GATEWAYMAC_CHOICE_ENUM._serialized_end=3143
  _LAYER1._serialized_start=3638
  _LAYER1._serialized_end=4458
  _LAYER1_SPEED._serialized_start=3988
  _LAYER1_SPEED._serialized_end=4265
  _LAYER1_SPEED_ENUM._serialized_start=3998
  _LAYER1_SPEED_ENUM._serialized_end=4265
  _LAYER1_MEDIA._serialized_start=4267
  _LAYER1_MEDIA._serialized_end=4333
  _LAYER1_MEDIA_ENUM._serialized_start=4276
  _LAYER1_MEDIA_ENUM._serialized_end=4333
  _LAYER1AUTONEGOTIATION._serialized_start=4461
  _LAYER1AUTONEGOTIATION._serialized_end=4864
  _LAYER1FLOWCONTROL._serialized_start=4867
  _LAYER1FLOWCONTROL._serialized_end=5211
  _LAYER1FLOWCONTROL_CHOICE._serialized_start=5076
  _LAYER1FLOWCONTROL_CHOICE._serialized_end=5145
  _LAYER1FLOWCONTROL_CHOICE_ENUM._serialized_start=5086
  _LAYER1FLOWCONTROL_CHOICE_ENUM._serialized_end=5145
  _LAYER1IEEE8023X._serialized_start=5213
  _LAYER1IEEE8023X._serialized_end=5230
  _LAYER1IEEE8021QBB._serialized_start=5233
  _LAYER1IEEE8021QBB._serialized_end=5626
  _CAPTURE._serialized_start=5629
  _CAPTURE._serialized_end=5904
  _CAPTURE_FORMAT._serialized_start=5808
  _CAPTURE_FORMAT._serialized_end=5863
  _CAPTURE_FORMAT_ENUM._serialized_start=5818
  _CAPTURE_FORMAT_ENUM._serialized_end=5863
  _CAPTUREFILTER._serialized_start=5907
  _CAPTUREFILTER._serialized_end=6325
  _CAPTUREFILTER_CHOICE._serialized_start=6174
  _CAPTUREFILTER_CHOICE._serialized_end=6263
  _CAPTUREFILTER_CHOICE_ENUM._serialized_start=6184
  _CAPTUREFILTER_CHOICE_ENUM._serialized_end=6263
  _CAPTURECUSTOM._serialized_start=6328
  _CAPTURECUSTOM._serialized_end=6505
  _CAPTUREFIELD._serialized_start=6507
  _CAPTUREFIELD._serialized_end=6611
  _CAPTUREETHERNET._serialized_start=6614
  _CAPTUREETHERNET._serialized_end=6837
  _CAPTUREVLAN._serialized_start=6840
  _CAPTUREVLAN._serialized_end=7051
  _CAPTUREIPV4._serialized_start=7054
  _CAPTUREIPV4._serialized_end=7903
  _CAPTUREIPV6._serialized_start=7906
  _CAPTUREIPV6._serialized_end=8371
  _DEVICE._serialized_start=8374
  _DEVICE._serialized_end=8726
  _PROTOCOLOPTIONS._serialized_start=8728
  _PROTOCOLOPTIONS._serialized_end=8793
  _DEVICEISISROUTER._serialized_start=8796
  _DEVICEISISROUTER._serialized_end=9205
  _DEVICEISISMULTIINSTANCE._serialized_start=9207
  _DEVICEISISMULTIINSTANCE._serialized_end=9273
  _ISISINTERFACE._serialized_start=9276
  _ISISINTERFACE._serialized_end=10138
  _ISISINTERFACE_NETWORKTYPE._serialized_start=9859
  _ISISINTERFACE_NETWORKTYPE._serialized_end=9932
  _ISISINTERFACE_NETWORKTYPE_ENUM._serialized_start=9874
  _ISISINTERFACE_NETWORKTYPE_ENUM._serialized_end=9932
  _ISISINTERFACE_LEVELTYPE._serialized_start=9934
  _ISISINTERFACE_LEVELTYPE._serialized_end=10011
  _ISISINTERFACE_LEVELTYPE_ENUM._serialized_start=9947
  _ISISINTERFACE_LEVELTYPE_ENUM._serialized_end=10011
  _ISISINTERFACELEVEL._serialized_start=10141
  _ISISINTERFACELEVEL._serialized_end=10291
  _ISISMT._serialized_start=10293
  _ISISMT._serialized_end=10373
  _LINKSTATETE._serialized_start=10376
  _LINKSTATETE._serialized_end=10697
  _LINKSTATEPRIORITYBANDWIDTHS._serialized_start=10700
  _LINKSTATEPRIORITYBANDWIDTHS._serialized_end=10937
  _ISISINTERFACEAUTHENTICATION._serialized_start=10940
  _ISISINTERFACEAUTHENTICATION._serialized_end=11158
  _ISISINTERFACEAUTHENTICATION_AUTHTYPE._serialized_start=11079
  _ISISINTERFACEAUTHENTICATION_AUTHTYPE._serialized_end=11137
  _ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM._serialized_start=11091
  _ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM._serialized_end=11137
  _ISISINTERFACEADVANCED._serialized_start=11161
  _ISISINTERFACEADVANCED._serialized_end=11500
  _ISISINTERFACELINKPROTECTION._serialized_start=11503
  _ISISINTERFACELINKPROTECTION._serialized_end=11880
  _ISISBASIC._serialized_start=11883
  _ISISBASIC._serialized_end=12096
  _ISISADVANCED._serialized_start=12099
  _ISISADVANCED._serialized_end=12621
  _ISISAUTHENTICATION._serialized_start=12624
  _ISISAUTHENTICATION._serialized_end=12838
  _ISISAUTHENTICATIONBASE._serialized_start=12841
  _ISISAUTHENTICATIONBASE._serialized_end=13049
  _ISISAUTHENTICATIONBASE_AUTHTYPE._serialized_start=11079
  _ISISAUTHENTICATIONBASE_AUTHTYPE._serialized_end=11137
  _ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM._serialized_start=11091
  _ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM._serialized_end=11137
  _ISISV4ROUTERANGE._serialized_start=13052
  _ISISV4ROUTERANGE._serialized_end=13638
  _ISISV4ROUTERANGE_ORIGINTYPE._serialized_start=13395
  _ISISV4ROUTERANGE_ORIGINTYPE._serialized_end=13460
  _ISISV4ROUTERANGE_ORIGINTYPE_ENUM._serialized_start=13409
  _ISISV4ROUTERANGE_ORIGINTYPE_ENUM._serialized_end=13460
  _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE._serialized_start=13462
  _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE._serialized_end=13525
  _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM._serialized_start=13484
  _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM._serialized_end=13525
  _V4ROUTEADDRESS._serialized_start=13640
  _V4ROUTEADDRESS._serialized_end=13763
  _V6ROUTEADDRESS._serialized_start=13765
  _V6ROUTEADDRESS._serialized_end=13888
  _MACROUTEADDRESS._serialized_start=13890
  _MACROUTEADDRESS._serialized_end=14014
  _ISISV6ROUTERANGE._serialized_start=14017
  _ISISV6ROUTERANGE._serialized_end=14603
  _ISISV6ROUTERANGE_ORIGINTYPE._serialized_start=13395
  _ISISV6ROUTERANGE_ORIGINTYPE._serialized_end=13460
  _ISISV6ROUTERANGE_ORIGINTYPE_ENUM._serialized_start=13409
  _ISISV6ROUTERANGE_ORIGINTYPE_ENUM._serialized_end=13460
  _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE._serialized_start=13462
  _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE._serialized_end=13525
  _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM._serialized_start=13484
  _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM._serialized_end=13525
  _DEVICEBGPROUTER._serialized_start=14606
  _DEVICEBGPROUTER._serialized_end=14734
  _DEVICEBGPMESSAGEHEADERERROR._serialized_start=14737
  _DEVICEBGPMESSAGEHEADERERROR._serialized_end=15009
  _DEVICEBGPMESSAGEHEADERERROR_SUBCODE._serialized_start=14838
  _DEVICEBGPMESSAGEHEADERERROR_SUBCODE._serialized_end=14997
  _DEVICEBGPMESSAGEHEADERERROR_SUBCODE_ENUM._serialized_start=14850
  _DEVICEBGPMESSAGEHEADERERROR_SUBCODE_ENUM._serialized_end=14997
  _DEVICEBGPOPENMESSAGEERROR._serialized_start=15012
  _DEVICEBGPOPENMESSAGEERROR._serialized_end=15438
  _DEVICEBGPOPENMESSAGEERROR_SUBCODE._serialized_start=15109
  _DEVICEBGPOPENMESSAGEERROR_SUBCODE._serialized_end=15426
  _DEVICEBGPOPENMESSAGEERROR_SUBCODE_ENUM._serialized_start=15121
  _DEVICEBGPOPENMESSAGEERROR_SUBCODE_ENUM._serialized_end=15426
  _DEVICEBGPUPDATEMESSAGEERROR._serialized_start=15441
  _DEVICEBGPUPDATEMESSAGEERROR._serialized_end=16045
  _DEVICEBGPUPDATEMESSAGEERROR_SUBCODE._serialized_start=15542
  _DEVICEBGPUPDATEMESSAGEERROR_SUBCODE._serialized_end=16033
  _DEVICEBGPUPDATEMESSAGEERROR_SUBCODE_ENUM._serialized_start=15554
  _DEVICEBGPUPDATEMESSAGEERROR_SUBCODE_ENUM._serialized_end=16033
  _DEVICEBGPHOLDTIMEREXPIRED._serialized_start=16047
  _DEVICEBGPHOLDTIMEREXPIRED._serialized_end=16074
  _DEVICEBGPFINITESTATEMACHINEERROR._serialized_start=16076
  _DEVICEBGPFINITESTATEMACHINEERROR._serialized_end=16110
  _DEVICEBGPCEASEERROR._serialized_start=16113
  _DEVICEBGPCEASEERROR._serialized_end=16596
  _DEVICEBGPCEASEERROR_SUBCODE._serialized_start=16198
  _DEVICEBGPCEASEERROR_SUBCODE._serialized_end=16584
  _DEVICEBGPCEASEERROR_SUBCODE_ENUM._serialized_start=16210
  _DEVICEBGPCEASEERROR_SUBCODE_ENUM._serialized_end=16584
  _DEVICEBGPCUSTOMERROR._serialized_start=16598
  _DEVICEBGPCUSTOMERROR._serialized_end=16682
  _BGPV4PEER._serialized_start=16685
  _BGPV4PEER._serialized_end=17531
  _BGPV4PEER_ASTYPE._serialized_start=17317
  _BGPV4PEER_ASTYPE._serialized_end=17370
  _BGPV4PEER_ASTYPE_ENUM._serialized_start=17327
  _BGPV4PEER_ASTYPE_ENUM._serialized_end=17370
  _BGPV4PEER_ASNUMBERWIDTH._serialized_start=17372
  _BGPV4PEER_ASNUMBERWIDTH._serialized_end=17431
  _BGPV4PEER_ASNUMBERWIDTH_ENUM._serialized_start=17389
  _BGPV4PEER_ASNUMBERWIDTH_ENUM._serialized_end=17431
  _BGPV4INTERFACE._serialized_start=17533
  _BGPV4INTERFACE._serialized_end=17599
  _BGPV4ETHERNETSEGMENT._serialized_start=17602
  _BGPV4ETHERNETSEGMENT._serialized_end=18154
  _BGPV4ETHERNETSEGMENT_ACTIVEMODE._serialized_start=18003
  _BGPV4ETHERNETSEGMENT_ACTIVEMODE._serialized_end=18075
  _BGPV4ETHERNETSEGMENT_ACTIVEMODE_ENUM._serialized_start=18017
  _BGPV4ETHERNETSEGMENT_ACTIVEMODE_ENUM._serialized_end=18075
  _BGPETHERNETSEGMENTDFELECTION._serialized_start=18156
  _BGPETHERNETSEGMENTDFELECTION._serialized_end=18234
  _BGPROUTEADVANCED._serialized_start=18237
  _BGPROUTEADVANCED._serialized_end=18711
  _BGPROUTEADVANCED_ORIGIN._serialized_start=18498
  _BGPROUTEADVANCED_ORIGIN._serialized_end=18565
  _BGPROUTEADVANCED_ORIGIN_ENUM._serialized_start=18508
  _BGPROUTEADVANCED_ORIGIN_ENUM._serialized_end=18565
  _BGPCOMMUNITY._serialized_start=18714
  _BGPCOMMUNITY._serialized_end=19006
  _BGPCOMMUNITY_TYPE._serialized_start=18827
  _BGPCOMMUNITY_TYPE._serialized_end=18969
  _BGPCOMMUNITY_TYPE_ENUM._serialized_start=18836
  _BGPCOMMUNITY_TYPE_ENUM._serialized_end=18969
  _BGPEXTCOMMUNITY._serialized_start=19009
  _BGPEXTCOMMUNITY._serialized_end=19514
  _BGPEXTCOMMUNITY_TYPE._serialized_start=19157
  _BGPEXTCOMMUNITY_TYPE._serialized_end=19345
  _BGPEXTCOMMUNITY_TYPE_ENUM._serialized_start=19166
  _BGPEXTCOMMUNITY_TYPE_ENUM._serialized_end=19345
  _BGPEXTCOMMUNITY_SUBTYPE._serialized_start=19348
  _BGPEXTCOMMUNITY_SUBTYPE._serialized_end=19483
  _BGPEXTCOMMUNITY_SUBTYPE_ENUM._serialized_start=19359
  _BGPEXTCOMMUNITY_SUBTYPE_ENUM._serialized_end=19483
  _BGPASPATH._serialized_start=19517
  _BGPASPATH._serialized_end=19835
  _BGPASPATH_ASSETMODE._serialized_start=19629
  _BGPASPATH_ASSETMODE._serialized_end=19819
  _BGPASPATH_ASSETMODE_ENUM._serialized_start=19643
  _BGPASPATH_ASSETMODE_ENUM._serialized_end=19819
  _BGPASPATHSEGMENT._serialized_start=19838
  _BGPASPATHSEGMENT._serialized_end=20032
  _BGPASPATHSEGMENT_TYPE._serialized_start=19930
  _BGPASPATHSEGMENT_TYPE._serialized_end=20023
  _BGPASPATHSEGMENT_TYPE_ENUM._serialized_start=19938
  _BGPASPATHSEGMENT_TYPE_ENUM._serialized_end=20023
  _BGPV4EVPNEVIS._serialized_start=20035
  _BGPV4EVPNEVIS._serialized_end=20222
  _BGPV4EVPNEVIS_CHOICE._serialized_start=20149
  _BGPV4EVPNEVIS_CHOICE._serialized_end=20197
  _BGPV4EVPNEVIS_CHOICE_ENUM._serialized_start=20159
  _BGPV4EVPNEVIS_CHOICE_ENUM._serialized_end=20197
  _BGPV4EVIVXLAN._serialized_start=20225
  _BGPV4EVIVXLAN._serialized_end=21028
  _BGPV4EVIVXLAN_REPLICATIONTYPE._serialized_start=20863
  _BGPV4EVIVXLAN_REPLICATIONTYPE._serialized_end=20930
  _BGPV4EVIVXLAN_REPLICATIONTYPE_ENUM._serialized_start=20882
  _BGPV4EVIVXLAN_REPLICATIONTYPE_ENUM._serialized_end=20930
  _BGPV4EVIVXLANBROADCASTDOMAIN._serialized_start=21031
  _BGPV4EVIVXLANBROADCASTDOMAIN._serialized_end=21211
  _BGPCMACIPRANGE._serialized_start=21214
  _BGPCMACIPRANGE._serialized_end=21772
  _BGPROUTEDISTINGUISHER._serialized_start=21775
  _BGPROUTEDISTINGUISHER._serialized_end=22055
  _BGPROUTEDISTINGUISHER_RDTYPE._serialized_start=21922
  _BGPROUTEDISTINGUISHER_RDTYPE._serialized_end=22003
  _BGPROUTEDISTINGUISHER_RDTYPE_ENUM._serialized_start=21932
  _BGPROUTEDISTINGUISHER_RDTYPE_ENUM._serialized_end=22003
  _BGPROUTETARGET._serialized_start=22058
  _BGPROUTETARGET._serialized_end=22260
  _BGPROUTETARGET_RTTYPE._serialized_start=22154
  _BGPROUTETARGET_RTTYPE._serialized_end=22235
  _BGPROUTETARGET_RTTYPE_ENUM._serialized_start=21932
  _BGPROUTETARGET_RTTYPE_ENUM._serialized_end=22003
  _BGPADVANCED._serialized_start=22263
  _BGPADVANCED._serialized_end=22518
  _BGPCAPABILITY._serialized_start=22521
  _BGPCAPABILITY._serialized_end=23818
  _BGPLEARNEDINFORMATIONFILTER._serialized_start=23821
  _BGPLEARNEDINFORMATIONFILTER._serialized_end=23966
  _BGPV4ROUTERANGE._serialized_start=23969
  _BGPV4ROUTERANGE._serialized_end=24739
  _BGPV4ROUTERANGE_NEXTHOPMODE._serialized_start=24474
  _BGPV4ROUTERANGE_NEXTHOPMODE._serialized_end=24538
  _BGPV4ROUTERANGE_NEXTHOPMODE_ENUM._serialized_start=24489
  _BGPV4ROUTERANGE_NEXTHOPMODE_ENUM._serialized_end=24538
  _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE._serialized_start=24540
  _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE._serialized_end=24605
  _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM._serialized_start=24562
  _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM._serialized_end=24605
  _BGPADDPATH._serialized_start=24741
  _BGPADDPATH._serialized_end=24787
  _BGPV6ROUTERANGE._serialized_start=24790
  _BGPV6ROUTERANGE._serialized_end=25560
  _BGPV6ROUTERANGE_NEXTHOPMODE._serialized_start=24474
  _BGPV6ROUTERANGE_NEXTHOPMODE._serialized_end=24538
  _BGPV6ROUTERANGE_NEXTHOPMODE_ENUM._serialized_start=24489
  _BGPV6ROUTERANGE_NEXTHOPMODE_ENUM._serialized_end=24538
  _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE._serialized_start=24540
  _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE._serialized_end=24605
  _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM._serialized_start=24562
  _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM._serialized_end=24605
  _BGPSRTEV4POLICY._serialized_start=25563
  _BGPSRTEV4POLICY._serialized_end=26470
  _BGPSRTEV4POLICY_NEXTHOPMODE._serialized_start=24474
  _BGPSRTEV4POLICY_NEXTHOPMODE._serialized_end=24538
  _BGPSRTEV4POLICY_NEXTHOPMODE_ENUM._serialized_start=24489
  _BGPSRTEV4POLICY_NEXTHOPMODE_ENUM._serialized_end=24538
  _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE._serialized_start=24540
  _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE._serialized_end=24605
  _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM._serialized_start=24562
  _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM._serialized_end=24605
  _BGPSRTEV4TUNNELTLV._serialized_start=26473
  _BGPSRTEV4TUNNELTLV._serialized_end=27240
  _BGPSRTEREMOTEENDPOINTSUBTLV._serialized_start=27243
  _BGPSRTEREMOTEENDPOINTSUBTLV._serialized_end=27561
  _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY._serialized_start=27434
  _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY._serialized_end=27494
  _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM._serialized_start=24562
  _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM._serialized_end=24605
  _BGPSRTECOLORSUBTLV._serialized_start=27563
  _BGPSRTECOLORSUBTLV._serialized_end=27613
  _BGPSRTEBINDINGSUBTLV._serialized_start=27616
  _BGPSRTEBINDINGSUBTLV._serialized_end=27978
  _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE._serialized_start=27812
  _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE._serialized_end=27903
  _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM._serialized_start=27830
  _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM._serialized_end=27903
  _BGPSRTEPREFERENCESUBTLV._serialized_start=27980
  _BGPSRTEPREFERENCESUBTLV._serialized_end=28045
  _BGPSRTEPOLICYPRIORITYSUBTLV._serialized_start=28047
  _BGPSRTEPOLICYPRIORITYSUBTLV._serialized_end=28126
  _BGPSRTEPOLICYNAMESUBTLV._serialized_start=28128
  _BGPSRTEPOLICYNAMESUBTLV._serialized_end=28195
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV._serialized_start=28198
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV._serialized_end=28540
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY._serialized_start=28352
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY._serialized_end=28509
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM._serialized_start=28380
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM._serialized_end=28509
  _BGPSRTESEGMENTLIST._serialized_start=28543
  _BGPSRTESEGMENTLIST._serialized_end=28680
  _BGPSRTESEGMENT._serialized_start=28683
  _BGPSRTESEGMENT._serialized_end=29683
  _BGPSRTESEGMENT_SEGMENTTYPE._serialized_start=29380
  _BGPSRTESEGMENT_SEGMENTTYPE._serialized_end=29551
  _BGPSRTESEGMENT_SEGMENTTYPE_ENUM._serialized_start=29396
  _BGPSRTESEGMENT_SEGMENTTYPE_ENUM._serialized_end=29551
  _BGPSRTESRMPLSSID._serialized_start=29686
  _BGPSRTESRMPLSSID._serialized_end=29814
  _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE._serialized_start=29817
  _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE._serialized_end=30019
  _BGPSRTESEGMENTATYPESUBTLV._serialized_start=30022
  _BGPSRTESEGMENTATYPESUBTLV._serialized_end=30189
  _BGPSRTESEGMENTBTYPESUBTLV._serialized_start=30192
  _BGPSRTESEGMENTBTYPESUBTLV._serialized_end=30388
  _BGPSRTESEGMENTCTYPESUBTLV._serialized_start=30391
  _BGPSRTESEGMENTCTYPESUBTLV._serialized_end=30584
  _BGPSRTESEGMENTDTYPESUBTLV._serialized_start=30587
  _BGPSRTESEGMENTDTYPESUBTLV._serialized_end=30780
  _BGPSRTESEGMENTETYPESUBTLV._serialized_start=30783
  _BGPSRTESEGMENTETYPESUBTLV._serialized_end=30988
  _BGPSRTESEGMENTFTYPESUBTLV._serialized_start=30991
  _BGPSRTESEGMENTFTYPESUBTLV._serialized_end=31170
  _BGPSRTESEGMENTGTYPESUBTLV._serialized_start=31173
  _BGPSRTESEGMENTGTYPESUBTLV._serialized_end=31476
  _BGPSRTESEGMENTHTYPESUBTLV._serialized_start=31479
  _BGPSRTESEGMENTHTYPESUBTLV._serialized_end=31658
  _BGPSRTESEGMENTITYPESUBTLV._serialized_start=31661
  _BGPSRTESEGMENTITYPESUBTLV._serialized_end=31902
  _BGPSRTESEGMENTJTYPESUBTLV._serialized_start=31905
  _BGPSRTESEGMENTJTYPESUBTLV._serialized_end=32344
  _BGPSRTESEGMENTKTYPESUBTLV._serialized_start=32347
  _BGPSRTESEGMENTKTYPESUBTLV._serialized_end=32662
  _BGPSRTEV6POLICY._serialized_start=32665
  _BGPSRTEV6POLICY._serialized_end=33571
  _BGPSRTEV6POLICY_NEXTHOPMODE._serialized_start=24474
  _BGPSRTEV6POLICY_NEXTHOPMODE._serialized_end=24538
  _BGPSRTEV6POLICY_NEXTHOPMODE_ENUM._serialized_start=24489
  _BGPSRTEV6POLICY_NEXTHOPMODE_ENUM._serialized_end=24538
  _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE._serialized_start=24540
  _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE._serialized_end=24605
  _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM._serialized_start=24562
  _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM._serialized_end=24605
  _BGPSRTEV6TUNNELTLV._serialized_start=33574
  _BGPSRTEV6TUNNELTLV._serialized_end=34341
  _BGPGRACEFULRESTART._serialized_start=34344
  _BGPGRACEFULRESTART._serialized_end=34528
  _BGPV6PEER._serialized_start=34531
  _BGPV6PEER._serialized_end=35453
  _BGPV6PEER_ASTYPE._serialized_start=17317
  _BGPV6PEER_ASTYPE._serialized_end=17370
  _BGPV6PEER_ASTYPE_ENUM._serialized_start=17327
  _BGPV6PEER_ASTYPE_ENUM._serialized_end=17370
  _BGPV6PEER_ASNUMBERWIDTH._serialized_start=17372
  _BGPV6PEER_ASNUMBERWIDTH._serialized_end=17431
  _BGPV6PEER_ASNUMBERWIDTH_ENUM._serialized_start=17389
  _BGPV6PEER_ASNUMBERWIDTH_ENUM._serialized_end=17431
  _BGPV6INTERFACE._serialized_start=35455
  _BGPV6INTERFACE._serialized_end=35521
  _BGPV6SEGMENTROUTING._serialized_start=35524
  _BGPV6SEGMENTROUTING._serialized_end=36021
  _BGPV6ETHERNETSEGMENT._serialized_start=36024
  _BGPV6ETHERNETSEGMENT._serialized_end=36576
  _BGPV6ETHERNETSEGMENT_ACTIVEMODE._serialized_start=18003
  _BGPV6ETHERNETSEGMENT_ACTIVEMODE._serialized_end=18075
  _BGPV6ETHERNETSEGMENT_ACTIVEMODE_ENUM._serialized_start=18017
  _BGPV6ETHERNETSEGMENT_ACTIVEMODE_ENUM._serialized_end=18075
  _BGPV6EVPNEVIS._serialized_start=36579
  _BGPV6EVPNEVIS._serialized_end=36766
  _BGPV6EVPNEVIS_CHOICE._serialized_start=20149
  _BGPV6EVPNEVIS_CHOICE._serialized_end=20197
  _BGPV6EVPNEVIS_CHOICE_ENUM._serialized_start=20159
  _BGPV6EVPNEVIS_CHOICE_ENUM._serialized_end=20197
  _BGPV6EVIVXLAN._serialized_start=36769
  _BGPV6EVIVXLAN._serialized_end=37572
  _BGPV6EVIVXLAN_REPLICATIONTYPE._serialized_start=20863
  _BGPV6EVIVXLAN_REPLICATIONTYPE._serialized_end=20930
  _BGPV6EVIVXLAN_REPLICATIONTYPE_ENUM._serialized_start=20882
  _BGPV6EVIVXLAN_REPLICATIONTYPE_ENUM._serialized_end=20930
  _BGPV6EVIVXLANBROADCASTDOMAIN._serialized_start=37575
  _BGPV6EVIVXLANBROADCASTDOMAIN._serialized_end=37755
  _DEVICEVXLAN._serialized_start=37757
  _DEVICEVXLAN._serialized_end=37850
  _VXLANV4TUNNEL._serialized_start=37853
  _VXLANV4TUNNEL._serialized_end=38016
  _VXLANV6TUNNEL._serialized_start=38019
  _VXLANV6TUNNEL._serialized_end=38182
  _VXLANV4TUNNELDESTINATIONIPMODE._serialized_start=38185
  _VXLANV4TUNNELDESTINATIONIPMODE._serialized_end=38523
  _VXLANV4TUNNELDESTINATIONIPMODE_CHOICE._serialized_start=38425
  _VXLANV4TUNNELDESTINATIONIPMODE_CHOICE._serialized_end=38486
  _VXLANV4TUNNELDESTINATIONIPMODE_CHOICE_ENUM._serialized_start=38435
  _VXLANV4TUNNELDESTINATIONIPMODE_CHOICE_ENUM._serialized_end=38486
  _VXLANV6TUNNELDESTINATIONIPMODE._serialized_start=38526
  _VXLANV6TUNNELDESTINATIONIPMODE._serialized_end=38864
  _VXLANV6TUNNELDESTINATIONIPMODE_CHOICE._serialized_start=38425
  _VXLANV6TUNNELDESTINATIONIPMODE_CHOICE._serialized_end=38486
  _VXLANV6TUNNELDESTINATIONIPMODE_CHOICE_ENUM._serialized_start=38435
  _VXLANV6TUNNELDESTINATIONIPMODE_CHOICE_ENUM._serialized_end=38486
  _VXLANV4TUNNELDESTINATIONIPMODEUNICAST._serialized_start=38866
  _VXLANV4TUNNELDESTINATIONIPMODEUNICAST._serialized_end=38968
  _VXLANV6TUNNELDESTINATIONIPMODEUNICAST._serialized_start=38970
  _VXLANV6TUNNELDESTINATIONIPMODEUNICAST._serialized_end=39072
  _VXLANTUNNELDESTINATIONIPMODEUNICASTARPSUPPRESSIONCACHE._serialized_start=39075
  _VXLANTUNNELDESTINATIONIPMODEUNICASTARPSUPPRESSIONCACHE._serialized_end=39225
  _VXLANV4TUNNELDESTINATIONIPMODEUNICASTVTEP._serialized_start=39228
  _VXLANV4TUNNELDESTINATIONIPMODEUNICASTVTEP._serialized_end=39421
  _VXLANV6TUNNELDESTINATIONIPMODEUNICASTVTEP._serialized_start=39424
  _VXLANV6TUNNELDESTINATIONIPMODEUNICASTVTEP._serialized_end=39617
  _VXLANV4TUNNELDESTINATIONIPMODEMULTICAST._serialized_start=39619
  _VXLANV4TUNNELDESTINATIONIPMODEMULTICAST._serialized_end=39694
  _VXLANV6TUNNELDESTINATIONIPMODEMULTICAST._serialized_start=39696
  _VXLANV6TUNNELDESTINATIONIPMODEMULTICAST._serialized_end=39771
  _DEVICERSVP._serialized_start=39774
  _DEVICERSVP._serialized_end=39919
  _RSVPIPV4INTERFACE._serialized_start=39922
  _RSVPIPV4INTERFACE._serialized_end=40463
  _RSVPLSPIPV4INTERFACE._serialized_start=40466
  _RSVPLSPIPV4INTERFACE._serialized_end=40685
  _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP._serialized_start=40688
  _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP._serialized_end=41171
  _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE._serialized_start=40968
  _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE._serialized_end=41060
  _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE_ENUM._serialized_start=40988
  _RSVPLSPIPV4INTERFACEP2PEGRESSIPV4LSP_RESERVATIONSTYLE_ENUM._serialized_end=41060
  _RSVPLSPIPV4INTERFACEP2PINGRESSIPV4LSP._serialized_start=41174
  _RSVPLSPIPV4INTERFACEP2PINGRESSIPV4LSP._serialized_end=41768
  _RSVPSESSIONATTRIBUTE._serialized_start=41771
  _RSVPSESSIONATTRIBUTE._serialized_end=42424
  _RSVPRESOURCEAFFINITIES._serialized_start=42427
  _RSVPRESOURCEAFFINITIES._serialized_end=42577
  _RSVPTSPEC._serialized_start=42580
  _RSVPTSPEC._serialized_end=42867
  _RSVPFASTREROUTE._serialized_start=42870
  _RSVPFASTREROUTE._serialized_end=43325
  _RSVPERO._serialized_start=43328
  _RSVPERO._serialized_end=43624
  _RSVPERO_PREPENDNEIGHBORIP._serialized_start=43481
  _RSVPERO_PREPENDNEIGHBORIP._serialized_end=43582
  _RSVPERO_PREPENDNEIGHBORIP_ENUM._serialized_start=43502
  _RSVPERO_PREPENDNEIGHBORIP_ENUM._serialized_end=43582
  _RSVPEROSUBOBJECT._serialized_start=43627
  _RSVPEROSUBOBJECT._serialized_end=44023
  _RSVPEROSUBOBJECT_TYPE._serialized_start=43837
  _RSVPEROSUBOBJECT_TYPE._serialized_end=43893
  _RSVPEROSUBOBJECT_TYPE_ENUM._serialized_start=43845
  _RSVPEROSUBOBJECT_TYPE_ENUM._serialized_end=43893
  _RSVPEROSUBOBJECT_HOPTYPE._serialized_start=43895
  _RSVPEROSUBOBJECT_HOPTYPE._serialized_end=43952
  _RSVPEROSUBOBJECT_HOPTYPE_ENUM._serialized_start=43906
  _RSVPEROSUBOBJECT_HOPTYPE_ENUM._serialized_end=43952
  _FLOW._serialized_start=44026
  _FLOW._serialized_end=44342
  _FLOWTXRX._serialized_start=44345
  _FLOWTXRX._serialized_end=44563
  _FLOWTXRX_CHOICE._serialized_start=44477
  _FLOWTXRX_CHOICE._serialized_end=44532
  _FLOWTXRX_CHOICE_ENUM._serialized_start=44487
  _FLOWTXRX_CHOICE_ENUM._serialized_end=44532
  _FLOWPORT._serialized_start=44565
  _FLOWPORT._serialized_end=44644
  _FLOWROUTER._serialized_start=44647
  _FLOWROUTER._serialized_end=44809
  _FLOWROUTER_MODE._serialized_start=44743
  _FLOWROUTER_MODE._serialized_end=44800
  _FLOWROUTER_MODE_ENUM._serialized_start=44751
  _FLOWROUTER_MODE_ENUM._serialized_end=44800
  _FLOWHEADER._serialized_start=44812
  _FLOWHEADER._serialized_end=46013
  _FLOWHEADER_CHOICE._serialized_start=45565
  _FLOWHEADER_CHOICE._serialized_end=45810
  _FLOWHEADER_CHOICE_ENUM._serialized_start=45576
  _FLOWHEADER_CHOICE_ENUM._serialized_end=45810
  _FLOWCUSTOM._serialized_start=46015
  _FLOWCUSTOM._serialized_end=46089
  _FLOWCUSTOMMETRICTAG._serialized_start=46091
  _FLOWCUSTOMMETRICTAG._serialized_end=46190
  _FLOWETHERNET._serialized_start=46193
  _FLOWETHERNET._serialized_end=46464
  _FLOWVLAN._serialized_start=46467
  _FLOWVLAN._serialized_end=46696
  _FLOWVXLAN._serialized_start=46699
  _FLOWVXLAN._serialized_end=46960
  _FLOWIPV4._serialized_start=46963
  _FLOWIPV4._serialized_end=47981
  _FLOWIPV4PRIORITY._serialized_start=47984
  _FLOWIPV4PRIORITY._serialized_end=48282
  _FLOWIPV4PRIORITY_CHOICE._serialized_start=48185
  _FLOWIPV4PRIORITY_CHOICE._serialized_end=48246
  _FLOWIPV4PRIORITY_CHOICE_ENUM._serialized_start=48195
  _FLOWIPV4PRIORITY_CHOICE_ENUM._serialized_end=48246
  _FLOWIPV4DSCP._serialized_start=48284
  _FLOWIPV4DSCP._serialized_end=48408
  _FLOWIPV4TOS._serialized_start=48411
  _FLOWIPV4TOS._serialized_end=48844
  _FLOWIPV6._serialized_start=48847
  _FLOWIPV6._serialized_end=49398
  _FLOWPFCPAUSE._serialized_start=49401
  _FLOWPFCPAUSE._serialized_end=50454
  _FLOWETHERNETPAUSE._serialized_start=50457
  _FLOWETHERNETPAUSE._serialized_end=50833
  _FLOWTCP._serialized_start=50836
  _FLOWTCP._serialized_end=51776
  _FLOWUDP._serialized_start=51779
  _FLOWUDP._serialized_end=52040
  _FLOWGRE._serialized_start=52043
  _FLOWGRE._serialized_end=52468
  _FLOWGTPV1._serialized_start=52471
  _FLOWGTPV1._serialized_end=53423
  _FLOWGTPEXTENSION._serialized_start=53426
  _FLOWGTPEXTENSION._serialized_end=53726
  _FLOWGTPV2._serialized_start=53729
  _FLOWGTPV2._serialized_end=54392
  _FLOWARP._serialized_start=54395
  _FLOWARP._serialized_end=55196
  _FLOWICMP._serialized_start=55199
  _FLOWICMP._serialized_end=55360
  _FLOWICMP_CHOICE._serialized_start=55297
  _FLOWICMP_CHOICE._serialized_end=55340
  _FLOWICMP_CHOICE_ENUM._serialized_start=55307
  _FLOWICMP_CHOICE_ENUM._serialized_end=55340
  _FLOWICMPECHO._serialized_start=55363
  _FLOWICMPECHO._serialized_end=55729
  _FLOWICMPV6._serialized_start=55732
  _FLOWICMPV6._serialized_end=55899
  _FLOWICMPV6_CHOICE._serialized_start=55297
  _FLOWICMPV6_CHOICE._serialized_end=55340
  _FLOWICMPV6_CHOICE_ENUM._serialized_start=55307
  _FLOWICMPV6_CHOICE_ENUM._serialized_end=55340
  _FLOWICMPV6ECHO._serialized_start=55902
  _FLOWICMPV6ECHO._serialized_end=56280
  _FLOWPPP._serialized_start=56283
  _FLOWPPP._serialized_end=56495
  _FLOWIGMPV1._serialized_start=56498
  _FLOWIGMPV1._serialized_end=56843
  _FLOWMPLS._serialized_start=56846
  _FLOWMPLS._serialized_end=57154
  _FLOWSIZE._serialized_start=57157
  _FLOWSIZE._serialized_end=57532
  _FLOWSIZE_CHOICE._serialized_start=57380
  _FLOWSIZE_CHOICE._serialized_end=57469
  _FLOWSIZE_CHOICE_ENUM._serialized_start=57390
  _FLOWSIZE_CHOICE_ENUM._serialized_end=57469
  _FLOWSIZEINCREMENT._serialized_start=57534
  _FLOWSIZEINCREMENT._serialized_end=57637
  _FLOWSIZERANDOM._serialized_start=57639
  _FLOWSIZERANDOM._serialized_end=57707
  _FLOWSIZEWEIGHTPAIRS._serialized_start=57710
  _FLOWSIZEWEIGHTPAIRS._serialized_end=58107
  _FLOWSIZEWEIGHTPAIRS_CHOICE._serialized_start=57907
  _FLOWSIZEWEIGHTPAIRS_CHOICE._serialized_end=57968
  _FLOWSIZEWEIGHTPAIRS_CHOICE_ENUM._serialized_start=57917
  _FLOWSIZEWEIGHTPAIRS_CHOICE_ENUM._serialized_end=57968
  _FLOWSIZEWEIGHTPAIRS_PREDEFINED._serialized_start=57970
  _FLOWSIZEWEIGHTPAIRS_PREDEFINED._serialized_end=58081
  _FLOWSIZEWEIGHTPAIRS_PREDEFINED_ENUM._serialized_start=57984
  _FLOWSIZEWEIGHTPAIRS_PREDEFINED_ENUM._serialized_end=58081
  _FLOWSIZEWEIGHTPAIRSCUSTOM._serialized_start=58109
  _FLOWSIZEWEIGHTPAIRSCUSTOM._serialized_end=58196
  _FLOWRATE._serialized_start=58199
  _FLOWRATE._serialized_end=58543
  _FLOWRATE_CHOICE._serialized_start=58377
  _FLOWRATE_CHOICE._serialized_end=58474
  _FLOWRATE_CHOICE_ENUM._serialized_start=58387
  _FLOWRATE_CHOICE_ENUM._serialized_end=58474
  _FLOWDURATION._serialized_start=58546
  _FLOWDURATION._serialized_end=58968
  _FLOWDURATION_CHOICE._serialized_start=58798
  _FLOWDURATION_CHOICE._serialized_end=58896
  _FLOWDURATION_CHOICE_ENUM._serialized_start=58808
  _FLOWDURATION_CHOICE_ENUM._serialized_end=58896
  _FLOWCONTINUOUS._serialized_start=58970
  _FLOWCONTINUOUS._serialized_end=59058
  _FLOWDELAY._serialized_start=59061
  _FLOWDELAY._serialized_end=59329
  _FLOWDELAY_CHOICE._serialized_start=59196
  _FLOWDELAY_CHOICE._serialized_end=59275
  _FLOWDELAY_CHOICE_ENUM._serialized_start=59206
  _FLOWDELAY_CHOICE_ENUM._serialized_end=59275
  _FLOWFIXEDPACKETS._serialized_start=59331
  _FLOWFIXEDPACKETS._serialized_end=59455
  _FLOWFIXEDSECONDS._serialized_start=59457
  _FLOWFIXEDSECONDS._serialized_end=59581
  _FLOWBURST._serialized_start=59584
  _FLOWBURST._serialized_end=59769
  _FLOWDURATIONINTERBURSTGAP._serialized_start=59772
  _FLOWDURATIONINTERBURSTGAP._serialized_end=60072
  _FLOWDURATIONINTERBURSTGAP_CHOICE._serialized_start=59196
  _FLOWDURATIONINTERBURSTGAP_CHOICE._serialized_end=59275
  _FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM._serialized_start=59206
  _FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM._serialized_end=59275
  _FLOWMETRICS._serialized_start=60075
  _FLOWMETRICS._serialized_end=60398
  _FLOWLATENCYMETRICS._serialized_start=60401
  _FLOWLATENCYMETRICS._serialized_end=60585
  _FLOWLATENCYMETRICS_MODE._serialized_start=60498
  _FLOWLATENCYMETRICS_MODE._serialized_end=60565
  _FLOWLATENCYMETRICS_MODE_ENUM._serialized_start=60506
  _FLOWLATENCYMETRICS_MODE_ENUM._serialized_end=60565
  _FLOWPREDEFINEDTAGS._serialized_start=60587
  _FLOWPREDEFINEDTAGS._serialized_end=60641
  _FLOWRXTXRATIO._serialized_start=60644
  _FLOWRXTXRATIO._serialized_end=60876
  _FLOWRXTXRATIO_CHOICE._serialized_start=60784
  _FLOWRXTXRATIO_CHOICE._serialized_end=60842
  _FLOWRXTXRATIO_CHOICE_ENUM._serialized_start=60794
  _FLOWRXTXRATIO_CHOICE_ENUM._serialized_end=60842
  _FLOWRXTXRATIORXCOUNT._serialized_start=60878
  _FLOWRXTXRATIORXCOUNT._serialized_end=60900
  _EVENT._serialized_start=60903
  _EVENT._serialized_end=61169
  _EVENTRXRATETHRESHOLD._serialized_start=61171
  _EVENTRXRATETHRESHOLD._serialized_end=61263
  _EVENTLINK._serialized_start=61265
  _EVENTLINK._serialized_end=61308
  _EVENTROUTEADVERTISEWITHDRAW._serialized_start=61310
  _EVENTROUTEADVERTISEWITHDRAW._serialized_end=61371
  _EVENTREQUEST._serialized_start=61374
  _EVENTREQUEST._serialized_end=61619
  _EVENTREQUEST_TYPE._serialized_start=61450
  _EVENTREQUEST_TYPE._serialized_end=61619
  _EVENTREQUEST_TYPE_ENUM._serialized_start=61459
  _EVENTREQUEST_TYPE_ENUM._serialized_end=61619
  _EVENTSUBSCRIPTION._serialized_start=61621
  _EVENTSUBSCRIPTION._serialized_end=61735
  _LLDP._serialized_start=61738
  _LLDP._serialized_end=62075
  _LLDPCONNECTION._serialized_start=62078
  _LLDPCONNECTION._serialized_end=62247
  _LLDPCONNECTION_CHOICE._serialized_start=62174
  _LLDPCONNECTION_CHOICE._serialized_end=62222
  _LLDPCONNECTION_CHOICE_ENUM._serialized_start=2358
  _LLDPCONNECTION_CHOICE_ENUM._serialized_end=2396
  _LLDPCHASSISID._serialized_start=62250
  _LLDPCHASSISID._serialized_end=62632
  _LLDPCHASSISID_CHOICE._serialized_start=62447
  _LLDPCHASSISID_CHOICE._serialized_end=62552
  _LLDPCHASSISID_CHOICE_ENUM._serialized_start=62457
  _LLDPCHASSISID_CHOICE_ENUM._serialized_end=62552
  _LLDPPORTID._serialized_start=62635
  _LLDPPORTID._serialized_end=63018
  _LLDPPORTID_CHOICE._serialized_start=62447
  _LLDPPORTID_CHOICE._serialized_end=62552
  _LLDPPORTID_CHOICE_ENUM._serialized_start=62457
  _LLDPPORTID_CHOICE_ENUM._serialized_end=62552
  _LLDPCHASSISMACSUBTYPE._serialized_start=63021
  _LLDPCHASSISMACSUBTYPE._serialized_end=63230
  _LLDPCHASSISMACSUBTYPE_CHOICE._serialized_start=3089
  _LLDPCHASSISMACSUBTYPE_CHOICE._serialized_end=3143
  _LLDPCHASSISMACSUBTYPE_CHOICE_ENUM._serialized_start=3099
  _LLDPCHASSISMACSUBTYPE_CHOICE_ENUM._serialized_end=3143
  _LLDPPORTINTERFACENAMESUBTYPE._serialized_start=63233
  _LLDPPORTINTERFACENAMESUBTYPE._serialized_end=63456
  _LLDPPORTINTERFACENAMESUBTYPE_CHOICE._serialized_start=3089
  _LLDPPORTINTERFACENAMESUBTYPE_CHOICE._serialized_end=3143
  _LLDPPORTINTERFACENAMESUBTYPE_CHOICE_ENUM._serialized_start=3099
  _LLDPPORTINTERFACENAMESUBTYPE_CHOICE_ENUM._serialized_end=3143
  _LLDPSYSTEMNAME._serialized_start=63459
  _LLDPSYSTEMNAME._serialized_end=63654
  _LLDPSYSTEMNAME_CHOICE._serialized_start=3089
  _LLDPSYSTEMNAME_CHOICE._serialized_end=3143
  _LLDPSYSTEMNAME_CHOICE_ENUM._serialized_start=3099
  _LLDPSYSTEMNAME_CHOICE_ENUM._serialized_end=3143
  _ERROR._serialized_start=63657
  _ERROR._serialized_end=63807
  _ERROR_KIND._serialized_start=63737
  _ERROR_KIND._serialized_end=63798
  _ERROR_KIND_ENUM._serialized_start=63745
  _ERROR_KIND_ENUM._serialized_end=63798
  _WARNING._serialized_start=63809
  _WARNING._serialized_end=63836
  _CONFIGUPDATE._serialized_start=63839
  _CONFIGUPDATE._serialized_end=64010
  _CONFIGUPDATE_CHOICE._serialized_start=63945
  _CONFIGUPDATE_CHOICE._serialized_end=63989
  _CONFIGUPDATE_CHOICE_ENUM._serialized_start=63955
  _CONFIGUPDATE_CHOICE_ENUM._serialized_end=63989
  _FLOWSUPDATE._serialized_start=64013
  _FLOWSUPDATE._serialized_end=64175
  _FLOWSUPDATE_PROPERTYNAMES._serialized_start=64115
  _FLOWSUPDATE_PROPERTYNAMES._serialized_end=64175
  _FLOWSUPDATE_PROPERTYNAMES_ENUM._serialized_start=64132
  _FLOWSUPDATE_PROPERTYNAMES_ENUM._serialized_end=64175
  _CONTROLSTATE._serialized_start=64178
  _CONTROLSTATE._serialized_end=64464
  _CONTROLSTATE_CHOICE._serialized_start=64360
  _CONTROLSTATE_CHOICE._serialized_end=64430
  _CONTROLSTATE_CHOICE_ENUM._serialized_start=64370
  _CONTROLSTATE_CHOICE_ENUM._serialized_end=64430
  _STATEPORT._serialized_start=64467
  _STATEPORT._serialized_end=64685
  _STATEPORT_CHOICE._serialized_start=64608
  _STATEPORT_CHOICE._serialized_end=64664
  _STATEPORT_CHOICE_ENUM._serialized_start=64618
  _STATEPORT_CHOICE_ENUM._serialized_end=64664
  _STATETRAFFIC._serialized_start=64688
  _STATETRAFFIC._serialized_end=64880
  _STATETRAFFIC_CHOICE._serialized_start=64810
  _STATETRAFFIC_CHOICE._serialized_end=64862
  _STATETRAFFIC_CHOICE_ENUM._serialized_start=64820
  _STATETRAFFIC_CHOICE_ENUM._serialized_end=64862
  _STATEPROTOCOL._serialized_start=64883
  _STATEPROTOCOL._serialized_end=65167
  _STATEPROTOCOL_CHOICE._serialized_start=65077
  _STATEPROTOCOL_CHOICE._serialized_end=65140
  _STATEPROTOCOL_CHOICE_ENUM._serialized_start=65087
  _STATEPROTOCOL_CHOICE_ENUM._serialized_end=65140
  _LINKSTATE._serialized_start=65169
  _LINKSTATE._serialized_end=65294
  _LINKSTATE_STATE._serialized_start=65244
  _LINKSTATE_STATE._serialized_end=65294
  _LINKSTATE_STATE_ENUM._serialized_start=13484
  _LINKSTATE_STATE_ENUM._serialized_end=13525
  _TRANSMITSTATE._serialized_start=65297
  _TRANSMITSTATE._serialized_end=65456
  _TRANSMITSTATE_STATE._serialized_start=65380
  _TRANSMITSTATE_STATE._serialized_end=65456
  _TRANSMITSTATE_STATE_ENUM._serialized_start=65389
  _TRANSMITSTATE_STATE_ENUM._serialized_end=65456
  _CAPTURESTATE._serialized_start=65459
  _CAPTURESTATE._serialized_end=65593
  _CAPTURESTATE_STATE._serialized_start=65540
  _CAPTURESTATE_STATE._serialized_end=65593
  _CAPTURESTATE_STATE_ENUM._serialized_start=65389
  _CAPTURESTATE_STATE_ENUM._serialized_end=65433
  _ROUTESTATE._serialized_start=65596
  _ROUTESTATE._serialized_end=65729
  _ROUTESTATE_STATE._serialized_start=65668
  _ROUTESTATE_STATE._serialized_end=65729
  _ROUTESTATE_STATE_ENUM._serialized_start=65677
  _ROUTESTATE_STATE_ENUM._serialized_end=65729
  _PROTOCOLSTATE._serialized_start=65731
  _PROTOCOLSTATE._serialized_end=65847
  _PROTOCOLSTATE_STATE._serialized_start=65540
  _PROTOCOLSTATE_STATE._serialized_end=65593
  _PROTOCOLSTATE_STATE_ENUM._serialized_start=65389
  _PROTOCOLSTATE_STATE_ENUM._serialized_end=65433
  _DEVICESTATE._serialized_start=65850
  _DEVICESTATE._serialized_end=66059
  _DEVICESTATE_CHOICE._serialized_start=65970
  _DEVICESTATE_CHOICE._serialized_end=66026
  _DEVICESTATE_CHOICE_ENUM._serialized_start=65980
  _DEVICESTATE_CHOICE_ENUM._serialized_end=66026
  _STATEPORTLINK._serialized_start=66062
  _STATEPORTLINK._serialized_end=66195
  _STATEPORTLINK_STATE._serialized_start=65244
  _STATEPORTLINK_STATE._serialized_end=65294
  _STATEPORTLINK_STATE_ENUM._serialized_start=13484
  _STATEPORTLINK_STATE_ENUM._serialized_end=13525
  _STATEPORTCAPTURE._serialized_start=66198
  _STATEPORTCAPTURE._serialized_end=66340
  _STATEPORTCAPTURE_STATE._serialized_start=65540
  _STATEPORTCAPTURE_STATE._serialized_end=65593
  _STATEPORTCAPTURE_STATE_ENUM._serialized_start=65389
  _STATEPORTCAPTURE_STATE_ENUM._serialized_end=65433
  _STATETRAFFICFLOWTRANSMIT._serialized_start=66343
  _STATETRAFFICFLOWTRANSMIT._serialized_end=66539
  _STATETRAFFICFLOWTRANSMIT_STATE._serialized_start=65380
  _STATETRAFFICFLOWTRANSMIT_STATE._serialized_end=65456
  _STATETRAFFICFLOWTRANSMIT_STATE_ENUM._serialized_start=65389
  _STATETRAFFICFLOWTRANSMIT_STATE_ENUM._serialized_end=65456
  _STATEPROTOCOLALL._serialized_start=66541
  _STATEPROTOCOLALL._serialized_end=66663
  _STATEPROTOCOLALL_STATE._serialized_start=65540
  _STATEPROTOCOLALL_STATE._serialized_end=65593
  _STATEPROTOCOLALL_STATE_ENUM._serialized_start=65389
  _STATEPROTOCOLALL_STATE_ENUM._serialized_end=65433
  _STATEPROTOCOLROUTE._serialized_start=66666
  _STATEPROTOCOLROUTE._serialized_end=66815
  _STATEPROTOCOLROUTE_STATE._serialized_start=65668
  _STATEPROTOCOLROUTE_STATE._serialized_end=65729
  _STATEPROTOCOLROUTE_STATE_ENUM._serialized_start=65677
  _STATEPROTOCOLROUTE_STATE_ENUM._serialized_end=65729
  _STATEPROTOCOLLACP._serialized_start=66818
  _STATEPROTOCOLLACP._serialized_end=66994
  _STATEPROTOCOLLACP_CHOICE._serialized_start=66940
  _STATEPROTOCOLLACP_CHOICE._serialized_end=66984
  _STATEPROTOCOLLACP_CHOICE_ENUM._serialized_start=66950
  _STATEPROTOCOLLACP_CHOICE_ENUM._serialized_end=66984
  _STATEPROTOCOLLACPADMIN._serialized_start=66997
  _STATEPROTOCOLLACPADMIN._serialized_end=67169
  _STATEPROTOCOLLACPADMIN_STATE._serialized_start=65244
  _STATEPROTOCOLLACPADMIN_STATE._serialized_end=65294
  _STATEPROTOCOLLACPADMIN_STATE_ENUM._serialized_start=13484
  _STATEPROTOCOLLACPADMIN_STATE_ENUM._serialized_end=13525
  _LACPMEMBERSTATE._serialized_start=67172
  _LACPMEMBERSTATE._serialized_end=67320
  _LACPMEMBERSTATE_STATE._serialized_start=65244
  _LACPMEMBERSTATE_STATE._serialized_end=65294
  _LACPMEMBERSTATE_STATE_ENUM._serialized_start=13484
  _LACPMEMBERSTATE_STATE_ENUM._serialized_end=13525
  _CONTROLACTION._serialized_start=67323
  _CONTROLACTION._serialized_end=67492
  _CONTROLACTION_CHOICE._serialized_start=67432
  _CONTROLACTION_CHOICE._serialized_end=67479
  _CONTROLACTION_CHOICE_ENUM._serialized_start=67442
  _CONTROLACTION_CHOICE_ENUM._serialized_end=67479
  _CONTROLACTIONRESPONSE._serialized_start=67494
  _CONTROLACTIONRESPONSE._serialized_end=67592
  _ACTIONRESPONSE._serialized_start=67595
  _ACTIONRESPONSE._serialized_end=67774
  _ACTIONRESPONSE_CHOICE._serialized_start=67432
  _ACTIONRESPONSE_CHOICE._serialized_end=67479
  _ACTIONRESPONSE_CHOICE_ENUM._serialized_start=67442
  _ACTIONRESPONSE_CHOICE_ENUM._serialized_end=67479
  _ACTIONPROTOCOL._serialized_start=67777
  _ACTIONPROTOCOL._serialized_end=68062
  _ACTIONPROTOCOL_CHOICE._serialized_start=67974
  _ACTIONPROTOCOL_CHOICE._serialized_end=68036
  _ACTIONPROTOCOL_CHOICE_ENUM._serialized_start=67984
  _ACTIONPROTOCOL_CHOICE_ENUM._serialized_end=68036
  _ACTIONRESPONSEPROTOCOL._serialized_start=68065
  _ACTIONRESPONSEPROTOCOL._serialized_end=68323
  _ACTIONRESPONSEPROTOCOL_CHOICE._serialized_start=68252
  _ACTIONRESPONSEPROTOCOL_CHOICE._serialized_end=68305
  _ACTIONRESPONSEPROTOCOL_CHOICE_ENUM._serialized_start=24562
  _ACTIONRESPONSEPROTOCOL_CHOICE_ENUM._serialized_end=24605
  _ACTIONPROTOCOLIPV4._serialized_start=68326
  _ACTIONPROTOCOLIPV4._serialized_end=68501
  _ACTIONPROTOCOLIPV4_CHOICE._serialized_start=68449
  _ACTIONPROTOCOLIPV4_CHOICE._serialized_end=68492
  _ACTIONPROTOCOLIPV4_CHOICE_ENUM._serialized_start=68459
  _ACTIONPROTOCOLIPV4_CHOICE_ENUM._serialized_end=68492
  _ACTIONRESPONSEPROTOCOLIPV4._serialized_start=68504
  _ACTIONRESPONSEPROTOCOLIPV4._serialized_end=68703
  _ACTIONRESPONSEPROTOCOLIPV4_CHOICE._serialized_start=68449
  _ACTIONRESPONSEPROTOCOLIPV4_CHOICE._serialized_end=68492
  _ACTIONRESPONSEPROTOCOLIPV4_CHOICE_ENUM._serialized_start=68459
  _ACTIONRESPONSEPROTOCOLIPV4_CHOICE_ENUM._serialized_end=68492
  _ACTIONPROTOCOLIPV4PING._serialized_start=68705
  _ACTIONPROTOCOLIPV4PING._serialized_end=68783
  _ACTIONPROTOCOLIPV4PINGREQUEST._serialized_start=68785
  _ACTIONPROTOCOLIPV4PINGREQUEST._serialized_end=68884
  _ACTIONRESPONSEPROTOCOLIPV4PING._serialized_start=68886
  _ACTIONRESPONSEPROTOCOLIPV4PING._serialized_end=68982
  _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE._serialized_start=68985
  _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE._serialized_end=69194
  _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT._serialized_start=69134
  _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT._serialized_end=69194
  _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT_ENUM._serialized_start=69144
  _ACTIONRESPONSEPROTOCOLIPV4PINGRESPONSE_RESULT_ENUM._serialized_end=69194
  _ACTIONPROTOCOLIPV6._serialized_start=69197
  _ACTIONPROTOCOLIPV6._serialized_end=69372
  _ACTIONPROTOCOLIPV6_CHOICE._serialized_start=68449
  _ACTIONPROTOCOLIPV6_CHOICE._serialized_end=68492
  _ACTIONPROTOCOLIPV6_CHOICE_ENUM._serialized_start=68459
  _ACTIONPROTOCOLIPV6_CHOICE_ENUM._serialized_end=68492
  _ACTIONRESPONSEPROTOCOLIPV6._serialized_start=69375
  _ACTIONRESPONSEPROTOCOLIPV6._serialized_end=69574
  _ACTIONRESPONSEPROTOCOLIPV6_CHOICE._serialized_start=68449
  _ACTIONRESPONSEPROTOCOLIPV6_CHOICE._serialized_end=68492
  _ACTIONRESPONSEPROTOCOLIPV6_CHOICE_ENUM._serialized_start=68459
  _ACTIONRESPONSEPROTOCOLIPV6_CHOICE_ENUM._serialized_end=68492
  _ACTIONPROTOCOLIPV6PING._serialized_start=69576
  _ACTIONPROTOCOLIPV6PING._serialized_end=69654
  _ACTIONPROTOCOLIPV6PINGREQUEST._serialized_start=69656
  _ACTIONPROTOCOLIPV6PINGREQUEST._serialized_end=69755
  _ACTIONRESPONSEPROTOCOLIPV6PING._serialized_start=69757
  _ACTIONRESPONSEPROTOCOLIPV6PING._serialized_end=69853
  _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE._serialized_start=69856
  _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE._serialized_end=70065
  _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT._serialized_start=69134
  _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT._serialized_end=69194
  _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT_ENUM._serialized_start=69144
  _ACTIONRESPONSEPROTOCOLIPV6PINGRESPONSE_RESULT_ENUM._serialized_end=69194
  _ACTIONPROTOCOLBGP._serialized_start=70068
  _ACTIONPROTOCOLBGP._serialized_end=70420
  _ACTIONPROTOCOLBGP_CHOICE._serialized_start=70291
  _ACTIONPROTOCOLBGP_CHOICE._serialized_end=70373
  _ACTIONPROTOCOLBGP_CHOICE_ENUM._serialized_start=70301
  _ACTIONPROTOCOLBGP_CHOICE_ENUM._serialized_end=70373
  _ACTIONPROTOCOLBGPNOTIFICATION._serialized_start=70423
  _ACTIONPROTOCOLBGPNOTIFICATION._serialized_end=71331
  _ACTIONPROTOCOLBGPNOTIFICATION_CHOICE._serialized_start=70983
  _ACTIONPROTOCOLBGPNOTIFICATION_CHOICE._serialized_end=71172
  _ACTIONPROTOCOLBGPNOTIFICATION_CHOICE_ENUM._serialized_start=70994
  _ACTIONPROTOCOLBGPNOTIFICATION_CHOICE_ENUM._serialized_end=71172
  _ACTIONPROTOCOLBGPINITIATEGRACEFULRESTART._serialized_start=71333
  _ACTIONPROTOCOLBGPINITIATEGRACEFULRESTART._serialized_end=71441
  _PING._serialized_start=71444
  _PING._serialized_end=71646
  _PING_CHOICE._serialized_start=68252
  _PING_CHOICE._serialized_end=68305
  _PING_CHOICE_ENUM._serialized_start=24562
  _PING_CHOICE_ENUM._serialized_end=24605
  _PINGIPV4._serialized_start=71648
  _PINGIPV4._serialized_end=71726
  _PINGIPV6._serialized_start=71728
  _PINGIPV6._serialized_end=71806
  _PINGREQUEST._serialized_start=71808
  _PINGREQUEST._serialized_end=71851
  _PINGRESPONSE._serialized_start=71853
  _PINGRESPONSE._serialized_end=71901
  _RESPONSE._serialized_start=71904
  _RESPONSE._serialized_end=72102
  _RESPONSE_RESULT._serialized_start=72008
  _RESPONSE_RESULT._serialized_end=72067
  _RESPONSE_RESULT_ENUM._serialized_start=72018
  _RESPONSE_RESULT_ENUM._serialized_end=72067
  _METRICSREQUEST._serialized_start=72105
  _METRICSREQUEST._serialized_end=72792
  _METRICSREQUEST_CHOICE._serialized_start=72575
  _METRICSREQUEST_CHOICE._serialized_end=72699
  _METRICSREQUEST_CHOICE_ENUM._serialized_start=72585
  _METRICSREQUEST_CHOICE_ENUM._serialized_end=72699
  _METRICSRESPONSE._serialized_start=72795
  _METRICSRESPONSE._serialized_end=73431
  _METRICSRESPONSE_CHOICE._serialized_start=73223
  _METRICSRESPONSE_CHOICE._serialized_end=73420
  _METRICSRESPONSE_CHOICE_ENUM._serialized_start=73234
  _METRICSRESPONSE_CHOICE_ENUM._serialized_end=73420
  _PORTMETRICSREQUEST._serialized_start=73434
  _PORTMETRICSREQUEST._serialized_end=73767
  _PORTMETRICSREQUEST_COLUMNNAMES._serialized_start=73541
  _PORTMETRICSREQUEST_COLUMNNAMES._serialized_end=73767
  _PORTMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=73557
  _PORTMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=73767
  _PORTMETRIC._serialized_start=73770
  _PORTMETRIC._serialized_end=74544
  _PORTMETRIC_LINK._serialized_start=74186
  _PORTMETRIC_LINK._serialized_end=74235
  _PORTMETRIC_LINK_ENUM._serialized_start=13484
  _PORTMETRIC_LINK_ENUM._serialized_end=13525
  _PORTMETRIC_CAPTURE._serialized_start=74237
  _PORTMETRIC_CAPTURE._serialized_end=74297
  _PORTMETRIC_CAPTURE_ENUM._serialized_start=74248
  _PORTMETRIC_CAPTURE_ENUM._serialized_end=74297
  _PORTMETRIC_TRANSMIT._serialized_start=74299
  _PORTMETRIC_TRANSMIT._serialized_end=74360
  _PORTMETRIC_TRANSMIT_ENUM._serialized_start=74248
  _PORTMETRIC_TRANSMIT_ENUM._serialized_end=74297
  _FLOWMETRICSREQUEST._serialized_start=74547
  _FLOWMETRICSREQUEST._serialized_end=74883
  _FLOWMETRICSREQUEST_METRICNAMES._serialized_start=74713
  _FLOWMETRICSREQUEST_METRICNAMES._serialized_end=74864
  _FLOWMETRICSREQUEST_METRICNAMES_ENUM._serialized_start=74729
  _FLOWMETRICSREQUEST_METRICNAMES_ENUM._serialized_end=74864
  _FLOWTAGGEDMETRICSFILTER._serialized_start=74886
  _FLOWTAGGEDMETRICSFILTER._serialized_end=75258
  _FLOWTAGGEDMETRICSFILTER_METRICNAMES._serialized_start=75084
  _FLOWTAGGEDMETRICSFILTER_METRICNAMES._serialized_end=75220
  _FLOWTAGGEDMETRICSFILTER_METRICNAMES_ENUM._serialized_start=75099
  _FLOWTAGGEDMETRICSFILTER_METRICNAMES_ENUM._serialized_end=75220
  _FLOWMETRICTAGFILTER._serialized_start=75260
  _FLOWMETRICTAGFILTER._serialized_end=75325
  _FLOWMETRIC._serialized_start=75328
  _FLOWMETRIC._serialized_end=76013
  _FLOWMETRIC_TRANSMIT._serialized_start=75766
  _FLOWMETRIC_TRANSMIT._serialized_end=75839
  _FLOWMETRIC_TRANSMIT_ENUM._serialized_start=75778
  _FLOWMETRIC_TRANSMIT_ENUM._serialized_end=75839
  _FLOWTAGGEDMETRIC._serialized_start=76016
  _FLOWTAGGEDMETRIC._serialized_end=76456
  _FLOWMETRICTAG._serialized_start=76458
  _FLOWMETRICTAG._serialized_end=76556
  _FLOWMETRICTAGVALUE._serialized_start=76559
  _FLOWMETRICTAGVALUE._serialized_end=76753
  _FLOWMETRICTAGVALUE_CHOICE._serialized_start=76675
  _FLOWMETRICTAGVALUE_CHOICE._serialized_end=76726
  _FLOWMETRICTAGVALUE_CHOICE_ENUM._serialized_start=76685
  _FLOWMETRICTAGVALUE_CHOICE_ENUM._serialized_end=76726
  _METRICTIMESTAMP._serialized_start=76755
  _METRICTIMESTAMP._serialized_end=76882
  _METRICLATENCY._serialized_start=76885
  _METRICLATENCY._serialized_end=77020
  _BGPV4METRICSREQUEST._serialized_start=77023
  _BGPV4METRICSREQUEST._serialized_end=77528
  _BGPV4METRICSREQUEST_COLUMNNAMES._serialized_start=77132
  _BGPV4METRICSREQUEST_COLUMNNAMES._serialized_end=77528
  _BGPV4METRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=77148
  _BGPV4METRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=77528
  _BGPV4METRIC._serialized_start=77531
  _BGPV4METRIC._serialized_end=78661
  _BGPV4METRIC_SESSIONSTATE._serialized_start=78134
  _BGPV4METRIC_SESSIONSTATE._serialized_end=78191
  _BGPV4METRIC_SESSIONSTATE_ENUM._serialized_start=13484
  _BGPV4METRIC_SESSIONSTATE_ENUM._serialized_end=13525
  _BGPV4METRIC_FSMSTATE._serialized_start=78193
  _BGPV4METRIC_FSMSTATE._serialized_end=78311
  _BGPV4METRIC_FSMSTATE_ENUM._serialized_start=78205
  _BGPV4METRIC_FSMSTATE_ENUM._serialized_end=78311
  _BGPV6METRICSREQUEST._serialized_start=78664
  _BGPV6METRICSREQUEST._serialized_end=79169
  _BGPV6METRICSREQUEST_COLUMNNAMES._serialized_start=77132
  _BGPV6METRICSREQUEST_COLUMNNAMES._serialized_end=77528
  _BGPV6METRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=77148
  _BGPV6METRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=77528
  _BGPV6METRIC._serialized_start=79172
  _BGPV6METRIC._serialized_end=80302
  _BGPV6METRIC_SESSIONSTATE._serialized_start=78134
  _BGPV6METRIC_SESSIONSTATE._serialized_end=78191
  _BGPV6METRIC_SESSIONSTATE_ENUM._serialized_start=13484
  _BGPV6METRIC_SESSIONSTATE_ENUM._serialized_end=13525
  _BGPV6METRIC_FSMSTATE._serialized_start=78193
  _BGPV6METRIC_FSMSTATE._serialized_end=78311
  _BGPV6METRIC_FSMSTATE_ENUM._serialized_start=78205
  _BGPV6METRIC_FSMSTATE_ENUM._serialized_end=78311
  _ISISMETRICSREQUEST._serialized_start=80305
  _ISISMETRICSREQUEST._serialized_end=81091
  _ISISMETRICSREQUEST_COLUMNNAMES._serialized_start=80414
  _ISISMETRICSREQUEST_COLUMNNAMES._serialized_end=81091
  _ISISMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=80430
  _ISISMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=81091
  _ISISMETRIC._serialized_start=81094
  _ISISMETRIC._serialized_end=82618
  _LAGMETRICSREQUEST._serialized_start=82621
  _LAGMETRICSREQUEST._serialized_end=82938
  _LAGMETRICSREQUEST_COLUMNNAMES._serialized_start=82725
  _LAGMETRICSREQUEST_COLUMNNAMES._serialized_end=82938
  _LAGMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=82741
  _LAGMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=82938
  _LAGMETRIC._serialized_start=82941
  _LAGMETRIC._serialized_end=83497
  _LAGMETRIC_OPERSTATUS._serialized_start=83269
  _LAGMETRIC_OPERSTATUS._serialized_end=83324
  _LAGMETRIC_OPERSTATUS_ENUM._serialized_start=13484
  _LAGMETRIC_OPERSTATUS_ENUM._serialized_end=13525
  _LACPMETRICSREQUEST._serialized_start=83500
  _LACPMETRICSREQUEST._serialized_end=83936
  _LACPMETRICSREQUEST_COLUMNNAMES._serialized_start=83637
  _LACPMETRICSREQUEST_COLUMNNAMES._serialized_end=83936
  _LACPMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=83653
  _LACPMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=83936
  _LACPMETRIC._serialized_start=83939
  _LACPMETRIC._serialized_end=84976
  _LACPMETRIC_ACTIVITY._serialized_start=84505
  _LACPMETRIC_ACTIVITY._serialized_end=84565
  _LACPMETRIC_ACTIVITY_ENUM._serialized_start=84517
  _LACPMETRIC_ACTIVITY_ENUM._serialized_end=84565
  _LACPMETRIC_TIMEOUT._serialized_start=84567
  _LACPMETRIC_TIMEOUT._serialized_end=84622
  _LACPMETRIC_TIMEOUT_ENUM._serialized_start=84578
  _LACPMETRIC_TIMEOUT_ENUM._serialized_end=84622
  _LACPMETRIC_SYNCHRONIZATION._serialized_start=84624
  _LACPMETRIC_SYNCHRONIZATION._serialized_end=84693
  _LACPMETRIC_SYNCHRONIZATION_ENUM._serialized_start=84643
  _LACPMETRIC_SYNCHRONIZATION_ENUM._serialized_end=84693
  _LLDPMETRICSREQUEST._serialized_start=84979
  _LLDPMETRICSREQUEST._serialized_end=85232
  _LLDPMETRICSREQUEST_COLUMNNAMES._serialized_start=85086
  _LLDPMETRICSREQUEST_COLUMNNAMES._serialized_end=85232
  _LLDPMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=85102
  _LLDPMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=85232
  _LLDPMETRIC._serialized_start=85235
  _LLDPMETRIC._serialized_end=85537
  _RSVPMETRICSREQUEST._serialized_start=85540
  _RSVPMETRICSREQUEST._serialized_end=86246
  _RSVPMETRICSREQUEST_COLUMNNAMES._serialized_start=85649
  _RSVPMETRICSREQUEST_COLUMNNAMES._serialized_end=86246
  _RSVPMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=85665
  _RSVPMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=86246
  _RSVPMETRIC._serialized_start=86249
  _RSVPMETRIC._serialized_end=87645
  _STATESREQUEST._serialized_start=87648
  _STATESREQUEST._serialized_end=88312
  _STATESREQUEST_CHOICE._serialized_start=88057
  _STATESREQUEST_CHOICE._serialized_end=88199
  _STATESREQUEST_CHOICE_ENUM._serialized_start=88068
  _STATESREQUEST_CHOICE_ENUM._serialized_end=88199
  _STATESRESPONSE._serialized_start=88315
  _STATESRESPONSE._serialized_end=88807
  _STATESRESPONSE_CHOICE._serialized_start=88057
  _STATESRESPONSE_CHOICE._serialized_end=88199
  _STATESRESPONSE_CHOICE_ENUM._serialized_start=88068
  _STATESRESPONSE_CHOICE_ENUM._serialized_end=88199
  _NEIGHBORSV4STATESREQUEST._serialized_start=88809
  _NEIGHBORSV4STATESREQUEST._serialized_end=88859
  _NEIGHBORSV4STATE._serialized_start=88861
  _NEIGHBORSV4STATE._serialized_end=88980
  _NEIGHBORSV6STATESREQUEST._serialized_start=88982
  _NEIGHBORSV6STATESREQUEST._serialized_end=89032
  _NEIGHBORSV6STATE._serialized_start=89034
  _NEIGHBORSV6STATE._serialized_end=89153
  _BGPPREFIXSTATEREQUEST._serialized_start=89156
  _BGPPREFIXSTATEREQUEST._serialized_end=89478
  _BGPPREFIXSTATEREQUEST_PREFIXFILTERS._serialized_start=89402
  _BGPPREFIXSTATEREQUEST_PREFIXFILTERS._serialized_end=89478
  _BGPPREFIXSTATEREQUEST_PREFIXFILTERS_ENUM._serialized_start=89419
  _BGPPREFIXSTATEREQUEST_PREFIXFILTERS_ENUM._serialized_end=89478
  _BGPPREFIXIPV4UNICASTFILTER._serialized_start=89481
  _BGPPREFIXIPV4UNICASTFILTER._serialized_end=89754
  _BGPPREFIXIPV4UNICASTFILTER_ORIGIN._serialized_start=18498
  _BGPPREFIXIPV4UNICASTFILTER_ORIGIN._serialized_end=18565
  _BGPPREFIXIPV4UNICASTFILTER_ORIGIN_ENUM._serialized_start=18508
  _BGPPREFIXIPV4UNICASTFILTER_ORIGIN_ENUM._serialized_end=18565
  _BGPPREFIXIPV6UNICASTFILTER._serialized_start=89757
  _BGPPREFIXIPV6UNICASTFILTER._serialized_end=90030
  _BGPPREFIXIPV6UNICASTFILTER_ORIGIN._serialized_start=18498
  _BGPPREFIXIPV6UNICASTFILTER_ORIGIN._serialized_end=18565
  _BGPPREFIXIPV6UNICASTFILTER_ORIGIN_ENUM._serialized_start=18508
  _BGPPREFIXIPV6UNICASTFILTER_ORIGIN_ENUM._serialized_end=18565
  _BGPPREFIXESSTATE._serialized_start=90033
  _BGPPREFIXESSTATE._serialized_end=90223
  _BGPPREFIXIPV4UNICASTSTATE._serialized_start=90226
  _BGPPREFIXIPV4UNICASTSTATE._serialized_end=90836
  _BGPPREFIXIPV4UNICASTSTATE_ORIGIN._serialized_start=18498
  _BGPPREFIXIPV4UNICASTSTATE_ORIGIN._serialized_end=18565
  _BGPPREFIXIPV4UNICASTSTATE_ORIGIN_ENUM._serialized_start=18508
  _BGPPREFIXIPV4UNICASTSTATE_ORIGIN_ENUM._serialized_end=18565
  _BGPPREFIXIPV6UNICASTSTATE._serialized_start=90839
  _BGPPREFIXIPV6UNICASTSTATE._serialized_end=91449
  _BGPPREFIXIPV6UNICASTSTATE_ORIGIN._serialized_start=18498
  _BGPPREFIXIPV6UNICASTSTATE_ORIGIN._serialized_end=18565
  _BGPPREFIXIPV6UNICASTSTATE_ORIGIN_ENUM._serialized_start=18508
  _BGPPREFIXIPV6UNICASTSTATE_ORIGIN_ENUM._serialized_end=18565
  _RESULTBGPCOMMUNITY._serialized_start=91452
  _RESULTBGPCOMMUNITY._serialized_end=91756
  _RESULTBGPCOMMUNITY_TYPE._serialized_start=18827
  _RESULTBGPCOMMUNITY_TYPE._serialized_end=18969
  _RESULTBGPCOMMUNITY_TYPE_ENUM._serialized_start=18836
  _RESULTBGPCOMMUNITY_TYPE_ENUM._serialized_end=18969
  _RESULTBGPASPATH._serialized_start=91758
  _RESULTBGPASPATH._serialized_end=91822
  _RESULTBGPASPATHSEGMENT._serialized_start=91825
  _RESULTBGPASPATHSEGMENT._serialized_end=92031
  _RESULTBGPASPATHSEGMENT_TYPE._serialized_start=19930
  _RESULTBGPASPATHSEGMENT_TYPE._serialized_end=20023
  _RESULTBGPASPATHSEGMENT_TYPE_ENUM._serialized_start=19938
  _RESULTBGPASPATHSEGMENT_TYPE_ENUM._serialized_end=20023
  _ISISLSPSSTATEREQUEST._serialized_start=92033
  _ISISLSPSSTATEREQUEST._serialized_end=92082
  _ISISLSPSSTATE._serialized_start=92084
  _ISISLSPSSTATE._serialized_end=92184
  _ISISLSPSTATE._serialized_start=92187
  _ISISLSPSTATE._serialized_end=92622
  _ISISLSPSTATE_PDUTYPE._serialized_start=92460
  _ISISLSPSTATE_PDUTYPE._serialized_end=92520
  _ISISLSPSTATE_PDUTYPE_ENUM._serialized_start=9947
  _ISISLSPSTATE_PDUTYPE_ENUM._serialized_end=9996
  _ISISLSPTLVS._serialized_start=92625
  _ISISLSPTLVS._serialized_end=93133
  _ISISLSPHOSTNAME._serialized_start=93135
  _ISISLSPHOSTNAME._serialized_end=93188
  _ISISLSPFLAGS._serialized_start=93191
  _ISISLSPFLAGS._serialized_end=93493
  _ISISLSPISREACHABILITYTLV._serialized_start=93495
  _ISISLSPISREACHABILITYTLV._serialized_end=93562
  _ISISLSPEXTENDEDISREACHABILITYTLV._serialized_start=93564
  _ISISLSPEXTENDEDISREACHABILITYTLV._serialized_end=93639
  _ISISLSPNEIGHBOR._serialized_start=93641
  _ISISLSPNEIGHBOR._serialized_end=93696
  _ISISLSPIPV4INTERNALREACHABILITYTLV._serialized_start=93698
  _ISISLSPIPV4INTERNALREACHABILITYTLV._serialized_end=93774
  _ISISLSPIPV4EXTERNALREACHABILITYTLV._serialized_start=93776
  _ISISLSPIPV4EXTERNALREACHABILITYTLV._serialized_end=93852
  _ISISLSPV4PREFIX._serialized_start=93855
  _ISISLSPV4PREFIX._serialized_end=94326
  _ISISLSPV4PREFIX_REDISTRIBUTIONTYPE._serialized_start=13462
  _ISISLSPV4PREFIX_REDISTRIBUTIONTYPE._serialized_end=13525
  _ISISLSPV4PREFIX_REDISTRIBUTIONTYPE_ENUM._serialized_start=13484
  _ISISLSPV4PREFIX_REDISTRIBUTIONTYPE_ENUM._serialized_end=13525
  _ISISLSPV4PREFIX_ORIGINTYPE._serialized_start=13395
  _ISISLSPV4PREFIX_ORIGINTYPE._serialized_end=13460
  _ISISLSPV4PREFIX_ORIGINTYPE_ENUM._serialized_start=13409
  _ISISLSPV4PREFIX_ORIGINTYPE_ENUM._serialized_end=13460
  _ISISLSPEXTENDEDIPV4REACHABILITYTLV._serialized_start=94328
  _ISISLSPEXTENDEDIPV4REACHABILITYTLV._serialized_end=94412
  _ISISLSPEXTENDEDV4PREFIX._serialized_start=94415
  _ISISLSPEXTENDEDV4PREFIX._serialized_end=94823
  _ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE._serialized_start=13462
  _ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE._serialized_end=13525
  _ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE_ENUM._serialized_start=13484
  _ISISLSPEXTENDEDV4PREFIX_REDISTRIBUTIONTYPE_ENUM._serialized_end=13525
  _ISISLSPIPV6REACHABILITYTLV._serialized_start=94825
  _ISISLSPIPV6REACHABILITYTLV._serialized_end=94893
  _ISISLSPV6PREFIX._serialized_start=94896
  _ISISLSPV6PREFIX._serialized_end=95435
  _ISISLSPV6PREFIX_REDISTRIBUTIONTYPE._serialized_start=13462
  _ISISLSPV6PREFIX_REDISTRIBUTIONTYPE._serialized_end=13525
  _ISISLSPV6PREFIX_REDISTRIBUTIONTYPE_ENUM._serialized_start=13484
  _ISISLSPV6PREFIX_REDISTRIBUTIONTYPE_ENUM._serialized_end=13525
  _ISISLSPV6PREFIX_ORIGINTYPE._serialized_start=13395
  _ISISLSPV6PREFIX_ORIGINTYPE._serialized_end=13460
  _ISISLSPV6PREFIX_ORIGINTYPE_ENUM._serialized_start=13409
  _ISISLSPV6PREFIX_ORIGINTYPE_ENUM._serialized_end=13460
  _ISISLSPPREFIXATTRIBUTES._serialized_start=95437
  _ISISLSPPREFIXATTRIBUTES._serialized_end=95558
  _LLDPNEIGHBORSSTATEREQUEST._serialized_start=95560
  _LLDPNEIGHBORSSTATEREQUEST._serialized_end=95636
  _LLDPNEIGHBORSSTATE._serialized_start=95639
  _LLDPNEIGHBORSSTATE._serialized_end=96802
  _LLDPNEIGHBORSSTATE_CHASSISIDTYPE._serialized_start=96218
  _LLDPNEIGHBORSSTATE_CHASSISIDTYPE._serialized_end=96392
  _LLDPNEIGHBORSSTATE_CHASSISIDTYPE_ENUM._serialized_start=96236
  _LLDPNEIGHBORSSTATE_CHASSISIDTYPE_ENUM._serialized_end=96392
  _LLDPNEIGHBORSSTATE_PORTIDTYPE._serialized_start=96395
  _LLDPNEIGHBORSSTATE_PORTIDTYPE._serialized_end=96565
  _LLDPNEIGHBORSSTATE_PORTIDTYPE_ENUM._serialized_start=96410
  _LLDPNEIGHBORSSTATE_PORTIDTYPE_ENUM._serialized_end=96565
  _LLDPCUSTOMTLVSTATE._serialized_start=96805
  _LLDPCUSTOMTLVSTATE._serialized_end=96935
  _LLDPCAPABILITYSTATE._serialized_start=96938
  _LLDPCAPABILITYSTATE._serialized_end=97338
  _LLDPCAPABILITYSTATE_CAPABILITYNAME._serialized_start=97071
  _LLDPCAPABILITYSTATE_CAPABILITYNAME._serialized_end=97295
  _LLDPCAPABILITYSTATE_CAPABILITYNAME_ENUM._serialized_start=97090
  _LLDPCAPABILITYSTATE_CAPABILITYNAME_ENUM._serialized_end=97295
  _RSVPLSPSSTATEREQUEST._serialized_start=97340
  _RSVPLSPSSTATEREQUEST._serialized_end=97389
  _RSVPLSPSSTATE._serialized_start=97391
  _RSVPLSPSSTATE._serialized_end=97500
  _RSVPIPV4LSPSTATE._serialized_start=97503
  _RSVPIPV4LSPSTATE._serialized_end=97742
  _RSVPLSPSTATE._serialized_start=97745
  _RSVPLSPSTATE._serialized_end=98309
  _RSVPLSPSTATE_SESSIONSTATUS._serialized_start=98039
  _RSVPLSPSTATE_SESSIONSTATUS._serialized_end=98097
  _RSVPLSPSTATE_SESSIONSTATUS_ENUM._serialized_start=13484
  _RSVPLSPSTATE_SESSIONSTATUS_ENUM._serialized_end=13525
  _RSVPLSPSTATE_LASTFLAPREASON._serialized_start=98099
  _RSVPLSPSTATE_LASTFLAPREASON._serialized_end=98188
  _RSVPLSPSTATE_LASTFLAPREASON_ENUM._serialized_start=98117
  _RSVPLSPSTATE_LASTFLAPREASON_ENUM._serialized_end=98188
  _RSVPLSPIPV4RRO._serialized_start=98311
  _RSVPLSPIPV4RRO._serialized_end=98409
  _RSVPLSPIPV4ERO._serialized_start=98412
  _RSVPLSPIPV4ERO._serialized_end=98654
  _RSVPLSPIPV4ERO_TYPE._serialized_start=98519
  _RSVPLSPIPV4ERO_TYPE._serialized_end=98626
  _RSVPLSPIPV4ERO_TYPE_ENUM._serialized_start=98527
  _RSVPLSPIPV4ERO_TYPE_ENUM._serialized_end=98626
  _CAPTUREREQUEST._serialized_start=98656
  _CAPTUREREQUEST._serialized_end=98691
  _PATTERNFLOWETHERNETDSTCOUNTER._serialized_start=98693
  _PATTERNFLOWETHERNETDSTCOUNTER._serialized_end=98812
  _PATTERNFLOWETHERNETDSTMETRICTAG._serialized_start=98814
  _PATTERNFLOWETHERNETDSTMETRICTAG._serialized_end=98925
  _PATTERNFLOWETHERNETDST._serialized_start=98928
  _PATTERNFLOWETHERNETDST._serialized_end=99404
  _PATTERNFLOWETHERNETDST_CHOICE._serialized_start=99250
  _PATTERNFLOWETHERNETDST_CHOICE._serialized_end=99346
  _PATTERNFLOWETHERNETDST_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWETHERNETDST_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWETHERNETSRCCOUNTER._serialized_start=99406
  _PATTERNFLOWETHERNETSRCCOUNTER._serialized_end=99525
  _PATTERNFLOWETHERNETSRCMETRICTAG._serialized_start=99527
  _PATTERNFLOWETHERNETSRCMETRICTAG._serialized_end=99638
  _PATTERNFLOWETHERNETSRC._serialized_start=99641
  _PATTERNFLOWETHERNETSRC._serialized_end=100079
  _PATTERNFLOWETHERNETSRC_CHOICE._serialized_start=99944
  _PATTERNFLOWETHERNETSRC_CHOICE._serialized_end=100030
  _PATTERNFLOWETHERNETSRC_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWETHERNETSRC_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWETHERNETETHERTYPECOUNTER._serialized_start=100081
  _PATTERNFLOWETHERNETETHERTYPECOUNTER._serialized_end=100206
  _PATTERNFLOWETHERNETETHERTYPEMETRICTAG._serialized_start=100208
  _PATTERNFLOWETHERNETETHERTYPEMETRICTAG._serialized_end=100325
  _PATTERNFLOWETHERNETETHERTYPE._serialized_start=100328
  _PATTERNFLOWETHERNETETHERTYPE._serialized_end=100834
  _PATTERNFLOWETHERNETETHERTYPE_CHOICE._serialized_start=99250
  _PATTERNFLOWETHERNETETHERTYPE_CHOICE._serialized_end=99346
  _PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWETHERNETPFCQUEUECOUNTER._serialized_start=100836
  _PATTERNFLOWETHERNETPFCQUEUECOUNTER._serialized_end=100960
  _PATTERNFLOWETHERNETPFCQUEUEMETRICTAG._serialized_start=100962
  _PATTERNFLOWETHERNETPFCQUEUEMETRICTAG._serialized_end=101078
  _PATTERNFLOWETHERNETPFCQUEUE._serialized_start=101081
  _PATTERNFLOWETHERNETPFCQUEUE._serialized_end=101544
  _PATTERNFLOWETHERNETPFCQUEUE_CHOICE._serialized_start=99944
  _PATTERNFLOWETHERNETPFCQUEUE_CHOICE._serialized_end=100030
  _PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWVLANPRIORITYCOUNTER._serialized_start=101546
  _PATTERNFLOWVLANPRIORITYCOUNTER._serialized_end=101666
  _PATTERNFLOWVLANPRIORITYMETRICTAG._serialized_start=101668
  _PATTERNFLOWVLANPRIORITYMETRICTAG._serialized_end=101780
  _PATTERNFLOWVLANPRIORITY._serialized_start=101783
  _PATTERNFLOWVLANPRIORITY._serialized_end=102226
  _PATTERNFLOWVLANPRIORITY_CHOICE._serialized_start=99944
  _PATTERNFLOWVLANPRIORITY_CHOICE._serialized_end=100030
  _PATTERNFLOWVLANPRIORITY_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWVLANPRIORITY_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWVLANCFICOUNTER._serialized_start=102228
  _PATTERNFLOWVLANCFICOUNTER._serialized_end=102343
  _PATTERNFLOWVLANCFIMETRICTAG._serialized_start=102345
  _PATTERNFLOWVLANCFIMETRICTAG._serialized_end=102452
  _PATTERNFLOWVLANCFI._serialized_start=102455
  _PATTERNFLOWVLANCFI._serialized_end=102873
  _PATTERNFLOWVLANCFI_CHOICE._serialized_start=99944
  _PATTERNFLOWVLANCFI_CHOICE._serialized_end=100030
  _PATTERNFLOWVLANCFI_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWVLANCFI_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWVLANIDCOUNTER._serialized_start=102875
  _PATTERNFLOWVLANIDCOUNTER._serialized_end=102989
  _PATTERNFLOWVLANIDMETRICTAG._serialized_start=102991
  _PATTERNFLOWVLANIDMETRICTAG._serialized_end=103097
  _PATTERNFLOWVLANID._serialized_start=103100
  _PATTERNFLOWVLANID._serialized_end=103513
  _PATTERNFLOWVLANID_CHOICE._serialized_start=99944
  _PATTERNFLOWVLANID_CHOICE._serialized_end=100030
  _PATTERNFLOWVLANID_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWVLANID_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWVLANTPIDCOUNTER._serialized_start=103515
  _PATTERNFLOWVLANTPIDCOUNTER._serialized_end=103631
  _PATTERNFLOWVLANTPIDMETRICTAG._serialized_start=103633
  _PATTERNFLOWVLANTPIDMETRICTAG._serialized_end=103741
  _PATTERNFLOWVLANTPID._serialized_start=103744
  _PATTERNFLOWVLANTPID._serialized_end=104167
  _PATTERNFLOWVLANTPID_CHOICE._serialized_start=99944
  _PATTERNFLOWVLANTPID_CHOICE._serialized_end=100030
  _PATTERNFLOWVLANTPID_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWVLANTPID_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWVXLANFLAGSCOUNTER._serialized_start=104169
  _PATTERNFLOWVXLANFLAGSCOUNTER._serialized_end=104287
  _PATTERNFLOWVXLANFLAGSMETRICTAG._serialized_start=104289
  _PATTERNFLOWVXLANFLAGSMETRICTAG._serialized_end=104399
  _PATTERNFLOWVXLANFLAGS._serialized_start=104402
  _PATTERNFLOWVXLANFLAGS._serialized_end=104835
  _PATTERNFLOWVXLANFLAGS_CHOICE._serialized_start=99944
  _PATTERNFLOWVXLANFLAGS_CHOICE._serialized_end=100030
  _PATTERNFLOWVXLANFLAGS_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWVXLANFLAGS_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWVXLANRESERVED0COUNTER._serialized_start=104837
  _PATTERNFLOWVXLANRESERVED0COUNTER._serialized_end=104959
  _PATTERNFLOWVXLANRESERVED0METRICTAG._serialized_start=104961
  _PATTERNFLOWVXLANRESERVED0METRICTAG._serialized_end=105075
  _PATTERNFLOWVXLANRESERVED0._serialized_start=105078
  _PATTERNFLOWVXLANRESERVED0._serialized_end=105531
  _PATTERNFLOWVXLANRESERVED0_CHOICE._serialized_start=99944
  _PATTERNFLOWVXLANRESERVED0_CHOICE._serialized_end=100030
  _PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWVXLANVNICOUNTER._serialized_start=105533
  _PATTERNFLOWVXLANVNICOUNTER._serialized_end=105649
  _PATTERNFLOWVXLANVNIMETRICTAG._serialized_start=105651
  _PATTERNFLOWVXLANVNIMETRICTAG._serialized_end=105759
  _PATTERNFLOWVXLANVNI._serialized_start=105762
  _PATTERNFLOWVXLANVNI._serialized_end=106223
  _PATTERNFLOWVXLANVNI_CHOICE._serialized_start=99250
  _PATTERNFLOWVXLANVNI_CHOICE._serialized_end=99346
  _PATTERNFLOWVXLANVNI_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWVXLANVNI_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWVXLANRESERVED1COUNTER._serialized_start=106225
  _PATTERNFLOWVXLANRESERVED1COUNTER._serialized_end=106347
  _PATTERNFLOWVXLANRESERVED1METRICTAG._serialized_start=106349
  _PATTERNFLOWVXLANRESERVED1METRICTAG._serialized_end=106463
  _PATTERNFLOWVXLANRESERVED1._serialized_start=106466
  _PATTERNFLOWVXLANRESERVED1._serialized_end=106919
  _PATTERNFLOWVXLANRESERVED1_CHOICE._serialized_start=99944
  _PATTERNFLOWVXLANRESERVED1_CHOICE._serialized_end=100030
  _PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4VERSIONCOUNTER._serialized_start=106921
  _PATTERNFLOWIPV4VERSIONCOUNTER._serialized_end=107040
  _PATTERNFLOWIPV4VERSIONMETRICTAG._serialized_start=107042
  _PATTERNFLOWIPV4VERSIONMETRICTAG._serialized_end=107153
  _PATTERNFLOWIPV4VERSION._serialized_start=107156
  _PATTERNFLOWIPV4VERSION._serialized_end=107594
  _PATTERNFLOWIPV4VERSION_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4VERSION_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4VERSION_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4VERSION_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4HEADERLENGTHCOUNTER._serialized_start=107596
  _PATTERNFLOWIPV4HEADERLENGTHCOUNTER._serialized_end=107720
  _PATTERNFLOWIPV4HEADERLENGTHMETRICTAG._serialized_start=107722
  _PATTERNFLOWIPV4HEADERLENGTHMETRICTAG._serialized_end=107838
  _PATTERNFLOWIPV4HEADERLENGTH._serialized_start=107841
  _PATTERNFLOWIPV4HEADERLENGTH._serialized_end=108342
  _PATTERNFLOWIPV4HEADERLENGTH_CHOICE._serialized_start=99250
  _PATTERNFLOWIPV4HEADERLENGTH_CHOICE._serialized_end=99346
  _PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWIPV4TOTALLENGTHCOUNTER._serialized_start=108344
  _PATTERNFLOWIPV4TOTALLENGTHCOUNTER._serialized_end=108467
  _PATTERNFLOWIPV4TOTALLENGTHMETRICTAG._serialized_start=108469
  _PATTERNFLOWIPV4TOTALLENGTHMETRICTAG._serialized_end=108584
  _PATTERNFLOWIPV4TOTALLENGTH._serialized_start=108587
  _PATTERNFLOWIPV4TOTALLENGTH._serialized_end=109083
  _PATTERNFLOWIPV4TOTALLENGTH_CHOICE._serialized_start=99250
  _PATTERNFLOWIPV4TOTALLENGTH_CHOICE._serialized_end=99346
  _PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER._serialized_start=109085
  _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER._serialized_end=109211
  _PATTERNFLOWIPV4IDENTIFICATIONMETRICTAG._serialized_start=109213
  _PATTERNFLOWIPV4IDENTIFICATIONMETRICTAG._serialized_end=109331
  _PATTERNFLOWIPV4IDENTIFICATION._serialized_start=109334
  _PATTERNFLOWIPV4IDENTIFICATION._serialized_end=109807
  _PATTERNFLOWIPV4IDENTIFICATION_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4IDENTIFICATION_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4RESERVEDCOUNTER._serialized_start=109809
  _PATTERNFLOWIPV4RESERVEDCOUNTER._serialized_end=109929
  _PATTERNFLOWIPV4RESERVEDMETRICTAG._serialized_start=109931
  _PATTERNFLOWIPV4RESERVEDMETRICTAG._serialized_end=110043
  _PATTERNFLOWIPV4RESERVED._serialized_start=110046
  _PATTERNFLOWIPV4RESERVED._serialized_end=110489
  _PATTERNFLOWIPV4RESERVED_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4RESERVED_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4RESERVED_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4RESERVED_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER._serialized_start=110491
  _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER._serialized_end=110615
  _PATTERNFLOWIPV4DONTFRAGMENTMETRICTAG._serialized_start=110617
  _PATTERNFLOWIPV4DONTFRAGMENTMETRICTAG._serialized_end=110733
  _PATTERNFLOWIPV4DONTFRAGMENT._serialized_start=110736
  _PATTERNFLOWIPV4DONTFRAGMENT._serialized_end=111199
  _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER._serialized_start=111201
  _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER._serialized_end=111326
  _PATTERNFLOWIPV4MOREFRAGMENTSMETRICTAG._serialized_start=111328
  _PATTERNFLOWIPV4MOREFRAGMENTSMETRICTAG._serialized_end=111445
  _PATTERNFLOWIPV4MOREFRAGMENTS._serialized_start=111448
  _PATTERNFLOWIPV4MOREFRAGMENTS._serialized_end=111916
  _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER._serialized_start=111918
  _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER._serialized_end=112044
  _PATTERNFLOWIPV4FRAGMENTOFFSETMETRICTAG._serialized_start=112046
  _PATTERNFLOWIPV4FRAGMENTOFFSETMETRICTAG._serialized_end=112164
  _PATTERNFLOWIPV4FRAGMENTOFFSET._serialized_start=112167
  _PATTERNFLOWIPV4FRAGMENTOFFSET._serialized_end=112640
  _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4TIMETOLIVECOUNTER._serialized_start=112642
  _PATTERNFLOWIPV4TIMETOLIVECOUNTER._serialized_end=112764
  _PATTERNFLOWIPV4TIMETOLIVEMETRICTAG._serialized_start=112766
  _PATTERNFLOWIPV4TIMETOLIVEMETRICTAG._serialized_end=112880
  _PATTERNFLOWIPV4TIMETOLIVE._serialized_start=112883
  _PATTERNFLOWIPV4TIMETOLIVE._serialized_end=113336
  _PATTERNFLOWIPV4TIMETOLIVE_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4TIMETOLIVE_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4PROTOCOLCOUNTER._serialized_start=113338
  _PATTERNFLOWIPV4PROTOCOLCOUNTER._serialized_end=113458
  _PATTERNFLOWIPV4PROTOCOLMETRICTAG._serialized_start=113460
  _PATTERNFLOWIPV4PROTOCOLMETRICTAG._serialized_end=113572
  _PATTERNFLOWIPV4PROTOCOL._serialized_start=113575
  _PATTERNFLOWIPV4PROTOCOL._serialized_end=114056
  _PATTERNFLOWIPV4PROTOCOL_CHOICE._serialized_start=99250
  _PATTERNFLOWIPV4PROTOCOL_CHOICE._serialized_end=99346
  _PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWIPV4HEADERCHECKSUM._serialized_start=114059
  _PATTERNFLOWIPV4HEADERCHECKSUM._serialized_end=114410
  _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE._serialized_start=114257
  _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE._serialized_end=114317
  _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM._serialized_start=114267
  _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM._serialized_end=114317
  _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED._serialized_start=114319
  _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED._serialized_end=114374
  _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM._serialized_start=114332
  _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM._serialized_end=114374
  _PATTERNFLOWIPV4SRCCOUNTER._serialized_start=114412
  _PATTERNFLOWIPV4SRCCOUNTER._serialized_end=114527
  _PATTERNFLOWIPV4SRCMETRICTAG._serialized_start=114529
  _PATTERNFLOWIPV4SRCMETRICTAG._serialized_end=114636
  _PATTERNFLOWIPV4SRC._serialized_start=114639
  _PATTERNFLOWIPV4SRC._serialized_end=115057
  _PATTERNFLOWIPV4SRC_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4SRC_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4SRC_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4SRC_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4DSTCOUNTER._serialized_start=115059
  _PATTERNFLOWIPV4DSTCOUNTER._serialized_end=115174
  _PATTERNFLOWIPV4DSTMETRICTAG._serialized_start=115176
  _PATTERNFLOWIPV4DSTMETRICTAG._serialized_end=115283
  _PATTERNFLOWIPV4DST._serialized_start=115286
  _PATTERNFLOWIPV4DST._serialized_end=115704
  _PATTERNFLOWIPV4DST_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4DST_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4DST_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4DST_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4PRIORITYRAWCOUNTER._serialized_start=115706
  _PATTERNFLOWIPV4PRIORITYRAWCOUNTER._serialized_end=115829
  _PATTERNFLOWIPV4PRIORITYRAWMETRICTAG._serialized_start=115831
  _PATTERNFLOWIPV4PRIORITYRAWMETRICTAG._serialized_end=115946
  _PATTERNFLOWIPV4PRIORITYRAW._serialized_start=115949
  _PATTERNFLOWIPV4PRIORITYRAW._serialized_end=116407
  _PATTERNFLOWIPV4PRIORITYRAW_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4PRIORITYRAW_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4DSCPPHBCOUNTER._serialized_start=116409
  _PATTERNFLOWIPV4DSCPPHBCOUNTER._serialized_end=116528
  _PATTERNFLOWIPV4DSCPPHBMETRICTAG._serialized_start=116530
  _PATTERNFLOWIPV4DSCPPHBMETRICTAG._serialized_end=116641
  _PATTERNFLOWIPV4DSCPPHB._serialized_start=116644
  _PATTERNFLOWIPV4DSCPPHB._serialized_end=117082
  _PATTERNFLOWIPV4DSCPPHB_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4DSCPPHB_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4DSCPECNCOUNTER._serialized_start=117084
  _PATTERNFLOWIPV4DSCPECNCOUNTER._serialized_end=117203
  _PATTERNFLOWIPV4DSCPECNMETRICTAG._serialized_start=117205
  _PATTERNFLOWIPV4DSCPECNMETRICTAG._serialized_end=117316
  _PATTERNFLOWIPV4DSCPECN._serialized_start=117319
  _PATTERNFLOWIPV4DSCPECN._serialized_end=117757
  _PATTERNFLOWIPV4DSCPECN_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4DSCPECN_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER._serialized_start=117759
  _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER._serialized_end=117884
  _PATTERNFLOWIPV4TOSPRECEDENCEMETRICTAG._serialized_start=117886
  _PATTERNFLOWIPV4TOSPRECEDENCEMETRICTAG._serialized_end=118003
  _PATTERNFLOWIPV4TOSPRECEDENCE._serialized_start=118006
  _PATTERNFLOWIPV4TOSPRECEDENCE._serialized_end=118474
  _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4TOSDELAYCOUNTER._serialized_start=118476
  _PATTERNFLOWIPV4TOSDELAYCOUNTER._serialized_end=118596
  _PATTERNFLOWIPV4TOSDELAYMETRICTAG._serialized_start=118598
  _PATTERNFLOWIPV4TOSDELAYMETRICTAG._serialized_end=118710
  _PATTERNFLOWIPV4TOSDELAY._serialized_start=118713
  _PATTERNFLOWIPV4TOSDELAY._serialized_end=119156
  _PATTERNFLOWIPV4TOSDELAY_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4TOSDELAY_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER._serialized_start=119158
  _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER._serialized_end=119283
  _PATTERNFLOWIPV4TOSTHROUGHPUTMETRICTAG._serialized_start=119285
  _PATTERNFLOWIPV4TOSTHROUGHPUTMETRICTAG._serialized_end=119402
  _PATTERNFLOWIPV4TOSTHROUGHPUT._serialized_start=119405
  _PATTERNFLOWIPV4TOSTHROUGHPUT._serialized_end=119873
  _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER._serialized_start=119875
  _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER._serialized_end=120001
  _PATTERNFLOWIPV4TOSRELIABILITYMETRICTAG._serialized_start=120003
  _PATTERNFLOWIPV4TOSRELIABILITYMETRICTAG._serialized_end=120121
  _PATTERNFLOWIPV4TOSRELIABILITY._serialized_start=120124
  _PATTERNFLOWIPV4TOSRELIABILITY._serialized_end=120597
  _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4TOSMONETARYCOUNTER._serialized_start=120599
  _PATTERNFLOWIPV4TOSMONETARYCOUNTER._serialized_end=120722
  _PATTERNFLOWIPV4TOSMONETARYMETRICTAG._serialized_start=120724
  _PATTERNFLOWIPV4TOSMONETARYMETRICTAG._serialized_end=120839
  _PATTERNFLOWIPV4TOSMONETARY._serialized_start=120842
  _PATTERNFLOWIPV4TOSMONETARY._serialized_end=121300
  _PATTERNFLOWIPV4TOSMONETARY_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4TOSMONETARY_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV4TOSUNUSEDCOUNTER._serialized_start=121302
  _PATTERNFLOWIPV4TOSUNUSEDCOUNTER._serialized_end=121423
  _PATTERNFLOWIPV4TOSUNUSEDMETRICTAG._serialized_start=121425
  _PATTERNFLOWIPV4TOSUNUSEDMETRICTAG._serialized_end=121538
  _PATTERNFLOWIPV4TOSUNUSED._serialized_start=121541
  _PATTERNFLOWIPV4TOSUNUSED._serialized_end=121989
  _PATTERNFLOWIPV4TOSUNUSED_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV4TOSUNUSED_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV6VERSIONCOUNTER._serialized_start=121991
  _PATTERNFLOWIPV6VERSIONCOUNTER._serialized_end=122110
  _PATTERNFLOWIPV6VERSIONMETRICTAG._serialized_start=122112
  _PATTERNFLOWIPV6VERSIONMETRICTAG._serialized_end=122223
  _PATTERNFLOWIPV6VERSION._serialized_start=122226
  _PATTERNFLOWIPV6VERSION._serialized_end=122664
  _PATTERNFLOWIPV6VERSION_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV6VERSION_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV6VERSION_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV6VERSION_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER._serialized_start=122666
  _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER._serialized_end=122790
  _PATTERNFLOWIPV6TRAFFICCLASSMETRICTAG._serialized_start=122792
  _PATTERNFLOWIPV6TRAFFICCLASSMETRICTAG._serialized_end=122908
  _PATTERNFLOWIPV6TRAFFICCLASS._serialized_start=122911
  _PATTERNFLOWIPV6TRAFFICCLASS._serialized_end=123374
  _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV6FLOWLABELCOUNTER._serialized_start=123376
  _PATTERNFLOWIPV6FLOWLABELCOUNTER._serialized_end=123497
  _PATTERNFLOWIPV6FLOWLABELMETRICTAG._serialized_start=123499
  _PATTERNFLOWIPV6FLOWLABELMETRICTAG._serialized_end=123612
  _PATTERNFLOWIPV6FLOWLABEL._serialized_start=123615
  _PATTERNFLOWIPV6FLOWLABEL._serialized_end=124063
  _PATTERNFLOWIPV6FLOWLABEL_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV6FLOWLABEL_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER._serialized_start=124065
  _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER._serialized_end=124190
  _PATTERNFLOWIPV6PAYLOADLENGTHMETRICTAG._serialized_start=124192
  _PATTERNFLOWIPV6PAYLOADLENGTHMETRICTAG._serialized_end=124309
  _PATTERNFLOWIPV6PAYLOADLENGTH._serialized_start=124312
  _PATTERNFLOWIPV6PAYLOADLENGTH._serialized_end=124818
  _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE._serialized_start=99250
  _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE._serialized_end=99346
  _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWIPV6NEXTHEADERCOUNTER._serialized_start=124820
  _PATTERNFLOWIPV6NEXTHEADERCOUNTER._serialized_end=124942
  _PATTERNFLOWIPV6NEXTHEADERMETRICTAG._serialized_start=124944
  _PATTERNFLOWIPV6NEXTHEADERMETRICTAG._serialized_end=125058
  _PATTERNFLOWIPV6NEXTHEADER._serialized_start=125061
  _PATTERNFLOWIPV6NEXTHEADER._serialized_end=125552
  _PATTERNFLOWIPV6NEXTHEADER_CHOICE._serialized_start=99250
  _PATTERNFLOWIPV6NEXTHEADER_CHOICE._serialized_end=99346
  _PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWIPV6HOPLIMITCOUNTER._serialized_start=125554
  _PATTERNFLOWIPV6HOPLIMITCOUNTER._serialized_end=125674
  _PATTERNFLOWIPV6HOPLIMITMETRICTAG._serialized_start=125676
  _PATTERNFLOWIPV6HOPLIMITMETRICTAG._serialized_end=125788
  _PATTERNFLOWIPV6HOPLIMIT._serialized_start=125791
  _PATTERNFLOWIPV6HOPLIMIT._serialized_end=126234
  _PATTERNFLOWIPV6HOPLIMIT_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV6HOPLIMIT_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV6SRCCOUNTER._serialized_start=126236
  _PATTERNFLOWIPV6SRCCOUNTER._serialized_end=126351
  _PATTERNFLOWIPV6SRCMETRICTAG._serialized_start=126353
  _PATTERNFLOWIPV6SRCMETRICTAG._serialized_end=126460
  _PATTERNFLOWIPV6SRC._serialized_start=126463
  _PATTERNFLOWIPV6SRC._serialized_end=126881
  _PATTERNFLOWIPV6SRC_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV6SRC_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV6SRC_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV6SRC_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIPV6DSTCOUNTER._serialized_start=126883
  _PATTERNFLOWIPV6DSTCOUNTER._serialized_end=126998
  _PATTERNFLOWIPV6DSTMETRICTAG._serialized_start=127000
  _PATTERNFLOWIPV6DSTMETRICTAG._serialized_end=127107
  _PATTERNFLOWIPV6DST._serialized_start=127110
  _PATTERNFLOWIPV6DST._serialized_end=127528
  _PATTERNFLOWIPV6DST_CHOICE._serialized_start=99944
  _PATTERNFLOWIPV6DST_CHOICE._serialized_end=100030
  _PATTERNFLOWIPV6DST_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIPV6DST_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEDSTCOUNTER._serialized_start=127530
  _PATTERNFLOWPFCPAUSEDSTCOUNTER._serialized_end=127649
  _PATTERNFLOWPFCPAUSEDSTMETRICTAG._serialized_start=127651
  _PATTERNFLOWPFCPAUSEDSTMETRICTAG._serialized_end=127762
  _PATTERNFLOWPFCPAUSEDST._serialized_start=127765
  _PATTERNFLOWPFCPAUSEDST._serialized_end=128203
  _PATTERNFLOWPFCPAUSEDST_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEDST_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSESRCCOUNTER._serialized_start=128205
  _PATTERNFLOWPFCPAUSESRCCOUNTER._serialized_end=128324
  _PATTERNFLOWPFCPAUSESRCMETRICTAG._serialized_start=128326
  _PATTERNFLOWPFCPAUSESRCMETRICTAG._serialized_end=128437
  _PATTERNFLOWPFCPAUSESRC._serialized_start=128440
  _PATTERNFLOWPFCPAUSESRC._serialized_end=128878
  _PATTERNFLOWPFCPAUSESRC_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSESRC_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER._serialized_start=128880
  _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER._serialized_end=129005
  _PATTERNFLOWPFCPAUSEETHERTYPEMETRICTAG._serialized_start=129007
  _PATTERNFLOWPFCPAUSEETHERTYPEMETRICTAG._serialized_end=129124
  _PATTERNFLOWPFCPAUSEETHERTYPE._serialized_start=129127
  _PATTERNFLOWPFCPAUSEETHERTYPE._serialized_end=129595
  _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER._serialized_start=129598
  _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER._serialized_end=129727
  _PATTERNFLOWPFCPAUSECONTROLOPCODEMETRICTAG._serialized_start=129729
  _PATTERNFLOWPFCPAUSECONTROLOPCODEMETRICTAG._serialized_end=129850
  _PATTERNFLOWPFCPAUSECONTROLOPCODE._serialized_start=129853
  _PATTERNFLOWPFCPAUSECONTROLOPCODE._serialized_end=130341
  _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER._serialized_start=130344
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER._serialized_end=130477
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTORMETRICTAG._serialized_start=130479
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTORMETRICTAG._serialized_end=130604
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR._serialized_start=130607
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR._serialized_end=131115
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER._serialized_start=131117
  _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER._serialized_end=131244
  _PATTERNFLOWPFCPAUSEPAUSECLASS0METRICTAG._serialized_start=131246
  _PATTERNFLOWPFCPAUSEPAUSECLASS0METRICTAG._serialized_end=131365
  _PATTERNFLOWPFCPAUSEPAUSECLASS0._serialized_start=131368
  _PATTERNFLOWPFCPAUSEPAUSECLASS0._serialized_end=131846
  _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER._serialized_start=131848
  _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER._serialized_end=131975
  _PATTERNFLOWPFCPAUSEPAUSECLASS1METRICTAG._serialized_start=131977
  _PATTERNFLOWPFCPAUSEPAUSECLASS1METRICTAG._serialized_end=132096
  _PATTERNFLOWPFCPAUSEPAUSECLASS1._serialized_start=132099
  _PATTERNFLOWPFCPAUSEPAUSECLASS1._serialized_end=132577
  _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER._serialized_start=132579
  _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER._serialized_end=132706
  _PATTERNFLOWPFCPAUSEPAUSECLASS2METRICTAG._serialized_start=132708
  _PATTERNFLOWPFCPAUSEPAUSECLASS2METRICTAG._serialized_end=132827
  _PATTERNFLOWPFCPAUSEPAUSECLASS2._serialized_start=132830
  _PATTERNFLOWPFCPAUSEPAUSECLASS2._serialized_end=133308
  _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER._serialized_start=133310
  _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER._serialized_end=133437
  _PATTERNFLOWPFCPAUSEPAUSECLASS3METRICTAG._serialized_start=133439
  _PATTERNFLOWPFCPAUSEPAUSECLASS3METRICTAG._serialized_end=133558
  _PATTERNFLOWPFCPAUSEPAUSECLASS3._serialized_start=133561
  _PATTERNFLOWPFCPAUSEPAUSECLASS3._serialized_end=134039
  _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER._serialized_start=134041
  _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER._serialized_end=134168
  _PATTERNFLOWPFCPAUSEPAUSECLASS4METRICTAG._serialized_start=134170
  _PATTERNFLOWPFCPAUSEPAUSECLASS4METRICTAG._serialized_end=134289
  _PATTERNFLOWPFCPAUSEPAUSECLASS4._serialized_start=134292
  _PATTERNFLOWPFCPAUSEPAUSECLASS4._serialized_end=134770
  _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER._serialized_start=134772
  _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER._serialized_end=134899
  _PATTERNFLOWPFCPAUSEPAUSECLASS5METRICTAG._serialized_start=134901
  _PATTERNFLOWPFCPAUSEPAUSECLASS5METRICTAG._serialized_end=135020
  _PATTERNFLOWPFCPAUSEPAUSECLASS5._serialized_start=135023
  _PATTERNFLOWPFCPAUSEPAUSECLASS5._serialized_end=135501
  _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER._serialized_start=135503
  _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER._serialized_end=135630
  _PATTERNFLOWPFCPAUSEPAUSECLASS6METRICTAG._serialized_start=135632
  _PATTERNFLOWPFCPAUSEPAUSECLASS6METRICTAG._serialized_end=135751
  _PATTERNFLOWPFCPAUSEPAUSECLASS6._serialized_start=135754
  _PATTERNFLOWPFCPAUSEPAUSECLASS6._serialized_end=136232
  _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER._serialized_start=136234
  _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER._serialized_end=136361
  _PATTERNFLOWPFCPAUSEPAUSECLASS7METRICTAG._serialized_start=136363
  _PATTERNFLOWPFCPAUSEPAUSECLASS7METRICTAG._serialized_end=136482
  _PATTERNFLOWPFCPAUSEPAUSECLASS7._serialized_start=136485
  _PATTERNFLOWPFCPAUSEPAUSECLASS7._serialized_end=136963
  _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE._serialized_start=99944
  _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE._serialized_end=100030
  _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSEDSTCOUNTER._serialized_start=136965
  _PATTERNFLOWETHERNETPAUSEDSTCOUNTER._serialized_end=137089
  _PATTERNFLOWETHERNETPAUSEDSTMETRICTAG._serialized_start=137091
  _PATTERNFLOWETHERNETPAUSEDSTMETRICTAG._serialized_end=137207
  _PATTERNFLOWETHERNETPAUSEDST._serialized_start=137210
  _PATTERNFLOWETHERNETPAUSEDST._serialized_end=137673
  _PATTERNFLOWETHERNETPAUSEDST_CHOICE._serialized_start=99944
  _PATTERNFLOWETHERNETPAUSEDST_CHOICE._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSESRCCOUNTER._serialized_start=137675
  _PATTERNFLOWETHERNETPAUSESRCCOUNTER._serialized_end=137799
  _PATTERNFLOWETHERNETPAUSESRCMETRICTAG._serialized_start=137801
  _PATTERNFLOWETHERNETPAUSESRCMETRICTAG._serialized_end=137917
  _PATTERNFLOWETHERNETPAUSESRC._serialized_start=137920
  _PATTERNFLOWETHERNETPAUSESRC._serialized_end=138383
  _PATTERNFLOWETHERNETPAUSESRC_CHOICE._serialized_start=99944
  _PATTERNFLOWETHERNETPAUSESRC_CHOICE._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER._serialized_start=138386
  _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER._serialized_end=138516
  _PATTERNFLOWETHERNETPAUSEETHERTYPEMETRICTAG._serialized_start=138518
  _PATTERNFLOWETHERNETPAUSEETHERTYPEMETRICTAG._serialized_end=138640
  _PATTERNFLOWETHERNETPAUSEETHERTYPE._serialized_start=138643
  _PATTERNFLOWETHERNETPAUSEETHERTYPE._serialized_end=139136
  _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER._serialized_start=139139
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER._serialized_end=139273
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODEMETRICTAG._serialized_start=139275
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODEMETRICTAG._serialized_end=139401
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE._serialized_start=139404
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE._serialized_end=139917
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE._serialized_start=99944
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSETIMECOUNTER._serialized_start=139919
  _PATTERNFLOWETHERNETPAUSETIMECOUNTER._serialized_end=140044
  _PATTERNFLOWETHERNETPAUSETIMEMETRICTAG._serialized_start=140046
  _PATTERNFLOWETHERNETPAUSETIMEMETRICTAG._serialized_end=140163
  _PATTERNFLOWETHERNETPAUSETIME._serialized_start=140166
  _PATTERNFLOWETHERNETPAUSETIME._serialized_end=140634
  _PATTERNFLOWETHERNETPAUSETIME_CHOICE._serialized_start=99944
  _PATTERNFLOWETHERNETPAUSETIME_CHOICE._serialized_end=100030
  _PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPSRCPORTCOUNTER._serialized_start=140636
  _PATTERNFLOWTCPSRCPORTCOUNTER._serialized_end=140754
  _PATTERNFLOWTCPSRCPORTMETRICTAG._serialized_start=140756
  _PATTERNFLOWTCPSRCPORTMETRICTAG._serialized_end=140866
  _PATTERNFLOWTCPSRCPORT._serialized_start=140869
  _PATTERNFLOWTCPSRCPORT._serialized_end=141302
  _PATTERNFLOWTCPSRCPORT_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPSRCPORT_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPSRCPORT_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPSRCPORT_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPDSTPORTCOUNTER._serialized_start=141304
  _PATTERNFLOWTCPDSTPORTCOUNTER._serialized_end=141422
  _PATTERNFLOWTCPDSTPORTMETRICTAG._serialized_start=141424
  _PATTERNFLOWTCPDSTPORTMETRICTAG._serialized_end=141534
  _PATTERNFLOWTCPDSTPORT._serialized_start=141537
  _PATTERNFLOWTCPDSTPORT._serialized_end=141970
  _PATTERNFLOWTCPDSTPORT_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPDSTPORT_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPDSTPORT_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPDSTPORT_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPSEQNUMCOUNTER._serialized_start=141972
  _PATTERNFLOWTCPSEQNUMCOUNTER._serialized_end=142089
  _PATTERNFLOWTCPSEQNUMMETRICTAG._serialized_start=142091
  _PATTERNFLOWTCPSEQNUMMETRICTAG._serialized_end=142200
  _PATTERNFLOWTCPSEQNUM._serialized_start=142203
  _PATTERNFLOWTCPSEQNUM._serialized_end=142631
  _PATTERNFLOWTCPSEQNUM_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPSEQNUM_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPSEQNUM_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPSEQNUM_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPACKNUMCOUNTER._serialized_start=142633
  _PATTERNFLOWTCPACKNUMCOUNTER._serialized_end=142750
  _PATTERNFLOWTCPACKNUMMETRICTAG._serialized_start=142752
  _PATTERNFLOWTCPACKNUMMETRICTAG._serialized_end=142861
  _PATTERNFLOWTCPACKNUM._serialized_start=142864
  _PATTERNFLOWTCPACKNUM._serialized_end=143292
  _PATTERNFLOWTCPACKNUM_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPACKNUM_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPACKNUM_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPACKNUM_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPDATAOFFSETCOUNTER._serialized_start=143294
  _PATTERNFLOWTCPDATAOFFSETCOUNTER._serialized_end=143415
  _PATTERNFLOWTCPDATAOFFSETMETRICTAG._serialized_start=143417
  _PATTERNFLOWTCPDATAOFFSETMETRICTAG._serialized_end=143530
  _PATTERNFLOWTCPDATAOFFSET._serialized_start=143533
  _PATTERNFLOWTCPDATAOFFSET._serialized_end=143981
  _PATTERNFLOWTCPDATAOFFSET_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPDATAOFFSET_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPECNNSCOUNTER._serialized_start=143983
  _PATTERNFLOWTCPECNNSCOUNTER._serialized_end=144099
  _PATTERNFLOWTCPECNNSMETRICTAG._serialized_start=144101
  _PATTERNFLOWTCPECNNSMETRICTAG._serialized_end=144209
  _PATTERNFLOWTCPECNNS._serialized_start=144212
  _PATTERNFLOWTCPECNNS._serialized_end=144635
  _PATTERNFLOWTCPECNNS_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPECNNS_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPECNNS_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPECNNS_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPECNCWRCOUNTER._serialized_start=144637
  _PATTERNFLOWTCPECNCWRCOUNTER._serialized_end=144754
  _PATTERNFLOWTCPECNCWRMETRICTAG._serialized_start=144756
  _PATTERNFLOWTCPECNCWRMETRICTAG._serialized_end=144865
  _PATTERNFLOWTCPECNCWR._serialized_start=144868
  _PATTERNFLOWTCPECNCWR._serialized_end=145296
  _PATTERNFLOWTCPECNCWR_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPECNCWR_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPECNCWR_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPECNCWR_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPECNECHOCOUNTER._serialized_start=145298
  _PATTERNFLOWTCPECNECHOCOUNTER._serialized_end=145416
  _PATTERNFLOWTCPECNECHOMETRICTAG._serialized_start=145418
  _PATTERNFLOWTCPECNECHOMETRICTAG._serialized_end=145528
  _PATTERNFLOWTCPECNECHO._serialized_start=145531
  _PATTERNFLOWTCPECNECHO._serialized_end=145964
  _PATTERNFLOWTCPECNECHO_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPECNECHO_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPECNECHO_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPECNECHO_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPCTLURGCOUNTER._serialized_start=145966
  _PATTERNFLOWTCPCTLURGCOUNTER._serialized_end=146083
  _PATTERNFLOWTCPCTLURGMETRICTAG._serialized_start=146085
  _PATTERNFLOWTCPCTLURGMETRICTAG._serialized_end=146194
  _PATTERNFLOWTCPCTLURG._serialized_start=146197
  _PATTERNFLOWTCPCTLURG._serialized_end=146625
  _PATTERNFLOWTCPCTLURG_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPCTLURG_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPCTLURG_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPCTLURG_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPCTLACKCOUNTER._serialized_start=146627
  _PATTERNFLOWTCPCTLACKCOUNTER._serialized_end=146744
  _PATTERNFLOWTCPCTLACKMETRICTAG._serialized_start=146746
  _PATTERNFLOWTCPCTLACKMETRICTAG._serialized_end=146855
  _PATTERNFLOWTCPCTLACK._serialized_start=146858
  _PATTERNFLOWTCPCTLACK._serialized_end=147286
  _PATTERNFLOWTCPCTLACK_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPCTLACK_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPCTLACK_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPCTLACK_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPCTLPSHCOUNTER._serialized_start=147288
  _PATTERNFLOWTCPCTLPSHCOUNTER._serialized_end=147405
  _PATTERNFLOWTCPCTLPSHMETRICTAG._serialized_start=147407
  _PATTERNFLOWTCPCTLPSHMETRICTAG._serialized_end=147516
  _PATTERNFLOWTCPCTLPSH._serialized_start=147519
  _PATTERNFLOWTCPCTLPSH._serialized_end=147947
  _PATTERNFLOWTCPCTLPSH_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPCTLPSH_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPCTLPSH_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPCTLPSH_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPCTLRSTCOUNTER._serialized_start=147949
  _PATTERNFLOWTCPCTLRSTCOUNTER._serialized_end=148066
  _PATTERNFLOWTCPCTLRSTMETRICTAG._serialized_start=148068
  _PATTERNFLOWTCPCTLRSTMETRICTAG._serialized_end=148177
  _PATTERNFLOWTCPCTLRST._serialized_start=148180
  _PATTERNFLOWTCPCTLRST._serialized_end=148608
  _PATTERNFLOWTCPCTLRST_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPCTLRST_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPCTLRST_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPCTLRST_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPCTLSYNCOUNTER._serialized_start=148610
  _PATTERNFLOWTCPCTLSYNCOUNTER._serialized_end=148727
  _PATTERNFLOWTCPCTLSYNMETRICTAG._serialized_start=148729
  _PATTERNFLOWTCPCTLSYNMETRICTAG._serialized_end=148838
  _PATTERNFLOWTCPCTLSYN._serialized_start=148841
  _PATTERNFLOWTCPCTLSYN._serialized_end=149269
  _PATTERNFLOWTCPCTLSYN_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPCTLSYN_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPCTLSYN_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPCTLSYN_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPCTLFINCOUNTER._serialized_start=149271
  _PATTERNFLOWTCPCTLFINCOUNTER._serialized_end=149388
  _PATTERNFLOWTCPCTLFINMETRICTAG._serialized_start=149390
  _PATTERNFLOWTCPCTLFINMETRICTAG._serialized_end=149499
  _PATTERNFLOWTCPCTLFIN._serialized_start=149502
  _PATTERNFLOWTCPCTLFIN._serialized_end=149930
  _PATTERNFLOWTCPCTLFIN_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPCTLFIN_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPCTLFIN_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPCTLFIN_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWTCPWINDOWCOUNTER._serialized_start=149932
  _PATTERNFLOWTCPWINDOWCOUNTER._serialized_end=150049
  _PATTERNFLOWTCPWINDOWMETRICTAG._serialized_start=150051
  _PATTERNFLOWTCPWINDOWMETRICTAG._serialized_end=150160
  _PATTERNFLOWTCPWINDOW._serialized_start=150163
  _PATTERNFLOWTCPWINDOW._serialized_end=150591
  _PATTERNFLOWTCPWINDOW_CHOICE._serialized_start=99944
  _PATTERNFLOWTCPWINDOW_CHOICE._serialized_end=100030
  _PATTERNFLOWTCPWINDOW_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWTCPWINDOW_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWUDPSRCPORTCOUNTER._serialized_start=150593
  _PATTERNFLOWUDPSRCPORTCOUNTER._serialized_end=150711
  _PATTERNFLOWUDPSRCPORTMETRICTAG._serialized_start=150713
  _PATTERNFLOWUDPSRCPORTMETRICTAG._serialized_end=150823
  _PATTERNFLOWUDPSRCPORT._serialized_start=150826
  _PATTERNFLOWUDPSRCPORT._serialized_end=151259
  _PATTERNFLOWUDPSRCPORT_CHOICE._serialized_start=99944
  _PATTERNFLOWUDPSRCPORT_CHOICE._serialized_end=100030
  _PATTERNFLOWUDPSRCPORT_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWUDPSRCPORT_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWUDPDSTPORTCOUNTER._serialized_start=151261
  _PATTERNFLOWUDPDSTPORTCOUNTER._serialized_end=151379
  _PATTERNFLOWUDPDSTPORTMETRICTAG._serialized_start=151381
  _PATTERNFLOWUDPDSTPORTMETRICTAG._serialized_end=151491
  _PATTERNFLOWUDPDSTPORT._serialized_start=151494
  _PATTERNFLOWUDPDSTPORT._serialized_end=151927
  _PATTERNFLOWUDPDSTPORT_CHOICE._serialized_start=99944
  _PATTERNFLOWUDPDSTPORT_CHOICE._serialized_end=100030
  _PATTERNFLOWUDPDSTPORT_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWUDPDSTPORT_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWUDPLENGTHCOUNTER._serialized_start=151929
  _PATTERNFLOWUDPLENGTHCOUNTER._serialized_end=152046
  _PATTERNFLOWUDPLENGTHMETRICTAG._serialized_start=152048
  _PATTERNFLOWUDPLENGTHMETRICTAG._serialized_end=152157
  _PATTERNFLOWUDPLENGTH._serialized_start=152160
  _PATTERNFLOWUDPLENGTH._serialized_end=152588
  _PATTERNFLOWUDPLENGTH_CHOICE._serialized_start=99944
  _PATTERNFLOWUDPLENGTH_CHOICE._serialized_end=100030
  _PATTERNFLOWUDPLENGTH_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWUDPLENGTH_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWUDPCHECKSUM._serialized_start=152591
  _PATTERNFLOWUDPCHECKSUM._serialized_end=152921
  _PATTERNFLOWUDPCHECKSUM_CHOICE._serialized_start=114257
  _PATTERNFLOWUDPCHECKSUM_CHOICE._serialized_end=114317
  _PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM._serialized_start=114267
  _PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM._serialized_end=114317
  _PATTERNFLOWUDPCHECKSUM_GENERATED._serialized_start=114319
  _PATTERNFLOWUDPCHECKSUM_GENERATED._serialized_end=114374
  _PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM._serialized_start=114332
  _PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM._serialized_end=114374
  _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER._serialized_start=152923
  _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER._serialized_end=153049
  _PATTERNFLOWGRECHECKSUMPRESENTMETRICTAG._serialized_start=153051
  _PATTERNFLOWGRECHECKSUMPRESENTMETRICTAG._serialized_end=153169
  _PATTERNFLOWGRECHECKSUMPRESENT._serialized_start=153172
  _PATTERNFLOWGRECHECKSUMPRESENT._serialized_end=153645
  _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE._serialized_start=99944
  _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE._serialized_end=100030
  _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGRERESERVED0COUNTER._serialized_start=153647
  _PATTERNFLOWGRERESERVED0COUNTER._serialized_end=153767
  _PATTERNFLOWGRERESERVED0METRICTAG._serialized_start=153769
  _PATTERNFLOWGRERESERVED0METRICTAG._serialized_end=153881
  _PATTERNFLOWGRERESERVED0._serialized_start=153884
  _PATTERNFLOWGRERESERVED0._serialized_end=154327
  _PATTERNFLOWGRERESERVED0_CHOICE._serialized_start=99944
  _PATTERNFLOWGRERESERVED0_CHOICE._serialized_end=100030
  _PATTERNFLOWGRERESERVED0_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGRERESERVED0_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGREVERSIONCOUNTER._serialized_start=154329
  _PATTERNFLOWGREVERSIONCOUNTER._serialized_end=154447
  _PATTERNFLOWGREVERSIONMETRICTAG._serialized_start=154449
  _PATTERNFLOWGREVERSIONMETRICTAG._serialized_end=154559
  _PATTERNFLOWGREVERSION._serialized_start=154562
  _PATTERNFLOWGREVERSION._serialized_end=154995
  _PATTERNFLOWGREVERSION_CHOICE._serialized_start=99944
  _PATTERNFLOWGREVERSION_CHOICE._serialized_end=100030
  _PATTERNFLOWGREVERSION_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGREVERSION_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGREPROTOCOLCOUNTER._serialized_start=154997
  _PATTERNFLOWGREPROTOCOLCOUNTER._serialized_end=155116
  _PATTERNFLOWGREPROTOCOLMETRICTAG._serialized_start=155118
  _PATTERNFLOWGREPROTOCOLMETRICTAG._serialized_end=155229
  _PATTERNFLOWGREPROTOCOL._serialized_start=155232
  _PATTERNFLOWGREPROTOCOL._serialized_end=155670
  _PATTERNFLOWGREPROTOCOL_CHOICE._serialized_start=99944
  _PATTERNFLOWGREPROTOCOL_CHOICE._serialized_end=100030
  _PATTERNFLOWGREPROTOCOL_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGREPROTOCOL_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGRECHECKSUM._serialized_start=155673
  _PATTERNFLOWGRECHECKSUM._serialized_end=156003
  _PATTERNFLOWGRECHECKSUM_CHOICE._serialized_start=114257
  _PATTERNFLOWGRECHECKSUM_CHOICE._serialized_end=114317
  _PATTERNFLOWGRECHECKSUM_CHOICE_ENUM._serialized_start=114267
  _PATTERNFLOWGRECHECKSUM_CHOICE_ENUM._serialized_end=114317
  _PATTERNFLOWGRECHECKSUM_GENERATED._serialized_start=114319
  _PATTERNFLOWGRECHECKSUM_GENERATED._serialized_end=114374
  _PATTERNFLOWGRECHECKSUM_GENERATED_ENUM._serialized_start=114332
  _PATTERNFLOWGRECHECKSUM_GENERATED_ENUM._serialized_end=114374
  _PATTERNFLOWGRERESERVED1COUNTER._serialized_start=156005
  _PATTERNFLOWGRERESERVED1COUNTER._serialized_end=156125
  _PATTERNFLOWGRERESERVED1METRICTAG._serialized_start=156127
  _PATTERNFLOWGRERESERVED1METRICTAG._serialized_end=156239
  _PATTERNFLOWGRERESERVED1._serialized_start=156242
  _PATTERNFLOWGRERESERVED1._serialized_end=156685
  _PATTERNFLOWGRERESERVED1_CHOICE._serialized_start=99944
  _PATTERNFLOWGRERESERVED1_CHOICE._serialized_end=100030
  _PATTERNFLOWGRERESERVED1_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGRERESERVED1_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1VERSIONCOUNTER._serialized_start=156687
  _PATTERNFLOWGTPV1VERSIONCOUNTER._serialized_end=156807
  _PATTERNFLOWGTPV1VERSIONMETRICTAG._serialized_start=156809
  _PATTERNFLOWGTPV1VERSIONMETRICTAG._serialized_end=156921
  _PATTERNFLOWGTPV1VERSION._serialized_start=156924
  _PATTERNFLOWGTPV1VERSION._serialized_end=157367
  _PATTERNFLOWGTPV1VERSION_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1VERSION_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1VERSION_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1VERSION_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER._serialized_start=157369
  _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER._serialized_end=157494
  _PATTERNFLOWGTPV1PROTOCOLTYPEMETRICTAG._serialized_start=157496
  _PATTERNFLOWGTPV1PROTOCOLTYPEMETRICTAG._serialized_end=157613
  _PATTERNFLOWGTPV1PROTOCOLTYPE._serialized_start=157616
  _PATTERNFLOWGTPV1PROTOCOLTYPE._serialized_end=158084
  _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1RESERVEDCOUNTER._serialized_start=158086
  _PATTERNFLOWGTPV1RESERVEDCOUNTER._serialized_end=158207
  _PATTERNFLOWGTPV1RESERVEDMETRICTAG._serialized_start=158209
  _PATTERNFLOWGTPV1RESERVEDMETRICTAG._serialized_end=158322
  _PATTERNFLOWGTPV1RESERVED._serialized_start=158325
  _PATTERNFLOWGTPV1RESERVED._serialized_end=158773
  _PATTERNFLOWGTPV1RESERVED_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1RESERVED_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1EFLAGCOUNTER._serialized_start=158775
  _PATTERNFLOWGTPV1EFLAGCOUNTER._serialized_end=158893
  _PATTERNFLOWGTPV1EFLAGMETRICTAG._serialized_start=158895
  _PATTERNFLOWGTPV1EFLAGMETRICTAG._serialized_end=159005
  _PATTERNFLOWGTPV1EFLAG._serialized_start=159008
  _PATTERNFLOWGTPV1EFLAG._serialized_end=159441
  _PATTERNFLOWGTPV1EFLAG_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1EFLAG_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1SFLAGCOUNTER._serialized_start=159443
  _PATTERNFLOWGTPV1SFLAGCOUNTER._serialized_end=159561
  _PATTERNFLOWGTPV1SFLAGMETRICTAG._serialized_start=159563
  _PATTERNFLOWGTPV1SFLAGMETRICTAG._serialized_end=159673
  _PATTERNFLOWGTPV1SFLAG._serialized_start=159676
  _PATTERNFLOWGTPV1SFLAG._serialized_end=160109
  _PATTERNFLOWGTPV1SFLAG_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1SFLAG_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1PNFLAGCOUNTER._serialized_start=160111
  _PATTERNFLOWGTPV1PNFLAGCOUNTER._serialized_end=160230
  _PATTERNFLOWGTPV1PNFLAGMETRICTAG._serialized_start=160232
  _PATTERNFLOWGTPV1PNFLAGMETRICTAG._serialized_end=160343
  _PATTERNFLOWGTPV1PNFLAG._serialized_start=160346
  _PATTERNFLOWGTPV1PNFLAG._serialized_end=160784
  _PATTERNFLOWGTPV1PNFLAG_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1PNFLAG_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1MESSAGETYPECOUNTER._serialized_start=160786
  _PATTERNFLOWGTPV1MESSAGETYPECOUNTER._serialized_end=160910
  _PATTERNFLOWGTPV1MESSAGETYPEMETRICTAG._serialized_start=160912
  _PATTERNFLOWGTPV1MESSAGETYPEMETRICTAG._serialized_end=161028
  _PATTERNFLOWGTPV1MESSAGETYPE._serialized_start=161031
  _PATTERNFLOWGTPV1MESSAGETYPE._serialized_end=161494
  _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER._serialized_start=161496
  _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER._serialized_end=161622
  _PATTERNFLOWGTPV1MESSAGELENGTHMETRICTAG._serialized_start=161624
  _PATTERNFLOWGTPV1MESSAGELENGTHMETRICTAG._serialized_end=161742
  _PATTERNFLOWGTPV1MESSAGELENGTH._serialized_start=161745
  _PATTERNFLOWGTPV1MESSAGELENGTH._serialized_end=162218
  _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1TEIDCOUNTER._serialized_start=162220
  _PATTERNFLOWGTPV1TEIDCOUNTER._serialized_end=162337
  _PATTERNFLOWGTPV1TEIDMETRICTAG._serialized_start=162339
  _PATTERNFLOWGTPV1TEIDMETRICTAG._serialized_end=162448
  _PATTERNFLOWGTPV1TEID._serialized_start=162451
  _PATTERNFLOWGTPV1TEID._serialized_end=162879
  _PATTERNFLOWGTPV1TEID_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1TEID_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1TEID_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1TEID_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER._serialized_start=162881
  _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER._serialized_end=163007
  _PATTERNFLOWGTPV1SQUENCENUMBERMETRICTAG._serialized_start=163009
  _PATTERNFLOWGTPV1SQUENCENUMBERMETRICTAG._serialized_end=163127
  _PATTERNFLOWGTPV1SQUENCENUMBER._serialized_start=163130
  _PATTERNFLOWGTPV1SQUENCENUMBER._serialized_end=163603
  _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER._serialized_start=163605
  _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER._serialized_end=163728
  _PATTERNFLOWGTPV1NPDUNUMBERMETRICTAG._serialized_start=163730
  _PATTERNFLOWGTPV1NPDUNUMBERMETRICTAG._serialized_end=163845
  _PATTERNFLOWGTPV1NPDUNUMBER._serialized_start=163848
  _PATTERNFLOWGTPV1NPDUNUMBER._serialized_end=164306
  _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER._serialized_start=164309
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER._serialized_end=164445
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPEMETRICTAG._serialized_start=164448
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPEMETRICTAG._serialized_end=164576
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE._serialized_start=164579
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE._serialized_end=165102
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER._serialized_start=165105
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER._serialized_end=165240
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHMETRICTAG._serialized_start=165242
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHMETRICTAG._serialized_end=165369
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH._serialized_start=165372
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH._serialized_end=165890
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER._serialized_start=165893
  _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER._serialized_end=166021
  _PATTERNFLOWGTPEXTENSIONCONTENTSMETRICTAG._serialized_start=166023
  _PATTERNFLOWGTPEXTENSIONCONTENTSMETRICTAG._serialized_end=166143
  _PATTERNFLOWGTPEXTENSIONCONTENTS._serialized_start=166146
  _PATTERNFLOWGTPEXTENSIONCONTENTS._serialized_end=166629
  _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER._serialized_start=166632
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER._serialized_end=166771
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERMETRICTAG._serialized_start=166774
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERMETRICTAG._serialized_end=166905
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER._serialized_start=166908
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER._serialized_end=167446
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV2VERSIONCOUNTER._serialized_start=167448
  _PATTERNFLOWGTPV2VERSIONCOUNTER._serialized_end=167568
  _PATTERNFLOWGTPV2VERSIONMETRICTAG._serialized_start=167570
  _PATTERNFLOWGTPV2VERSIONMETRICTAG._serialized_end=167682
  _PATTERNFLOWGTPV2VERSION._serialized_start=167685
  _PATTERNFLOWGTPV2VERSION._serialized_end=168128
  _PATTERNFLOWGTPV2VERSION_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV2VERSION_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV2VERSION_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV2VERSION_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER._serialized_start=168131
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER._serialized_end=168260
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAGMETRICTAG._serialized_start=168262
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAGMETRICTAG._serialized_end=168383
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG._serialized_start=168386
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG._serialized_end=168874
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV2TEIDFLAGCOUNTER._serialized_start=168876
  _PATTERNFLOWGTPV2TEIDFLAGCOUNTER._serialized_end=168997
  _PATTERNFLOWGTPV2TEIDFLAGMETRICTAG._serialized_start=168999
  _PATTERNFLOWGTPV2TEIDFLAGMETRICTAG._serialized_end=169112
  _PATTERNFLOWGTPV2TEIDFLAG._serialized_start=169115
  _PATTERNFLOWGTPV2TEIDFLAG._serialized_end=169563
  _PATTERNFLOWGTPV2TEIDFLAG_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV2TEIDFLAG_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV2SPARE1COUNTER._serialized_start=169565
  _PATTERNFLOWGTPV2SPARE1COUNTER._serialized_end=169684
  _PATTERNFLOWGTPV2SPARE1METRICTAG._serialized_start=169686
  _PATTERNFLOWGTPV2SPARE1METRICTAG._serialized_end=169797
  _PATTERNFLOWGTPV2SPARE1._serialized_start=169800
  _PATTERNFLOWGTPV2SPARE1._serialized_end=170238
  _PATTERNFLOWGTPV2SPARE1_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV2SPARE1_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV2MESSAGETYPECOUNTER._serialized_start=170240
  _PATTERNFLOWGTPV2MESSAGETYPECOUNTER._serialized_end=170364
  _PATTERNFLOWGTPV2MESSAGETYPEMETRICTAG._serialized_start=170366
  _PATTERNFLOWGTPV2MESSAGETYPEMETRICTAG._serialized_end=170482
  _PATTERNFLOWGTPV2MESSAGETYPE._serialized_start=170485
  _PATTERNFLOWGTPV2MESSAGETYPE._serialized_end=170948
  _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER._serialized_start=170950
  _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER._serialized_end=171076
  _PATTERNFLOWGTPV2MESSAGELENGTHMETRICTAG._serialized_start=171078
  _PATTERNFLOWGTPV2MESSAGELENGTHMETRICTAG._serialized_end=171196
  _PATTERNFLOWGTPV2MESSAGELENGTH._serialized_start=171199
  _PATTERNFLOWGTPV2MESSAGELENGTH._serialized_end=171672
  _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV2TEIDCOUNTER._serialized_start=171674
  _PATTERNFLOWGTPV2TEIDCOUNTER._serialized_end=171791
  _PATTERNFLOWGTPV2TEIDMETRICTAG._serialized_start=171793
  _PATTERNFLOWGTPV2TEIDMETRICTAG._serialized_end=171902
  _PATTERNFLOWGTPV2TEID._serialized_start=171905
  _PATTERNFLOWGTPV2TEID._serialized_end=172333
  _PATTERNFLOWGTPV2TEID_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV2TEID_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV2TEID_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV2TEID_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER._serialized_start=172335
  _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER._serialized_end=172462
  _PATTERNFLOWGTPV2SEQUENCENUMBERMETRICTAG._serialized_start=172464
  _PATTERNFLOWGTPV2SEQUENCENUMBERMETRICTAG._serialized_end=172583
  _PATTERNFLOWGTPV2SEQUENCENUMBER._serialized_start=172586
  _PATTERNFLOWGTPV2SEQUENCENUMBER._serialized_end=173064
  _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWGTPV2SPARE2COUNTER._serialized_start=173066
  _PATTERNFLOWGTPV2SPARE2COUNTER._serialized_end=173185
  _PATTERNFLOWGTPV2SPARE2METRICTAG._serialized_start=173187
  _PATTERNFLOWGTPV2SPARE2METRICTAG._serialized_end=173298
  _PATTERNFLOWGTPV2SPARE2._serialized_start=173301
  _PATTERNFLOWGTPV2SPARE2._serialized_end=173739
  _PATTERNFLOWGTPV2SPARE2_CHOICE._serialized_start=99944
  _PATTERNFLOWGTPV2SPARE2_CHOICE._serialized_end=100030
  _PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWARPHARDWARETYPECOUNTER._serialized_start=173741
  _PATTERNFLOWARPHARDWARETYPECOUNTER._serialized_end=173864
  _PATTERNFLOWARPHARDWARETYPEMETRICTAG._serialized_start=173866
  _PATTERNFLOWARPHARDWARETYPEMETRICTAG._serialized_end=173981
  _PATTERNFLOWARPHARDWARETYPE._serialized_start=173984
  _PATTERNFLOWARPHARDWARETYPE._serialized_end=174442
  _PATTERNFLOWARPHARDWARETYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWARPHARDWARETYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWARPPROTOCOLTYPECOUNTER._serialized_start=174444
  _PATTERNFLOWARPPROTOCOLTYPECOUNTER._serialized_end=174567
  _PATTERNFLOWARPPROTOCOLTYPEMETRICTAG._serialized_start=174569
  _PATTERNFLOWARPPROTOCOLTYPEMETRICTAG._serialized_end=174684
  _PATTERNFLOWARPPROTOCOLTYPE._serialized_start=174687
  _PATTERNFLOWARPPROTOCOLTYPE._serialized_end=175145
  _PATTERNFLOWARPPROTOCOLTYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWARPPROTOCOLTYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWARPHARDWARELENGTHCOUNTER._serialized_start=175147
  _PATTERNFLOWARPHARDWARELENGTHCOUNTER._serialized_end=175272
  _PATTERNFLOWARPHARDWARELENGTHMETRICTAG._serialized_start=175274
  _PATTERNFLOWARPHARDWARELENGTHMETRICTAG._serialized_end=175391
  _PATTERNFLOWARPHARDWARELENGTH._serialized_start=175394
  _PATTERNFLOWARPHARDWARELENGTH._serialized_end=175862
  _PATTERNFLOWARPHARDWARELENGTH_CHOICE._serialized_start=99944
  _PATTERNFLOWARPHARDWARELENGTH_CHOICE._serialized_end=100030
  _PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER._serialized_start=175864
  _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER._serialized_end=175989
  _PATTERNFLOWARPPROTOCOLLENGTHMETRICTAG._serialized_start=175991
  _PATTERNFLOWARPPROTOCOLLENGTHMETRICTAG._serialized_end=176108
  _PATTERNFLOWARPPROTOCOLLENGTH._serialized_start=176111
  _PATTERNFLOWARPPROTOCOLLENGTH._serialized_end=176579
  _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE._serialized_start=99944
  _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE._serialized_end=100030
  _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWARPOPERATIONCOUNTER._serialized_start=176581
  _PATTERNFLOWARPOPERATIONCOUNTER._serialized_end=176701
  _PATTERNFLOWARPOPERATIONMETRICTAG._serialized_start=176703
  _PATTERNFLOWARPOPERATIONMETRICTAG._serialized_end=176815
  _PATTERNFLOWARPOPERATION._serialized_start=176818
  _PATTERNFLOWARPOPERATION._serialized_end=177261
  _PATTERNFLOWARPOPERATION_CHOICE._serialized_start=99944
  _PATTERNFLOWARPOPERATION_CHOICE._serialized_end=100030
  _PATTERNFLOWARPOPERATION_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWARPOPERATION_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER._serialized_start=177264
  _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER._serialized_end=177393
  _PATTERNFLOWARPSENDERHARDWAREADDRMETRICTAG._serialized_start=177395
  _PATTERNFLOWARPSENDERHARDWAREADDRMETRICTAG._serialized_end=177516
  _PATTERNFLOWARPSENDERHARDWAREADDR._serialized_start=177519
  _PATTERNFLOWARPSENDERHARDWAREADDR._serialized_end=178007
  _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE._serialized_start=99944
  _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE._serialized_end=100030
  _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER._serialized_start=178010
  _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER._serialized_end=178139
  _PATTERNFLOWARPSENDERPROTOCOLADDRMETRICTAG._serialized_start=178141
  _PATTERNFLOWARPSENDERPROTOCOLADDRMETRICTAG._serialized_end=178262
  _PATTERNFLOWARPSENDERPROTOCOLADDR._serialized_start=178265
  _PATTERNFLOWARPSENDERPROTOCOLADDR._serialized_end=178753
  _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE._serialized_start=99944
  _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE._serialized_end=100030
  _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER._serialized_start=178756
  _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER._serialized_end=178885
  _PATTERNFLOWARPTARGETHARDWAREADDRMETRICTAG._serialized_start=178887
  _PATTERNFLOWARPTARGETHARDWAREADDRMETRICTAG._serialized_end=179008
  _PATTERNFLOWARPTARGETHARDWAREADDR._serialized_start=179011
  _PATTERNFLOWARPTARGETHARDWAREADDR._serialized_end=179499
  _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE._serialized_start=99944
  _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE._serialized_end=100030
  _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER._serialized_start=179502
  _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER._serialized_end=179631
  _PATTERNFLOWARPTARGETPROTOCOLADDRMETRICTAG._serialized_start=179633
  _PATTERNFLOWARPTARGETPROTOCOLADDRMETRICTAG._serialized_end=179754
  _PATTERNFLOWARPTARGETPROTOCOLADDR._serialized_start=179757
  _PATTERNFLOWARPTARGETPROTOCOLADDR._serialized_end=180245
  _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE._serialized_start=99944
  _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE._serialized_end=100030
  _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPECHOTYPECOUNTER._serialized_start=180247
  _PATTERNFLOWICMPECHOTYPECOUNTER._serialized_end=180367
  _PATTERNFLOWICMPECHOTYPEMETRICTAG._serialized_start=180369
  _PATTERNFLOWICMPECHOTYPEMETRICTAG._serialized_end=180481
  _PATTERNFLOWICMPECHOTYPE._serialized_start=180484
  _PATTERNFLOWICMPECHOTYPE._serialized_end=180927
  _PATTERNFLOWICMPECHOTYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPECHOTYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPECHOCODECOUNTER._serialized_start=180929
  _PATTERNFLOWICMPECHOCODECOUNTER._serialized_end=181049
  _PATTERNFLOWICMPECHOCODEMETRICTAG._serialized_start=181051
  _PATTERNFLOWICMPECHOCODEMETRICTAG._serialized_end=181163
  _PATTERNFLOWICMPECHOCODE._serialized_start=181166
  _PATTERNFLOWICMPECHOCODE._serialized_end=181609
  _PATTERNFLOWICMPECHOCODE_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPECHOCODE_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPECHOCODE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPECHOCODE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPECHOCHECKSUM._serialized_start=181612
  _PATTERNFLOWICMPECHOCHECKSUM._serialized_end=181957
  _PATTERNFLOWICMPECHOCHECKSUM_CHOICE._serialized_start=114257
  _PATTERNFLOWICMPECHOCHECKSUM_CHOICE._serialized_end=114317
  _PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM._serialized_start=114267
  _PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM._serialized_end=114317
  _PATTERNFLOWICMPECHOCHECKSUM_GENERATED._serialized_start=114319
  _PATTERNFLOWICMPECHOCHECKSUM_GENERATED._serialized_end=114374
  _PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM._serialized_start=114332
  _PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM._serialized_end=114374
  _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER._serialized_start=181959
  _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER._serialized_end=182085
  _PATTERNFLOWICMPECHOIDENTIFIERMETRICTAG._serialized_start=182087
  _PATTERNFLOWICMPECHOIDENTIFIERMETRICTAG._serialized_end=182205
  _PATTERNFLOWICMPECHOIDENTIFIER._serialized_start=182208
  _PATTERNFLOWICMPECHOIDENTIFIER._serialized_end=182681
  _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER._serialized_start=182684
  _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER._serialized_end=182814
  _PATTERNFLOWICMPECHOSEQUENCENUMBERMETRICTAG._serialized_start=182816
  _PATTERNFLOWICMPECHOSEQUENCENUMBERMETRICTAG._serialized_end=182938
  _PATTERNFLOWICMPECHOSEQUENCENUMBER._serialized_start=182941
  _PATTERNFLOWICMPECHOSEQUENCENUMBER._serialized_end=183434
  _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPCOMMONCHECKSUM._serialized_start=183437
  _PATTERNFLOWICMPCOMMONCHECKSUM._serialized_end=183788
  _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE._serialized_start=114257
  _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE._serialized_end=114317
  _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM._serialized_start=114267
  _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM._serialized_end=114317
  _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED._serialized_start=114319
  _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED._serialized_end=114374
  _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM._serialized_start=114332
  _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM._serialized_end=114374
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER._serialized_start=183791
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER._serialized_end=183923
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERMETRICTAG._serialized_start=183925
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERMETRICTAG._serialized_end=184049
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER._serialized_start=184052
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER._serialized_end=184555
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER._serialized_start=184558
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER._serialized_end=184694
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERMETRICTAG._serialized_start=184697
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERMETRICTAG._serialized_end=184825
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER._serialized_start=184828
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER._serialized_end=185351
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPV6ECHOTYPECOUNTER._serialized_start=185353
  _PATTERNFLOWICMPV6ECHOTYPECOUNTER._serialized_end=185475
  _PATTERNFLOWICMPV6ECHOTYPEMETRICTAG._serialized_start=185477
  _PATTERNFLOWICMPV6ECHOTYPEMETRICTAG._serialized_end=185591
  _PATTERNFLOWICMPV6ECHOTYPE._serialized_start=185594
  _PATTERNFLOWICMPV6ECHOTYPE._serialized_end=186047
  _PATTERNFLOWICMPV6ECHOTYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPV6ECHOTYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPV6ECHOCODECOUNTER._serialized_start=186049
  _PATTERNFLOWICMPV6ECHOCODECOUNTER._serialized_end=186171
  _PATTERNFLOWICMPV6ECHOCODEMETRICTAG._serialized_start=186173
  _PATTERNFLOWICMPV6ECHOCODEMETRICTAG._serialized_end=186287
  _PATTERNFLOWICMPV6ECHOCODE._serialized_start=186290
  _PATTERNFLOWICMPV6ECHOCODE._serialized_end=186743
  _PATTERNFLOWICMPV6ECHOCODE_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPV6ECHOCODE_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER._serialized_start=186746
  _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER._serialized_end=186874
  _PATTERNFLOWICMPV6ECHOIDENTIFIERMETRICTAG._serialized_start=186876
  _PATTERNFLOWICMPV6ECHOIDENTIFIERMETRICTAG._serialized_end=186996
  _PATTERNFLOWICMPV6ECHOIDENTIFIER._serialized_start=186999
  _PATTERNFLOWICMPV6ECHOIDENTIFIER._serialized_end=187482
  _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER._serialized_start=187485
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER._serialized_end=187617
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERMETRICTAG._serialized_start=187619
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERMETRICTAG._serialized_end=187743
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER._serialized_start=187746
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER._serialized_end=188249
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE._serialized_start=99944
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE._serialized_end=100030
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWICMPV6ECHOCHECKSUM._serialized_start=188252
  _PATTERNFLOWICMPV6ECHOCHECKSUM._serialized_end=188603
  _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE._serialized_start=114257
  _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE._serialized_end=114317
  _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM._serialized_start=114267
  _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM._serialized_end=114317
  _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED._serialized_start=114319
  _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED._serialized_end=114374
  _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM._serialized_start=114332
  _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM._serialized_end=114374
  _PATTERNFLOWICMPV6COMMONCHECKSUM._serialized_start=188606
  _PATTERNFLOWICMPV6COMMONCHECKSUM._serialized_end=188963
  _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE._serialized_start=114257
  _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE._serialized_end=114317
  _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM._serialized_start=114267
  _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM._serialized_end=114317
  _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED._serialized_start=114319
  _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED._serialized_end=114374
  _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM._serialized_start=114332
  _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM._serialized_end=114374
  _PATTERNFLOWPPPADDRESSCOUNTER._serialized_start=188965
  _PATTERNFLOWPPPADDRESSCOUNTER._serialized_end=189083
  _PATTERNFLOWPPPADDRESSMETRICTAG._serialized_start=189085
  _PATTERNFLOWPPPADDRESSMETRICTAG._serialized_end=189195
  _PATTERNFLOWPPPADDRESS._serialized_start=189198
  _PATTERNFLOWPPPADDRESS._serialized_end=189631
  _PATTERNFLOWPPPADDRESS_CHOICE._serialized_start=99944
  _PATTERNFLOWPPPADDRESS_CHOICE._serialized_end=100030
  _PATTERNFLOWPPPADDRESS_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPPPADDRESS_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPPPCONTROLCOUNTER._serialized_start=189633
  _PATTERNFLOWPPPCONTROLCOUNTER._serialized_end=189751
  _PATTERNFLOWPPPCONTROLMETRICTAG._serialized_start=189753
  _PATTERNFLOWPPPCONTROLMETRICTAG._serialized_end=189863
  _PATTERNFLOWPPPCONTROL._serialized_start=189866
  _PATTERNFLOWPPPCONTROL._serialized_end=190299
  _PATTERNFLOWPPPCONTROL_CHOICE._serialized_start=99944
  _PATTERNFLOWPPPCONTROL_CHOICE._serialized_end=100030
  _PATTERNFLOWPPPCONTROL_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWPPPCONTROL_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWPPPPROTOCOLTYPECOUNTER._serialized_start=190301
  _PATTERNFLOWPPPPROTOCOLTYPECOUNTER._serialized_end=190424
  _PATTERNFLOWPPPPROTOCOLTYPEMETRICTAG._serialized_start=190426
  _PATTERNFLOWPPPPROTOCOLTYPEMETRICTAG._serialized_end=190541
  _PATTERNFLOWPPPPROTOCOLTYPE._serialized_start=190544
  _PATTERNFLOWPPPPROTOCOLTYPE._serialized_end=191040
  _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE._serialized_start=99250
  _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE._serialized_end=99346
  _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWIGMPV1VERSIONCOUNTER._serialized_start=191042
  _PATTERNFLOWIGMPV1VERSIONCOUNTER._serialized_end=191163
  _PATTERNFLOWIGMPV1VERSIONMETRICTAG._serialized_start=191165
  _PATTERNFLOWIGMPV1VERSIONMETRICTAG._serialized_end=191278
  _PATTERNFLOWIGMPV1VERSION._serialized_start=191281
  _PATTERNFLOWIGMPV1VERSION._serialized_end=191729
  _PATTERNFLOWIGMPV1VERSION_CHOICE._serialized_start=99944
  _PATTERNFLOWIGMPV1VERSION_CHOICE._serialized_end=100030
  _PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIGMPV1TYPECOUNTER._serialized_start=191731
  _PATTERNFLOWIGMPV1TYPECOUNTER._serialized_end=191849
  _PATTERNFLOWIGMPV1TYPEMETRICTAG._serialized_start=191851
  _PATTERNFLOWIGMPV1TYPEMETRICTAG._serialized_end=191961
  _PATTERNFLOWIGMPV1TYPE._serialized_start=191964
  _PATTERNFLOWIGMPV1TYPE._serialized_end=192397
  _PATTERNFLOWIGMPV1TYPE_CHOICE._serialized_start=99944
  _PATTERNFLOWIGMPV1TYPE_CHOICE._serialized_end=100030
  _PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIGMPV1UNUSEDCOUNTER._serialized_start=192399
  _PATTERNFLOWIGMPV1UNUSEDCOUNTER._serialized_end=192519
  _PATTERNFLOWIGMPV1UNUSEDMETRICTAG._serialized_start=192521
  _PATTERNFLOWIGMPV1UNUSEDMETRICTAG._serialized_end=192633
  _PATTERNFLOWIGMPV1UNUSED._serialized_start=192636
  _PATTERNFLOWIGMPV1UNUSED._serialized_end=193079
  _PATTERNFLOWIGMPV1UNUSED_CHOICE._serialized_start=99944
  _PATTERNFLOWIGMPV1UNUSED_CHOICE._serialized_end=100030
  _PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWIGMPV1CHECKSUM._serialized_start=193082
  _PATTERNFLOWIGMPV1CHECKSUM._serialized_end=193421
  _PATTERNFLOWIGMPV1CHECKSUM_CHOICE._serialized_start=114257
  _PATTERNFLOWIGMPV1CHECKSUM_CHOICE._serialized_end=114317
  _PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM._serialized_start=114267
  _PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM._serialized_end=114317
  _PATTERNFLOWIGMPV1CHECKSUM_GENERATED._serialized_start=114319
  _PATTERNFLOWIGMPV1CHECKSUM_GENERATED._serialized_end=114374
  _PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM._serialized_start=114332
  _PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM._serialized_end=114374
  _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER._serialized_start=193423
  _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER._serialized_end=193549
  _PATTERNFLOWIGMPV1GROUPADDRESSMETRICTAG._serialized_start=193551
  _PATTERNFLOWIGMPV1GROUPADDRESSMETRICTAG._serialized_end=193669
  _PATTERNFLOWIGMPV1GROUPADDRESS._serialized_start=193672
  _PATTERNFLOWIGMPV1GROUPADDRESS._serialized_end=194145
  _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE._serialized_start=99944
  _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE._serialized_end=100030
  _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWMPLSLABELCOUNTER._serialized_start=194147
  _PATTERNFLOWMPLSLABELCOUNTER._serialized_end=194264
  _PATTERNFLOWMPLSLABELMETRICTAG._serialized_start=194266
  _PATTERNFLOWMPLSLABELMETRICTAG._serialized_end=194375
  _PATTERNFLOWMPLSLABEL._serialized_start=194378
  _PATTERNFLOWMPLSLABEL._serialized_end=194844
  _PATTERNFLOWMPLSLABEL_CHOICE._serialized_start=99250
  _PATTERNFLOWMPLSLABEL_CHOICE._serialized_end=99346
  _PATTERNFLOWMPLSLABEL_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWMPLSLABEL_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWMPLSTRAFFICCLASSCOUNTER._serialized_start=194846
  _PATTERNFLOWMPLSTRAFFICCLASSCOUNTER._serialized_end=194970
  _PATTERNFLOWMPLSTRAFFICCLASSMETRICTAG._serialized_start=194972
  _PATTERNFLOWMPLSTRAFFICCLASSMETRICTAG._serialized_end=195088
  _PATTERNFLOWMPLSTRAFFICCLASS._serialized_start=195091
  _PATTERNFLOWMPLSTRAFFICCLASS._serialized_end=195554
  _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE._serialized_start=99944
  _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE._serialized_end=100030
  _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM._serialized_end=100030
  _PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER._serialized_start=195556
  _PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER._serialized_end=195681
  _PATTERNFLOWMPLSBOTTOMOFSTACKMETRICTAG._serialized_start=195683
  _PATTERNFLOWMPLSBOTTOMOFSTACKMETRICTAG._serialized_end=195800
  _PATTERNFLOWMPLSBOTTOMOFSTACK._serialized_start=195803
  _PATTERNFLOWMPLSBOTTOMOFSTACK._serialized_end=196309
  _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE._serialized_start=99250
  _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE._serialized_end=99346
  _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM._serialized_start=99260
  _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM._serialized_end=99346
  _PATTERNFLOWMPLSTIMETOLIVECOUNTER._serialized_start=196311
  _PATTERNFLOWMPLSTIMETOLIVECOUNTER._serialized_end=196433
  _PATTERNFLOWMPLSTIMETOLIVEMETRICTAG._serialized_start=196435
  _PATTERNFLOWMPLSTIMETOLIVEMETRICTAG._serialized_end=196549
  _PATTERNFLOWMPLSTIMETOLIVE._serialized_start=196552
  _PATTERNFLOWMPLSTIMETOLIVE._serialized_end=197005
  _PATTERNFLOWMPLSTIMETOLIVE_CHOICE._serialized_start=99944
  _PATTERNFLOWMPLSTIMETOLIVE_CHOICE._serialized_end=100030
  _PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM._serialized_start=99954
  _PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM._serialized_end=100030
  _VERSION._serialized_start=197008
  _VERSION._serialized_end=197153
  _SUCCESS._serialized_start=197155
  _SUCCESS._serialized_end=197195
  _FAILURE._serialized_start=197197
  _FAILURE._serialized_end=197233
  _SETCONFIGREQUEST._serialized_start=197235
  _SETCONFIGREQUEST._serialized_end=197282
  _UPDATECONFIGREQUEST._serialized_start=197284
  _UPDATECONFIGREQUEST._serialized_end=197347
  _SETCONFIGRESPONSE._serialized_start=197349
  _SETCONFIGRESPONSE._serialized_end=197399
  _GETCONFIGRESPONSE._serialized_start=197401
  _GETCONFIGRESPONSE._serialized_end=197449
  _UPDATECONFIGRESPONSE._serialized_start=197451
  _UPDATECONFIGRESPONSE._serialized_end=197504
  _SETCONTROLSTATEREQUEST._serialized_start=197506
  _SETCONTROLSTATEREQUEST._serialized_end=197572
  _SETCONTROLSTATERESPONSE._serialized_start=197574
  _SETCONTROLSTATERESPONSE._serialized_end=197630
  _SETCONTROLACTIONREQUEST._serialized_start=197632
  _SETCONTROLACTIONREQUEST._serialized_end=197701
  _SETCONTROLACTIONRESPONSE._serialized_start=197703
  _SETCONTROLACTIONRESPONSE._serialized_end=197790
  _SETTRANSMITSTATEREQUEST._serialized_start=197792
  _SETTRANSMITSTATEREQUEST._serialized_end=197861
  _SETTRANSMITSTATERESPONSE._serialized_start=197863
  _SETTRANSMITSTATERESPONSE._serialized_end=197920
  _SETLINKSTATEREQUEST._serialized_start=197922
  _SETLINKSTATEREQUEST._serialized_end=197979
  _SETLINKSTATERESPONSE._serialized_start=197981
  _SETLINKSTATERESPONSE._serialized_end=198034
  _SETCAPTURESTATEREQUEST._serialized_start=198036
  _SETCAPTURESTATEREQUEST._serialized_end=198102
  _SETCAPTURESTATERESPONSE._serialized_start=198104
  _SETCAPTURESTATERESPONSE._serialized_end=198160
  _UPDATEFLOWSREQUEST._serialized_start=198162
  _UPDATEFLOWSREQUEST._serialized_end=198222
  _UPDATEFLOWSRESPONSE._serialized_start=198224
  _UPDATEFLOWSRESPONSE._serialized_end=198274
  _SETROUTESTATEREQUEST._serialized_start=198276
  _SETROUTESTATEREQUEST._serialized_end=198336
  _SETROUTESTATERESPONSE._serialized_start=198338
  _SETROUTESTATERESPONSE._serialized_end=198392
  _SENDPINGREQUEST._serialized_start=198394
  _SENDPINGREQUEST._serialized_end=198451
  _SENDPINGRESPONSE._serialized_start=198453
  _SENDPINGRESPONSE._serialized_end=198513
  _SETPROTOCOLSTATEREQUEST._serialized_start=198515
  _SETPROTOCOLSTATEREQUEST._serialized_end=198584
  _SETPROTOCOLSTATERESPONSE._serialized_start=198586
  _SETPROTOCOLSTATERESPONSE._serialized_end=198643
  _SETDEVICESTATEREQUEST._serialized_start=198645
  _SETDEVICESTATEREQUEST._serialized_end=198708
  _SETDEVICESTATERESPONSE._serialized_start=198710
  _SETDEVICESTATERESPONSE._serialized_end=198765
  _GETMETRICSREQUEST._serialized_start=198767
  _GETMETRICSREQUEST._serialized_end=198832
  _GETMETRICSRESPONSE._serialized_start=198834
  _GETMETRICSRESPONSE._serialized_end=198902
  _GETSTATESREQUEST._serialized_start=198904
  _GETSTATESREQUEST._serialized_end=198966
  _GETSTATESRESPONSE._serialized_start=198968
  _GETSTATESRESPONSE._serialized_end=199033
  _GETCAPTUREREQUEST._serialized_start=199035
  _GETCAPTUREREQUEST._serialized_end=199100
  _GETCAPTURERESPONSE._serialized_start=199102
  _GETCAPTURERESPONSE._serialized_end=199146
  _GETVERSIONRESPONSE._serialized_start=199148
  _GETVERSIONRESPONSE._serialized_end=199199
  _OPENAPI._serialized_start=199202
  _OPENAPI._serialized_end=200388
# @@protoc_insertion_point(module_scope)
